# -*- coding: utf-8 -

page_meta = [
    {
        'url': 'reviews:list',
        'title': 'Відгуки',
        'title_uk': 'Відгуки',
        'title_ru': 'Отзывы',
        'title_en': 'Reviews',
        'keywords': 'Відгуки',
        'keywords_uk': 'Відгуки',
        'keywords_ru': 'Отзывы',
        'keywords_en': 'Reviews',
        'description': 'Відгуки на сайті',
        'description_uk': 'Відгуки на сайті',
        'description_ru': 'Отзывы на сайте',
        'description_en': 'Reviews on site',
        'breadcrumb': 'Відгуки',
        'breadcrumb_uk': 'Відгуки',
        'breadcrumb_ru': 'Отзывы',
        'breadcrumb_en': 'Reviews',
        'header': 'Відгуки',
        'header_uk': 'Відгуки',
        'header_ru': 'Отзывы',
        'header_en': 'Reviews'
    }
]
