
{% extends 'error.html' %}

{% load i18n %}


{% block title %}
    404 - {% trans 'Page not found' %}
{% endblock %}


{% block code %}
    404
{% endblock %}


{% block message %}
    {% trans 'Page not found' %}
{% endblock %}

