
{% extends 'error.html' %}

{% load i18n %}


{% block title %}
    500 - {% trans 'Server error. Please contact administrator.' %}
{% endblock %}


{% block code %}
    500
{% endblock %}


{% block message %}
    {% trans 'Server error. Please contact administrator.' %}
{% endblock %}
