
{% load i18n %}


<h1>{% trans 'New review' %} #{{ object.id }}</h1> <br />

<strong>{% trans 'Name' %}:</strong> <br />
{{ object.name }} <br /><br />

<strong>{% trans 'Rating' %}:</strong> <br />
{{ object.rating }} <br /><br />

<strong>{% trans 'Text' %}:</strong> <br />
{{ object.text }} <br /><br />

<a href="http://{{ site.domain }}{% url 'admin:reviews_review_change' object.id %}">
    {% trans 'Show on site' %}
</a>
