{% for template, tab_position, tab in adminform.model_admin.cap_form_includes %}
    {% if position == tab_position or position == 'bottom' and not tab_position %}
        <div class="cap-include{% if tab %} cap-tab cap-tab-{{ tab }}{% endif %}">{% include template %}</div>
    {% endif %}
{% endfor %}
