# Generated by Django 3.0.7 on 2020-06-06 22:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0005_auto_20190427_1001'),
    ]

    operations = [
        migrations.AddField(
            model_name='pagemeta',
            name='og_image',
            field=models.CharField(blank=True, max_length=500, verbose_name='og:image'),
        ),
    ]
