
<meta http-equiv="Content-Language" content="{{ LANGUAGE_CODE }}" />

{% for lang in LANGUAGES %}
    <link rel="alternate"
          hreflang="{{ lang.0 }}"
          href="http://{{ request.META.HTTP_HOST }}/{{ lang.0 }}{{ request.path|slice:"3:" }}" />
{% endfor %}
