{% load i18n %}

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="robots" content="noindex, nofollow" />
    <title>{% block title %}{% endblock %}</title>
    <style>
        * {
            font-family: sans-serif;
        }
        h1 {
            font-size: 110px;
            text-align: center;
            font-family: sans-serif;
            color: #545151;
            margin: 50px 0 0 0;
        }
        p {
            text-align: center;
            font-size: 25px;
        }
        a {
            font-size: 25px;
            border: 2px solid #113344;
            padding: 20px;
            margin: 0 auto;
            display: block;
            width: 320px;
            text-align: center;
            text-decoration: none;
            background: #2a7eb1;
            text-transform: uppercase;
            border-radius: 3px;
            color: #fff;
        }
    </style>
</head>
<body>
    <h1>{% block code %}{% endblock %}</h1>

    <p>{% block message %}{% endblock %}</p>

    <a href="{% url 'home' %}">
        {% trans 'Go to home page' %}
    </a>
</body>
</html>