@charset "UTF-8";
/*! Bootstrap v4.0.0-alpha.5 (https://getbootstrap.com) Copyright 2011-2016 The Bootstrap Authors Copyright 2011-2016 Twitter, Inc. Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE) */
/*! normalize.css v4.2.0 | MIT License | github.com/necolas/normalize.css */
html {
    font-family: sans-serif;
    line-height: 1.15;
    -ms-text-size-adjust: 100%;
    -webkit-text-size-adjust: 100%;
}

body {
    margin: 0;
}

article, aside, details, figcaption, figure, footer, header, main, menu, nav, section, summary {
    display: block;
}

audio, canvas, progress, video {
    display: inline-block;
}

audio:not([controls]) {
    display: none;
    height: 0;
}

progress {
    vertical-align: baseline;
}

template, [hidden] {
    display: none;
}

a {
    background-color: transparent;
    -webkit-text-decoration-skip: objects;
}

a:active, a:hover {
    outline-width: 0;
}

abbr[title] {
    border-bottom: none;
    text-decoration: underline;
    text-decoration: underline dotted;
}

b, strong {
    font-weight: inherit;
}

b, strong {
    font-weight: bolder;
}

dfn {
    font-style: italic;
}

h1 {
    font-size: 2em;
    margin: 0.67em 0;
}

mark {
    background-color: #ff0;
    color: #000;
}

small, .timezonewarning {
    font-size: 80%;
}

sub, sup {
    font-size: 75%;
    line-height: 0;
    position: relative;
    vertical-align: baseline;
}

sub {
    bottom: -0.25em;
}

sup {
    top: -0.5em;
}

img {
    border-style: none;
}

svg:not(:root) {
    overflow: hidden;
}

code, kbd, pre, samp {
    font-family: monospace, monospace;
    font-size: 1em;
}

figure {
    margin: 1em 40px;
}

hr {
    box-sizing: content-box;
    height: 0;
    overflow: visible;
}

button, input, optgroup, select, textarea {
    font: inherit;
    margin: 0;
}

optgroup {
    font-weight: bold;
}

button, input {
    overflow: visible;
}

button, select {
    text-transform: none;
}

button, html [type="button"], [type="reset"], [type="submit"] {
    -webkit-appearance: button;
}

button::-moz-focus-inner, [type="button"]::-moz-focus-inner, [type="reset"]::-moz-focus-inner, [type="submit"]::-moz-focus-inner {
    border-style: none;
    padding: 0;
}

button:-moz-focusring, [type="button"]:-moz-focusring, [type="reset"]:-moz-focusring, [type="submit"]:-moz-focusring {
    outline: 1px dotted ButtonText;
}

fieldset {
    border: 1px solid #c0c0c0;
    margin: 0 2px;
    padding: 0.35em 0.625em 0.75em;
}

legend {
    box-sizing: border-box;
    color: inherit;
    display: table;
    max-width: 100%;
    padding: 0;
    white-space: normal;
}

textarea {
    overflow: auto;
}

[type="checkbox"], [type="radio"] {
    box-sizing: border-box;
    padding: 0;
}

[type="number"]::-webkit-inner-spin-button, [type="number"]::-webkit-outer-spin-button {
    height: auto;
}

[type="search"] {
    -webkit-appearance: textfield;
    outline-offset: -2px;
}

[type="search"]::-webkit-search-cancel-button, [type="search"]::-webkit-search-decoration {
    -webkit-appearance: none;
}

::-webkit-input-placeholder {
    color: inherit;
    opacity: 0.54;
}

::-webkit-file-upload-button {
    -webkit-appearance: button;
    font: inherit;
}

@media print {
    *, *::before, *::after, *::first-letter, p::first-line, div::first-line, blockquote::first-line, li::first-line {
        text-shadow: none !important;
        box-shadow: none !important;
    }

    a, a:visited {
        text-decoration: underline;
    }

    abbr[title]::after {
        content: " (" attr(title) ")";
    }

    pre {
        white-space: pre-wrap !important;
    }

    pre, blockquote {
        border: 1px solid #999;
        page-break-inside: avoid;
    }

    thead {
        display: table-header-group;
    }

    tr, img {
        page-break-inside: avoid;
    }

    p, h2, h3 {
        orphans: 3;
        widows: 3;
    }

    h2, h3 {
        page-break-after: avoid;
    }

    .navbar {
        display: none;
    }

    .btn > .caret, body.delete-confirmation .content-wrap input[type='button'] > .caret, body.delete-confirmation .content-wrap input[type='submit'] > .caret, body.delete-confirmation .content-wrap button > .caret, .submit-row .deletelink-box .deletelink > .caret, .submit-row input[type='submit']:not([class*="btn-"]) > .caret, .submit-row input[type='button']:not([class*="btn-"]) > .caret, .submit-row button:not([class*="btn-"]) > .caret, #content-main > .object-tools > li > a:not([class*="btn-"]) > .caret, body.login .submit-row input[type='submit'] > .caret, #changelist #toolbar #changelist-search input[type='submit'] > .caret, #changelist #changelist-form .actions button > .caret, #changelist #changelist-form .paginator input[type='submit'] > .caret, .dropup > .btn > .caret, body.delete-confirmation .content-wrap .dropup > input[type='button'] > .caret, body.delete-confirmation .content-wrap .dropup > input[type='submit'] > .caret, body.delete-confirmation .content-wrap .dropup > button > .caret, .submit-row .deletelink-box .dropup > .deletelink > .caret, .submit-row .dropup > input[type='submit']:not([class*="btn-"]) > .caret, .submit-row .dropup > input[type='button']:not([class*="btn-"]) > .caret, .submit-row .dropup > button:not([class*="btn-"]) > .caret, #content-main > .object-tools > li.dropup > a:not([class*="btn-"]) > .caret, body.login .submit-row .dropup > input[type='submit'] > .caret, #changelist #toolbar #changelist-search .dropup > input[type='submit'] > .caret, #changelist #changelist-form .actions .dropup > button > .caret, #changelist #changelist-form .paginator .dropup > input[type='submit'] > .caret {
        border-top-color: #000 !important;
    }

    .tag {
        border: 1px solid #000;
    }

    .table, .tabular table, table#change-history {
        border-collapse: collapse !important;
    }

    .table td, .tabular table td, table#change-history td, .table th, .tabular table th, table#change-history th {
        background-color: #fff !important;
    }

    .table-bordered th, .table-bordered td {
        border: 1px solid #ddd !important;
    }
}

html {
    box-sizing: border-box;
}

*, *::before, *::after {
    box-sizing: inherit;
}

@-ms-viewport {
    width: device-width;
}

html {
    font-size: 14px;
    -ms-overflow-style: scrollbar;
    -webkit-tap-highlight-color: transparent;
}

body {
    font-family: "Roboto", "Helvetica Neue", Helvetica, Arial, sans-serif;
    font-size: 1rem;
    line-height: 1.5;
    color: #373a3c;
    background-color: #f1f1f1;
}

[tabindex="-1"]:focus {
    outline: none !important;
}

h1, h2, h3, h4, h5, h6 {
    margin-top: 0;
    margin-bottom: .5rem;
}

p {
    margin-top: 0;
    margin-bottom: 1rem;
}

abbr[title], abbr[data-original-title] {
    cursor: help;
    border-bottom: 1px dotted #818a91;
}

address {
    margin-bottom: 1rem;
    font-style: normal;
    line-height: inherit;
}

ol, ul, dl {
    margin-top: 0;
    margin-bottom: 1rem;
}

ol ol, ul ul, ol ul, ul ol {
    margin-bottom: 0;
}

dt {
    font-weight: bold;
}

dd {
    margin-bottom: .5rem;
    margin-left: 0;
}

blockquote {
    margin: 0 0 1rem;
}

a {
    color: #0d64a2;
    text-decoration: none;
}

a:focus, a:hover {
    color: #07385b;
    text-decoration: underline;
}

a:focus {
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
}

a:not([href]):not([tabindex]) {
    color: inherit;
    text-decoration: none;
}

a:not([href]):not([tabindex]):focus, a:not([href]):not([tabindex]):hover {
    color: inherit;
    text-decoration: none;
}

a:not([href]):not([tabindex]):focus {
    outline: none;
}

pre {
    margin-top: 0;
    margin-bottom: 1rem;
    overflow: auto;
}

figure {
    margin: 0 0 1rem;
}

img {
    vertical-align: middle;
}

[role="button"] {
    cursor: pointer;
}

a, area, button, [role="button"], input, label, select, summary, textarea {
    -ms-touch-action: manipulation;
    touch-action: manipulation;
}

table {
    border-collapse: collapse;
    background-color: transparent;
}

caption {
    padding-top: 0.4rem 0.8rem;
    padding-bottom: 0.4rem 0.8rem;
    color: #9ca3a9;
    text-align: left;
    caption-side: bottom;
}

th {
    text-align: left;
}

label {
    display: inline-block;
    margin-bottom: .5rem;
}

button:focus {
    outline: 1px dotted;
    outline: 5px auto -webkit-focus-ring-color;
}

input, button, select, textarea {
    line-height: inherit;
}

input[type="radio"]:disabled, input[type="checkbox"]:disabled {
    cursor: not-allowed;
}

input[type="date"], input[type="time"], input[type="datetime-local"], input[type="month"] {
    -webkit-appearance: listbox;
}

textarea {
    resize: vertical;
}

fieldset {
    min-width: 0;
    padding: 0;
    margin: 0;
    border: 0;
}

legend {
    display: block;
    width: 100%;
    padding: 0;
    margin-bottom: .5rem;
    font-size: 1.5rem;
    line-height: inherit;
}

input[type="search"] {
    -webkit-appearance: none;
}

output {
    display: inline-block;
}

[hidden] {
    display: none !important;
}

h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6 {
    margin-bottom: 0.5rem;
    font-family: inherit;
    font-weight: 500;
    line-height: 1.1;
    color: inherit;
}

h1, .h1 {
    font-size: 1.714rem;
}

h2, .h2 {
    font-size: 1.571rem;
}

h3, .h3 {
    font-size: 1.429rem;
}

h4, .h4 {
    font-size: 1.286rem;
}

h5, .h5 {
    font-size: 1.143rem;
}

h6, .h6 {
    font-size: 1rem;
}

.lead {
    font-size: 1.25rem;
    font-weight: 300;
}

.display-1 {
    font-size: 6rem;
    font-weight: 300;
}

.display-2 {
    font-size: 5.5rem;
    font-weight: 300;
}

.display-3 {
    font-size: 4.5rem;
    font-weight: 300;
}

.display-4 {
    font-size: 3.5rem;
    font-weight: 300;
}

hr {
    margin-top: 1rem;
    margin-bottom: 1rem;
    border: 0;
    border-top: 1px solid rgba(0, 0, 0, 0.1);
}

small, .timezonewarning, .small {
    font-size: 80%;
    font-weight: normal;
}

mark, .mark {
    padding: 0.2em;
    background-color: #fcf8e3;
}

.list-unstyled {
    padding-left: 0;
    list-style: none;
}

.list-inline {
    padding-left: 0;
    list-style: none;
}

.list-inline-item {
    display: inline-block;
}

.list-inline-item:not(:last-child) {
    margin-right: 5px;
}

.initialism {
    font-size: 90%;
    text-transform: uppercase;
}

.blockquote {
    padding: 0.5rem 1rem;
    margin-bottom: 1rem;
    font-size: 1rem;
    border-left: 0.25rem solid #d0d5d8;
}

.blockquote-footer {
    display: block;
    font-size: 80%;
    color: #818a91;
}

.blockquote-footer::before {
    content: "\2014 \00A0";
}

.blockquote-reverse {
    padding-right: 1rem;
    padding-left: 0;
    text-align: right;
    border-right: 0.25rem solid #d0d5d8;
    border-left: 0;
}

.blockquote-reverse .blockquote-footer::before {
    content: "";
}

.blockquote-reverse .blockquote-footer::after {
    content: "\00A0 \2014";
}

.img-fluid {
    max-width: 100%;
    height: auto;
}

.img-thumbnail {
    padding: 0.25rem;
    background-color: #f1f1f1;
    border: 1px solid #ddd;
    border-radius: 0.25rem;
    -webkit-transition: all .2s ease-in-out;
    transition: all .2s ease-in-out;
    max-width: 100%;
    height: auto;
}

.figure {
    display: inline-block;
}

.figure-img {
    margin-bottom: 0.5rem;
    line-height: 1;
}

.figure-caption {
    font-size: 90%;
    color: #9ca3a9;
}

code, kbd, pre, samp {
    font-family: Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace;
}

code {
    padding: 0.2rem 0.4rem;
    font-size: 90%;
    color: #bd4147;
    background-color: #f7f7f9;
    border-radius: 0.25rem;
}

kbd {
    padding: 0.2rem 0.4rem;
    font-size: 90%;
    color: #fff;
    background-color: #333;
    border-radius: 0.2rem;
}

kbd kbd {
    padding: 0;
    font-size: 100%;
    font-weight: bold;
}

pre {
    display: block;
    margin-top: 0;
    margin-bottom: 1rem;
    font-size: 90%;
    color: #373a3c;
}

pre code {
    padding: 0;
    font-size: inherit;
    color: inherit;
    background-color: transparent;
    border-radius: 0;
}

.pre-scrollable {
    max-height: 340px;
    overflow-y: scroll;
}

.container {
    margin-left: auto;
    margin-right: auto;
    padding-left: 0.9375rem;
    padding-right: 0.9375rem;
}

@media (min-width: 576px) {
    .container {
        width: 540px;
        max-width: 100%;
    }
}

@media (min-width: 768px) {
    .container {
        width: 720px;
        max-width: 100%;
    }
}

@media (min-width: 992px) {
    .container {
        width: 960px;
        max-width: 100%;
    }
}

@media (min-width: 1200px) {
    .container {
        width: 1140px;
        max-width: 100%;
    }
}

.container-fluid {
    margin-left: auto;
    margin-right: auto;
    padding-left: 0.9375rem;
    padding-right: 0.9375rem;
}

.row {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    margin-right: -15px;
    margin-left: -15px;
}

@media (min-width: 576px) {
    .row {
        margin-right: -15px;
        margin-left: -15px;
    }
}

@media (min-width: 768px) {
    .row {
        margin-right: -15px;
        margin-left: -15px;
    }
}

@media (min-width: 992px) {
    .row {
        margin-right: -15px;
        margin-left: -15px;
    }
}

@media (min-width: 1200px) {
    .row {
        margin-right: -15px;
        margin-left: -15px;
    }
}

.col-xs, .col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12, .col-sm, .col-sm-1, .col-sm-2, fieldset .form-row:not(.form-group):not(tr) > label:not(.form-control-label), .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12, .col-md, .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12, .col-lg, .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12, .col-xl, .col-xl-1, .col-xl-2, .col-xl-3, .col-xl-4, .col-xl-5, .col-xl-6, .col-xl-7, .col-xl-8, .col-xl-9, .col-xl-10, .col-xl-11, .col-xl-12 {
    position: relative;
    min-height: 1px;
    width: 100%;
    padding-right: 15px;
    padding-left: 15px;
}

@media (min-width: 576px) {
    .col-xs, .col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12, .col-sm, .col-sm-1, .col-sm-2, fieldset .form-row:not(.form-group):not(tr) > label:not(.form-control-label), .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12, .col-md, .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12, .col-lg, .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12, .col-xl, .col-xl-1, .col-xl-2, .col-xl-3, .col-xl-4, .col-xl-5, .col-xl-6, .col-xl-7, .col-xl-8, .col-xl-9, .col-xl-10, .col-xl-11, .col-xl-12 {
        padding-right: 15px;
        padding-left: 15px;
    }
}

@media (min-width: 768px) {
    .col-xs, .col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12, .col-sm, .col-sm-1, .col-sm-2, fieldset .form-row:not(.form-group):not(tr) > label:not(.form-control-label), .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12, .col-md, .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12, .col-lg, .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12, .col-xl, .col-xl-1, .col-xl-2, .col-xl-3, .col-xl-4, .col-xl-5, .col-xl-6, .col-xl-7, .col-xl-8, .col-xl-9, .col-xl-10, .col-xl-11, .col-xl-12 {
        padding-right: 15px;
        padding-left: 15px;
    }
}

@media (min-width: 992px) {
    .col-xs, .col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12, .col-sm, .col-sm-1, .col-sm-2, fieldset .form-row:not(.form-group):not(tr) > label:not(.form-control-label), .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12, .col-md, .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12, .col-lg, .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12, .col-xl, .col-xl-1, .col-xl-2, .col-xl-3, .col-xl-4, .col-xl-5, .col-xl-6, .col-xl-7, .col-xl-8, .col-xl-9, .col-xl-10, .col-xl-11, .col-xl-12 {
        padding-right: 15px;
        padding-left: 15px;
    }
}

@media (min-width: 1200px) {
    .col-xs, .col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12, .col-sm, .col-sm-1, .col-sm-2, fieldset .form-row:not(.form-group):not(tr) > label:not(.form-control-label), .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12, .col-md, .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12, .col-lg, .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12, .col-xl, .col-xl-1, .col-xl-2, .col-xl-3, .col-xl-4, .col-xl-5, .col-xl-6, .col-xl-7, .col-xl-8, .col-xl-9, .col-xl-10, .col-xl-11, .col-xl-12 {
        padding-right: 15px;
        padding-left: 15px;
    }
}

.col-xs {
    -ms-flex-preferred-size: 0;
    flex-basis: 0;
    -webkit-box-flex: 1;
    -ms-flex-positive: 1;
    flex-grow: 1;
    max-width: 100%;
}

.col-xs-1 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 8.33333%;
    flex: 0 0 8.33333%;
    max-width: 8.33333%;
}

.col-xs-2 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 16.66667%;
    flex: 0 0 16.66667%;
    max-width: 16.66667%;
}

.col-xs-3 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 25%;
    flex: 0 0 25%;
    max-width: 25%;
}

.col-xs-4 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 33.33333%;
    flex: 0 0 33.33333%;
    max-width: 33.33333%;
}

.col-xs-5 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 41.66667%;
    flex: 0 0 41.66667%;
    max-width: 41.66667%;
}

.col-xs-6 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 50%;
    flex: 0 0 50%;
    max-width: 50%;
}

.col-xs-7 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 58.33333%;
    flex: 0 0 58.33333%;
    max-width: 58.33333%;
}

.col-xs-8 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 66.66667%;
    flex: 0 0 66.66667%;
    max-width: 66.66667%;
}

.col-xs-9 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 75%;
    flex: 0 0 75%;
    max-width: 75%;
}

.col-xs-10 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 83.33333%;
    flex: 0 0 83.33333%;
    max-width: 83.33333%;
}

.col-xs-11 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 91.66667%;
    flex: 0 0 91.66667%;
    max-width: 91.66667%;
}

.col-xs-12 {
    -webkit-box-flex: 0;
    -ms-flex: 0 0 100%;
    flex: 0 0 100%;
    max-width: 100%;
}

.pull-xs-0 {
    right: auto;
}

.pull-xs-1 {
    right: 8.33333%;
}

.pull-xs-2 {
    right: 16.66667%;
}

.pull-xs-3 {
    right: 25%;
}

.pull-xs-4 {
    right: 33.33333%;
}

.pull-xs-5 {
    right: 41.66667%;
}

.pull-xs-6 {
    right: 50%;
}

.pull-xs-7 {
    right: 58.33333%;
}

.pull-xs-8 {
    right: 66.66667%;
}

.pull-xs-9 {
    right: 75%;
}

.pull-xs-10 {
    right: 83.33333%;
}

.pull-xs-11 {
    right: 91.66667%;
}

.pull-xs-12 {
    right: 100%;
}

.push-xs-0 {
    left: auto;
}

.push-xs-1 {
    left: 8.33333%;
}

.push-xs-2 {
    left: 16.66667%;
}

.push-xs-3 {
    left: 25%;
}

.push-xs-4 {
    left: 33.33333%;
}

.push-xs-5 {
    left: 41.66667%;
}

.push-xs-6 {
    left: 50%;
}

.push-xs-7 {
    left: 58.33333%;
}

.push-xs-8 {
    left: 66.66667%;
}

.push-xs-9 {
    left: 75%;
}

.push-xs-10 {
    left: 83.33333%;
}

.push-xs-11 {
    left: 91.66667%;
}

.push-xs-12 {
    left: 100%;
}

.offset-xs-1 {
    margin-left: 8.33333%;
}

.offset-xs-2 {
    margin-left: 16.66667%;
}

.offset-xs-3 {
    margin-left: 25%;
}

.offset-xs-4 {
    margin-left: 33.33333%;
}

.offset-xs-5 {
    margin-left: 41.66667%;
}

.offset-xs-6 {
    margin-left: 50%;
}

.offset-xs-7 {
    margin-left: 58.33333%;
}

.offset-xs-8 {
    margin-left: 66.66667%;
}

.offset-xs-9 {
    margin-left: 75%;
}

.offset-xs-10 {
    margin-left: 83.33333%;
}

.offset-xs-11 {
    margin-left: 91.66667%;
}

@media (min-width: 576px) {
    .col-sm {
        -ms-flex-preferred-size: 0;
        flex-basis: 0;
        -webkit-box-flex: 1;
        -ms-flex-positive: 1;
        flex-grow: 1;
        max-width: 100%;
    }

    .col-sm-1 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 8.33333%;
        flex: 0 0 8.33333%;
        max-width: 8.33333%;
    }

    .col-sm-2, fieldset .form-row:not(.form-group):not(tr) > label:not(.form-control-label) {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 16.66667%;
        flex: 0 0 16.66667%;
        max-width: 16.66667%;
    }

    .col-sm-3 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 25%;
        flex: 0 0 25%;
        max-width: 25%;
    }

    .col-sm-4 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 33.33333%;
        flex: 0 0 33.33333%;
        max-width: 33.33333%;
    }

    .col-sm-5 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 41.66667%;
        flex: 0 0 41.66667%;
        max-width: 41.66667%;
    }

    .col-sm-6 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 50%;
        flex: 0 0 50%;
        max-width: 50%;
    }

    .col-sm-7 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 58.33333%;
        flex: 0 0 58.33333%;
        max-width: 58.33333%;
    }

    .col-sm-8 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 66.66667%;
        flex: 0 0 66.66667%;
        max-width: 66.66667%;
    }

    .col-sm-9 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 75%;
        flex: 0 0 75%;
        max-width: 75%;
    }

    .col-sm-10 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 83.33333%;
        flex: 0 0 83.33333%;
        max-width: 83.33333%;
    }

    .col-sm-11 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 91.66667%;
        flex: 0 0 91.66667%;
        max-width: 91.66667%;
    }

    .col-sm-12 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 100%;
        flex: 0 0 100%;
        max-width: 100%;
    }

    .pull-sm-0 {
        right: auto;
    }

    .pull-sm-1 {
        right: 8.33333%;
    }

    .pull-sm-2 {
        right: 16.66667%;
    }

    .pull-sm-3 {
        right: 25%;
    }

    .pull-sm-4 {
        right: 33.33333%;
    }

    .pull-sm-5 {
        right: 41.66667%;
    }

    .pull-sm-6 {
        right: 50%;
    }

    .pull-sm-7 {
        right: 58.33333%;
    }

    .pull-sm-8 {
        right: 66.66667%;
    }

    .pull-sm-9 {
        right: 75%;
    }

    .pull-sm-10 {
        right: 83.33333%;
    }

    .pull-sm-11 {
        right: 91.66667%;
    }

    .pull-sm-12 {
        right: 100%;
    }

    .push-sm-0 {
        left: auto;
    }

    .push-sm-1 {
        left: 8.33333%;
    }

    .push-sm-2 {
        left: 16.66667%;
    }

    .push-sm-3 {
        left: 25%;
    }

    .push-sm-4 {
        left: 33.33333%;
    }

    .push-sm-5 {
        left: 41.66667%;
    }

    .push-sm-6 {
        left: 50%;
    }

    .push-sm-7 {
        left: 58.33333%;
    }

    .push-sm-8 {
        left: 66.66667%;
    }

    .push-sm-9 {
        left: 75%;
    }

    .push-sm-10 {
        left: 83.33333%;
    }

    .push-sm-11 {
        left: 91.66667%;
    }

    .push-sm-12 {
        left: 100%;
    }

    .offset-sm-0 {
        margin-left: 0%;
    }

    .offset-sm-1 {
        margin-left: 8.33333%;
    }

    .offset-sm-2 {
        margin-left: 16.66667%;
    }

    .offset-sm-3 {
        margin-left: 25%;
    }

    .offset-sm-4 {
        margin-left: 33.33333%;
    }

    .offset-sm-5 {
        margin-left: 41.66667%;
    }

    .offset-sm-6 {
        margin-left: 50%;
    }

    .offset-sm-7 {
        margin-left: 58.33333%;
    }

    .offset-sm-8 {
        margin-left: 66.66667%;
    }

    .offset-sm-9 {
        margin-left: 75%;
    }

    .offset-sm-10 {
        margin-left: 83.33333%;
    }

    .offset-sm-11 {
        margin-left: 91.66667%;
    }
}

@media (min-width: 768px) {
    .col-md {
        -ms-flex-preferred-size: 0;
        flex-basis: 0;
        -webkit-box-flex: 1;
        -ms-flex-positive: 1;
        flex-grow: 1;
        max-width: 100%;
    }

    .col-md-1 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 8.33333%;
        flex: 0 0 8.33333%;
        max-width: 8.33333%;
    }

    .col-md-2 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 16.66667%;
        flex: 0 0 16.66667%;
        max-width: 16.66667%;
    }

    .col-md-3 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 25%;
        flex: 0 0 25%;
        max-width: 25%;
    }

    .col-md-4 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 33.33333%;
        flex: 0 0 33.33333%;
        max-width: 33.33333%;
    }

    .col-md-5 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 41.66667%;
        flex: 0 0 41.66667%;
        max-width: 41.66667%;
    }

    .col-md-6 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 50%;
        flex: 0 0 50%;
        max-width: 50%;
    }

    .col-md-7 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 58.33333%;
        flex: 0 0 58.33333%;
        max-width: 58.33333%;
    }

    .col-md-8 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 66.66667%;
        flex: 0 0 66.66667%;
        max-width: 66.66667%;
    }

    .col-md-9 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 75%;
        flex: 0 0 75%;
        max-width: 75%;
    }

    .col-md-10 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 83.33333%;
        flex: 0 0 83.33333%;
        max-width: 83.33333%;
    }

    .col-md-11 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 91.66667%;
        flex: 0 0 91.66667%;
        max-width: 91.66667%;
    }

    .col-md-12 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 100%;
        flex: 0 0 100%;
        max-width: 100%;
    }

    .pull-md-0 {
        right: auto;
    }

    .pull-md-1 {
        right: 8.33333%;
    }

    .pull-md-2 {
        right: 16.66667%;
    }

    .pull-md-3 {
        right: 25%;
    }

    .pull-md-4 {
        right: 33.33333%;
    }

    .pull-md-5 {
        right: 41.66667%;
    }

    .pull-md-6 {
        right: 50%;
    }

    .pull-md-7 {
        right: 58.33333%;
    }

    .pull-md-8 {
        right: 66.66667%;
    }

    .pull-md-9 {
        right: 75%;
    }

    .pull-md-10 {
        right: 83.33333%;
    }

    .pull-md-11 {
        right: 91.66667%;
    }

    .pull-md-12 {
        right: 100%;
    }

    .push-md-0 {
        left: auto;
    }

    .push-md-1 {
        left: 8.33333%;
    }

    .push-md-2 {
        left: 16.66667%;
    }

    .push-md-3 {
        left: 25%;
    }

    .push-md-4 {
        left: 33.33333%;
    }

    .push-md-5 {
        left: 41.66667%;
    }

    .push-md-6 {
        left: 50%;
    }

    .push-md-7 {
        left: 58.33333%;
    }

    .push-md-8 {
        left: 66.66667%;
    }

    .push-md-9 {
        left: 75%;
    }

    .push-md-10 {
        left: 83.33333%;
    }

    .push-md-11 {
        left: 91.66667%;
    }

    .push-md-12 {
        left: 100%;
    }

    .offset-md-0 {
        margin-left: 0%;
    }

    .offset-md-1 {
        margin-left: 8.33333%;
    }

    .offset-md-2 {
        margin-left: 16.66667%;
    }

    .offset-md-3 {
        margin-left: 25%;
    }

    .offset-md-4 {
        margin-left: 33.33333%;
    }

    .offset-md-5 {
        margin-left: 41.66667%;
    }

    .offset-md-6 {
        margin-left: 50%;
    }

    .offset-md-7 {
        margin-left: 58.33333%;
    }

    .offset-md-8 {
        margin-left: 66.66667%;
    }

    .offset-md-9 {
        margin-left: 75%;
    }

    .offset-md-10 {
        margin-left: 83.33333%;
    }

    .offset-md-11 {
        margin-left: 91.66667%;
    }
}

@media (min-width: 992px) {
    .col-lg {
        -ms-flex-preferred-size: 0;
        flex-basis: 0;
        -webkit-box-flex: 1;
        -ms-flex-positive: 1;
        flex-grow: 1;
        max-width: 100%;
    }

    .col-lg-1 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 8.33333%;
        flex: 0 0 8.33333%;
        max-width: 8.33333%;
    }

    .col-lg-2 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 16.66667%;
        flex: 0 0 16.66667%;
        max-width: 16.66667%;
    }

    .col-lg-3 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 25%;
        flex: 0 0 25%;
        max-width: 25%;
    }

    .col-lg-4 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 33.33333%;
        flex: 0 0 33.33333%;
        max-width: 33.33333%;
    }

    .col-lg-5 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 41.66667%;
        flex: 0 0 41.66667%;
        max-width: 41.66667%;
    }

    .col-lg-6 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 50%;
        flex: 0 0 50%;
        max-width: 50%;
    }

    .col-lg-7 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 58.33333%;
        flex: 0 0 58.33333%;
        max-width: 58.33333%;
    }

    .col-lg-8 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 66.66667%;
        flex: 0 0 66.66667%;
        max-width: 66.66667%;
    }

    .col-lg-9 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 75%;
        flex: 0 0 75%;
        max-width: 75%;
    }

    .col-lg-10 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 83.33333%;
        flex: 0 0 83.33333%;
        max-width: 83.33333%;
    }

    .col-lg-11 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 91.66667%;
        flex: 0 0 91.66667%;
        max-width: 91.66667%;
    }

    .col-lg-12 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 100%;
        flex: 0 0 100%;
        max-width: 100%;
    }

    .pull-lg-0 {
        right: auto;
    }

    .pull-lg-1 {
        right: 8.33333%;
    }

    .pull-lg-2 {
        right: 16.66667%;
    }

    .pull-lg-3 {
        right: 25%;
    }

    .pull-lg-4 {
        right: 33.33333%;
    }

    .pull-lg-5 {
        right: 41.66667%;
    }

    .pull-lg-6 {
        right: 50%;
    }

    .pull-lg-7 {
        right: 58.33333%;
    }

    .pull-lg-8 {
        right: 66.66667%;
    }

    .pull-lg-9 {
        right: 75%;
    }

    .pull-lg-10 {
        right: 83.33333%;
    }

    .pull-lg-11 {
        right: 91.66667%;
    }

    .pull-lg-12 {
        right: 100%;
    }

    .push-lg-0 {
        left: auto;
    }

    .push-lg-1 {
        left: 8.33333%;
    }

    .push-lg-2 {
        left: 16.66667%;
    }

    .push-lg-3 {
        left: 25%;
    }

    .push-lg-4 {
        left: 33.33333%;
    }

    .push-lg-5 {
        left: 41.66667%;
    }

    .push-lg-6 {
        left: 50%;
    }

    .push-lg-7 {
        left: 58.33333%;
    }

    .push-lg-8 {
        left: 66.66667%;
    }

    .push-lg-9 {
        left: 75%;
    }

    .push-lg-10 {
        left: 83.33333%;
    }

    .push-lg-11 {
        left: 91.66667%;
    }

    .push-lg-12 {
        left: 100%;
    }

    .offset-lg-0 {
        margin-left: 0%;
    }

    .offset-lg-1 {
        margin-left: 8.33333%;
    }

    .offset-lg-2 {
        margin-left: 16.66667%;
    }

    .offset-lg-3 {
        margin-left: 25%;
    }

    .offset-lg-4 {
        margin-left: 33.33333%;
    }

    .offset-lg-5 {
        margin-left: 41.66667%;
    }

    .offset-lg-6 {
        margin-left: 50%;
    }

    .offset-lg-7 {
        margin-left: 58.33333%;
    }

    .offset-lg-8 {
        margin-left: 66.66667%;
    }

    .offset-lg-9 {
        margin-left: 75%;
    }

    .offset-lg-10 {
        margin-left: 83.33333%;
    }

    .offset-lg-11 {
        margin-left: 91.66667%;
    }
}

@media (min-width: 1200px) {
    .col-xl {
        -ms-flex-preferred-size: 0;
        flex-basis: 0;
        -webkit-box-flex: 1;
        -ms-flex-positive: 1;
        flex-grow: 1;
        max-width: 100%;
    }

    .col-xl-1 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 8.33333%;
        flex: 0 0 8.33333%;
        max-width: 8.33333%;
    }

    .col-xl-2 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 16.66667%;
        flex: 0 0 16.66667%;
        max-width: 16.66667%;
    }

    .col-xl-3 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 25%;
        flex: 0 0 25%;
        max-width: 25%;
    }

    .col-xl-4 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 33.33333%;
        flex: 0 0 33.33333%;
        max-width: 33.33333%;
    }

    .col-xl-5 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 41.66667%;
        flex: 0 0 41.66667%;
        max-width: 41.66667%;
    }

    .col-xl-6 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 50%;
        flex: 0 0 50%;
        max-width: 50%;
    }

    .col-xl-7 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 58.33333%;
        flex: 0 0 58.33333%;
        max-width: 58.33333%;
    }

    .col-xl-8 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 66.66667%;
        flex: 0 0 66.66667%;
        max-width: 66.66667%;
    }

    .col-xl-9 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 75%;
        flex: 0 0 75%;
        max-width: 75%;
    }

    .col-xl-10 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 83.33333%;
        flex: 0 0 83.33333%;
        max-width: 83.33333%;
    }

    .col-xl-11 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 91.66667%;
        flex: 0 0 91.66667%;
        max-width: 91.66667%;
    }

    .col-xl-12 {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 100%;
        flex: 0 0 100%;
        max-width: 100%;
    }

    .pull-xl-0 {
        right: auto;
    }

    .pull-xl-1 {
        right: 8.33333%;
    }

    .pull-xl-2 {
        right: 16.66667%;
    }

    .pull-xl-3 {
        right: 25%;
    }

    .pull-xl-4 {
        right: 33.33333%;
    }

    .pull-xl-5 {
        right: 41.66667%;
    }

    .pull-xl-6 {
        right: 50%;
    }

    .pull-xl-7 {
        right: 58.33333%;
    }

    .pull-xl-8 {
        right: 66.66667%;
    }

    .pull-xl-9 {
        right: 75%;
    }

    .pull-xl-10 {
        right: 83.33333%;
    }

    .pull-xl-11 {
        right: 91.66667%;
    }

    .pull-xl-12 {
        right: 100%;
    }

    .push-xl-0 {
        left: auto;
    }

    .push-xl-1 {
        left: 8.33333%;
    }

    .push-xl-2 {
        left: 16.66667%;
    }

    .push-xl-3 {
        left: 25%;
    }

    .push-xl-4 {
        left: 33.33333%;
    }

    .push-xl-5 {
        left: 41.66667%;
    }

    .push-xl-6 {
        left: 50%;
    }

    .push-xl-7 {
        left: 58.33333%;
    }

    .push-xl-8 {
        left: 66.66667%;
    }

    .push-xl-9 {
        left: 75%;
    }

    .push-xl-10 {
        left: 83.33333%;
    }

    .push-xl-11 {
        left: 91.66667%;
    }

    .push-xl-12 {
        left: 100%;
    }

    .offset-xl-0 {
        margin-left: 0%;
    }

    .offset-xl-1 {
        margin-left: 8.33333%;
    }

    .offset-xl-2 {
        margin-left: 16.66667%;
    }

    .offset-xl-3 {
        margin-left: 25%;
    }

    .offset-xl-4 {
        margin-left: 33.33333%;
    }

    .offset-xl-5 {
        margin-left: 41.66667%;
    }

    .offset-xl-6 {
        margin-left: 50%;
    }

    .offset-xl-7 {
        margin-left: 58.33333%;
    }

    .offset-xl-8 {
        margin-left: 66.66667%;
    }

    .offset-xl-9 {
        margin-left: 75%;
    }

    .offset-xl-10 {
        margin-left: 83.33333%;
    }

    .offset-xl-11 {
        margin-left: 91.66667%;
    }
}

.table, .tabular table, table#change-history {
    width: 100%;
    max-width: 100%;
    margin-bottom: 1rem;
}

.table th, .tabular table th, table#change-history th, .table td, .tabular table td, table#change-history td {
    padding: 0.4rem 0.8rem;
    vertical-align: top;
    border-top: 1px solid #eceeef;
}

.table thead th, .tabular table thead th, table#change-history thead th {
    vertical-align: bottom;
    border-bottom: 2px solid #eceeef;
}

.table tbody + tbody, .tabular table tbody + tbody, table#change-history tbody + tbody {
    border-top: 2px solid #eceeef;
}

.table .table, .tabular table .table, table#change-history .table, .table .tabular table, .tabular .table table, .tabular table table, table#change-history .tabular table, .tabular table#change-history table, .table table#change-history, .tabular table table#change-history, table#change-history table#change-history {
    background-color: #f1f1f1;
}

.table-sm th, .table-sm td {
    padding: 0.3rem;
}

.table-bordered {
    border: 1px solid #eceeef;
}

.table-bordered th, .table-bordered td {
    border: 1px solid #eceeef;
}

.table-bordered thead th, .table-bordered thead td {
    border-bottom-width: 2px;
}

.table-striped tbody tr:nth-of-type(odd) {
    background-color: #f7f7f7;
}

.table-hover tbody tr:hover {
    background-color: rgba(0, 0, 0, 0.075);
}

.table-active, .table-active > th, .table-active > td {
    background-color: rgba(0, 0, 0, 0.075);
}

.table-hover .table-active:hover {
    background-color: rgba(0, 0, 0, 0.075);
}

.table-hover .table-active:hover > td, .table-hover .table-active:hover > th {
    background-color: rgba(0, 0, 0, 0.075);
}

.table-success, .table-success > th, .table-success > td {
    background-color: #dff0d8;
}

.table-hover .table-success:hover {
    background-color: #d0e9c6;
}

.table-hover .table-success:hover > td, .table-hover .table-success:hover > th {
    background-color: #d0e9c6;
}

.table-info, .table-info > th, .table-info > td {
    background-color: #d9edf7;
}

.table-hover .table-info:hover {
    background-color: #c4e3f3;
}

.table-hover .table-info:hover > td, .table-hover .table-info:hover > th {
    background-color: #c4e3f3;
}

.table-warning, .table-warning > th, .table-warning > td {
    background-color: #fcf8e3;
}

.table-hover .table-warning:hover {
    background-color: #faf2cc;
}

.table-hover .table-warning:hover > td, .table-hover .table-warning:hover > th {
    background-color: #faf2cc;
}

.table-danger, .table-danger > th, .table-danger > td {
    background-color: #f2dede;
}

.table-hover .table-danger:hover {
    background-color: #ebcccc;
}

.table-hover .table-danger:hover > td, .table-hover .table-danger:hover > th {
    background-color: #ebcccc;
}

.thead-inverse th {
    color: #fff;
    background-color: #373a3c;
}

.thead-default th {
    color: #55595c;
    background-color: #eceeef;
}

.table-inverse {
    color: #eceeef;
    background-color: #373a3c;
}

.table-inverse th, .table-inverse td, .table-inverse thead th {
    border-color: #55595c;
}

.table-inverse.table-bordered {
    border: 0;
}

.table-responsive {
    display: block;
    width: 100%;
    min-height: 0%;
    overflow-x: auto;
}

.table-reflow thead {
    float: left;
}

.table-reflow tbody {
    display: block;
    white-space: nowrap;
}

.table-reflow th, .table-reflow td {
    border-top: 1px solid #eceeef;
    border-left: 1px solid #eceeef;
}

.table-reflow th:last-child, .table-reflow td:last-child {
    border-right: 1px solid #eceeef;
}

.table-reflow thead:last-child tr:last-child th, .table-reflow thead:last-child tr:last-child td, .table-reflow tbody:last-child tr:last-child th, .table-reflow tbody:last-child tr:last-child td, .table-reflow tfoot:last-child tr:last-child th, .table-reflow tfoot:last-child tr:last-child td {
    border-bottom: 1px solid #eceeef;
}

.table-reflow tr {
    float: left;
}

.table-reflow tr th, .table-reflow tr td {
    display: block !important;
    border: 1px solid #eceeef;
}

.form-control, fieldset input[type=text], fieldset input[type=url], fieldset input[type=email], fieldset input[type=number], fieldset input[type=password], fieldset input[type=date], fieldset input[type=tel], fieldset .vTextField, fieldset .vURLField, fieldset .vLargeTextField, fieldset .vTimeField, fieldset .vDateField, .selector .selector-available select, .selector .selector-chosen select, #changelist #toolbar #changelist-search input[type='text'], #changelist #changelist-form .actions select {
    display: block;
    width: 100%;
    padding: 0.5rem 0.75rem;
    font-size: 1rem;
    line-height: 1.25;
    color: #55595c;
    background-color: #fff;
    background-image: none;
    background-clip: padding-box;
    border: 1px solid rgba(0, 0, 0, 0.15);
    border-radius: 0.25rem;
}

.form-control::-ms-expand, fieldset input[type=text]::-ms-expand, fieldset input[type=url]::-ms-expand, fieldset input[type=email]::-ms-expand, fieldset input[type=number]::-ms-expand, fieldset input[type=password]::-ms-expand, fieldset input[type=date]::-ms-expand, fieldset input[type=tel]::-ms-expand, fieldset .vTextField::-ms-expand, fieldset .vURLField::-ms-expand, fieldset .vLargeTextField::-ms-expand, fieldset .vTimeField::-ms-expand, fieldset .vDateField::-ms-expand, .selector .selector-available select::-ms-expand, .selector .selector-chosen select::-ms-expand, #changelist #toolbar #changelist-search input[type='text']::-ms-expand, #changelist #changelist-form .actions select::-ms-expand {
    background-color: transparent;
    border: 0;
}

.form-control:focus, fieldset input[type=text]:focus, fieldset input[type=url]:focus, fieldset input[type=email]:focus, fieldset input[type=number]:focus, fieldset input[type=password]:focus, fieldset input[type=date]:focus, fieldset input[type=tel]:focus, fieldset .vTextField:focus, fieldset .vURLField:focus, fieldset .vLargeTextField:focus, fieldset .vTimeField:focus, fieldset .vDateField:focus, .selector .selector-available select:focus, .selector .selector-chosen select:focus, #changelist #toolbar #changelist-search input[type='text']:focus, #changelist #changelist-form .actions select:focus {
    color: #55595c;
    background-color: #fff;
    border-color: #66afe9;
    outline: none;
}

.form-control::-webkit-input-placeholder, fieldset input[type=text]::-webkit-input-placeholder, fieldset input[type=url]::-webkit-input-placeholder, fieldset input[type=email]::-webkit-input-placeholder, fieldset input[type=number]::-webkit-input-placeholder, fieldset input[type=password]::-webkit-input-placeholder, fieldset input[type=date]::-webkit-input-placeholder, fieldset input[type=tel]::-webkit-input-placeholder, fieldset .vTextField::-webkit-input-placeholder, fieldset .vURLField::-webkit-input-placeholder, fieldset .vLargeTextField::-webkit-input-placeholder, fieldset .vTimeField::-webkit-input-placeholder, fieldset .vDateField::-webkit-input-placeholder, .selector .selector-available select::-webkit-input-placeholder, .selector .selector-chosen select::-webkit-input-placeholder, #changelist #toolbar #changelist-search input[type='text']::-webkit-input-placeholder, #changelist #changelist-form .actions select::-webkit-input-placeholder {
    color: #999;
    opacity: 1;
}

.form-control::-moz-placeholder, fieldset input[type=text]::-moz-placeholder, fieldset input[type=url]::-moz-placeholder, fieldset input[type=email]::-moz-placeholder, fieldset input[type=number]::-moz-placeholder, fieldset input[type=password]::-moz-placeholder, fieldset input[type=date]::-moz-placeholder, fieldset input[type=tel]::-moz-placeholder, fieldset .vTextField::-moz-placeholder, fieldset .vURLField::-moz-placeholder, fieldset .vLargeTextField::-moz-placeholder, fieldset .vTimeField::-moz-placeholder, fieldset .vDateField::-moz-placeholder, .selector .selector-available select::-moz-placeholder, .selector .selector-chosen select::-moz-placeholder, #changelist #toolbar #changelist-search input[type='text']::-moz-placeholder, #changelist #changelist-form .actions select::-moz-placeholder {
    color: #999;
    opacity: 1;
}

.form-control:-ms-input-placeholder, fieldset input[type=text]:-ms-input-placeholder, fieldset input[type=url]:-ms-input-placeholder, fieldset input[type=email]:-ms-input-placeholder, fieldset input[type=number]:-ms-input-placeholder, fieldset input[type=password]:-ms-input-placeholder, fieldset input[type=date]:-ms-input-placeholder, fieldset input[type=tel]:-ms-input-placeholder, fieldset .vTextField:-ms-input-placeholder, fieldset .vURLField:-ms-input-placeholder, fieldset .vLargeTextField:-ms-input-placeholder, fieldset .vTimeField:-ms-input-placeholder, fieldset .vDateField:-ms-input-placeholder, .selector .selector-available select:-ms-input-placeholder, .selector .selector-chosen select:-ms-input-placeholder, #changelist #toolbar #changelist-search input[type='text']:-ms-input-placeholder, #changelist #changelist-form .actions select:-ms-input-placeholder {
    color: #999;
    opacity: 1;
}

.form-control::placeholder, fieldset input[type=text]::placeholder, fieldset input[type=url]::placeholder, fieldset input[type=email]::placeholder, fieldset input[type=number]::placeholder, fieldset input[type=password]::placeholder, fieldset input[type=date]::placeholder, fieldset input[type=tel]::placeholder, fieldset .vTextField::placeholder, fieldset .vURLField::placeholder, fieldset .vLargeTextField::placeholder, fieldset .vTimeField::placeholder, fieldset .vDateField::placeholder, .selector .selector-available select::placeholder, .selector .selector-chosen select::placeholder, #changelist #toolbar #changelist-search input[type='text']::placeholder, #changelist #changelist-form .actions select::placeholder {
    color: #999;
    opacity: 1;
}

.form-control:disabled, fieldset input[type=text]:disabled, fieldset input[type=url]:disabled, fieldset input[type=email]:disabled, fieldset input[type=number]:disabled, fieldset input[type=password]:disabled, fieldset input[type=date]:disabled, fieldset input[type=tel]:disabled, fieldset .vTextField:disabled, fieldset .vURLField:disabled, fieldset .vLargeTextField:disabled, fieldset .vTimeField:disabled, fieldset .vDateField:disabled, .selector .selector-available select:disabled, .selector .selector-chosen select:disabled, #changelist #toolbar #changelist-search input[type='text']:disabled, #changelist #changelist-form .actions select:disabled, .form-control[readonly], fieldset input[readonly][type=text], fieldset input[readonly][type=url], fieldset input[readonly][type=email], fieldset input[readonly][type=number], fieldset input[readonly][type=password], fieldset input[readonly][type=date], fieldset input[readonly][type=tel], fieldset [readonly].vTextField, fieldset [readonly].vURLField, fieldset [readonly].vLargeTextField, fieldset [readonly].vTimeField, fieldset [readonly].vDateField, .selector .selector-available select[readonly], .selector .selector-chosen select[readonly], #changelist #toolbar #changelist-search input[readonly][type='text'], #changelist #changelist-form .actions select[readonly] {
    background-color: #eceeef;
    opacity: 1;
}

.form-control:disabled, fieldset input[type=text]:disabled, fieldset input[type=url]:disabled, fieldset input[type=email]:disabled, fieldset input[type=number]:disabled, fieldset input[type=password]:disabled, fieldset input[type=date]:disabled, fieldset input[type=tel]:disabled, fieldset .vTextField:disabled, fieldset .vURLField:disabled, fieldset .vLargeTextField:disabled, fieldset .vTimeField:disabled, fieldset .vDateField:disabled, .selector .selector-available select:disabled, .selector .selector-chosen select:disabled, #changelist #toolbar #changelist-search input[type='text']:disabled, #changelist #changelist-form .actions select:disabled {
    cursor: not-allowed;
}

select.form-control:not([size]):not([multiple]), fieldset select.vTextField:not([size]):not([multiple]), fieldset select.vURLField:not([size]):not([multiple]), fieldset select.vLargeTextField:not([size]):not([multiple]), fieldset select.vTimeField:not([size]):not([multiple]), fieldset select.vDateField:not([size]):not([multiple]), .selector .selector-available select:not([size]):not([multiple]), .selector .selector-chosen select:not([size]):not([multiple]), #changelist #changelist-form .actions select:not([size]):not([multiple]) {
    height: calc(2.5rem - 2px);
}

select.form-control:focus::-ms-value, fieldset select.vTextField:focus::-ms-value, fieldset select.vURLField:focus::-ms-value, fieldset select.vLargeTextField:focus::-ms-value, fieldset select.vTimeField:focus::-ms-value, fieldset select.vDateField:focus::-ms-value, .selector .selector-available select:focus::-ms-value, .selector .selector-chosen select:focus::-ms-value, #changelist #changelist-form .actions select:focus::-ms-value {
    color: #55595c;
    background-color: #fff;
}

.form-control-file, .form-control-range {
    display: block;
}

.col-form-label {
    padding-top: 0.5rem;
    padding-bottom: 0.5rem;
    margin-bottom: 0;
}

.col-form-label-lg {
    padding-top: 0.75rem;
    padding-bottom: 0.75rem;
    font-size: 1.143rem;
}

.col-form-label-sm {
    padding-top: 0.35rem;
    padding-bottom: 0.35rem;
    font-size: 0.929rem;
}

.col-form-legend {
    padding-top: 0.5rem;
    padding-bottom: 0.5rem;
    margin-bottom: 0;
    font-size: 1rem;
}

.form-control-static, .inline-group .tabular table tbody td.original p {
    padding-top: 0.5rem;
    padding-bottom: 0.5rem;
    line-height: 1.25;
    border: solid transparent;
    border-width: 1px 0;
}

.form-control-static.form-control-sm, .input-group-sm > .form-control-static.form-control, .inline-group .tabular table tbody td.original .input-group-sm > p.form-control, .inline-group .tabular table tbody td.original fieldset .input-group-sm > p.vTextField, fieldset .inline-group .tabular table tbody td.original .input-group-sm > p.vTextField, .inline-group .tabular table tbody td.original fieldset .input-group-sm > p.vURLField, fieldset .inline-group .tabular table tbody td.original .input-group-sm > p.vURLField, .inline-group .tabular table tbody td.original fieldset .input-group-sm > p.vLargeTextField, fieldset .inline-group .tabular table tbody td.original .input-group-sm > p.vLargeTextField, .inline-group .tabular table tbody td.original fieldset .input-group-sm > p.vTimeField, fieldset .inline-group .tabular table tbody td.original .input-group-sm > p.vTimeField, .inline-group .tabular table tbody td.original fieldset .input-group-sm > p.vDateField, fieldset .inline-group .tabular table tbody td.original .input-group-sm > p.vDateField, fieldset .input-group-sm > input.form-control-static[type=text], fieldset .input-group-sm > input.form-control-static[type=url], fieldset .input-group-sm > input.form-control-static[type=email], fieldset .input-group-sm > input.form-control-static[type=number], fieldset .input-group-sm > input.form-control-static[type=password], fieldset .input-group-sm > input.form-control-static[type=date], fieldset .input-group-sm > input.form-control-static[type=tel], fieldset .input-group-sm > .form-control-static.vTextField, fieldset .input-group-sm > .form-control-static.vURLField, fieldset .input-group-sm > .form-control-static.vLargeTextField, fieldset .input-group-sm > .form-control-static.vTimeField, fieldset .input-group-sm > .form-control-static.vDateField, .selector .selector-available .input-group-sm > select.form-control-static, .selector .selector-chosen .input-group-sm > select.form-control-static, #changelist #toolbar #changelist-search .input-group-sm > input.form-control-static[type='text'], #changelist #changelist-form .actions .input-group-sm > select.form-control-static, .input-group-sm > .form-control-static.input-group-addon, .inline-group .tabular table tbody td.original .input-group-sm > p.input-group-addon, .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.form-control-static[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.form-control-static[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.form-control-static[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.form-control-static[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.form-control-static[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.form-control-static[id^='clocklink'], .input-group-sm > .input-group-btn > .form-control-static.btn, .inline-group .tabular table tbody td.original .input-group-sm > .input-group-btn > p.btn, .inline-group .tabular table tbody td.original .submit-row .deletelink-box .input-group-sm > .input-group-btn > p.deletelink, .submit-row .deletelink-box .inline-group .tabular table tbody td.original .input-group-sm > .input-group-btn > p.deletelink, body.delete-confirmation .content-wrap .input-group-sm > .input-group-btn > input.form-control-static[type='button'], body.delete-confirmation .content-wrap .input-group-sm > .input-group-btn > input.form-control-static[type='submit'], body.delete-confirmation .content-wrap .input-group-sm > .input-group-btn > button.form-control-static, .submit-row .deletelink-box .input-group-sm > .input-group-btn > .form-control-static.deletelink, .submit-row .input-group-sm > .input-group-btn > input.form-control-static[type='submit']:not([class*="btn-"]), .submit-row .input-group-sm > .input-group-btn > input.form-control-static[type='button']:not([class*="btn-"]), .submit-row .input-group-sm > .input-group-btn > button.form-control-static:not([class*="btn-"]), #content-main > .object-tools.input-group-sm > li.input-group-btn > a.form-control-static:not([class*="btn-"]), body.login .submit-row .input-group-sm > .input-group-btn > input.form-control-static[type='submit'], #changelist #toolbar #changelist-search .input-group-sm > .input-group-btn > input.form-control-static[type='submit'], #changelist #changelist-form .actions .input-group-sm > .input-group-btn > button.form-control-static, #changelist #changelist-form .paginator .input-group-sm > .input-group-btn > input.form-control-static[type='submit'], .inline-group .tabular table tbody td.original p.form-control-sm, .form-control-static.form-control-lg, .input-group-lg > .form-control-static.form-control, .inline-group .tabular table tbody td.original .input-group-lg > p.form-control, .inline-group .tabular table tbody td.original fieldset .input-group-lg > p.vTextField, fieldset .inline-group .tabular table tbody td.original .input-group-lg > p.vTextField, .inline-group .tabular table tbody td.original fieldset .input-group-lg > p.vURLField, fieldset .inline-group .tabular table tbody td.original .input-group-lg > p.vURLField, .inline-group .tabular table tbody td.original fieldset .input-group-lg > p.vLargeTextField, fieldset .inline-group .tabular table tbody td.original .input-group-lg > p.vLargeTextField, .inline-group .tabular table tbody td.original fieldset .input-group-lg > p.vTimeField, fieldset .inline-group .tabular table tbody td.original .input-group-lg > p.vTimeField, .inline-group .tabular table tbody td.original fieldset .input-group-lg > p.vDateField, fieldset .inline-group .tabular table tbody td.original .input-group-lg > p.vDateField, fieldset .input-group-lg > input.form-control-static[type=text], fieldset .input-group-lg > input.form-control-static[type=url], fieldset .input-group-lg > input.form-control-static[type=email], fieldset .input-group-lg > input.form-control-static[type=number], fieldset .input-group-lg > input.form-control-static[type=password], fieldset .input-group-lg > input.form-control-static[type=date], fieldset .input-group-lg > input.form-control-static[type=tel], fieldset .input-group-lg > .form-control-static.vTextField, fieldset .input-group-lg > .form-control-static.vURLField, fieldset .input-group-lg > .form-control-static.vLargeTextField, fieldset .input-group-lg > .form-control-static.vTimeField, fieldset .input-group-lg > .form-control-static.vDateField, .selector .selector-available .input-group-lg > select.form-control-static, .selector .selector-chosen .input-group-lg > select.form-control-static, #changelist #toolbar #changelist-search .input-group-lg > input.form-control-static[type='text'], #changelist #changelist-form .actions .input-group-lg > select.form-control-static, .input-group-lg > .form-control-static.input-group-addon, .inline-group .tabular table tbody td.original .input-group-lg > p.input-group-addon, .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.form-control-static[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.form-control-static[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.form-control-static[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.form-control-static[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.form-control-static[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.form-control-static[id^='clocklink'], .input-group-lg > .input-group-btn > .form-control-static.btn, .inline-group .tabular table tbody td.original .input-group-lg > .input-group-btn > p.btn, .inline-group .tabular table tbody td.original .submit-row .deletelink-box .input-group-lg > .input-group-btn > p.deletelink, .submit-row .deletelink-box .inline-group .tabular table tbody td.original .input-group-lg > .input-group-btn > p.deletelink, body.delete-confirmation .content-wrap .input-group-lg > .input-group-btn > input.form-control-static[type='button'], body.delete-confirmation .content-wrap .input-group-lg > .input-group-btn > input.form-control-static[type='submit'], body.delete-confirmation .content-wrap .input-group-lg > .input-group-btn > button.form-control-static, .submit-row .deletelink-box .input-group-lg > .input-group-btn > .form-control-static.deletelink, .submit-row .input-group-lg > .input-group-btn > input.form-control-static[type='submit']:not([class*="btn-"]), .submit-row .input-group-lg > .input-group-btn > input.form-control-static[type='button']:not([class*="btn-"]), .submit-row .input-group-lg > .input-group-btn > button.form-control-static:not([class*="btn-"]), #content-main > .object-tools.input-group-lg > li.input-group-btn > a.form-control-static:not([class*="btn-"]), body.login .submit-row .input-group-lg > .input-group-btn > input.form-control-static[type='submit'], #changelist #toolbar #changelist-search .input-group-lg > .input-group-btn > input.form-control-static[type='submit'], #changelist #changelist-form .actions .input-group-lg > .input-group-btn > button.form-control-static, #changelist #changelist-form .paginator .input-group-lg > .input-group-btn > input.form-control-static[type='submit'], .inline-group .tabular table tbody td.original p.form-control-lg {
    padding-right: 0;
    padding-left: 0;
}

.form-control-sm, .input-group-sm > .form-control, fieldset .input-group-sm > input[type=text], fieldset .input-group-sm > input[type=url], fieldset .input-group-sm > input[type=email], fieldset .input-group-sm > input[type=number], fieldset .input-group-sm > input[type=password], fieldset .input-group-sm > input[type=date], fieldset .input-group-sm > input[type=tel], fieldset .input-group-sm > .vTextField, fieldset .input-group-sm > .vURLField, fieldset .input-group-sm > .vLargeTextField, fieldset .input-group-sm > .vTimeField, fieldset .input-group-sm > .vDateField, .selector .selector-available .input-group-sm > select, .selector .selector-chosen .input-group-sm > select, #changelist #toolbar #changelist-search .input-group-sm > input[type='text'], #changelist #changelist-form .actions .input-group-sm > select, .input-group-sm > .input-group-addon, .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a[id^='clocklink'], .input-group-sm > .input-group-btn > .btn, body.delete-confirmation .content-wrap .input-group-sm > .input-group-btn > input[type='button'], body.delete-confirmation .content-wrap .input-group-sm > .input-group-btn > input[type='submit'], body.delete-confirmation .content-wrap .input-group-sm > .input-group-btn > button, .submit-row .deletelink-box .input-group-sm > .input-group-btn > .deletelink, .submit-row .input-group-sm > .input-group-btn > input[type='submit']:not([class*="btn-"]), .submit-row .input-group-sm > .input-group-btn > input[type='button']:not([class*="btn-"]), .submit-row .input-group-sm > .input-group-btn > button:not([class*="btn-"]), #content-main > .object-tools.input-group-sm > li.input-group-btn > a:not([class*="btn-"]), body.login .submit-row .input-group-sm > .input-group-btn > input[type='submit'], #changelist #toolbar #changelist-search .input-group-sm > .input-group-btn > input[type='submit'], #changelist #changelist-form .actions .input-group-sm > .input-group-btn > button, #changelist #changelist-form .paginator .input-group-sm > .input-group-btn > input[type='submit'] {
    padding: 0.35rem 0.75rem;
    font-size: 0.929rem;
    border-radius: 0.2rem;
}

select.form-control-sm:not([size]):not([multiple]), .input-group-sm > select.form-control:not([size]):not([multiple]), fieldset .input-group-sm > select.vTextField:not([size]):not([multiple]), fieldset .input-group-sm > select.vURLField:not([size]):not([multiple]), fieldset .input-group-sm > select.vLargeTextField:not([size]):not([multiple]), fieldset .input-group-sm > select.vTimeField:not([size]):not([multiple]), fieldset .input-group-sm > select.vDateField:not([size]):not([multiple]), .selector .selector-available .input-group-sm > select:not([size]):not([multiple]), .selector .selector-chosen .input-group-sm > select:not([size]):not([multiple]), #changelist #changelist-form .actions .input-group-sm > select:not([size]):not([multiple]), .input-group-sm > select.input-group-addon:not([size]):not([multiple]), .input-group-sm > .input-group-btn > select.btn:not([size]):not([multiple]), .submit-row .deletelink-box .input-group-sm > .input-group-btn > select.deletelink:not([size]):not([multiple]) {
    height: 1.8125rem;
}

.form-control-lg, .input-group-lg > .form-control, fieldset .input-group-lg > input[type=text], fieldset .input-group-lg > input[type=url], fieldset .input-group-lg > input[type=email], fieldset .input-group-lg > input[type=number], fieldset .input-group-lg > input[type=password], fieldset .input-group-lg > input[type=date], fieldset .input-group-lg > input[type=tel], fieldset .input-group-lg > .vTextField, fieldset .input-group-lg > .vURLField, fieldset .input-group-lg > .vLargeTextField, fieldset .input-group-lg > .vTimeField, fieldset .input-group-lg > .vDateField, .selector .selector-available .input-group-lg > select, .selector .selector-chosen .input-group-lg > select, #changelist #toolbar #changelist-search .input-group-lg > input[type='text'], #changelist #changelist-form .actions .input-group-lg > select, .input-group-lg > .input-group-addon, .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a[id^='clocklink'], .input-group-lg > .input-group-btn > .btn, body.delete-confirmation .content-wrap .input-group-lg > .input-group-btn > input[type='button'], body.delete-confirmation .content-wrap .input-group-lg > .input-group-btn > input[type='submit'], body.delete-confirmation .content-wrap .input-group-lg > .input-group-btn > button, .submit-row .deletelink-box .input-group-lg > .input-group-btn > .deletelink, .submit-row .input-group-lg > .input-group-btn > input[type='submit']:not([class*="btn-"]), .submit-row .input-group-lg > .input-group-btn > input[type='button']:not([class*="btn-"]), .submit-row .input-group-lg > .input-group-btn > button:not([class*="btn-"]), #content-main > .object-tools.input-group-lg > li.input-group-btn > a:not([class*="btn-"]), body.login .submit-row .input-group-lg > .input-group-btn > input[type='submit'], #changelist #toolbar #changelist-search .input-group-lg > .input-group-btn > input[type='submit'], #changelist #changelist-form .actions .input-group-lg > .input-group-btn > button, #changelist #changelist-form .paginator .input-group-lg > .input-group-btn > input[type='submit'] {
    padding: 0.75rem 1.5rem;
    font-size: 1.143rem;
    border-radius: 0.3rem;
}

select.form-control-lg:not([size]):not([multiple]), .input-group-lg > select.form-control:not([size]):not([multiple]), fieldset .input-group-lg > select.vTextField:not([size]):not([multiple]), fieldset .input-group-lg > select.vURLField:not([size]):not([multiple]), fieldset .input-group-lg > select.vLargeTextField:not([size]):not([multiple]), fieldset .input-group-lg > select.vTimeField:not([size]):not([multiple]), fieldset .input-group-lg > select.vDateField:not([size]):not([multiple]), .selector .selector-available .input-group-lg > select:not([size]):not([multiple]), .selector .selector-chosen .input-group-lg > select:not([size]):not([multiple]), #changelist #changelist-form .actions .input-group-lg > select:not([size]):not([multiple]), .input-group-lg > select.input-group-addon:not([size]):not([multiple]), .input-group-lg > .input-group-btn > select.btn:not([size]):not([multiple]), .submit-row .deletelink-box .input-group-lg > .input-group-btn > select.deletelink:not([size]):not([multiple]) {
    height: 3.16667rem;
}

.form-group {
    margin-bottom: 1rem;
}

.form-text {
    display: block;
    margin-top: 0.25rem;
}

.form-check {
    position: relative;
    display: block;
    margin-bottom: 0.75rem;
}

.form-check + .form-check {
    margin-top: -.25rem;
}

.form-check.disabled .form-check-label {
    color: #9ca3a9;
    cursor: not-allowed;
}

.form-check-label {
    padding-left: 1.25rem;
    margin-bottom: 0;
    cursor: pointer;
}

.form-check-input {
    position: absolute;
    margin-top: .25rem;
    margin-left: -1.25rem;
}

.form-check-input:only-child {
    position: static;
}

.form-check-inline {
    position: relative;
    display: inline-block;
    padding-left: 1.25rem;
    margin-bottom: 0;
    vertical-align: middle;
    cursor: pointer;
}

.form-check-inline + .form-check-inline {
    margin-left: .75rem;
}

.form-check-inline.disabled {
    color: #9ca3a9;
    cursor: not-allowed;
}

.form-control-feedback {
    margin-top: 0.25rem;
}

.form-control-success, .form-control-warning, .form-control-danger {
    padding-right: 2.25rem;
    background-repeat: no-repeat;
    background-position: center right 0.625rem;
    background-size: 1.25rem 1.25rem;
}

.has-success .form-control-feedback, .has-success .form-control-label, .has-success .form-check-label, .has-success .form-check-inline, .has-success .custom-control {
    color: #4ACB68;
}

.has-success .form-control, .has-success fieldset input[type=text], fieldset .has-success input[type=text], .has-success fieldset input[type=url], fieldset .has-success input[type=url], .has-success fieldset input[type=email], fieldset .has-success input[type=email], .has-success fieldset input[type=number], fieldset .has-success input[type=number], .has-success fieldset input[type=password], fieldset .has-success input[type=password], .has-success fieldset input[type=date], fieldset .has-success input[type=date], .has-success fieldset input[type=tel], fieldset .has-success input[type=tel], .has-success fieldset .vTextField, fieldset .has-success .vTextField, .has-success fieldset .vURLField, fieldset .has-success .vURLField, .has-success fieldset .vLargeTextField, fieldset .has-success .vLargeTextField, .has-success fieldset .vTimeField, fieldset .has-success .vTimeField, .has-success fieldset .vDateField, fieldset .has-success .vDateField, .has-success .selector .selector-available select, .selector .selector-available .has-success select, .has-success .selector .selector-chosen select, .selector .selector-chosen .has-success select, .has-success #changelist #toolbar #changelist-search input[type='text'], #changelist #toolbar #changelist-search .has-success input[type='text'], .has-success #changelist #changelist-form .actions select, #changelist #changelist-form .actions .has-success select {
    border-color: #4ACB68;
}

.has-success .form-control:focus, .has-success fieldset input[type=text]:focus, fieldset .has-success input[type=text]:focus, .has-success fieldset input[type=url]:focus, fieldset .has-success input[type=url]:focus, .has-success fieldset input[type=email]:focus, fieldset .has-success input[type=email]:focus, .has-success fieldset input[type=number]:focus, fieldset .has-success input[type=number]:focus, .has-success fieldset input[type=password]:focus, fieldset .has-success input[type=password]:focus, .has-success fieldset input[type=date]:focus, fieldset .has-success input[type=date]:focus, .has-success fieldset input[type=tel]:focus, fieldset .has-success input[type=tel]:focus, .has-success fieldset .vTextField:focus, fieldset .has-success .vTextField:focus, .has-success fieldset .vURLField:focus, fieldset .has-success .vURLField:focus, .has-success fieldset .vLargeTextField:focus, fieldset .has-success .vLargeTextField:focus, .has-success fieldset .vTimeField:focus, fieldset .has-success .vTimeField:focus, .has-success fieldset .vDateField:focus, fieldset .has-success .vDateField:focus, .has-success .selector .selector-available select:focus, .selector .selector-available .has-success select:focus, .has-success .selector .selector-chosen select:focus, .selector .selector-chosen .has-success select:focus, .has-success #changelist #toolbar #changelist-search input[type='text']:focus, #changelist #toolbar #changelist-search .has-success input[type='text']:focus, .has-success #changelist #changelist-form .actions select:focus, #changelist #changelist-form .actions .has-success select:focus {
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #99e2aa;
}

.has-success .input-group-addon, .has-success .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .has-success a[id^='calendarlink'], .has-success .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts .has-success a[id^='clocklink'], .has-success .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .has-success a[id^='calendarlink'], .has-success .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .has-success a[id^='clocklink'], .has-success .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .has-success a[id^='calendarlink'], .has-success .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .has-success a[id^='clocklink'] {
    color: #4ACB68;
    border-color: #4ACB68;
    background-color: #e8f9ec;
}

.has-success .form-control-success {
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3E%3Cpath fill='#4ACB68' d='M2.3 6.73L.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z'/%3E%3C/svg%3E");
}

.has-warning .form-control-feedback, .has-warning .form-control-label, .has-warning .form-check-label, .has-warning .form-check-inline, .has-warning .custom-control {
    color: #F3C544;
}

.has-warning .form-control, .has-warning fieldset input[type=text], fieldset .has-warning input[type=text], .has-warning fieldset input[type=url], fieldset .has-warning input[type=url], .has-warning fieldset input[type=email], fieldset .has-warning input[type=email], .has-warning fieldset input[type=number], fieldset .has-warning input[type=number], .has-warning fieldset input[type=password], fieldset .has-warning input[type=password], .has-warning fieldset input[type=date], fieldset .has-warning input[type=date], .has-warning fieldset input[type=tel], fieldset .has-warning input[type=tel], .has-warning fieldset .vTextField, fieldset .has-warning .vTextField, .has-warning fieldset .vURLField, fieldset .has-warning .vURLField, .has-warning fieldset .vLargeTextField, fieldset .has-warning .vLargeTextField, .has-warning fieldset .vTimeField, fieldset .has-warning .vTimeField, .has-warning fieldset .vDateField, fieldset .has-warning .vDateField, .has-warning .selector .selector-available select, .selector .selector-available .has-warning select, .has-warning .selector .selector-chosen select, .selector .selector-chosen .has-warning select, .has-warning #changelist #toolbar #changelist-search input[type='text'], #changelist #toolbar #changelist-search .has-warning input[type='text'], .has-warning #changelist #changelist-form .actions select, #changelist #changelist-form .actions .has-warning select {
    border-color: #F3C544;
}

.has-warning .form-control:focus, .has-warning fieldset input[type=text]:focus, fieldset .has-warning input[type=text]:focus, .has-warning fieldset input[type=url]:focus, fieldset .has-warning input[type=url]:focus, .has-warning fieldset input[type=email]:focus, fieldset .has-warning input[type=email]:focus, .has-warning fieldset input[type=number]:focus, fieldset .has-warning input[type=number]:focus, .has-warning fieldset input[type=password]:focus, fieldset .has-warning input[type=password]:focus, .has-warning fieldset input[type=date]:focus, fieldset .has-warning input[type=date]:focus, .has-warning fieldset input[type=tel]:focus, fieldset .has-warning input[type=tel]:focus, .has-warning fieldset .vTextField:focus, fieldset .has-warning .vTextField:focus, .has-warning fieldset .vURLField:focus, fieldset .has-warning .vURLField:focus, .has-warning fieldset .vLargeTextField:focus, fieldset .has-warning .vLargeTextField:focus, .has-warning fieldset .vTimeField:focus, fieldset .has-warning .vTimeField:focus, .has-warning fieldset .vDateField:focus, fieldset .has-warning .vDateField:focus, .has-warning .selector .selector-available select:focus, .selector .selector-available .has-warning select:focus, .has-warning .selector .selector-chosen select:focus, .selector .selector-chosen .has-warning select:focus, .has-warning #changelist #toolbar #changelist-search input[type='text']:focus, #changelist #toolbar #changelist-search .has-warning input[type='text']:focus, .has-warning #changelist #changelist-form .actions select:focus, #changelist #changelist-form .actions .has-warning select:focus {
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #f9e3a4;
}

.has-warning .input-group-addon, .has-warning .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .has-warning a[id^='calendarlink'], .has-warning .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts .has-warning a[id^='clocklink'], .has-warning .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .has-warning a[id^='calendarlink'], .has-warning .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .has-warning a[id^='clocklink'], .has-warning .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .has-warning a[id^='calendarlink'], .has-warning .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .has-warning a[id^='clocklink'] {
    color: #F3C544;
    border-color: #F3C544;
    background-color: white;
}

.has-warning .form-control-warning {
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3E%3Cpath fill='#F3C544' d='M4.4 5.324h-.8v-2.46h.8zm0 1.42h-.8V5.89h.8zM3.76.63L.04 7.075c-.115.2.016.425.26.426h7.397c.242 0 .372-.226.258-.426C6.726 4.924 5.47 2.79 4.253.63c-.113-.174-.39-.174-.494 0z'/%3E%3C/svg%3E");
}

.has-danger .form-control-feedback, .has-danger .form-control-label, .has-danger .form-check-label, .has-danger .form-check-inline, .has-danger .custom-control {
    color: #E04F3C;
}

.has-danger .form-control, .has-danger fieldset input[type=text], fieldset .has-danger input[type=text], .has-danger fieldset input[type=url], fieldset .has-danger input[type=url], .has-danger fieldset input[type=email], fieldset .has-danger input[type=email], .has-danger fieldset input[type=number], fieldset .has-danger input[type=number], .has-danger fieldset input[type=password], fieldset .has-danger input[type=password], .has-danger fieldset input[type=date], fieldset .has-danger input[type=date], .has-danger fieldset input[type=tel], fieldset .has-danger input[type=tel], .has-danger fieldset .vTextField, fieldset .has-danger .vTextField, .has-danger fieldset .vURLField, fieldset .has-danger .vURLField, .has-danger fieldset .vLargeTextField, fieldset .has-danger .vLargeTextField, .has-danger fieldset .vTimeField, fieldset .has-danger .vTimeField, .has-danger fieldset .vDateField, fieldset .has-danger .vDateField, .has-danger .selector .selector-available select, .selector .selector-available .has-danger select, .has-danger .selector .selector-chosen select, .selector .selector-chosen .has-danger select, .has-danger #changelist #toolbar #changelist-search input[type='text'], #changelist #toolbar #changelist-search .has-danger input[type='text'], .has-danger #changelist #changelist-form .actions select, #changelist #changelist-form .actions .has-danger select {
    border-color: #E04F3C;
}

.has-danger .form-control:focus, .has-danger fieldset input[type=text]:focus, fieldset .has-danger input[type=text]:focus, .has-danger fieldset input[type=url]:focus, fieldset .has-danger input[type=url]:focus, .has-danger fieldset input[type=email]:focus, fieldset .has-danger input[type=email]:focus, .has-danger fieldset input[type=number]:focus, fieldset .has-danger input[type=number]:focus, .has-danger fieldset input[type=password]:focus, fieldset .has-danger input[type=password]:focus, .has-danger fieldset input[type=date]:focus, fieldset .has-danger input[type=date]:focus, .has-danger fieldset input[type=tel]:focus, fieldset .has-danger input[type=tel]:focus, .has-danger fieldset .vTextField:focus, fieldset .has-danger .vTextField:focus, .has-danger fieldset .vURLField:focus, fieldset .has-danger .vURLField:focus, .has-danger fieldset .vLargeTextField:focus, fieldset .has-danger .vLargeTextField:focus, .has-danger fieldset .vTimeField:focus, fieldset .has-danger .vTimeField:focus, .has-danger fieldset .vDateField:focus, fieldset .has-danger .vDateField:focus, .has-danger .selector .selector-available select:focus, .selector .selector-available .has-danger select:focus, .has-danger .selector .selector-chosen select:focus, .selector .selector-chosen .has-danger select:focus, .has-danger #changelist #toolbar #changelist-search input[type='text']:focus, #changelist #toolbar #changelist-search .has-danger input[type='text']:focus, .has-danger #changelist #changelist-form .actions select:focus, #changelist #changelist-form .actions .has-danger select:focus {
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ee9e94;
}

.has-danger .input-group-addon, .has-danger .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .has-danger a[id^='calendarlink'], .has-danger .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts .has-danger a[id^='clocklink'], .has-danger .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .has-danger a[id^='calendarlink'], .has-danger .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .has-danger a[id^='clocklink'], .has-danger .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .has-danger a[id^='calendarlink'], .has-danger .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .has-danger a[id^='clocklink'] {
    color: #E04F3C;
    border-color: #E04F3C;
    background-color: #fceeec;
}

.has-danger .form-control-danger {
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='#E04F3C' viewBox='-2 -2 7 7'%3E%3Cpath stroke='%23d9534f' d='M0 0l3 3m0-3L0 3'/%3E%3Ccircle r='.5'/%3E%3Ccircle cx='3' r='.5'/%3E%3Ccircle cy='3' r='.5'/%3E%3Ccircle cx='3' cy='3' r='.5'/%3E%3C/svg%3E");
}

@media (min-width: 576px) {
    .form-inline .form-group {
        display: inline-block;
        margin-bottom: 0;
        vertical-align: middle;
    }

    .form-inline .form-control, .form-inline fieldset input[type=text], fieldset .form-inline input[type=text], .form-inline fieldset input[type=url], fieldset .form-inline input[type=url], .form-inline fieldset input[type=email], fieldset .form-inline input[type=email], .form-inline fieldset input[type=number], fieldset .form-inline input[type=number], .form-inline fieldset input[type=password], fieldset .form-inline input[type=password], .form-inline fieldset input[type=date], fieldset .form-inline input[type=date], .form-inline fieldset input[type=tel], fieldset .form-inline input[type=tel], .form-inline fieldset .vTextField, fieldset .form-inline .vTextField, .form-inline fieldset .vURLField, fieldset .form-inline .vURLField, .form-inline fieldset .vLargeTextField, fieldset .form-inline .vLargeTextField, .form-inline fieldset .vTimeField, fieldset .form-inline .vTimeField, .form-inline fieldset .vDateField, fieldset .form-inline .vDateField, .form-inline .selector .selector-available select, .selector .selector-available .form-inline select, .form-inline .selector .selector-chosen select, .selector .selector-chosen .form-inline select, .form-inline #changelist #toolbar #changelist-search input[type='text'], #changelist #toolbar #changelist-search .form-inline input[type='text'], .form-inline #changelist #changelist-form .actions select, #changelist #changelist-form .actions .form-inline select {
        display: inline-block;
        width: auto;
        vertical-align: middle;
    }

    .form-inline .form-control-static, .form-inline .inline-group .tabular table tbody td.original p, .inline-group .tabular table tbody td.original .form-inline p {
        display: inline-block;
    }

    .form-inline .input-group {
        display: inline-table;
        width: auto;
        vertical-align: middle;
    }

    .form-inline .input-group .input-group-addon, .form-inline .input-group .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .form-inline .input-group a[id^='calendarlink'], .form-inline .input-group .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts .form-inline .input-group a[id^='clocklink'], .form-inline .input-group .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .form-inline .input-group a[id^='calendarlink'], .form-inline .input-group .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .form-inline .input-group a[id^='clocklink'], .form-inline .input-group .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .form-inline .input-group a[id^='calendarlink'], .form-inline .input-group .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .form-inline .input-group a[id^='clocklink'], .form-inline .input-group .input-group-btn, .form-inline .input-group .form-control, .form-inline .input-group fieldset input[type=text], fieldset .form-inline .input-group input[type=text], .form-inline .input-group fieldset input[type=url], fieldset .form-inline .input-group input[type=url], .form-inline .input-group fieldset input[type=email], fieldset .form-inline .input-group input[type=email], .form-inline .input-group fieldset input[type=number], fieldset .form-inline .input-group input[type=number], .form-inline .input-group fieldset input[type=password], fieldset .form-inline .input-group input[type=password], .form-inline .input-group fieldset input[type=date], fieldset .form-inline .input-group input[type=date], .form-inline .input-group fieldset input[type=tel], fieldset .form-inline .input-group input[type=tel], .form-inline .input-group fieldset .vTextField, fieldset .form-inline .input-group .vTextField, .form-inline .input-group fieldset .vURLField, fieldset .form-inline .input-group .vURLField, .form-inline .input-group fieldset .vLargeTextField, fieldset .form-inline .input-group .vLargeTextField, .form-inline .input-group fieldset .vTimeField, fieldset .form-inline .input-group .vTimeField, .form-inline .input-group fieldset .vDateField, fieldset .form-inline .input-group .vDateField, .form-inline .input-group .selector .selector-available select, .selector .selector-available .form-inline .input-group select, .form-inline .input-group .selector .selector-chosen select, .selector .selector-chosen .form-inline .input-group select, .form-inline .input-group #changelist #toolbar #changelist-search input[type='text'], #changelist #toolbar #changelist-search .form-inline .input-group input[type='text'], .form-inline .input-group #changelist #changelist-form .actions select, #changelist #changelist-form .actions .form-inline .input-group select {
        width: auto;
    }

    .form-inline .input-group > .form-control, .form-inline fieldset .input-group > input[type=text], fieldset .form-inline .input-group > input[type=text], .form-inline fieldset .input-group > input[type=url], fieldset .form-inline .input-group > input[type=url], .form-inline fieldset .input-group > input[type=email], fieldset .form-inline .input-group > input[type=email], .form-inline fieldset .input-group > input[type=number], fieldset .form-inline .input-group > input[type=number], .form-inline fieldset .input-group > input[type=password], fieldset .form-inline .input-group > input[type=password], .form-inline fieldset .input-group > input[type=date], fieldset .form-inline .input-group > input[type=date], .form-inline fieldset .input-group > input[type=tel], fieldset .form-inline .input-group > input[type=tel], .form-inline fieldset .input-group > .vTextField, fieldset .form-inline .input-group > .vTextField, .form-inline fieldset .input-group > .vURLField, fieldset .form-inline .input-group > .vURLField, .form-inline fieldset .input-group > .vLargeTextField, fieldset .form-inline .input-group > .vLargeTextField, .form-inline fieldset .input-group > .vTimeField, fieldset .form-inline .input-group > .vTimeField, .form-inline fieldset .input-group > .vDateField, fieldset .form-inline .input-group > .vDateField, .form-inline .selector .selector-available .input-group > select, .selector .selector-available .form-inline .input-group > select, .form-inline .selector .selector-chosen .input-group > select, .selector .selector-chosen .form-inline .input-group > select, .form-inline #changelist #toolbar #changelist-search .input-group > input[type='text'], #changelist #toolbar #changelist-search .form-inline .input-group > input[type='text'], .form-inline #changelist #changelist-form .actions .input-group > select, #changelist #changelist-form .actions .form-inline .input-group > select {
        width: 100%;
    }

    .form-inline .form-control-label {
        margin-bottom: 0;
        vertical-align: middle;
    }

    .form-inline .form-check {
        display: inline-block;
        margin-top: 0;
        margin-bottom: 0;
        vertical-align: middle;
    }

    .form-inline .form-check-label {
        padding-left: 0;
    }

    .form-inline .form-check-input {
        position: relative;
        margin-left: 0;
    }

    .form-inline .has-feedback .form-control-feedback {
        top: 0;
    }
}

.btn, body.delete-confirmation .content-wrap input[type='button'], body.delete-confirmation .content-wrap input[type='submit'], body.delete-confirmation .content-wrap button, .submit-row .deletelink-box .deletelink, .submit-row input[type='submit']:not([class*="btn-"]), .submit-row input[type='button']:not([class*="btn-"]), .submit-row button:not([class*="btn-"]), #content-main > .object-tools > li > a:not([class*="btn-"]), #content-main > .object-tools > li > a.addlink:not([class*="btn-"]), body.login .submit-row input[type='submit'], #changelist #toolbar #changelist-search input[type='submit'], #changelist #changelist-form .actions button, #changelist #changelist-form .paginator input[type='submit'] {
    display: inline-block;
    font-weight: normal;
    line-height: 1.25;
    text-align: center;
    white-space: nowrap;
    vertical-align: middle;
    cursor: pointer;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    border: 1px solid transparent;
    padding: 0.5rem 1rem;
    font-size: 1rem;
    border-radius: 0.25rem;
}

.btn:focus, body.delete-confirmation .content-wrap input[type='button']:focus, body.delete-confirmation .content-wrap input[type='submit']:focus, body.delete-confirmation .content-wrap button:focus, .submit-row .deletelink-box .deletelink:focus, .submit-row input[type='submit']:focus:not([class*="btn-"]), .submit-row input[type='button']:focus:not([class*="btn-"]), .submit-row button:focus:not([class*="btn-"]), #content-main > .object-tools > li > a:focus:not([class*="btn-"]), body.login .submit-row input[type='submit']:focus, #changelist #toolbar #changelist-search input[type='submit']:focus, #changelist #changelist-form .actions button:focus, #changelist #changelist-form .paginator input[type='submit']:focus, .btn.focus, body.delete-confirmation .content-wrap input.focus[type='button'], body.delete-confirmation .content-wrap input.focus[type='submit'], body.delete-confirmation .content-wrap button.focus, .submit-row .deletelink-box .focus.deletelink, .submit-row input.focus[type='submit']:not([class*="btn-"]), .submit-row input.focus[type='button']:not([class*="btn-"]), .submit-row button.focus:not([class*="btn-"]), #content-main > .object-tools > li > a.focus:not([class*="btn-"]), body.login .submit-row input.focus[type='submit'], #changelist #toolbar #changelist-search input.focus[type='submit'], #changelist #changelist-form .actions button.focus, #changelist #changelist-form .paginator input.focus[type='submit'], .btn:active:focus, body.delete-confirmation .content-wrap input[type='button']:active:focus, body.delete-confirmation .content-wrap input[type='submit']:active:focus, body.delete-confirmation .content-wrap button:active:focus, .submit-row .deletelink-box .deletelink:active:focus, .submit-row input[type='submit']:active:focus:not([class*="btn-"]), .submit-row input[type='button']:active:focus:not([class*="btn-"]), .submit-row button:active:focus:not([class*="btn-"]), #content-main > .object-tools > li > a:active:focus:not([class*="btn-"]), body.login .submit-row input[type='submit']:active:focus, #changelist #toolbar #changelist-search input[type='submit']:active:focus, #changelist #changelist-form .actions button:active:focus, #changelist #changelist-form .paginator input[type='submit']:active:focus, .btn:active.focus, body.delete-confirmation .content-wrap input[type='button']:active.focus, body.delete-confirmation .content-wrap input[type='submit']:active.focus, body.delete-confirmation .content-wrap button:active.focus, .submit-row .deletelink-box .deletelink:active.focus, .submit-row input[type='submit']:active.focus:not([class*="btn-"]), .submit-row input[type='button']:active.focus:not([class*="btn-"]), .submit-row button:active.focus:not([class*="btn-"]), #content-main > .object-tools > li > a:active.focus:not([class*="btn-"]), body.login .submit-row input[type='submit']:active.focus, #changelist #toolbar #changelist-search input[type='submit']:active.focus, #changelist #changelist-form .actions button:active.focus, #changelist #changelist-form .paginator input[type='submit']:active.focus, .btn.active:focus, body.delete-confirmation .content-wrap input.active[type='button']:focus, body.delete-confirmation .content-wrap input.active[type='submit']:focus, body.delete-confirmation .content-wrap button.active:focus, .submit-row .deletelink-box .active.deletelink:focus, .submit-row input.active[type='submit']:focus:not([class*="btn-"]), .submit-row input.active[type='button']:focus:not([class*="btn-"]), .submit-row button.active:focus:not([class*="btn-"]), #content-main > .object-tools > li > a.active:focus:not([class*="btn-"]), body.login .submit-row input.active[type='submit']:focus, #changelist #toolbar #changelist-search input.active[type='submit']:focus, #changelist #changelist-form .actions button.active:focus, #changelist #changelist-form .paginator input.active[type='submit']:focus, .btn.active.focus, body.delete-confirmation .content-wrap input.active.focus[type='button'], body.delete-confirmation .content-wrap input.active.focus[type='submit'], body.delete-confirmation .content-wrap button.active.focus, .submit-row .deletelink-box .active.focus.deletelink, .submit-row input.active.focus[type='submit']:not([class*="btn-"]), .submit-row input.active.focus[type='button']:not([class*="btn-"]), .submit-row button.active.focus:not([class*="btn-"]), #content-main > .object-tools > li > a.active.focus:not([class*="btn-"]), body.login .submit-row input.active.focus[type='submit'], #changelist #toolbar #changelist-search input.active.focus[type='submit'], #changelist #changelist-form .actions button.active.focus, #changelist #changelist-form .paginator input.active.focus[type='submit'] {
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
}

.btn:focus, body.delete-confirmation .content-wrap input[type='button']:focus, body.delete-confirmation .content-wrap input[type='submit']:focus, body.delete-confirmation .content-wrap button:focus, .submit-row .deletelink-box .deletelink:focus, .submit-row input[type='submit']:focus:not([class*="btn-"]), .submit-row input[type='button']:focus:not([class*="btn-"]), .submit-row button:focus:not([class*="btn-"]), #content-main > .object-tools > li > a:focus:not([class*="btn-"]), body.login .submit-row input[type='submit']:focus, #changelist #toolbar #changelist-search input[type='submit']:focus, #changelist #changelist-form .actions button:focus, #changelist #changelist-form .paginator input[type='submit']:focus, .btn:hover, body.delete-confirmation .content-wrap input[type='button']:hover, body.delete-confirmation .content-wrap input[type='submit']:hover, body.delete-confirmation .content-wrap button:hover, .submit-row .deletelink-box .deletelink:hover, .submit-row input[type='submit']:hover:not([class*="btn-"]), .submit-row input[type='button']:hover:not([class*="btn-"]), .submit-row button:hover:not([class*="btn-"]), #content-main > .object-tools > li > a:hover:not([class*="btn-"]), body.login .submit-row input[type='submit']:hover, #changelist #toolbar #changelist-search input[type='submit']:hover, #changelist #changelist-form .actions button:hover, #changelist #changelist-form .paginator input[type='submit']:hover {
    text-decoration: none;
}

.btn.focus, body.delete-confirmation .content-wrap input.focus[type='button'], body.delete-confirmation .content-wrap input.focus[type='submit'], body.delete-confirmation .content-wrap button.focus, .submit-row .deletelink-box .focus.deletelink, .submit-row input.focus[type='submit']:not([class*="btn-"]), .submit-row input.focus[type='button']:not([class*="btn-"]), .submit-row button.focus:not([class*="btn-"]), #content-main > .object-tools > li > a.focus:not([class*="btn-"]), body.login .submit-row input.focus[type='submit'], #changelist #toolbar #changelist-search input.focus[type='submit'], #changelist #changelist-form .actions button.focus, #changelist #changelist-form .paginator input.focus[type='submit'] {
    text-decoration: none;
}

.btn:active, body.delete-confirmation .content-wrap input[type='button']:active, body.delete-confirmation .content-wrap input[type='submit']:active, body.delete-confirmation .content-wrap button:active, .submit-row .deletelink-box .deletelink:active, .submit-row input[type='submit']:active:not([class*="btn-"]), .submit-row input[type='button']:active:not([class*="btn-"]), .submit-row button:active:not([class*="btn-"]), #content-main > .object-tools > li > a:active:not([class*="btn-"]), body.login .submit-row input[type='submit']:active, #changelist #toolbar #changelist-search input[type='submit']:active, #changelist #changelist-form .actions button:active, #changelist #changelist-form .paginator input[type='submit']:active, .btn.active, body.delete-confirmation .content-wrap input.active[type='button'], body.delete-confirmation .content-wrap input.active[type='submit'], body.delete-confirmation .content-wrap button.active, .submit-row .deletelink-box .active.deletelink, .submit-row input.active[type='submit']:not([class*="btn-"]), .submit-row input.active[type='button']:not([class*="btn-"]), .submit-row button.active:not([class*="btn-"]), #content-main > .object-tools > li > a.active:not([class*="btn-"]), body.login .submit-row input.active[type='submit'], #changelist #toolbar #changelist-search input.active[type='submit'], #changelist #changelist-form .actions button.active, #changelist #changelist-form .paginator input.active[type='submit'] {
    background-image: none;
    outline: 0;
}

.btn.disabled, body.delete-confirmation .content-wrap input.disabled[type='button'], body.delete-confirmation .content-wrap input.disabled[type='submit'], body.delete-confirmation .content-wrap button.disabled, .submit-row .deletelink-box .disabled.deletelink, .submit-row input.disabled[type='submit']:not([class*="btn-"]), .submit-row input.disabled[type='button']:not([class*="btn-"]), .submit-row button.disabled:not([class*="btn-"]), #content-main > .object-tools > li > a.disabled:not([class*="btn-"]), body.login .submit-row input.disabled[type='submit'], #changelist #toolbar #changelist-search input.disabled[type='submit'], #changelist #changelist-form .actions button.disabled, #changelist #changelist-form .paginator input.disabled[type='submit'], .btn:disabled, body.delete-confirmation .content-wrap input[type='button']:disabled, body.delete-confirmation .content-wrap input[type='submit']:disabled, body.delete-confirmation .content-wrap button:disabled, .submit-row .deletelink-box .deletelink:disabled, .submit-row input[type='submit']:disabled:not([class*="btn-"]), .submit-row input[type='button']:disabled:not([class*="btn-"]), .submit-row button:disabled:not([class*="btn-"]), #content-main > .object-tools > li > a:disabled:not([class*="btn-"]), body.login .submit-row input[type='submit']:disabled, #changelist #toolbar #changelist-search input[type='submit']:disabled, #changelist #changelist-form .actions button:disabled, #changelist #changelist-form .paginator input[type='submit']:disabled {
    cursor: not-allowed;
    opacity: .65;
}

a.btn.disabled, .submit-row .deletelink-box a.disabled.deletelink, #content-main > .object-tools > li > a.disabled:not([class*="btn-"]), fieldset[disabled] a.btn, fieldset[disabled] .submit-row .deletelink-box a.deletelink, .submit-row .deletelink-box fieldset[disabled] a.deletelink, fieldset[disabled] #content-main > .object-tools > li > a:not([class*="btn-"]) {
    pointer-events: none;
}

.btn-primary, .submit-row input[type='submit']:not([class*="btn-"]):first-child, .submit-row input[type='button']:not([class*="btn-"]):first-child, .submit-row button:not([class*="btn-"]):first-child, body.login .submit-row input[type='submit'], #changelist #toolbar #changelist-search input[type='submit'], #changelist #changelist-form .actions button, #changelist #changelist-form .paginator input[type='submit'] {
    color: #fff;
    background-color: #237919;
    border-color: #103e0d;
}

.btn-primary:hover, .submit-row input[type='submit']:hover:not([class*="btn-"]):first-child, .submit-row input[type='button']:hover:not([class*="btn-"]):first-child, .submit-row button:hover:not([class*="btn-"]):first-child, body.login .submit-row input[type='submit']:hover, #changelist #toolbar #changelist-search input[type='submit']:hover, #changelist #changelist-form .actions button:hover, #changelist #changelist-form .paginator input[type='submit']:hover {
    color: #fff;
    background-color: #237fca;
    border-color: #227ac1;
}

.btn-primary:focus, .submit-row input[type='submit']:focus:not([class*="btn-"]):first-child, .submit-row input[type='button']:focus:not([class*="btn-"]):first-child, .submit-row button:focus:not([class*="btn-"]):first-child, body.login .submit-row input[type='submit']:focus, #changelist #toolbar #changelist-search input[type='submit']:focus, #changelist #changelist-form .actions button:focus, #changelist #changelist-form .paginator input[type='submit']:focus, .btn-primary.focus, .submit-row input.focus[type='submit']:not([class*="btn-"]):first-child, .submit-row input.focus[type='button']:not([class*="btn-"]):first-child, .submit-row button.focus:not([class*="btn-"]):first-child, body.login .submit-row input.focus[type='submit'], #changelist #toolbar #changelist-search input.focus[type='submit'], #changelist #changelist-form .actions button.focus, #changelist #changelist-form .paginator input.focus[type='submit'] {
    color: #fff;
    background-color: #237fca;
    border-color: #227ac1;
}

.btn-primary:active, .submit-row input[type='submit']:active:not([class*="btn-"]):first-child, .submit-row input[type='button']:active:not([class*="btn-"]):first-child, .submit-row button:active:not([class*="btn-"]):first-child, body.login .submit-row input[type='submit']:active, #changelist #toolbar #changelist-search input[type='submit']:active, #changelist #changelist-form .actions button:active, #changelist #changelist-form .paginator input[type='submit']:active, .btn-primary.active, .submit-row input.active[type='submit']:not([class*="btn-"]):first-child, .submit-row input.active[type='button']:not([class*="btn-"]):first-child, .submit-row button.active:not([class*="btn-"]):first-child, body.login .submit-row input.active[type='submit'], #changelist #toolbar #changelist-search input.active[type='submit'], #changelist #changelist-form .actions button.active, #changelist #changelist-form .paginator input.active[type='submit'], .open > .btn-primary.dropdown-toggle, .submit-row .open > input.dropdown-toggle[type='submit']:not([class*="btn-"]):first-child, .submit-row .open > input.dropdown-toggle[type='button']:not([class*="btn-"]):first-child, .submit-row .open > button.dropdown-toggle:not([class*="btn-"]):first-child, body.login .submit-row .open > input.dropdown-toggle[type='submit'], #changelist #toolbar #changelist-search .open > input.dropdown-toggle[type='submit'], #changelist #changelist-form .actions .open > button.dropdown-toggle, #changelist #changelist-form .paginator .open > input.dropdown-toggle[type='submit'] {
    color: #fff;
    background-color: #237fca;
    border-color: #227ac1;
    background-image: none;
}

.btn-primary:active:hover, .submit-row input[type='submit']:active:hover:not([class*="btn-"]):first-child, .submit-row input[type='button']:active:hover:not([class*="btn-"]):first-child, .submit-row button:active:hover:not([class*="btn-"]):first-child, body.login .submit-row input[type='submit']:active:hover, #changelist #toolbar #changelist-search input[type='submit']:active:hover, #changelist #changelist-form .actions button:active:hover, #changelist #changelist-form .paginator input[type='submit']:active:hover, .btn-primary:active:focus, .submit-row input[type='submit']:active:focus:not([class*="btn-"]):first-child, .submit-row input[type='button']:active:focus:not([class*="btn-"]):first-child, .submit-row button:active:focus:not([class*="btn-"]):first-child, body.login .submit-row input[type='submit']:active:focus, #changelist #toolbar #changelist-search input[type='submit']:active:focus, #changelist #changelist-form .actions button:active:focus, #changelist #changelist-form .paginator input[type='submit']:active:focus, .btn-primary:active.focus, .submit-row input[type='submit']:active.focus:not([class*="btn-"]):first-child, .submit-row input[type='button']:active.focus:not([class*="btn-"]):first-child, .submit-row button:active.focus:not([class*="btn-"]):first-child, body.login .submit-row input[type='submit']:active.focus, #changelist #toolbar #changelist-search input[type='submit']:active.focus, #changelist #changelist-form .actions button:active.focus, #changelist #changelist-form .paginator input[type='submit']:active.focus, .btn-primary.active:hover, .submit-row input.active[type='submit']:hover:not([class*="btn-"]):first-child, .submit-row input.active[type='button']:hover:not([class*="btn-"]):first-child, .submit-row button.active:hover:not([class*="btn-"]):first-child, body.login .submit-row input.active[type='submit']:hover, #changelist #toolbar #changelist-search input.active[type='submit']:hover, #changelist #changelist-form .actions button.active:hover, #changelist #changelist-form .paginator input.active[type='submit']:hover, .btn-primary.active:focus, .submit-row input.active[type='submit']:focus:not([class*="btn-"]):first-child, .submit-row input.active[type='button']:focus:not([class*="btn-"]):first-child, .submit-row button.active:focus:not([class*="btn-"]):first-child, body.login .submit-row input.active[type='submit']:focus, #changelist #toolbar #changelist-search input.active[type='submit']:focus, #changelist #changelist-form .actions button.active:focus, #changelist #changelist-form .paginator input.active[type='submit']:focus, .btn-primary.active.focus, .submit-row input.active.focus[type='submit']:not([class*="btn-"]):first-child, .submit-row input.active.focus[type='button']:not([class*="btn-"]):first-child, .submit-row button.active.focus:not([class*="btn-"]):first-child, body.login .submit-row input.active.focus[type='submit'], #changelist #toolbar #changelist-search input.active.focus[type='submit'], #changelist #changelist-form .actions button.active.focus, #changelist #changelist-form .paginator input.active.focus[type='submit'], .open > .btn-primary.dropdown-toggle:hover, .submit-row .open > input.dropdown-toggle[type='submit']:hover:not([class*="btn-"]):first-child, .submit-row .open > input.dropdown-toggle[type='button']:hover:not([class*="btn-"]):first-child, .submit-row .open > button.dropdown-toggle:hover:not([class*="btn-"]):first-child, body.login .submit-row .open > input.dropdown-toggle[type='submit']:hover, #changelist #toolbar #changelist-search .open > input.dropdown-toggle[type='submit']:hover, #changelist #changelist-form .actions .open > button.dropdown-toggle:hover, #changelist #changelist-form .paginator .open > input.dropdown-toggle[type='submit']:hover, .open > .btn-primary.dropdown-toggle:focus, .submit-row .open > input.dropdown-toggle[type='submit']:focus:not([class*="btn-"]):first-child, .submit-row .open > input.dropdown-toggle[type='button']:focus:not([class*="btn-"]):first-child, .submit-row .open > button.dropdown-toggle:focus:not([class*="btn-"]):first-child, body.login .submit-row .open > input.dropdown-toggle[type='submit']:focus, #changelist #toolbar #changelist-search .open > input.dropdown-toggle[type='submit']:focus, #changelist #changelist-form .actions .open > button.dropdown-toggle:focus, #changelist #changelist-form .paginator .open > input.dropdown-toggle[type='submit']:focus, .open > .btn-primary.dropdown-toggle.focus, .submit-row .open > input.dropdown-toggle.focus[type='submit']:not([class*="btn-"]):first-child, .submit-row .open > input.dropdown-toggle.focus[type='button']:not([class*="btn-"]):first-child, .submit-row .open > button.dropdown-toggle.focus:not([class*="btn-"]):first-child, body.login .submit-row .open > input.dropdown-toggle.focus[type='submit'], #changelist #toolbar #changelist-search .open > input.dropdown-toggle.focus[type='submit'], #changelist #changelist-form .actions .open > button.dropdown-toggle.focus, #changelist #changelist-form .paginator .open > input.dropdown-toggle.focus[type='submit'] {
    color: #fff;
    background-color: #1e6cab;
    border-color: #185689;
}

.btn-primary.disabled:focus, .submit-row input.disabled[type='submit']:focus:not([class*="btn-"]):first-child, .submit-row input.disabled[type='button']:focus:not([class*="btn-"]):first-child, .submit-row button.disabled:focus:not([class*="btn-"]):first-child, body.login .submit-row input.disabled[type='submit']:focus, #changelist #toolbar #changelist-search input.disabled[type='submit']:focus, #changelist #changelist-form .actions button.disabled:focus, #changelist #changelist-form .paginator input.disabled[type='submit']:focus, .btn-primary.disabled.focus, .submit-row input.disabled.focus[type='submit']:not([class*="btn-"]):first-child, .submit-row input.disabled.focus[type='button']:not([class*="btn-"]):first-child, .submit-row button.disabled.focus:not([class*="btn-"]):first-child, body.login .submit-row input.disabled.focus[type='submit'], #changelist #toolbar #changelist-search input.disabled.focus[type='submit'], #changelist #changelist-form .actions button.disabled.focus, #changelist #changelist-form .paginator input.disabled.focus[type='submit'], .btn-primary:disabled:focus, .submit-row input[type='submit']:disabled:focus:not([class*="btn-"]):first-child, .submit-row input[type='button']:disabled:focus:not([class*="btn-"]):first-child, .submit-row button:disabled:focus:not([class*="btn-"]):first-child, body.login .submit-row input[type='submit']:disabled:focus, #changelist #toolbar #changelist-search input[type='submit']:disabled:focus, #changelist #changelist-form .actions button:disabled:focus, #changelist #changelist-form .paginator input[type='submit']:disabled:focus, .btn-primary:disabled.focus, .submit-row input[type='submit']:disabled.focus:not([class*="btn-"]):first-child, .submit-row input[type='button']:disabled.focus:not([class*="btn-"]):first-child, .submit-row button:disabled.focus:not([class*="btn-"]):first-child, body.login .submit-row input[type='submit']:disabled.focus, #changelist #toolbar #changelist-search input[type='submit']:disabled.focus, #changelist #changelist-form .actions button:disabled.focus, #changelist #changelist-form .paginator input[type='submit']:disabled.focus {
    background-color: #4298DE;
    border-color: #4298DE;
}

.btn-primary.disabled:hover, .submit-row input.disabled[type='submit']:hover:not([class*="btn-"]):first-child, .submit-row input.disabled[type='button']:hover:not([class*="btn-"]):first-child, .submit-row button.disabled:hover:not([class*="btn-"]):first-child, body.login .submit-row input.disabled[type='submit']:hover, #changelist #toolbar #changelist-search input.disabled[type='submit']:hover, #changelist #changelist-form .actions button.disabled:hover, #changelist #changelist-form .paginator input.disabled[type='submit']:hover, .btn-primary:disabled:hover, .submit-row input[type='submit']:disabled:hover:not([class*="btn-"]):first-child, .submit-row input[type='button']:disabled:hover:not([class*="btn-"]):first-child, .submit-row button:disabled:hover:not([class*="btn-"]):first-child, body.login .submit-row input[type='submit']:disabled:hover, #changelist #toolbar #changelist-search input[type='submit']:disabled:hover, #changelist #changelist-form .actions button:disabled:hover, #changelist #changelist-form .paginator input[type='submit']:disabled:hover {
    background-color: #4298DE;
    border-color: #4298DE;
}

.btn-secondary, body.delete-confirmation .content-wrap input[type='button'], body.delete-confirmation .content-wrap button, .submit-row input[type='submit']:not([class*="btn-"]), .submit-row input[type='button']:not([class*="btn-"]), .submit-row button:not([class*="btn-"]), #changelist #changelist-form .actions button {
    color: #373a3c;
    background-color: #fff;
    border-color: #ccc;
}

.btn-secondary:hover, body.delete-confirmation .content-wrap input[type='button']:hover, body.delete-confirmation .content-wrap button:hover, .submit-row input[type='submit']:hover:not([class*="btn-"]), .submit-row input[type='button']:hover:not([class*="btn-"]), .submit-row button:hover:not([class*="btn-"]), #changelist #changelist-form .actions button:hover {
    color: #373a3c;
    background-color: #e6e6e6;
    border-color: #adadad;
}

.btn-secondary:focus, body.delete-confirmation .content-wrap input[type='button']:focus, body.delete-confirmation .content-wrap button:focus, .submit-row input[type='submit']:focus:not([class*="btn-"]), .submit-row input[type='button']:focus:not([class*="btn-"]), .submit-row button:focus:not([class*="btn-"]), #changelist #changelist-form .actions button:focus, .btn-secondary.focus, body.delete-confirmation .content-wrap input.focus[type='button'], body.delete-confirmation .content-wrap button.focus, .submit-row input.focus[type='submit']:not([class*="btn-"]), .submit-row input.focus[type='button']:not([class*="btn-"]), .submit-row button.focus:not([class*="btn-"]), #changelist #changelist-form .actions button.focus {
    color: #373a3c;
    background-color: #e6e6e6;
    border-color: #adadad;
}

.btn-secondary:active, body.delete-confirmation .content-wrap input[type='button']:active, body.delete-confirmation .content-wrap button:active, .submit-row input[type='submit']:active:not([class*="btn-"]), .submit-row input[type='button']:active:not([class*="btn-"]), .submit-row button:active:not([class*="btn-"]), #changelist #changelist-form .actions button:active, .btn-secondary.active, body.delete-confirmation .content-wrap input.active[type='button'], body.delete-confirmation .content-wrap button.active, .submit-row input.active[type='submit']:not([class*="btn-"]), .submit-row input.active[type='button']:not([class*="btn-"]), .submit-row button.active:not([class*="btn-"]), #changelist #changelist-form .actions button.active, .open > .btn-secondary.dropdown-toggle, body.delete-confirmation .content-wrap .open > input.dropdown-toggle[type='button'], body.delete-confirmation .content-wrap .open > button.dropdown-toggle, .submit-row .open > input.dropdown-toggle[type='submit']:not([class*="btn-"]), .submit-row .open > input.dropdown-toggle[type='button']:not([class*="btn-"]), .submit-row .open > button.dropdown-toggle:not([class*="btn-"]), #changelist #changelist-form .actions .open > button.dropdown-toggle {
    color: #373a3c;
    background-color: #e6e6e6;
    border-color: #adadad;
    background-image: none;
}

.btn-secondary:active:hover, body.delete-confirmation .content-wrap input[type='button']:active:hover, body.delete-confirmation .content-wrap button:active:hover, .submit-row input[type='submit']:active:hover:not([class*="btn-"]), .submit-row input[type='button']:active:hover:not([class*="btn-"]), .submit-row button:active:hover:not([class*="btn-"]), #changelist #changelist-form .actions button:active:hover, .btn-secondary:active:focus, body.delete-confirmation .content-wrap input[type='button']:active:focus, body.delete-confirmation .content-wrap button:active:focus, .submit-row input[type='submit']:active:focus:not([class*="btn-"]), .submit-row input[type='button']:active:focus:not([class*="btn-"]), .submit-row button:active:focus:not([class*="btn-"]), #changelist #changelist-form .actions button:active:focus, .btn-secondary:active.focus, body.delete-confirmation .content-wrap input[type='button']:active.focus, body.delete-confirmation .content-wrap button:active.focus, .submit-row input[type='submit']:active.focus:not([class*="btn-"]), .submit-row input[type='button']:active.focus:not([class*="btn-"]), .submit-row button:active.focus:not([class*="btn-"]), #changelist #changelist-form .actions button:active.focus, .btn-secondary.active:hover, body.delete-confirmation .content-wrap input.active[type='button']:hover, body.delete-confirmation .content-wrap button.active:hover, .submit-row input.active[type='submit']:hover:not([class*="btn-"]), .submit-row input.active[type='button']:hover:not([class*="btn-"]), .submit-row button.active:hover:not([class*="btn-"]), #changelist #changelist-form .actions button.active:hover, .btn-secondary.active:focus, body.delete-confirmation .content-wrap input.active[type='button']:focus, body.delete-confirmation .content-wrap button.active:focus, .submit-row input.active[type='submit']:focus:not([class*="btn-"]), .submit-row input.active[type='button']:focus:not([class*="btn-"]), .submit-row button.active:focus:not([class*="btn-"]), #changelist #changelist-form .actions button.active:focus, .btn-secondary.active.focus, body.delete-confirmation .content-wrap input.active.focus[type='button'], body.delete-confirmation .content-wrap button.active.focus, .submit-row input.active.focus[type='submit']:not([class*="btn-"]), .submit-row input.active.focus[type='button']:not([class*="btn-"]), .submit-row button.active.focus:not([class*="btn-"]), #changelist #changelist-form .actions button.active.focus, .open > .btn-secondary.dropdown-toggle:hover, body.delete-confirmation .content-wrap .open > input.dropdown-toggle[type='button']:hover, body.delete-confirmation .content-wrap .open > button.dropdown-toggle:hover, .submit-row .open > input.dropdown-toggle[type='submit']:hover:not([class*="btn-"]), .submit-row .open > input.dropdown-toggle[type='button']:hover:not([class*="btn-"]), .submit-row .open > button.dropdown-toggle:hover:not([class*="btn-"]), #changelist #changelist-form .actions .open > button.dropdown-toggle:hover, .open > .btn-secondary.dropdown-toggle:focus, body.delete-confirmation .content-wrap .open > input.dropdown-toggle[type='button']:focus, body.delete-confirmation .content-wrap .open > button.dropdown-toggle:focus, .submit-row .open > input.dropdown-toggle[type='submit']:focus:not([class*="btn-"]), .submit-row .open > input.dropdown-toggle[type='button']:focus:not([class*="btn-"]), .submit-row .open > button.dropdown-toggle:focus:not([class*="btn-"]), #changelist #changelist-form .actions .open > button.dropdown-toggle:focus, .open > .btn-secondary.dropdown-toggle.focus, body.delete-confirmation .content-wrap .open > input.dropdown-toggle.focus[type='button'], body.delete-confirmation .content-wrap .open > button.dropdown-toggle.focus, .submit-row .open > input.dropdown-toggle.focus[type='submit']:not([class*="btn-"]), .submit-row .open > input.dropdown-toggle.focus[type='button']:not([class*="btn-"]), .submit-row .open > button.dropdown-toggle.focus:not([class*="btn-"]), #changelist #changelist-form .actions .open > button.dropdown-toggle.focus {
    color: #373a3c;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
}

.btn-secondary.disabled:focus, body.delete-confirmation .content-wrap input.disabled[type='button']:focus, body.delete-confirmation .content-wrap button.disabled:focus, .submit-row input.disabled[type='submit']:focus:not([class*="btn-"]), .submit-row input.disabled[type='button']:focus:not([class*="btn-"]), .submit-row button.disabled:focus:not([class*="btn-"]), #changelist #changelist-form .actions button.disabled:focus, .btn-secondary.disabled.focus, body.delete-confirmation .content-wrap input.disabled.focus[type='button'], body.delete-confirmation .content-wrap button.disabled.focus, .submit-row input.disabled.focus[type='submit']:not([class*="btn-"]), .submit-row input.disabled.focus[type='button']:not([class*="btn-"]), .submit-row button.disabled.focus:not([class*="btn-"]), #changelist #changelist-form .actions button.disabled.focus, .btn-secondary:disabled:focus, body.delete-confirmation .content-wrap input[type='button']:disabled:focus, body.delete-confirmation .content-wrap button:disabled:focus, .submit-row input[type='submit']:disabled:focus:not([class*="btn-"]), .submit-row input[type='button']:disabled:focus:not([class*="btn-"]), .submit-row button:disabled:focus:not([class*="btn-"]), #changelist #changelist-form .actions button:disabled:focus, .btn-secondary:disabled.focus, body.delete-confirmation .content-wrap input[type='button']:disabled.focus, body.delete-confirmation .content-wrap button:disabled.focus, .submit-row input[type='submit']:disabled.focus:not([class*="btn-"]), .submit-row input[type='button']:disabled.focus:not([class*="btn-"]), .submit-row button:disabled.focus:not([class*="btn-"]), #changelist #changelist-form .actions button:disabled.focus {
    background-color: #fff;
    border-color: #ccc;
}

.btn-secondary.disabled:hover, body.delete-confirmation .content-wrap input.disabled[type='button']:hover, body.delete-confirmation .content-wrap button.disabled:hover, .submit-row input.disabled[type='submit']:hover:not([class*="btn-"]), .submit-row input.disabled[type='button']:hover:not([class*="btn-"]), .submit-row button.disabled:hover:not([class*="btn-"]), #changelist #changelist-form .actions button.disabled:hover, .btn-secondary:disabled:hover, body.delete-confirmation .content-wrap input[type='button']:disabled:hover, body.delete-confirmation .content-wrap button:disabled:hover, .submit-row input[type='submit']:disabled:hover:not([class*="btn-"]), .submit-row input[type='button']:disabled:hover:not([class*="btn-"]), .submit-row button:disabled:hover:not([class*="btn-"]), #changelist #changelist-form .actions button:disabled:hover {
    background-color: #fff;
    border-color: #ccc;
}

.btn-info, #content-main > .object-tools > li > a:not([class*="btn-"]) {
    color: #fff;
    background-color: #5bc0de;
    border-color: #5bc0de;
}

.btn-info:hover, #content-main > .object-tools > li > a:hover:not([class*="btn-"]) {
    color: #fff;
    background-color: #31b0d5;
    border-color: #2aabd2;
}

.btn-info:focus, #content-main > .object-tools > li > a:focus:not([class*="btn-"]), .btn-info.focus, #content-main > .object-tools > li > a.focus:not([class*="btn-"]) {
    color: #fff;
    background-color: #31b0d5;
    border-color: #2aabd2;
}

.btn-info:active, #content-main > .object-tools > li > a:active:not([class*="btn-"]), .btn-info.active, #content-main > .object-tools > li > a.active:not([class*="btn-"]), .open > .btn-info.dropdown-toggle, #content-main > .object-tools > li.open > a.dropdown-toggle:not([class*="btn-"]) {
    color: #fff;
    background-color: #31b0d5;
    border-color: #2aabd2;
    background-image: none;
}

.btn-info:active:hover, #content-main > .object-tools > li > a:active:hover:not([class*="btn-"]), .btn-info:active:focus, #content-main > .object-tools > li > a:active:focus:not([class*="btn-"]), .btn-info:active.focus, #content-main > .object-tools > li > a:active.focus:not([class*="btn-"]), .btn-info.active:hover, #content-main > .object-tools > li > a.active:hover:not([class*="btn-"]), .btn-info.active:focus, #content-main > .object-tools > li > a.active:focus:not([class*="btn-"]), .btn-info.active.focus, #content-main > .object-tools > li > a.active.focus:not([class*="btn-"]), .open > .btn-info.dropdown-toggle:hover, #content-main > .object-tools > li.open > a.dropdown-toggle:hover:not([class*="btn-"]), .open > .btn-info.dropdown-toggle:focus, #content-main > .object-tools > li.open > a.dropdown-toggle:focus:not([class*="btn-"]), .open > .btn-info.dropdown-toggle.focus, #content-main > .object-tools > li.open > a.dropdown-toggle.focus:not([class*="btn-"]) {
    color: #fff;
    background-color: #269abc;
    border-color: #1f7e9a;
}

.btn-info.disabled:focus, #content-main > .object-tools > li > a.disabled:focus:not([class*="btn-"]), .btn-info.disabled.focus, #content-main > .object-tools > li > a.disabled.focus:not([class*="btn-"]), .btn-info:disabled:focus, #content-main > .object-tools > li > a:disabled:focus:not([class*="btn-"]), .btn-info:disabled.focus, #content-main > .object-tools > li > a:disabled.focus:not([class*="btn-"]) {
    background-color: #5bc0de;
    border-color: #5bc0de;
}

.btn-info.disabled:hover, #content-main > .object-tools > li > a.disabled:hover:not([class*="btn-"]), .btn-info:disabled:hover, #content-main > .object-tools > li > a:disabled:hover:not([class*="btn-"]) {
    background-color: #5bc0de;
    border-color: #5bc0de;
}

.btn-success, #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) {
    color: #fff;
    background-color: #4ACB68;
    border-color: #4ACB68;
}

.btn-success:hover, #content-main > .object-tools > li > a.addlink:hover:not([class*="btn-"]) {
    color: #fff;
    background-color: #32b050;
    border-color: #30a84c;
}

.btn-success:focus, #content-main > .object-tools > li > a.addlink:focus:not([class*="btn-"]), .btn-success.focus, #content-main > .object-tools > li > a.focus.addlink:not([class*="btn-"]) {
    color: #fff;
    background-color: #32b050;
    border-color: #30a84c;
}

.btn-success:active, #content-main > .object-tools > li > a.addlink:active:not([class*="btn-"]), .btn-success.active, #content-main > .object-tools > li > a.active.addlink:not([class*="btn-"]), .open > .btn-success.dropdown-toggle, #content-main > .object-tools > li.open > a.dropdown-toggle.addlink:not([class*="btn-"]) {
    color: #fff;
    background-color: #32b050;
    border-color: #30a84c;
    background-image: none;
}

.btn-success:active:hover, #content-main > .object-tools > li > a.addlink:active:hover:not([class*="btn-"]), .btn-success:active:focus, #content-main > .object-tools > li > a.addlink:active:focus:not([class*="btn-"]), .btn-success:active.focus, #content-main > .object-tools > li > a.addlink:active.focus:not([class*="btn-"]), .btn-success.active:hover, #content-main > .object-tools > li > a.active.addlink:hover:not([class*="btn-"]), .btn-success.active:focus, #content-main > .object-tools > li > a.active.addlink:focus:not([class*="btn-"]), .btn-success.active.focus, #content-main > .object-tools > li > a.active.focus.addlink:not([class*="btn-"]), .open > .btn-success.dropdown-toggle:hover, #content-main > .object-tools > li.open > a.dropdown-toggle.addlink:hover:not([class*="btn-"]), .open > .btn-success.dropdown-toggle:focus, #content-main > .object-tools > li.open > a.dropdown-toggle.addlink:focus:not([class*="btn-"]), .open > .btn-success.dropdown-toggle.focus, #content-main > .object-tools > li.open > a.dropdown-toggle.focus.addlink:not([class*="btn-"]) {
    color: #fff;
    background-color: #2a9443;
    border-color: #217435;
}

.btn-success.disabled:focus, #content-main > .object-tools > li > a.disabled.addlink:focus:not([class*="btn-"]), .btn-success.disabled.focus, #content-main > .object-tools > li > a.disabled.focus.addlink:not([class*="btn-"]), .btn-success:disabled:focus, #content-main > .object-tools > li > a.addlink:disabled:focus:not([class*="btn-"]), .btn-success:disabled.focus, #content-main > .object-tools > li > a.addlink:disabled.focus:not([class*="btn-"]) {
    background-color: #4ACB68;
    border-color: #4ACB68;
}

.btn-success.disabled:hover, #content-main > .object-tools > li > a.disabled.addlink:hover:not([class*="btn-"]), .btn-success:disabled:hover, #content-main > .object-tools > li > a.addlink:disabled:hover:not([class*="btn-"]) {
    background-color: #4ACB68;
    border-color: #4ACB68;
}

.btn-warning {
    color: #fff;
    background-color: #F3C544;
    border-color: #F3C544;
}

.btn-warning:hover {
    color: #fff;
    background-color: #f0b614;
    border-color: #ebb10f;
}

.btn-warning:focus, .btn-warning.focus {
    color: #fff;
    background-color: #f0b614;
    border-color: #ebb10f;
}

.btn-warning:active, .btn-warning.active, .open > .btn-warning.dropdown-toggle {
    color: #fff;
    background-color: #f0b614;
    border-color: #ebb10f;
    background-image: none;
}

.btn-warning:active:hover, .btn-warning:active:focus, .btn-warning:active.focus, .btn-warning.active:hover, .btn-warning.active:focus, .btn-warning.active.focus, .open > .btn-warning.dropdown-toggle:hover, .open > .btn-warning.dropdown-toggle:focus, .open > .btn-warning.dropdown-toggle.focus {
    color: #fff;
    background-color: #d39f0e;
    border-color: #ac820b;
}

.btn-warning.disabled:focus, .btn-warning.disabled.focus, .btn-warning:disabled:focus, .btn-warning:disabled.focus {
    background-color: #F3C544;
    border-color: #F3C544;
}

.btn-warning.disabled:hover, .btn-warning:disabled:hover {
    background-color: #F3C544;
    border-color: #F3C544;
}

.btn-danger, body.delete-confirmation .content-wrap input[type='submit'] {
    color: #fff;
    background-color: #E04F3C;
    border-color: #E04F3C;
}

.btn-danger:hover, body.delete-confirmation .content-wrap input[type='submit']:hover {
    color: #fff;
    background-color: #c93420;
    border-color: #c0311f;
}

.btn-danger:focus, body.delete-confirmation .content-wrap input[type='submit']:focus, .btn-danger.focus, body.delete-confirmation .content-wrap input.focus[type='submit'] {
    color: #fff;
    background-color: #c93420;
    border-color: #c0311f;
}

.btn-danger:active, body.delete-confirmation .content-wrap input[type='submit']:active, .btn-danger.active, body.delete-confirmation .content-wrap input.active[type='submit'], .open > .btn-danger.dropdown-toggle, body.delete-confirmation .content-wrap .open > input.dropdown-toggle[type='submit'] {
    color: #fff;
    background-color: #c93420;
    border-color: #c0311f;
    background-image: none;
}

.btn-danger:active:hover, body.delete-confirmation .content-wrap input[type='submit']:active:hover, .btn-danger:active:focus, body.delete-confirmation .content-wrap input[type='submit']:active:focus, .btn-danger:active.focus, body.delete-confirmation .content-wrap input[type='submit']:active.focus, .btn-danger.active:hover, body.delete-confirmation .content-wrap input.active[type='submit']:hover, .btn-danger.active:focus, body.delete-confirmation .content-wrap input.active[type='submit']:focus, .btn-danger.active.focus, body.delete-confirmation .content-wrap input.active.focus[type='submit'], .open > .btn-danger.dropdown-toggle:hover, body.delete-confirmation .content-wrap .open > input.dropdown-toggle[type='submit']:hover, .open > .btn-danger.dropdown-toggle:focus, body.delete-confirmation .content-wrap .open > input.dropdown-toggle[type='submit']:focus, .open > .btn-danger.dropdown-toggle.focus, body.delete-confirmation .content-wrap .open > input.dropdown-toggle.focus[type='submit'] {
    color: #fff;
    background-color: #aa2c1b;
    border-color: #872315;
}

.btn-danger.disabled:focus, body.delete-confirmation .content-wrap input.disabled[type='submit']:focus, .btn-danger.disabled.focus, body.delete-confirmation .content-wrap input.disabled.focus[type='submit'], .btn-danger:disabled:focus, body.delete-confirmation .content-wrap input[type='submit']:disabled:focus, .btn-danger:disabled.focus, body.delete-confirmation .content-wrap input[type='submit']:disabled.focus {
    background-color: #E04F3C;
    border-color: #E04F3C;
}

.btn-danger.disabled:hover, body.delete-confirmation .content-wrap input.disabled[type='submit']:hover, .btn-danger:disabled:hover, body.delete-confirmation .content-wrap input[type='submit']:disabled:hover {
    background-color: #E04F3C;
    border-color: #E04F3C;
}

.btn-outline-primary {
    color: #4298DE;
    background-image: none;
    background-color: transparent;
    border-color: #4298DE;
}

.btn-outline-primary:hover {
    color: #fff;
    background-color: #4298DE;
    border-color: #4298DE;
}

.btn-outline-primary:focus, .btn-outline-primary.focus {
    color: #fff;
    background-color: #4298DE;
    border-color: #4298DE;
}

.btn-outline-primary:active, .btn-outline-primary.active, .open > .btn-outline-primary.dropdown-toggle {
    color: #fff;
    background-color: #4298DE;
    border-color: #4298DE;
}

.btn-outline-primary:active:hover, .btn-outline-primary:active:focus, .btn-outline-primary:active.focus, .btn-outline-primary.active:hover, .btn-outline-primary.active:focus, .btn-outline-primary.active.focus, .open > .btn-outline-primary.dropdown-toggle:hover, .open > .btn-outline-primary.dropdown-toggle:focus, .open > .btn-outline-primary.dropdown-toggle.focus {
    color: #fff;
    background-color: #1e6cab;
    border-color: #185689;
}

.btn-outline-primary.disabled:focus, .btn-outline-primary.disabled.focus, .btn-outline-primary:disabled:focus, .btn-outline-primary:disabled.focus {
    border-color: #99c7ed;
}

.btn-outline-primary.disabled:hover, .btn-outline-primary:disabled:hover {
    border-color: #99c7ed;
}

.btn-outline-secondary {
    color: #ccc;
    background-image: none;
    background-color: transparent;
    border-color: #ccc;
}

.btn-outline-secondary:hover {
    color: #fff;
    background-color: #ccc;
    border-color: #ccc;
}

.btn-outline-secondary:focus, .btn-outline-secondary.focus {
    color: #fff;
    background-color: #ccc;
    border-color: #ccc;
}

.btn-outline-secondary:active, .btn-outline-secondary.active, .open > .btn-outline-secondary.dropdown-toggle {
    color: #fff;
    background-color: #ccc;
    border-color: #ccc;
}

.btn-outline-secondary:active:hover, .btn-outline-secondary:active:focus, .btn-outline-secondary:active.focus, .btn-outline-secondary.active:hover, .btn-outline-secondary.active:focus, .btn-outline-secondary.active.focus, .open > .btn-outline-secondary.dropdown-toggle:hover, .open > .btn-outline-secondary.dropdown-toggle:focus, .open > .btn-outline-secondary.dropdown-toggle.focus {
    color: #fff;
    background-color: #a1a1a1;
    border-color: #8c8c8c;
}

.btn-outline-secondary.disabled:focus, .btn-outline-secondary.disabled.focus, .btn-outline-secondary:disabled:focus, .btn-outline-secondary:disabled.focus {
    border-color: white;
}

.btn-outline-secondary.disabled:hover, .btn-outline-secondary:disabled:hover {
    border-color: white;
}

.btn-outline-info {
    color: #5bc0de;
    background-image: none;
    background-color: transparent;
    border-color: #5bc0de;
}

.btn-outline-info:hover {
    color: #fff;
    background-color: #5bc0de;
    border-color: #5bc0de;
}

.btn-outline-info:focus, .btn-outline-info.focus {
    color: #fff;
    background-color: #5bc0de;
    border-color: #5bc0de;
}

.btn-outline-info:active, .btn-outline-info.active, .open > .btn-outline-info.dropdown-toggle {
    color: #fff;
    background-color: #5bc0de;
    border-color: #5bc0de;
}

.btn-outline-info:active:hover, .btn-outline-info:active:focus, .btn-outline-info:active.focus, .btn-outline-info.active:hover, .btn-outline-info.active:focus, .btn-outline-info.active.focus, .open > .btn-outline-info.dropdown-toggle:hover, .open > .btn-outline-info.dropdown-toggle:focus, .open > .btn-outline-info.dropdown-toggle.focus {
    color: #fff;
    background-color: #269abc;
    border-color: #1f7e9a;
}

.btn-outline-info.disabled:focus, .btn-outline-info.disabled.focus, .btn-outline-info:disabled:focus, .btn-outline-info:disabled.focus {
    border-color: #b0e1ef;
}

.btn-outline-info.disabled:hover, .btn-outline-info:disabled:hover {
    border-color: #b0e1ef;
}

.btn-outline-success {
    color: #4ACB68;
    background-image: none;
    background-color: transparent;
    border-color: #4ACB68;
}

.btn-outline-success:hover {
    color: #fff;
    background-color: #4ACB68;
    border-color: #4ACB68;
}

.btn-outline-success:focus, .btn-outline-success.focus {
    color: #fff;
    background-color: #4ACB68;
    border-color: #4ACB68;
}

.btn-outline-success:active, .btn-outline-success.active, .open > .btn-outline-success.dropdown-toggle {
    color: #fff;
    background-color: #4ACB68;
    border-color: #4ACB68;
}

.btn-outline-success:active:hover, .btn-outline-success:active:focus, .btn-outline-success:active.focus, .btn-outline-success.active:hover, .btn-outline-success.active:focus, .btn-outline-success.active.focus, .open > .btn-outline-success.dropdown-toggle:hover, .open > .btn-outline-success.dropdown-toggle:focus, .open > .btn-outline-success.dropdown-toggle.focus {
    color: #fff;
    background-color: #2a9443;
    border-color: #217435;
}

.btn-outline-success.disabled:focus, .btn-outline-success.disabled.focus, .btn-outline-success:disabled:focus, .btn-outline-success:disabled.focus {
    border-color: #99e2aa;
}

.btn-outline-success.disabled:hover, .btn-outline-success:disabled:hover {
    border-color: #99e2aa;
}

.btn-outline-warning {
    color: #F3C544;
    background-image: none;
    background-color: transparent;
    border-color: #F3C544;
}

.btn-outline-warning:hover {
    color: #fff;
    background-color: #F3C544;
    border-color: #F3C544;
}

.btn-outline-warning:focus, .btn-outline-warning.focus {
    color: #fff;
    background-color: #F3C544;
    border-color: #F3C544;
}

.btn-outline-warning:active, .btn-outline-warning.active, .open > .btn-outline-warning.dropdown-toggle {
    color: #fff;
    background-color: #F3C544;
    border-color: #F3C544;
}

.btn-outline-warning:active:hover, .btn-outline-warning:active:focus, .btn-outline-warning:active.focus, .btn-outline-warning.active:hover, .btn-outline-warning.active:focus, .btn-outline-warning.active.focus, .open > .btn-outline-warning.dropdown-toggle:hover, .open > .btn-outline-warning.dropdown-toggle:focus, .open > .btn-outline-warning.dropdown-toggle.focus {
    color: #fff;
    background-color: #d39f0e;
    border-color: #ac820b;
}

.btn-outline-warning.disabled:focus, .btn-outline-warning.disabled.focus, .btn-outline-warning:disabled:focus, .btn-outline-warning:disabled.focus {
    border-color: #f9e3a4;
}

.btn-outline-warning.disabled:hover, .btn-outline-warning:disabled:hover {
    border-color: #f9e3a4;
}

.btn-outline-danger, .submit-row .deletelink-box .deletelink {
    color: #E04F3C;
    background-image: none;
    background-color: transparent;
    border-color: #E04F3C;
}

.btn-outline-danger:hover, .submit-row .deletelink-box .deletelink:hover {
    color: #fff;
    background-color: #E04F3C;
    border-color: #E04F3C;
}

.btn-outline-danger:focus, .submit-row .deletelink-box .deletelink:focus, .btn-outline-danger.focus, .submit-row .deletelink-box .focus.deletelink {
    color: #fff;
    background-color: #E04F3C;
    border-color: #E04F3C;
}

.btn-outline-danger:active, .submit-row .deletelink-box .deletelink:active, .btn-outline-danger.active, .submit-row .deletelink-box .active.deletelink, .open > .btn-outline-danger.dropdown-toggle, .submit-row .deletelink-box .open > .dropdown-toggle.deletelink {
    color: #fff;
    background-color: #E04F3C;
    border-color: #E04F3C;
}

.btn-outline-danger:active:hover, .submit-row .deletelink-box .deletelink:active:hover, .btn-outline-danger:active:focus, .submit-row .deletelink-box .deletelink:active:focus, .btn-outline-danger:active.focus, .submit-row .deletelink-box .deletelink:active.focus, .btn-outline-danger.active:hover, .submit-row .deletelink-box .active.deletelink:hover, .btn-outline-danger.active:focus, .submit-row .deletelink-box .active.deletelink:focus, .btn-outline-danger.active.focus, .submit-row .deletelink-box .active.focus.deletelink, .open > .btn-outline-danger.dropdown-toggle:hover, .submit-row .deletelink-box .open > .dropdown-toggle.deletelink:hover, .open > .btn-outline-danger.dropdown-toggle:focus, .submit-row .deletelink-box .open > .dropdown-toggle.deletelink:focus, .open > .btn-outline-danger.dropdown-toggle.focus, .submit-row .deletelink-box .open > .dropdown-toggle.focus.deletelink {
    color: #fff;
    background-color: #aa2c1b;
    border-color: #872315;
}

.btn-outline-danger.disabled:focus, .submit-row .deletelink-box .disabled.deletelink:focus, .btn-outline-danger.disabled.focus, .submit-row .deletelink-box .disabled.focus.deletelink, .btn-outline-danger:disabled:focus, .submit-row .deletelink-box .deletelink:disabled:focus, .btn-outline-danger:disabled.focus, .submit-row .deletelink-box .deletelink:disabled.focus {
    border-color: #ee9e94;
}

.btn-outline-danger.disabled:hover, .submit-row .deletelink-box .disabled.deletelink:hover, .btn-outline-danger:disabled:hover, .submit-row .deletelink-box .deletelink:disabled:hover {
    border-color: #ee9e94;
}

.btn-link {
    font-weight: normal;
    color: #0d64a2;
    border-radius: 0;
}

.btn-link, .btn-link:active, .btn-link.active, .btn-link:disabled {
    background-color: transparent;
}

.btn-link, .btn-link:focus, .btn-link:active {
    border-color: transparent;
}

.btn-link:hover {
    border-color: transparent;
}

.btn-link:focus, .btn-link:hover {
    color: #07385b;
    text-decoration: underline;
    background-color: transparent;
}

.btn-link:disabled:focus, .btn-link:disabled:hover {
    color: #818a91;
    text-decoration: none;
}

.btn-lg, .btn-group-lg > .btn, .submit-row .deletelink-box .btn-group-lg > .deletelink, #content-main > .object-tools > li.btn-group-lg > a:not([class*="btn-"]), #changelist #toolbar #changelist-search .btn-group-lg > input[type='submit'], #changelist #changelist-form .actions .btn-group-lg > button, #changelist #changelist-form .paginator .btn-group-lg > input[type='submit'], body.delete-confirmation .content-wrap input[type='button'], body.delete-confirmation .content-wrap input[type='submit'], body.delete-confirmation .content-wrap button, .submit-row input[type='submit']:not([class*="btn-"]), .submit-row input[type='button']:not([class*="btn-"]), .submit-row button:not([class*="btn-"]), body.login .submit-row input[type='submit'] {
    font-size: 1.143rem;
    border-radius: 0.3rem;
}

.btn-sm, .btn-group-sm > .btn, body.delete-confirmation .content-wrap .btn-group-sm > input[type='button'], body.delete-confirmation .content-wrap .btn-group-sm > input[type='submit'], body.delete-confirmation .content-wrap .btn-group-sm > button, .submit-row .deletelink-box .btn-group-sm > .deletelink, .submit-row .btn-group-sm > input[type='submit']:not([class*="btn-"]), .submit-row .btn-group-sm > input[type='button']:not([class*="btn-"]), .submit-row .btn-group-sm > button:not([class*="btn-"]), body.login .submit-row .btn-group-sm > input[type='submit'], #changelist #toolbar #changelist-search .btn-group-sm > input[type='submit'], #changelist #changelist-form .actions .btn-group-sm > button, #changelist #changelist-form .paginator .btn-group-sm > input[type='submit'], #content-main > .object-tools > li > a:not([class*="btn-"]), #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) {
    padding: 0.35rem 0.75rem;
    font-size: 0.929rem;
    border-radius: 0.2rem;
}

.btn-block {
    display: block;
    width: 100%;
}

.btn-block + .btn-block {
    margin-top: 0.5rem;
}

input[type="submit"].btn-block, input[type="reset"].btn-block, input[type="button"].btn-block {
    width: 100%;
}

.fade {
    opacity: 0;
    -webkit-transition: opacity .15s linear;
    transition: opacity .15s linear;
}

.fade.in {
    opacity: 1;
}

.collapse {
    display: none;
}

.collapse.in {
    display: block;
}

tr.collapse.in {
    display: table-row;
}

tbody.collapse.in {
    display: table-row-group;
}

.collapsing {
    position: relative;
    height: 0;
    overflow: hidden;
    -webkit-transition-timing-function: ease;
    transition-timing-function: ease;
    -webkit-transition-duration: .35s;
    transition-duration: .35s;
    -webkit-transition-property: height;
    transition-property: height;
}

.dropup, .dropdown {
    position: relative;
}

.dropdown-toggle::after {
    display: inline-block;
    width: 0;
    height: 0;
    margin-left: 0.3em;
    vertical-align: middle;
    content: "";
    border-top: 0.3em solid;
    border-right: 0.3em solid transparent;
    border-left: 0.3em solid transparent;
}

.dropdown-toggle:focus {
    outline: 0;
}

.dropup .dropdown-toggle::after {
    border-top: 0;
    border-bottom: 0.3em solid;
}

.dropdown-menu {
    position: absolute;
    top: 100%;
    left: 0;
    z-index: 1000;
    display: none;
    float: left;
    min-width: 10rem;
    padding: 0.5rem 0;
    margin: 0.125rem 0 0;
    font-size: 1rem;
    color: #373a3c;
    text-align: left;
    list-style: none;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid rgba(0, 0, 0, 0.15);
    border-radius: 0.25rem;
}

.dropdown-divider {
    height: 1px;
    margin: 0.5rem 0;
    overflow: hidden;
    background-color: #e5e5e5;
}

.dropdown-item {
    display: block;
    width: 100%;
    padding: 3px 1.5rem;
    clear: both;
    font-weight: normal;
    color: #373a3c;
    text-align: inherit;
    white-space: nowrap;
    background: none;
    border: 0;
}

.dropdown-item:focus, .dropdown-item:hover {
    color: #2b2d2f;
    text-decoration: none;
    background-color: #f5f5f5;
}

.dropdown-item.active, .dropdown-item.active:focus, .dropdown-item.active:hover {
    color: #fff;
    text-decoration: none;
    background-color: #4298DE;
    outline: 0;
}

.dropdown-item.disabled, .dropdown-item.disabled:focus, .dropdown-item.disabled:hover {
    color: #818a91;
}

.dropdown-item.disabled:focus, .dropdown-item.disabled:hover {
    text-decoration: none;
    cursor: not-allowed;
    background-color: transparent;
    background-image: none;
    filter: "progid:DXImageTransform.Microsoft.gradient(enabled = false)";
}

.open > .dropdown-menu {
    display: block;
}

.open > a {
    outline: 0;
}

.dropdown-menu-right {
    right: 0;
    left: auto;
}

.dropdown-menu-left {
    right: auto;
    left: 0;
}

.dropdown-header {
    display: block;
    padding: 0.5rem 1.5rem;
    margin-bottom: 0;
    font-size: 0.929rem;
    color: #818a91;
    white-space: nowrap;
}

.dropdown-backdrop {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 990;
}

.dropup .caret, .navbar-fixed-bottom .dropdown .caret {
    content: "";
    border-top: 0;
    border-bottom: 0.3em solid;
}

.dropup .dropdown-menu, .navbar-fixed-bottom .dropdown .dropdown-menu {
    top: auto;
    bottom: 100%;
    margin-bottom: 0.125rem;
}

.btn-group, .btn-group-vertical {
    position: relative;
    display: inline-block;
    vertical-align: middle;
}

.btn-group > .btn, body.delete-confirmation .content-wrap .btn-group > input[type='button'], body.delete-confirmation .content-wrap .btn-group > input[type='submit'], body.delete-confirmation .content-wrap .btn-group > button, .submit-row .deletelink-box .btn-group > .deletelink, .submit-row .btn-group > input[type='submit']:not([class*="btn-"]), .submit-row .btn-group > input[type='button']:not([class*="btn-"]), .submit-row .btn-group > button:not([class*="btn-"]), #content-main > .object-tools > li.btn-group > a:not([class*="btn-"]), body.login .submit-row .btn-group > input[type='submit'], #changelist #toolbar #changelist-search .btn-group > input[type='submit'], #changelist #changelist-form .actions .btn-group > button, #changelist #changelist-form .paginator .btn-group > input[type='submit'], .btn-group-vertical > .btn, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'], body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'], body.delete-confirmation .content-wrap .btn-group-vertical > button, .submit-row .deletelink-box .btn-group-vertical > .deletelink, .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]), .submit-row .btn-group-vertical > button:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > input[type='submit'], #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'], #changelist #changelist-form .actions .btn-group-vertical > button, #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] {
    position: relative;
    float: left;
    margin-bottom: 0;
}

.btn-group > .btn:focus, body.delete-confirmation .content-wrap .btn-group > input[type='button']:focus, body.delete-confirmation .content-wrap .btn-group > input[type='submit']:focus, body.delete-confirmation .content-wrap .btn-group > button:focus, .submit-row .deletelink-box .btn-group > .deletelink:focus, .submit-row .btn-group > input[type='submit']:focus:not([class*="btn-"]), .submit-row .btn-group > input[type='button']:focus:not([class*="btn-"]), .submit-row .btn-group > button:focus:not([class*="btn-"]), #content-main > .object-tools > li.btn-group > a:focus:not([class*="btn-"]), body.login .submit-row .btn-group > input[type='submit']:focus, #changelist #toolbar #changelist-search .btn-group > input[type='submit']:focus, #changelist #changelist-form .actions .btn-group > button:focus, #changelist #changelist-form .paginator .btn-group > input[type='submit']:focus, .btn-group > .btn:active, body.delete-confirmation .content-wrap .btn-group > input[type='button']:active, body.delete-confirmation .content-wrap .btn-group > input[type='submit']:active, body.delete-confirmation .content-wrap .btn-group > button:active, .submit-row .deletelink-box .btn-group > .deletelink:active, .submit-row .btn-group > input[type='submit']:active:not([class*="btn-"]), .submit-row .btn-group > input[type='button']:active:not([class*="btn-"]), .submit-row .btn-group > button:active:not([class*="btn-"]), #content-main > .object-tools > li.btn-group > a:active:not([class*="btn-"]), body.login .submit-row .btn-group > input[type='submit']:active, #changelist #toolbar #changelist-search .btn-group > input[type='submit']:active, #changelist #changelist-form .actions .btn-group > button:active, #changelist #changelist-form .paginator .btn-group > input[type='submit']:active, .btn-group > .btn.active, body.delete-confirmation .content-wrap .btn-group > input.active[type='button'], body.delete-confirmation .content-wrap .btn-group > input.active[type='submit'], body.delete-confirmation .content-wrap .btn-group > button.active, .submit-row .deletelink-box .btn-group > .active.deletelink, .submit-row .btn-group > input.active[type='submit']:not([class*="btn-"]), .submit-row .btn-group > input.active[type='button']:not([class*="btn-"]), .submit-row .btn-group > button.active:not([class*="btn-"]), #content-main > .object-tools > li.btn-group > a.active:not([class*="btn-"]), body.login .submit-row .btn-group > input.active[type='submit'], #changelist #toolbar #changelist-search .btn-group > input.active[type='submit'], #changelist #changelist-form .actions .btn-group > button.active, #changelist #changelist-form .paginator .btn-group > input.active[type='submit'], .btn-group-vertical > .btn:focus, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button']:focus, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit']:focus, body.delete-confirmation .content-wrap .btn-group-vertical > button:focus, .submit-row .deletelink-box .btn-group-vertical > .deletelink:focus, .submit-row .btn-group-vertical > input[type='submit']:focus:not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='button']:focus:not([class*="btn-"]), .submit-row .btn-group-vertical > button:focus:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a:focus:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > input[type='submit']:focus, #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit']:focus, #changelist #changelist-form .actions .btn-group-vertical > button:focus, #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit']:focus, .btn-group-vertical > .btn:active, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button']:active, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit']:active, body.delete-confirmation .content-wrap .btn-group-vertical > button:active, .submit-row .deletelink-box .btn-group-vertical > .deletelink:active, .submit-row .btn-group-vertical > input[type='submit']:active:not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='button']:active:not([class*="btn-"]), .submit-row .btn-group-vertical > button:active:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a:active:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > input[type='submit']:active, #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit']:active, #changelist #changelist-form .actions .btn-group-vertical > button:active, #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit']:active, .btn-group-vertical > .btn.active, body.delete-confirmation .content-wrap .btn-group-vertical > input.active[type='button'], body.delete-confirmation .content-wrap .btn-group-vertical > input.active[type='submit'], body.delete-confirmation .content-wrap .btn-group-vertical > button.active, .submit-row .deletelink-box .btn-group-vertical > .active.deletelink, .submit-row .btn-group-vertical > input.active[type='submit']:not([class*="btn-"]), .submit-row .btn-group-vertical > input.active[type='button']:not([class*="btn-"]), .submit-row .btn-group-vertical > button.active:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a.active:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > input.active[type='submit'], #changelist #toolbar #changelist-search .btn-group-vertical > input.active[type='submit'], #changelist #changelist-form .actions .btn-group-vertical > button.active, #changelist #changelist-form .paginator .btn-group-vertical > input.active[type='submit'] {
    z-index: 2;
}

.btn-group > .btn:hover, body.delete-confirmation .content-wrap .btn-group > input[type='button']:hover, body.delete-confirmation .content-wrap .btn-group > input[type='submit']:hover, body.delete-confirmation .content-wrap .btn-group > button:hover, .submit-row .deletelink-box .btn-group > .deletelink:hover, .submit-row .btn-group > input[type='submit']:hover:not([class*="btn-"]), .submit-row .btn-group > input[type='button']:hover:not([class*="btn-"]), .submit-row .btn-group > button:hover:not([class*="btn-"]), #content-main > .object-tools > li.btn-group > a:hover:not([class*="btn-"]), body.login .submit-row .btn-group > input[type='submit']:hover, #changelist #toolbar #changelist-search .btn-group > input[type='submit']:hover, #changelist #changelist-form .actions .btn-group > button:hover, #changelist #changelist-form .paginator .btn-group > input[type='submit']:hover, .btn-group-vertical > .btn:hover, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button']:hover, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit']:hover, body.delete-confirmation .content-wrap .btn-group-vertical > button:hover, .submit-row .deletelink-box .btn-group-vertical > .deletelink:hover, .submit-row .btn-group-vertical > input[type='submit']:hover:not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='button']:hover:not([class*="btn-"]), .submit-row .btn-group-vertical > button:hover:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a:hover:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > input[type='submit']:hover, #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit']:hover, #changelist #changelist-form .actions .btn-group-vertical > button:hover, #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit']:hover {
    z-index: 2;
}

.btn-group .btn + .btn, .btn-group body.delete-confirmation .content-wrap input[type='button'] + .btn, body.delete-confirmation .content-wrap .btn-group input[type='button'] + .btn, .btn-group body.delete-confirmation .content-wrap input[type='submit'] + .btn, body.delete-confirmation .content-wrap .btn-group input[type='submit'] + .btn, .btn-group body.delete-confirmation .content-wrap button + .btn, body.delete-confirmation .content-wrap .btn-group button + .btn, .btn-group .submit-row .deletelink-box .deletelink + .btn, .submit-row .deletelink-box .btn-group .deletelink + .btn, .btn-group .submit-row input[type='submit']:not([class*="btn-"]) + .btn, .submit-row .btn-group input[type='submit']:not([class*="btn-"]) + .btn, .btn-group .submit-row input[type='button']:not([class*="btn-"]) + .btn, .submit-row .btn-group input[type='button']:not([class*="btn-"]) + .btn, .btn-group .submit-row button:not([class*="btn-"]) + .btn, .submit-row .btn-group button:not([class*="btn-"]) + .btn, .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + .btn, .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + .btn, .btn-group body.login .submit-row input[type='submit'] + .btn, body.login .submit-row .btn-group input[type='submit'] + .btn, .btn-group #changelist #toolbar #changelist-search input[type='submit'] + .btn, #changelist #toolbar #changelist-search .btn-group input[type='submit'] + .btn, .btn-group #changelist #changelist-form .actions button + .btn, #changelist #changelist-form .actions .btn-group button + .btn, .btn-group #changelist #changelist-form .paginator input[type='submit'] + .btn, #changelist #changelist-form .paginator .btn-group input[type='submit'] + .btn, .btn-group body.delete-confirmation .content-wrap .btn + input[type='button'], body.delete-confirmation .content-wrap .btn-group .btn + input[type='button'], .btn-group body.delete-confirmation .content-wrap input[type='button'] + input[type='button'], body.delete-confirmation .content-wrap .btn-group input[type='button'] + input[type='button'], .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap .btn-group input[type='submit'] + input[type='button'], .btn-group body.delete-confirmation .content-wrap button + input[type='button'], body.delete-confirmation .content-wrap .btn-group button + input[type='button'], .btn-group .submit-row .deletelink-box body.delete-confirmation .content-wrap .deletelink + input[type='button'], body.delete-confirmation .content-wrap .btn-group .submit-row .deletelink-box .deletelink + input[type='button'], .submit-row .deletelink-box .btn-group body.delete-confirmation .content-wrap .deletelink + input[type='button'], body.delete-confirmation .content-wrap .submit-row .deletelink-box .btn-group .deletelink + input[type='button'], .btn-group .submit-row body.delete-confirmation .content-wrap input[type='submit']:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .btn-group .submit-row input[type='submit']:not([class*="btn-"]) + input[type='button'], .submit-row .btn-group body.delete-confirmation .content-wrap input[type='submit']:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .submit-row .btn-group input[type='submit']:not([class*="btn-"]) + input[type='button'], .btn-group .submit-row body.delete-confirmation .content-wrap input[type='button']:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .btn-group .submit-row input[type='button']:not([class*="btn-"]) + input[type='button'], .submit-row .btn-group body.delete-confirmation .content-wrap input[type='button']:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .submit-row .btn-group input[type='button']:not([class*="btn-"]) + input[type='button'], .btn-group .submit-row body.delete-confirmation .content-wrap button:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .btn-group .submit-row button:not([class*="btn-"]) + input[type='button'], .submit-row .btn-group body.delete-confirmation .content-wrap button:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .submit-row .btn-group button:not([class*="btn-"]) + input[type='button'], .btn-group body.delete-confirmation .content-wrap #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='button'], .btn-group body.delete-confirmation .content-wrap #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='button'], .btn-group body.login .submit-row body.delete-confirmation .content-wrap input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap .btn-group body.login .submit-row input[type='submit'] + input[type='button'], body.login .submit-row .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap body.login .submit-row .btn-group input[type='submit'] + input[type='button'], .btn-group #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap .btn-group #changelist #toolbar #changelist-search input[type='submit'] + input[type='button'], #changelist #toolbar #changelist-search .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .btn-group input[type='submit'] + input[type='button'], .btn-group #changelist #changelist-form .actions body.delete-confirmation .content-wrap button + input[type='button'], body.delete-confirmation .content-wrap .btn-group #changelist #changelist-form .actions button + input[type='button'], #changelist #changelist-form .actions .btn-group body.delete-confirmation .content-wrap button + input[type='button'], body.delete-confirmation .content-wrap #changelist #changelist-form .actions .btn-group button + input[type='button'], .btn-group #changelist #changelist-form .paginator body.delete-confirmation .content-wrap input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap .btn-group #changelist #changelist-form .paginator input[type='submit'] + input[type='button'], #changelist #changelist-form .paginator .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .btn-group input[type='submit'] + input[type='button'], .btn-group body.delete-confirmation .content-wrap .btn + input[type='submit'], body.delete-confirmation .content-wrap .btn-group .btn + input[type='submit'], .btn-group body.delete-confirmation .content-wrap input[type='button'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group input[type='button'] + input[type='submit'], .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group input[type='submit'] + input[type='submit'], .btn-group body.delete-confirmation .content-wrap button + input[type='submit'], body.delete-confirmation .content-wrap .btn-group button + input[type='submit'], .btn-group .submit-row .deletelink-box body.delete-confirmation .content-wrap .deletelink + input[type='submit'], body.delete-confirmation .content-wrap .btn-group .submit-row .deletelink-box .deletelink + input[type='submit'], .submit-row .deletelink-box .btn-group body.delete-confirmation .content-wrap .deletelink + input[type='submit'], body.delete-confirmation .content-wrap .submit-row .deletelink-box .btn-group .deletelink + input[type='submit'], .btn-group .submit-row body.delete-confirmation .content-wrap input[type='submit']:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .btn-group .submit-row input[type='submit']:not([class*="btn-"]) + input[type='submit'], .submit-row .btn-group body.delete-confirmation .content-wrap input[type='submit']:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .submit-row .btn-group input[type='submit']:not([class*="btn-"]) + input[type='submit'], .btn-group .submit-row body.delete-confirmation .content-wrap input[type='button']:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .btn-group .submit-row input[type='button']:not([class*="btn-"]) + input[type='submit'], .submit-row .btn-group body.delete-confirmation .content-wrap input[type='button']:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .submit-row .btn-group input[type='button']:not([class*="btn-"]) + input[type='submit'], .btn-group .submit-row body.delete-confirmation .content-wrap button:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .btn-group .submit-row button:not([class*="btn-"]) + input[type='submit'], .submit-row .btn-group body.delete-confirmation .content-wrap button:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .submit-row .btn-group button:not([class*="btn-"]) + input[type='submit'], .btn-group body.delete-confirmation .content-wrap #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='submit'], .btn-group body.delete-confirmation .content-wrap #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='submit'], .btn-group body.login .submit-row body.delete-confirmation .content-wrap input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group body.login .submit-row input[type='submit'] + input[type='submit'], body.login .submit-row .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap body.login .submit-row .btn-group input[type='submit'] + input[type='submit'], .btn-group #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group #changelist #toolbar #changelist-search input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .btn-group input[type='submit'] + input[type='submit'], .btn-group #changelist #changelist-form .actions body.delete-confirmation .content-wrap button + input[type='submit'], body.delete-confirmation .content-wrap .btn-group #changelist #changelist-form .actions button + input[type='submit'], #changelist #changelist-form .actions .btn-group body.delete-confirmation .content-wrap button + input[type='submit'], body.delete-confirmation .content-wrap #changelist #changelist-form .actions .btn-group button + input[type='submit'], .btn-group #changelist #changelist-form .paginator body.delete-confirmation .content-wrap input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group #changelist #changelist-form .paginator input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .btn-group input[type='submit'] + input[type='submit'], .btn-group body.delete-confirmation .content-wrap .btn + button, body.delete-confirmation .content-wrap .btn-group .btn + button, .btn-group body.delete-confirmation .content-wrap input[type='button'] + button, body.delete-confirmation .content-wrap .btn-group input[type='button'] + button, .btn-group body.delete-confirmation .content-wrap input[type='submit'] + button, body.delete-confirmation .content-wrap .btn-group input[type='submit'] + button, .btn-group body.delete-confirmation .content-wrap button + button, body.delete-confirmation .content-wrap .btn-group button + button, .btn-group .submit-row .deletelink-box body.delete-confirmation .content-wrap .deletelink + button, body.delete-confirmation .content-wrap .btn-group .submit-row .deletelink-box .deletelink + button, .submit-row .deletelink-box .btn-group body.delete-confirmation .content-wrap .deletelink + button, body.delete-confirmation .content-wrap .submit-row .deletelink-box .btn-group .deletelink + button, .btn-group .submit-row body.delete-confirmation .content-wrap input[type='submit']:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .btn-group .submit-row input[type='submit']:not([class*="btn-"]) + button, .submit-row .btn-group body.delete-confirmation .content-wrap input[type='submit']:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .submit-row .btn-group input[type='submit']:not([class*="btn-"]) + button, .btn-group .submit-row body.delete-confirmation .content-wrap input[type='button']:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .btn-group .submit-row input[type='button']:not([class*="btn-"]) + button, .submit-row .btn-group body.delete-confirmation .content-wrap input[type='button']:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .submit-row .btn-group input[type='button']:not([class*="btn-"]) + button, .btn-group .submit-row body.delete-confirmation .content-wrap button:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .btn-group .submit-row button:not([class*="btn-"]) + button, .submit-row .btn-group body.delete-confirmation .content-wrap button:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .submit-row .btn-group button:not([class*="btn-"]) + button, .btn-group body.delete-confirmation .content-wrap #content-main > .object-tools > li > a:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + button, .btn-group body.delete-confirmation .content-wrap #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + button, .btn-group body.login .submit-row body.delete-confirmation .content-wrap input[type='submit'] + button, body.delete-confirmation .content-wrap .btn-group body.login .submit-row input[type='submit'] + button, body.login .submit-row .btn-group body.delete-confirmation .content-wrap input[type='submit'] + button, body.delete-confirmation .content-wrap body.login .submit-row .btn-group input[type='submit'] + button, .btn-group #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap input[type='submit'] + button, body.delete-confirmation .content-wrap .btn-group #changelist #toolbar #changelist-search input[type='submit'] + button, #changelist #toolbar #changelist-search .btn-group body.delete-confirmation .content-wrap input[type='submit'] + button, body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .btn-group input[type='submit'] + button, .btn-group #changelist #changelist-form .actions body.delete-confirmation .content-wrap button + button, body.delete-confirmation .content-wrap .btn-group #changelist #changelist-form .actions button + button, #changelist #changelist-form .actions .btn-group body.delete-confirmation .content-wrap button + button, body.delete-confirmation .content-wrap #changelist #changelist-form .actions .btn-group button + button, .btn-group #changelist #changelist-form .paginator body.delete-confirmation .content-wrap input[type='submit'] + button, body.delete-confirmation .content-wrap .btn-group #changelist #changelist-form .paginator input[type='submit'] + button, #changelist #changelist-form .paginator .btn-group body.delete-confirmation .content-wrap input[type='submit'] + button, body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .btn-group input[type='submit'] + button, .btn-group .submit-row .deletelink-box .btn + .deletelink, .submit-row .deletelink-box .btn-group .btn + .deletelink, .btn-group body.delete-confirmation .content-wrap .submit-row .deletelink-box input[type='button'] + .deletelink, .submit-row .deletelink-box .btn-group body.delete-confirmation .content-wrap input[type='button'] + .deletelink, body.delete-confirmation .content-wrap .btn-group .submit-row .deletelink-box input[type='button'] + .deletelink, .submit-row .deletelink-box body.delete-confirmation .content-wrap .btn-group input[type='button'] + .deletelink, .btn-group body.delete-confirmation .content-wrap .submit-row .deletelink-box input[type='submit'] + .deletelink, .submit-row .deletelink-box .btn-group body.delete-confirmation .content-wrap input[type='submit'] + .deletelink, body.delete-confirmation .content-wrap .btn-group .submit-row .deletelink-box input[type='submit'] + .deletelink, .submit-row .deletelink-box body.delete-confirmation .content-wrap .btn-group input[type='submit'] + .deletelink, .btn-group body.delete-confirmation .content-wrap .submit-row .deletelink-box button + .deletelink, .submit-row .deletelink-box .btn-group body.delete-confirmation .content-wrap button + .deletelink, body.delete-confirmation .content-wrap .btn-group .submit-row .deletelink-box button + .deletelink, .submit-row .deletelink-box body.delete-confirmation .content-wrap .btn-group button + .deletelink, .btn-group .submit-row .deletelink-box .deletelink + .deletelink, .submit-row .deletelink-box .btn-group .deletelink + .deletelink, .btn-group .submit-row .deletelink-box input[type='submit']:not([class*="btn-"]) + .deletelink, .submit-row .btn-group .deletelink-box input[type='submit']:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box .btn-group input[type='submit']:not([class*="btn-"]) + .deletelink, .btn-group .submit-row .deletelink-box input[type='button']:not([class*="btn-"]) + .deletelink, .submit-row .btn-group .deletelink-box input[type='button']:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box .btn-group input[type='button']:not([class*="btn-"]) + .deletelink, .btn-group .submit-row .deletelink-box button:not([class*="btn-"]) + .deletelink, .submit-row .btn-group .deletelink-box button:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box .btn-group button:not([class*="btn-"]) + .deletelink, .btn-group .submit-row .deletelink-box #content-main > .object-tools > li > a:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + .deletelink, .btn-group .submit-row .deletelink-box #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + .deletelink, .btn-group body.login .submit-row .deletelink-box input[type='submit'] + .deletelink, body.login .submit-row .btn-group .deletelink-box input[type='submit'] + .deletelink, body.login .submit-row .deletelink-box .btn-group input[type='submit'] + .deletelink, .btn-group #changelist #toolbar #changelist-search .submit-row .deletelink-box input[type='submit'] + .deletelink, .submit-row .deletelink-box .btn-group #changelist #toolbar #changelist-search input[type='submit'] + .deletelink, #changelist #toolbar #changelist-search .btn-group .submit-row .deletelink-box input[type='submit'] + .deletelink, .submit-row .deletelink-box #changelist #toolbar #changelist-search .btn-group input[type='submit'] + .deletelink, .btn-group #changelist #changelist-form .actions .submit-row .deletelink-box button + .deletelink, .submit-row .deletelink-box .btn-group #changelist #changelist-form .actions button + .deletelink, #changelist #changelist-form .actions .btn-group .submit-row .deletelink-box button + .deletelink, .submit-row .deletelink-box #changelist #changelist-form .actions .btn-group button + .deletelink, .btn-group #changelist #changelist-form .paginator .submit-row .deletelink-box input[type='submit'] + .deletelink, .submit-row .deletelink-box .btn-group #changelist #changelist-form .paginator input[type='submit'] + .deletelink, #changelist #changelist-form .paginator .btn-group .submit-row .deletelink-box input[type='submit'] + .deletelink, .submit-row .deletelink-box #changelist #changelist-form .paginator .btn-group input[type='submit'] + .deletelink, .btn-group .submit-row .btn + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group .btn + input[type='submit']:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap .submit-row input[type='button'] + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group body.delete-confirmation .content-wrap input[type='button'] + input[type='submit']:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group .submit-row input[type='button'] + input[type='submit']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group input[type='button'] + input[type='submit']:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap .submit-row input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='submit']:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group .submit-row input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group input[type='submit'] + input[type='submit']:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap .submit-row button + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group body.delete-confirmation .content-wrap button + input[type='submit']:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group .submit-row button + input[type='submit']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group button + input[type='submit']:not([class*="btn-"]), .btn-group .submit-row .deletelink-box .deletelink + input[type='submit']:not([class*="btn-"]), .submit-row .deletelink-box .btn-group .deletelink + input[type='submit']:not([class*="btn-"]), .btn-group .submit-row input[type='submit']:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group input[type='submit']:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .btn-group .submit-row input[type='button']:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group input[type='button']:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .btn-group .submit-row button:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group button:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .btn-group .submit-row #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .btn-group .submit-row #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .btn-group body.login .submit-row input[type='submit'] + input[type='submit']:not([class*="btn-"]), body.login .submit-row .btn-group input[type='submit'] + input[type='submit']:not([class*="btn-"]), .btn-group #changelist #toolbar #changelist-search .submit-row input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group #changelist #toolbar #changelist-search input[type='submit'] + input[type='submit']:not([class*="btn-"]), #changelist #toolbar #changelist-search .btn-group .submit-row input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row #changelist #toolbar #changelist-search .btn-group input[type='submit'] + input[type='submit']:not([class*="btn-"]), .btn-group #changelist #changelist-form .actions .submit-row button + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group #changelist #changelist-form .actions button + input[type='submit']:not([class*="btn-"]), #changelist #changelist-form .actions .btn-group .submit-row button + input[type='submit']:not([class*="btn-"]), .submit-row #changelist #changelist-form .actions .btn-group button + input[type='submit']:not([class*="btn-"]), .btn-group #changelist #changelist-form .paginator .submit-row input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group #changelist #changelist-form .paginator input[type='submit'] + input[type='submit']:not([class*="btn-"]), #changelist #changelist-form .paginator .btn-group .submit-row input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row #changelist #changelist-form .paginator .btn-group input[type='submit'] + input[type='submit']:not([class*="btn-"]), .btn-group .submit-row .btn + input[type='button']:not([class*="btn-"]), .submit-row .btn-group .btn + input[type='button']:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap .submit-row input[type='button'] + input[type='button']:not([class*="btn-"]), .submit-row .btn-group body.delete-confirmation .content-wrap input[type='button'] + input[type='button']:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group .submit-row input[type='button'] + input[type='button']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group input[type='button'] + input[type='button']:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap .submit-row input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='button']:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group .submit-row input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group input[type='submit'] + input[type='button']:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap .submit-row button + input[type='button']:not([class*="btn-"]), .submit-row .btn-group body.delete-confirmation .content-wrap button + input[type='button']:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group .submit-row button + input[type='button']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group button + input[type='button']:not([class*="btn-"]), .btn-group .submit-row .deletelink-box .deletelink + input[type='button']:not([class*="btn-"]), .submit-row .deletelink-box .btn-group .deletelink + input[type='button']:not([class*="btn-"]), .btn-group .submit-row input[type='submit']:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row .btn-group input[type='submit']:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .btn-group .submit-row input[type='button']:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row .btn-group input[type='button']:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .btn-group .submit-row button:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row .btn-group button:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .btn-group .submit-row #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .btn-group .submit-row #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .btn-group body.login .submit-row input[type='submit'] + input[type='button']:not([class*="btn-"]), body.login .submit-row .btn-group input[type='submit'] + input[type='button']:not([class*="btn-"]), .btn-group #changelist #toolbar #changelist-search .submit-row input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row .btn-group #changelist #toolbar #changelist-search input[type='submit'] + input[type='button']:not([class*="btn-"]), #changelist #toolbar #changelist-search .btn-group .submit-row input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row #changelist #toolbar #changelist-search .btn-group input[type='submit'] + input[type='button']:not([class*="btn-"]), .btn-group #changelist #changelist-form .actions .submit-row button + input[type='button']:not([class*="btn-"]), .submit-row .btn-group #changelist #changelist-form .actions button + input[type='button']:not([class*="btn-"]), #changelist #changelist-form .actions .btn-group .submit-row button + input[type='button']:not([class*="btn-"]), .submit-row #changelist #changelist-form .actions .btn-group button + input[type='button']:not([class*="btn-"]), .btn-group #changelist #changelist-form .paginator .submit-row input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row .btn-group #changelist #changelist-form .paginator input[type='submit'] + input[type='button']:not([class*="btn-"]), #changelist #changelist-form .paginator .btn-group .submit-row input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row #changelist #changelist-form .paginator .btn-group input[type='submit'] + input[type='button']:not([class*="btn-"]), .btn-group .submit-row .btn + button:not([class*="btn-"]), .submit-row .btn-group .btn + button:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap .submit-row input[type='button'] + button:not([class*="btn-"]), .submit-row .btn-group body.delete-confirmation .content-wrap input[type='button'] + button:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group .submit-row input[type='button'] + button:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group input[type='button'] + button:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap .submit-row input[type='submit'] + button:not([class*="btn-"]), .submit-row .btn-group body.delete-confirmation .content-wrap input[type='submit'] + button:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group .submit-row input[type='submit'] + button:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group input[type='submit'] + button:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap .submit-row button + button:not([class*="btn-"]), .submit-row .btn-group body.delete-confirmation .content-wrap button + button:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group .submit-row button + button:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group button + button:not([class*="btn-"]), .btn-group .submit-row .deletelink-box .deletelink + button:not([class*="btn-"]), .submit-row .deletelink-box .btn-group .deletelink + button:not([class*="btn-"]), .btn-group .submit-row input[type='submit']:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row .btn-group input[type='submit']:not([class*="btn-"]) + button:not([class*="btn-"]), .btn-group .submit-row input[type='button']:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row .btn-group input[type='button']:not([class*="btn-"]) + button:not([class*="btn-"]), .btn-group .submit-row button:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row .btn-group button:not([class*="btn-"]) + button:not([class*="btn-"]), .btn-group .submit-row #content-main > .object-tools > li > a:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + button:not([class*="btn-"]), .btn-group .submit-row #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + button:not([class*="btn-"]), .btn-group body.login .submit-row input[type='submit'] + button:not([class*="btn-"]), body.login .submit-row .btn-group input[type='submit'] + button:not([class*="btn-"]), .btn-group #changelist #toolbar #changelist-search .submit-row input[type='submit'] + button:not([class*="btn-"]), .submit-row .btn-group #changelist #toolbar #changelist-search input[type='submit'] + button:not([class*="btn-"]), #changelist #toolbar #changelist-search .btn-group .submit-row input[type='submit'] + button:not([class*="btn-"]), .submit-row #changelist #toolbar #changelist-search .btn-group input[type='submit'] + button:not([class*="btn-"]), .btn-group #changelist #changelist-form .actions .submit-row button + button:not([class*="btn-"]), .submit-row .btn-group #changelist #changelist-form .actions button + button:not([class*="btn-"]), #changelist #changelist-form .actions .btn-group .submit-row button + button:not([class*="btn-"]), .submit-row #changelist #changelist-form .actions .btn-group button + button:not([class*="btn-"]), .btn-group #changelist #changelist-form .paginator .submit-row input[type='submit'] + button:not([class*="btn-"]), .submit-row .btn-group #changelist #changelist-form .paginator input[type='submit'] + button:not([class*="btn-"]), #changelist #changelist-form .paginator .btn-group .submit-row input[type='submit'] + button:not([class*="btn-"]), .submit-row #changelist #changelist-form .paginator .btn-group input[type='submit'] + button:not([class*="btn-"]), .btn-group #content-main > .object-tools > li > .btn + a:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap #content-main > .object-tools > li > input[type='button'] + a:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group #content-main > .object-tools > li > input[type='button'] + a:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap #content-main > .object-tools > li > input[type='submit'] + a:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group #content-main > .object-tools > li > input[type='submit'] + a:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap #content-main > .object-tools > li > button + a:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group #content-main > .object-tools > li > button + a:not([class*="btn-"]), .btn-group .submit-row .deletelink-box #content-main > .object-tools > li > .deletelink + a:not([class*="btn-"]), .submit-row .deletelink-box .btn-group #content-main > .object-tools > li > .deletelink + a:not([class*="btn-"]), .btn-group .submit-row #content-main > .object-tools > li > input[type='submit']:not([class*="btn-"]) + a:not([class*="btn-"]), .submit-row .btn-group #content-main > .object-tools > li > input[type='submit']:not([class*="btn-"]) + a:not([class*="btn-"]), .btn-group .submit-row #content-main > .object-tools > li > input[type='button']:not([class*="btn-"]) + a:not([class*="btn-"]), .submit-row .btn-group #content-main > .object-tools > li > input[type='button']:not([class*="btn-"]) + a:not([class*="btn-"]), .btn-group .submit-row #content-main > .object-tools > li > button:not([class*="btn-"]) + a:not([class*="btn-"]), .submit-row .btn-group #content-main > .object-tools > li > button:not([class*="btn-"]) + a:not([class*="btn-"]), .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + a:not([class*="btn-"]), .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + a:not([class*="btn-"]), .btn-group body.login .submit-row #content-main > .object-tools > li > input[type='submit'] + a:not([class*="btn-"]), body.login .submit-row .btn-group #content-main > .object-tools > li > input[type='submit'] + a:not([class*="btn-"]), .btn-group #changelist #toolbar #changelist-search #content-main > .object-tools > li > input[type='submit'] + a:not([class*="btn-"]), #changelist #toolbar #changelist-search .btn-group #content-main > .object-tools > li > input[type='submit'] + a:not([class*="btn-"]), .btn-group #changelist #changelist-form .actions #content-main > .object-tools > li > button + a:not([class*="btn-"]), #changelist #changelist-form .actions .btn-group #content-main > .object-tools > li > button + a:not([class*="btn-"]), .btn-group #changelist #changelist-form .paginator #content-main > .object-tools > li > input[type='submit'] + a:not([class*="btn-"]), #changelist #changelist-form .paginator .btn-group #content-main > .object-tools > li > input[type='submit'] + a:not([class*="btn-"]), .btn-group #content-main > .object-tools > li > .btn + a.addlink:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap #content-main > .object-tools > li > input[type='button'] + a.addlink:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group #content-main > .object-tools > li > input[type='button'] + a.addlink:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap #content-main > .object-tools > li > input[type='submit'] + a.addlink:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group #content-main > .object-tools > li > input[type='submit'] + a.addlink:not([class*="btn-"]), .btn-group body.delete-confirmation .content-wrap #content-main > .object-tools > li > button + a.addlink:not([class*="btn-"]), body.delete-confirmation .content-wrap .btn-group #content-main > .object-tools > li > button + a.addlink:not([class*="btn-"]), .btn-group .submit-row .deletelink-box #content-main > .object-tools > li > .deletelink + a.addlink:not([class*="btn-"]), .submit-row .deletelink-box .btn-group #content-main > .object-tools > li > .deletelink + a.addlink:not([class*="btn-"]), .btn-group .submit-row #content-main > .object-tools > li > input[type='submit']:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), .submit-row .btn-group #content-main > .object-tools > li > input[type='submit']:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), .btn-group .submit-row #content-main > .object-tools > li > input[type='button']:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), .submit-row .btn-group #content-main > .object-tools > li > input[type='button']:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), .btn-group .submit-row #content-main > .object-tools > li > button:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), .submit-row .btn-group #content-main > .object-tools > li > button:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), .btn-group body.login .submit-row #content-main > .object-tools > li > input[type='submit'] + a.addlink:not([class*="btn-"]), body.login .submit-row .btn-group #content-main > .object-tools > li > input[type='submit'] + a.addlink:not([class*="btn-"]), .btn-group #changelist #toolbar #changelist-search #content-main > .object-tools > li > input[type='submit'] + a.addlink:not([class*="btn-"]), #changelist #toolbar #changelist-search .btn-group #content-main > .object-tools > li > input[type='submit'] + a.addlink:not([class*="btn-"]), .btn-group #changelist #changelist-form .actions #content-main > .object-tools > li > button + a.addlink:not([class*="btn-"]), #changelist #changelist-form .actions .btn-group #content-main > .object-tools > li > button + a.addlink:not([class*="btn-"]), .btn-group #changelist #changelist-form .paginator #content-main > .object-tools > li > input[type='submit'] + a.addlink:not([class*="btn-"]), #changelist #changelist-form .paginator .btn-group #content-main > .object-tools > li > input[type='submit'] + a.addlink:not([class*="btn-"]), .btn-group body.login .submit-row .btn + input[type='submit'], body.login .submit-row .btn-group .btn + input[type='submit'], .btn-group body.delete-confirmation .content-wrap body.login .submit-row input[type='button'] + input[type='submit'], body.login .submit-row .btn-group body.delete-confirmation .content-wrap input[type='button'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group body.login .submit-row input[type='button'] + input[type='submit'], body.login .submit-row body.delete-confirmation .content-wrap .btn-group input[type='button'] + input[type='submit'], .btn-group body.delete-confirmation .content-wrap body.login .submit-row input[type='submit'] + input[type='submit'], body.login .submit-row .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group body.login .submit-row input[type='submit'] + input[type='submit'], body.login .submit-row body.delete-confirmation .content-wrap .btn-group input[type='submit'] + input[type='submit'], .btn-group body.delete-confirmation .content-wrap body.login .submit-row button + input[type='submit'], body.login .submit-row .btn-group body.delete-confirmation .content-wrap button + input[type='submit'], body.delete-confirmation .content-wrap .btn-group body.login .submit-row button + input[type='submit'], body.login .submit-row body.delete-confirmation .content-wrap .btn-group button + input[type='submit'], .btn-group body.login .submit-row .deletelink-box .deletelink + input[type='submit'], body.login .btn-group .submit-row .deletelink-box .deletelink + input[type='submit'], body.login .submit-row .deletelink-box .btn-group .deletelink + input[type='submit'], .btn-group body.login .submit-row input[type='submit']:not([class*="btn-"]) + input[type='submit'], body.login .btn-group .submit-row input[type='submit']:not([class*="btn-"]) + input[type='submit'], body.login .submit-row .btn-group input[type='submit']:not([class*="btn-"]) + input[type='submit'], .btn-group body.login .submit-row input[type='button']:not([class*="btn-"]) + input[type='submit'], body.login .btn-group .submit-row input[type='button']:not([class*="btn-"]) + input[type='submit'], body.login .submit-row .btn-group input[type='button']:not([class*="btn-"]) + input[type='submit'], .btn-group body.login .submit-row button:not([class*="btn-"]) + input[type='submit'], body.login .btn-group .submit-row button:not([class*="btn-"]) + input[type='submit'], body.login .submit-row .btn-group button:not([class*="btn-"]) + input[type='submit'], .btn-group body.login .submit-row #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='submit'], body.login .submit-row .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='submit'], .btn-group body.login .submit-row #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='submit'], body.login .submit-row .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='submit'], .btn-group body.login .submit-row input[type='submit'] + input[type='submit'], body.login .submit-row .btn-group input[type='submit'] + input[type='submit'], .btn-group #changelist #toolbar #changelist-search body.login .submit-row input[type='submit'] + input[type='submit'], body.login .submit-row .btn-group #changelist #toolbar #changelist-search input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search .btn-group body.login .submit-row input[type='submit'] + input[type='submit'], body.login .submit-row #changelist #toolbar #changelist-search .btn-group input[type='submit'] + input[type='submit'], .btn-group #changelist #changelist-form .actions body.login .submit-row button + input[type='submit'], body.login .submit-row .btn-group #changelist #changelist-form .actions button + input[type='submit'], #changelist #changelist-form .actions .btn-group body.login .submit-row button + input[type='submit'], body.login .submit-row #changelist #changelist-form .actions .btn-group button + input[type='submit'], .btn-group #changelist #changelist-form .paginator body.login .submit-row input[type='submit'] + input[type='submit'], body.login .submit-row .btn-group #changelist #changelist-form .paginator input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator .btn-group body.login .submit-row input[type='submit'] + input[type='submit'], body.login .submit-row #changelist #changelist-form .paginator .btn-group input[type='submit'] + input[type='submit'], .btn-group #changelist #toolbar #changelist-search .btn + input[type='submit'], #changelist #toolbar #changelist-search .btn-group .btn + input[type='submit'], .btn-group body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search input[type='button'] + input[type='submit'], #changelist #toolbar #changelist-search .btn-group body.delete-confirmation .content-wrap input[type='button'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group #changelist #toolbar #changelist-search input[type='button'] + input[type='submit'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .btn-group input[type='button'] + input[type='submit'], .btn-group body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group #changelist #toolbar #changelist-search input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .btn-group input[type='submit'] + input[type='submit'], .btn-group body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search button + input[type='submit'], #changelist #toolbar #changelist-search .btn-group body.delete-confirmation .content-wrap button + input[type='submit'], body.delete-confirmation .content-wrap .btn-group #changelist #toolbar #changelist-search button + input[type='submit'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .btn-group button + input[type='submit'], .btn-group .submit-row .deletelink-box #changelist #toolbar #changelist-search .deletelink + input[type='submit'], #changelist #toolbar #changelist-search .btn-group .submit-row .deletelink-box .deletelink + input[type='submit'], .submit-row .deletelink-box .btn-group #changelist #toolbar #changelist-search .deletelink + input[type='submit'], #changelist #toolbar #changelist-search .submit-row .deletelink-box .btn-group .deletelink + input[type='submit'], .btn-group .submit-row #changelist #toolbar #changelist-search input[type='submit']:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .btn-group .submit-row input[type='submit']:not([class*="btn-"]) + input[type='submit'], .submit-row .btn-group #changelist #toolbar #changelist-search input[type='submit']:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .submit-row .btn-group input[type='submit']:not([class*="btn-"]) + input[type='submit'], .btn-group .submit-row #changelist #toolbar #changelist-search input[type='button']:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .btn-group .submit-row input[type='button']:not([class*="btn-"]) + input[type='submit'], .submit-row .btn-group #changelist #toolbar #changelist-search input[type='button']:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .submit-row .btn-group input[type='button']:not([class*="btn-"]) + input[type='submit'], .btn-group .submit-row #changelist #toolbar #changelist-search button:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .btn-group .submit-row button:not([class*="btn-"]) + input[type='submit'], .submit-row .btn-group #changelist #toolbar #changelist-search button:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .submit-row .btn-group button:not([class*="btn-"]) + input[type='submit'], .btn-group #changelist #toolbar #changelist-search #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='submit'], .btn-group #changelist #toolbar #changelist-search #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='submit'], .btn-group body.login .submit-row #changelist #toolbar #changelist-search input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search .btn-group body.login .submit-row input[type='submit'] + input[type='submit'], body.login .submit-row .btn-group #changelist #toolbar #changelist-search input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search body.login .submit-row .btn-group input[type='submit'] + input[type='submit'], .btn-group #changelist #toolbar #changelist-search input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search .btn-group input[type='submit'] + input[type='submit'], .btn-group #changelist #changelist-form .actions #toolbar #changelist-search button + input[type='submit'], .btn-group #changelist #toolbar #changelist-search #changelist-form .actions button + input[type='submit'], #changelist #changelist-form .actions .btn-group #toolbar #changelist-search button + input[type='submit'], #changelist #toolbar #changelist-search #changelist-form .actions .btn-group button + input[type='submit'], .btn-group #changelist #changelist-form .paginator #toolbar #changelist-search input[type='submit'] + input[type='submit'], .btn-group #changelist #toolbar #changelist-search #changelist-form .paginator input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator .btn-group #toolbar #changelist-search input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search #changelist-form .paginator .btn-group input[type='submit'] + input[type='submit'], .btn-group #changelist #changelist-form .actions .btn + button, #changelist #changelist-form .actions .btn-group .btn + button, .btn-group body.delete-confirmation .content-wrap #changelist #changelist-form .actions input[type='button'] + button, #changelist #changelist-form .actions .btn-group body.delete-confirmation .content-wrap input[type='button'] + button, body.delete-confirmation .content-wrap .btn-group #changelist #changelist-form .actions input[type='button'] + button, #changelist #changelist-form .actions body.delete-confirmation .content-wrap .btn-group input[type='button'] + button, .btn-group body.delete-confirmation .content-wrap #changelist #changelist-form .actions input[type='submit'] + button, #changelist #changelist-form .actions .btn-group body.delete-confirmation .content-wrap input[type='submit'] + button, body.delete-confirmation .content-wrap .btn-group #changelist #changelist-form .actions input[type='submit'] + button, #changelist #changelist-form .actions body.delete-confirmation .content-wrap .btn-group input[type='submit'] + button, .btn-group body.delete-confirmation .content-wrap #changelist #changelist-form .actions button + button, #changelist #changelist-form .actions .btn-group body.delete-confirmation .content-wrap button + button, body.delete-confirmation .content-wrap .btn-group #changelist #changelist-form .actions button + button, #changelist #changelist-form .actions body.delete-confirmation .content-wrap .btn-group button + button, .btn-group .submit-row .deletelink-box #changelist #changelist-form .actions .deletelink + button, #changelist #changelist-form .actions .btn-group .submit-row .deletelink-box .deletelink + button, .submit-row .deletelink-box .btn-group #changelist #changelist-form .actions .deletelink + button, #changelist #changelist-form .actions .submit-row .deletelink-box .btn-group .deletelink + button, .btn-group .submit-row #changelist #changelist-form .actions input[type='submit']:not([class*="btn-"]) + button, #changelist #changelist-form .actions .btn-group .submit-row input[type='submit']:not([class*="btn-"]) + button, .submit-row .btn-group #changelist #changelist-form .actions input[type='submit']:not([class*="btn-"]) + button, #changelist #changelist-form .actions .submit-row .btn-group input[type='submit']:not([class*="btn-"]) + button, .btn-group .submit-row #changelist #changelist-form .actions input[type='button']:not([class*="btn-"]) + button, #changelist #changelist-form .actions .btn-group .submit-row input[type='button']:not([class*="btn-"]) + button, .submit-row .btn-group #changelist #changelist-form .actions input[type='button']:not([class*="btn-"]) + button, #changelist #changelist-form .actions .submit-row .btn-group input[type='button']:not([class*="btn-"]) + button, .btn-group .submit-row #changelist #changelist-form .actions button:not([class*="btn-"]) + button, #changelist #changelist-form .actions .btn-group .submit-row button:not([class*="btn-"]) + button, .submit-row .btn-group #changelist #changelist-form .actions button:not([class*="btn-"]) + button, #changelist #changelist-form .actions .submit-row .btn-group button:not([class*="btn-"]) + button, .btn-group #changelist #changelist-form .actions #content-main > .object-tools > li > a:not([class*="btn-"]) + button, #changelist #changelist-form .actions .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + button, .btn-group #changelist #changelist-form .actions #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + button, #changelist #changelist-form .actions .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + button, .btn-group body.login .submit-row #changelist #changelist-form .actions input[type='submit'] + button, #changelist #changelist-form .actions .btn-group body.login .submit-row input[type='submit'] + button, body.login .submit-row .btn-group #changelist #changelist-form .actions input[type='submit'] + button, #changelist #changelist-form .actions body.login .submit-row .btn-group input[type='submit'] + button, .btn-group #changelist #toolbar #changelist-search #changelist-form .actions input[type='submit'] + button, .btn-group #changelist #changelist-form .actions #toolbar #changelist-search input[type='submit'] + button, #changelist #toolbar #changelist-search .btn-group #changelist-form .actions input[type='submit'] + button, #changelist #changelist-form .actions #toolbar #changelist-search .btn-group input[type='submit'] + button, .btn-group #changelist #changelist-form .actions button + button, #changelist #changelist-form .actions .btn-group button + button, .btn-group #changelist #changelist-form .paginator .actions input[type='submit'] + button, .btn-group #changelist #changelist-form .actions .paginator input[type='submit'] + button, #changelist #changelist-form .paginator .btn-group .actions input[type='submit'] + button, #changelist #changelist-form .actions .paginator .btn-group input[type='submit'] + button, .btn-group #changelist #changelist-form .paginator .btn + input[type='submit'], #changelist #changelist-form .paginator .btn-group .btn + input[type='submit'], .btn-group body.delete-confirmation .content-wrap #changelist #changelist-form .paginator input[type='button'] + input[type='submit'], #changelist #changelist-form .paginator .btn-group body.delete-confirmation .content-wrap input[type='button'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group #changelist #changelist-form .paginator input[type='button'] + input[type='submit'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .btn-group input[type='button'] + input[type='submit'], .btn-group body.delete-confirmation .content-wrap #changelist #changelist-form .paginator input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator .btn-group body.delete-confirmation .content-wrap input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group #changelist #changelist-form .paginator input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .btn-group input[type='submit'] + input[type='submit'], .btn-group body.delete-confirmation .content-wrap #changelist #changelist-form .paginator button + input[type='submit'], #changelist #changelist-form .paginator .btn-group body.delete-confirmation .content-wrap button + input[type='submit'], body.delete-confirmation .content-wrap .btn-group #changelist #changelist-form .paginator button + input[type='submit'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .btn-group button + input[type='submit'], .btn-group .submit-row .deletelink-box #changelist #changelist-form .paginator .deletelink + input[type='submit'], #changelist #changelist-form .paginator .btn-group .submit-row .deletelink-box .deletelink + input[type='submit'], .submit-row .deletelink-box .btn-group #changelist #changelist-form .paginator .deletelink + input[type='submit'], #changelist #changelist-form .paginator .submit-row .deletelink-box .btn-group .deletelink + input[type='submit'], .btn-group .submit-row #changelist #changelist-form .paginator input[type='submit']:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .btn-group .submit-row input[type='submit']:not([class*="btn-"]) + input[type='submit'], .submit-row .btn-group #changelist #changelist-form .paginator input[type='submit']:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .submit-row .btn-group input[type='submit']:not([class*="btn-"]) + input[type='submit'], .btn-group .submit-row #changelist #changelist-form .paginator input[type='button']:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .btn-group .submit-row input[type='button']:not([class*="btn-"]) + input[type='submit'], .submit-row .btn-group #changelist #changelist-form .paginator input[type='button']:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .submit-row .btn-group input[type='button']:not([class*="btn-"]) + input[type='submit'], .btn-group .submit-row #changelist #changelist-form .paginator button:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .btn-group .submit-row button:not([class*="btn-"]) + input[type='submit'], .submit-row .btn-group #changelist #changelist-form .paginator button:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .submit-row .btn-group button:not([class*="btn-"]) + input[type='submit'], .btn-group #changelist #changelist-form .paginator #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + input[type='submit'], .btn-group #changelist #changelist-form .paginator #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .btn-group #content-main > .object-tools > li > a.addlink:not([class*="btn-"]) + input[type='submit'], .btn-group body.login .submit-row #changelist #changelist-form .paginator input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator .btn-group body.login .submit-row input[type='submit'] + input[type='submit'], body.login .submit-row .btn-group #changelist #changelist-form .paginator input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator body.login .submit-row .btn-group input[type='submit'] + input[type='submit'], .btn-group #changelist #toolbar #changelist-search #changelist-form .paginator input[type='submit'] + input[type='submit'], .btn-group #changelist #changelist-form .paginator #toolbar #changelist-search input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search .btn-group #changelist-form .paginator input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator #toolbar #changelist-search .btn-group input[type='submit'] + input[type='submit'], .btn-group #changelist #changelist-form .actions .paginator button + input[type='submit'], .btn-group #changelist #changelist-form .paginator .actions button + input[type='submit'], #changelist #changelist-form .actions .btn-group .paginator button + input[type='submit'], #changelist #changelist-form .paginator .actions .btn-group button + input[type='submit'], .btn-group #changelist #changelist-form .paginator input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator .btn-group input[type='submit'] + input[type='submit'], .btn-group .btn + .btn-group, .btn-group body.delete-confirmation .content-wrap input[type='button'] + .btn-group, body.delete-confirmation .content-wrap .btn-group input[type='button'] + .btn-group, .btn-group body.delete-confirmation .content-wrap input[type='submit'] + .btn-group, body.delete-confirmation .content-wrap .btn-group input[type='submit'] + .btn-group, .btn-group body.delete-confirmation .content-wrap button + .btn-group, body.delete-confirmation .content-wrap .btn-group button + .btn-group, .btn-group .submit-row .deletelink-box .deletelink + .btn-group, .submit-row .deletelink-box .btn-group .deletelink + .btn-group, .btn-group .submit-row input[type='submit']:not([class*="btn-"]) + .btn-group, .submit-row .btn-group input[type='submit']:not([class*="btn-"]) + .btn-group, .btn-group .submit-row input[type='button']:not([class*="btn-"]) + .btn-group, .submit-row .btn-group input[type='button']:not([class*="btn-"]) + .btn-group, .btn-group .submit-row button:not([class*="btn-"]) + .btn-group, .submit-row .btn-group button:not([class*="btn-"]) + .btn-group, .btn-group #content-main > .object-tools > li > a:not([class*="btn-"]) + .btn-group, .btn-group body.login .submit-row input[type='submit'] + .btn-group, body.login .submit-row .btn-group input[type='submit'] + .btn-group, .btn-group #changelist #toolbar #changelist-search input[type='submit'] + .btn-group, #changelist #toolbar #changelist-search .btn-group input[type='submit'] + .btn-group, .btn-group #changelist #changelist-form .actions button + .btn-group, #changelist #changelist-form .actions .btn-group button + .btn-group, .btn-group #changelist #changelist-form .paginator input[type='submit'] + .btn-group, #changelist #changelist-form .paginator .btn-group input[type='submit'] + .btn-group, .btn-group .btn-group + .btn, .btn-group body.delete-confirmation .content-wrap .btn-group + input[type='button'], body.delete-confirmation .content-wrap .btn-group .btn-group + input[type='button'], .btn-group body.delete-confirmation .content-wrap .btn-group + input[type='submit'], body.delete-confirmation .content-wrap .btn-group .btn-group + input[type='submit'], .btn-group body.delete-confirmation .content-wrap .btn-group + button, body.delete-confirmation .content-wrap .btn-group .btn-group + button, .btn-group .submit-row .deletelink-box .btn-group + .deletelink, .submit-row .deletelink-box .btn-group .btn-group + .deletelink, .btn-group .submit-row .btn-group + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group .btn-group + input[type='submit']:not([class*="btn-"]), .btn-group .submit-row .btn-group + input[type='button']:not([class*="btn-"]), .submit-row .btn-group .btn-group + input[type='button']:not([class*="btn-"]), .btn-group .submit-row .btn-group + button:not([class*="btn-"]), .submit-row .btn-group .btn-group + button:not([class*="btn-"]), .btn-group #content-main > .object-tools > li > .btn-group + a:not([class*="btn-"]), .btn-group body.login .submit-row .btn-group + input[type='submit'], body.login .submit-row .btn-group .btn-group + input[type='submit'], .btn-group #changelist #toolbar #changelist-search .btn-group + input[type='submit'], #changelist #toolbar #changelist-search .btn-group .btn-group + input[type='submit'], .btn-group #changelist #changelist-form .actions .btn-group + button, #changelist #changelist-form .actions .btn-group .btn-group + button, .btn-group #changelist #changelist-form .paginator .btn-group + input[type='submit'], #changelist #changelist-form .paginator .btn-group .btn-group + input[type='submit'], .btn-group .btn-group + .btn-group {
    margin-left: -1px;
}

.btn-toolbar {
    margin-left: -0.5rem;
}

.btn-toolbar::after {
    content: "";
    display: table;
    clear: both;
}

.btn-toolbar .btn-group, .btn-toolbar .input-group {
    float: left;
}

.btn-toolbar > .btn, body.delete-confirmation .content-wrap .btn-toolbar > input[type='button'], body.delete-confirmation .content-wrap .btn-toolbar > input[type='submit'], body.delete-confirmation .content-wrap .btn-toolbar > button, .submit-row .deletelink-box .btn-toolbar > .deletelink, .submit-row .btn-toolbar > input[type='submit']:not([class*="btn-"]), .submit-row .btn-toolbar > input[type='button']:not([class*="btn-"]), .submit-row .btn-toolbar > button:not([class*="btn-"]), #content-main > .object-tools > li.btn-toolbar > a:not([class*="btn-"]), body.login .submit-row .btn-toolbar > input[type='submit'], #changelist #toolbar #changelist-search .btn-toolbar > input[type='submit'], #changelist #changelist-form .actions .btn-toolbar > button, #changelist #changelist-form .paginator .btn-toolbar > input[type='submit'], .btn-toolbar > .btn-group, .btn-toolbar > .input-group {
    margin-left: 0.5rem;
}

.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle), body.delete-confirmation .content-wrap .btn-group > input[type='button']:not(:first-child):not(:last-child):not(.dropdown-toggle), body.delete-confirmation .content-wrap .btn-group > input[type='submit']:not(:first-child):not(:last-child):not(.dropdown-toggle), body.delete-confirmation .content-wrap .btn-group > button:not(:first-child):not(:last-child):not(.dropdown-toggle), .submit-row .deletelink-box .btn-group > .deletelink:not(:first-child):not(:last-child):not(.dropdown-toggle), .submit-row .btn-group > input[type='submit']:not(:first-child):not(:last-child):not(.dropdown-toggle):not([class*="btn-"]), .submit-row .btn-group > input[type='button']:not(:first-child):not(:last-child):not(.dropdown-toggle):not([class*="btn-"]), .submit-row .btn-group > button:not(:first-child):not(:last-child):not(.dropdown-toggle):not([class*="btn-"]), #content-main > .object-tools > li.btn-group > a:not(:first-child):not(:last-child):not(.dropdown-toggle):not([class*="btn-"]), body.login .submit-row .btn-group > input[type='submit']:not(:first-child):not(:last-child):not(.dropdown-toggle), #changelist #toolbar #changelist-search .btn-group > input[type='submit']:not(:first-child):not(:last-child):not(.dropdown-toggle), #changelist #changelist-form .actions .btn-group > button:not(:first-child):not(:last-child):not(.dropdown-toggle), #changelist #changelist-form .paginator .btn-group > input[type='submit']:not(:first-child):not(:last-child):not(.dropdown-toggle) {
    border-radius: 0;
}

.btn-group > .btn:first-child, body.delete-confirmation .content-wrap .btn-group > input[type='button']:first-child, body.delete-confirmation .content-wrap .btn-group > input[type='submit']:first-child, body.delete-confirmation .content-wrap .btn-group > button:first-child, .submit-row .deletelink-box .btn-group > .deletelink:first-child, .submit-row .btn-group > input[type='submit']:first-child:not([class*="btn-"]), .submit-row .btn-group > input[type='button']:first-child:not([class*="btn-"]), .submit-row .btn-group > button:first-child:not([class*="btn-"]), #content-main > .object-tools > li.btn-group > a:first-child:not([class*="btn-"]), body.login .submit-row .btn-group > input[type='submit']:first-child, #changelist #toolbar #changelist-search .btn-group > input[type='submit']:first-child, #changelist #changelist-form .actions .btn-group > button:first-child, #changelist #changelist-form .paginator .btn-group > input[type='submit']:first-child {
    margin-left: 0;
}

.btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle), body.delete-confirmation .content-wrap .btn-group > input[type='button']:first-child:not(:last-child):not(.dropdown-toggle), body.delete-confirmation .content-wrap .btn-group > input[type='submit']:first-child:not(:last-child):not(.dropdown-toggle), body.delete-confirmation .content-wrap .btn-group > button:first-child:not(:last-child):not(.dropdown-toggle), .submit-row .deletelink-box .btn-group > .deletelink:first-child:not(:last-child):not(.dropdown-toggle), .submit-row .btn-group > input[type='submit']:first-child:not(:last-child):not(.dropdown-toggle):not([class*="btn-"]), .submit-row .btn-group > input[type='button']:first-child:not(:last-child):not(.dropdown-toggle):not([class*="btn-"]), .submit-row .btn-group > button:first-child:not(:last-child):not(.dropdown-toggle):not([class*="btn-"]), #content-main > .object-tools > li.btn-group > a:first-child:not(:last-child):not(.dropdown-toggle):not([class*="btn-"]), body.login .submit-row .btn-group > input[type='submit']:first-child:not(:last-child):not(.dropdown-toggle), #changelist #toolbar #changelist-search .btn-group > input[type='submit']:first-child:not(:last-child):not(.dropdown-toggle), #changelist #changelist-form .actions .btn-group > button:first-child:not(:last-child):not(.dropdown-toggle), #changelist #changelist-form .paginator .btn-group > input[type='submit']:first-child:not(:last-child):not(.dropdown-toggle) {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
}

.btn-group > .btn:last-child:not(:first-child), body.delete-confirmation .content-wrap .btn-group > input[type='button']:last-child:not(:first-child), body.delete-confirmation .content-wrap .btn-group > input[type='submit']:last-child:not(:first-child), body.delete-confirmation .content-wrap .btn-group > button:last-child:not(:first-child), .submit-row .deletelink-box .btn-group > .deletelink:last-child:not(:first-child), .submit-row .btn-group > input[type='submit']:last-child:not(:first-child):not([class*="btn-"]), .submit-row .btn-group > input[type='button']:last-child:not(:first-child):not([class*="btn-"]), .submit-row .btn-group > button:last-child:not(:first-child):not([class*="btn-"]), #content-main > .object-tools > li.btn-group > a:last-child:not(:first-child):not([class*="btn-"]), body.login .submit-row .btn-group > input[type='submit']:last-child:not(:first-child), #changelist #toolbar #changelist-search .btn-group > input[type='submit']:last-child:not(:first-child), #changelist #changelist-form .actions .btn-group > button:last-child:not(:first-child), #changelist #changelist-form .paginator .btn-group > input[type='submit']:last-child:not(:first-child), .btn-group > .dropdown-toggle:not(:first-child) {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}

.btn-group > .btn-group {
    float: left;
}

.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn, body.delete-confirmation .content-wrap .btn-group > .btn-group:not(:first-child):not(:last-child) > input[type='button'], body.delete-confirmation .content-wrap .btn-group > .btn-group:not(:first-child):not(:last-child) > input[type='submit'], body.delete-confirmation .content-wrap .btn-group > .btn-group:not(:first-child):not(:last-child) > button, .submit-row .deletelink-box .btn-group > .btn-group:not(:first-child):not(:last-child) > .deletelink, .submit-row .btn-group > .btn-group:not(:first-child):not(:last-child) > input[type='submit']:not([class*="btn-"]), .submit-row .btn-group > .btn-group:not(:first-child):not(:last-child) > input[type='button']:not([class*="btn-"]), .submit-row .btn-group > .btn-group:not(:first-child):not(:last-child) > button:not([class*="btn-"]), #content-main > .object-tools.btn-group > li.btn-group:not(:first-child):not(:last-child) > a:not([class*="btn-"]), body.login .submit-row .btn-group > .btn-group:not(:first-child):not(:last-child) > input[type='submit'], #changelist #toolbar #changelist-search .btn-group > .btn-group:not(:first-child):not(:last-child) > input[type='submit'], #changelist #changelist-form .actions .btn-group > .btn-group:not(:first-child):not(:last-child) > button, #changelist #changelist-form .paginator .btn-group > .btn-group:not(:first-child):not(:last-child) > input[type='submit'] {
    border-radius: 0;
}

.btn-group > .btn-group:first-child:not(:last-child) > .btn:last-child, body.delete-confirmation .content-wrap .btn-group > .btn-group:first-child:not(:last-child) > input[type='button']:last-child, body.delete-confirmation .content-wrap .btn-group > .btn-group:first-child:not(:last-child) > input[type='submit']:last-child, body.delete-confirmation .content-wrap .btn-group > .btn-group:first-child:not(:last-child) > button:last-child, .submit-row .deletelink-box .btn-group > .btn-group:first-child:not(:last-child) > .deletelink:last-child, .submit-row .btn-group > .btn-group:first-child:not(:last-child) > input[type='submit']:last-child:not([class*="btn-"]), .submit-row .btn-group > .btn-group:first-child:not(:last-child) > input[type='button']:last-child:not([class*="btn-"]), .submit-row .btn-group > .btn-group:first-child:not(:last-child) > button:last-child:not([class*="btn-"]), #content-main > .object-tools.btn-group > li.btn-group:first-child:not(:last-child) > a:last-child:not([class*="btn-"]), body.login .submit-row .btn-group > .btn-group:first-child:not(:last-child) > input[type='submit']:last-child, #changelist #toolbar #changelist-search .btn-group > .btn-group:first-child:not(:last-child) > input[type='submit']:last-child, #changelist #changelist-form .actions .btn-group > .btn-group:first-child:not(:last-child) > button:last-child, #changelist #changelist-form .paginator .btn-group > .btn-group:first-child:not(:last-child) > input[type='submit']:last-child, .btn-group > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
}

.btn-group > .btn-group:last-child:not(:first-child) > .btn:first-child, body.delete-confirmation .content-wrap .btn-group > .btn-group:last-child:not(:first-child) > input[type='button']:first-child, body.delete-confirmation .content-wrap .btn-group > .btn-group:last-child:not(:first-child) > input[type='submit']:first-child, body.delete-confirmation .content-wrap .btn-group > .btn-group:last-child:not(:first-child) > button:first-child, .submit-row .deletelink-box .btn-group > .btn-group:last-child:not(:first-child) > .deletelink:first-child, .submit-row .btn-group > .btn-group:last-child:not(:first-child) > input[type='submit']:first-child:not([class*="btn-"]), .submit-row .btn-group > .btn-group:last-child:not(:first-child) > input[type='button']:first-child:not([class*="btn-"]), .submit-row .btn-group > .btn-group:last-child:not(:first-child) > button:first-child:not([class*="btn-"]), #content-main > .object-tools.btn-group > li.btn-group:last-child:not(:first-child) > a:first-child:not([class*="btn-"]), body.login .submit-row .btn-group > .btn-group:last-child:not(:first-child) > input[type='submit']:first-child, #changelist #toolbar #changelist-search .btn-group > .btn-group:last-child:not(:first-child) > input[type='submit']:first-child, #changelist #changelist-form .actions .btn-group > .btn-group:last-child:not(:first-child) > button:first-child, #changelist #changelist-form .paginator .btn-group > .btn-group:last-child:not(:first-child) > input[type='submit']:first-child {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}

.btn-group .dropdown-toggle:active, .btn-group.open .dropdown-toggle {
    outline: 0;
}

.btn + .dropdown-toggle-split, body.delete-confirmation .content-wrap input[type='button'] + .dropdown-toggle-split, body.delete-confirmation .content-wrap input[type='submit'] + .dropdown-toggle-split, body.delete-confirmation .content-wrap button + .dropdown-toggle-split, .submit-row .deletelink-box .deletelink + .dropdown-toggle-split, .submit-row input[type='submit']:not([class*="btn-"]) + .dropdown-toggle-split, .submit-row input[type='button']:not([class*="btn-"]) + .dropdown-toggle-split, .submit-row button:not([class*="btn-"]) + .dropdown-toggle-split, #content-main > .object-tools > li > a:not([class*="btn-"]) + .dropdown-toggle-split, body.login .submit-row input[type='submit'] + .dropdown-toggle-split, #changelist #toolbar #changelist-search input[type='submit'] + .dropdown-toggle-split, #changelist #changelist-form .actions button + .dropdown-toggle-split, #changelist #changelist-form .paginator input[type='submit'] + .dropdown-toggle-split {
    padding-right: 0.75rem;
    padding-left: 0.75rem;
}

.btn + .dropdown-toggle-split::after, body.delete-confirmation .content-wrap input[type='button'] + .dropdown-toggle-split::after, body.delete-confirmation .content-wrap input[type='submit'] + .dropdown-toggle-split::after, body.delete-confirmation .content-wrap button + .dropdown-toggle-split::after, .submit-row .deletelink-box .deletelink + .dropdown-toggle-split::after, .submit-row input[type='submit']:not([class*="btn-"]) + .dropdown-toggle-split::after, .submit-row input[type='button']:not([class*="btn-"]) + .dropdown-toggle-split::after, .submit-row button:not([class*="btn-"]) + .dropdown-toggle-split::after, #content-main > .object-tools > li > a:not([class*="btn-"]) + .dropdown-toggle-split::after, body.login .submit-row input[type='submit'] + .dropdown-toggle-split::after, #changelist #toolbar #changelist-search input[type='submit'] + .dropdown-toggle-split::after, #changelist #changelist-form .actions button + .dropdown-toggle-split::after, #changelist #changelist-form .paginator input[type='submit'] + .dropdown-toggle-split::after {
    margin-left: 0;
}

.btn-sm + .dropdown-toggle-split, .btn-group-sm > .btn + .dropdown-toggle-split, body.delete-confirmation .content-wrap .btn-group-sm > input[type='button'] + .dropdown-toggle-split, body.delete-confirmation .content-wrap .btn-group-sm > input[type='submit'] + .dropdown-toggle-split, body.delete-confirmation .content-wrap .btn-group-sm > button + .dropdown-toggle-split, .submit-row .deletelink-box .btn-group-sm > .deletelink + .dropdown-toggle-split, .submit-row .btn-group-sm > input[type='submit']:not([class*="btn-"]) + .dropdown-toggle-split, .submit-row .btn-group-sm > input[type='button']:not([class*="btn-"]) + .dropdown-toggle-split, .submit-row .btn-group-sm > button:not([class*="btn-"]) + .dropdown-toggle-split, body.login .submit-row .btn-group-sm > input[type='submit'] + .dropdown-toggle-split, #changelist #toolbar #changelist-search .btn-group-sm > input[type='submit'] + .dropdown-toggle-split, #changelist #changelist-form .actions .btn-group-sm > button + .dropdown-toggle-split, #changelist #changelist-form .paginator .btn-group-sm > input[type='submit'] + .dropdown-toggle-split, #content-main > .object-tools > li > a:not([class*="btn-"]) + .dropdown-toggle-split {
    padding-right: 0.5625rem;
    padding-left: 0.5625rem;
}

.btn-lg + .dropdown-toggle-split, .btn-group-lg > .btn + .dropdown-toggle-split, body.delete-confirmation .content-wrap .btn-group-lg > input[type='button'] + .dropdown-toggle-split, body.delete-confirmation .content-wrap .btn-group-lg > input[type='submit'] + .dropdown-toggle-split, body.delete-confirmation .content-wrap .btn-group-lg > button + .dropdown-toggle-split, .submit-row .deletelink-box .btn-group-lg > .deletelink + .dropdown-toggle-split, .submit-row .btn-group-lg > input[type='submit']:not([class*="btn-"]) + .dropdown-toggle-split, .submit-row .btn-group-lg > input[type='button']:not([class*="btn-"]) + .dropdown-toggle-split, .submit-row .btn-group-lg > button:not([class*="btn-"]) + .dropdown-toggle-split, #content-main > .object-tools > li.btn-group-lg > a:not([class*="btn-"]) + .dropdown-toggle-split, body.login .submit-row .btn-group-lg > input[type='submit'] + .dropdown-toggle-split, #changelist #toolbar #changelist-search .btn-group-lg > input[type='submit'] + .dropdown-toggle-split, #changelist #changelist-form .actions .btn-group-lg > button + .dropdown-toggle-split, #changelist #changelist-form .paginator .btn-group-lg > input[type='submit'] + .dropdown-toggle-split, body.delete-confirmation .content-wrap input[type='button'] + .dropdown-toggle-split, body.delete-confirmation .content-wrap input[type='submit'] + .dropdown-toggle-split, body.delete-confirmation .content-wrap button + .dropdown-toggle-split, .submit-row input[type='submit']:not([class*="btn-"]) + .dropdown-toggle-split, .submit-row input[type='button']:not([class*="btn-"]) + .dropdown-toggle-split, .submit-row button:not([class*="btn-"]) + .dropdown-toggle-split, body.login .submit-row input[type='submit'] + .dropdown-toggle-split {
    padding-right: 1.125rem;
    padding-left: 1.125rem;
}

.btn .caret, body.delete-confirmation .content-wrap input[type='button'] .caret, body.delete-confirmation .content-wrap input[type='submit'] .caret, body.delete-confirmation .content-wrap button .caret, .submit-row .deletelink-box .deletelink .caret, .submit-row input[type='submit']:not([class*="btn-"]) .caret, .submit-row input[type='button']:not([class*="btn-"]) .caret, .submit-row button:not([class*="btn-"]) .caret, #content-main > .object-tools > li > a:not([class*="btn-"]) .caret, body.login .submit-row input[type='submit'] .caret, #changelist #toolbar #changelist-search input[type='submit'] .caret, #changelist #changelist-form .actions button .caret, #changelist #changelist-form .paginator input[type='submit'] .caret {
    margin-left: 0;
}

.btn-lg .caret, .btn-group-lg > .btn .caret, .submit-row .deletelink-box .btn-group-lg > .deletelink .caret, #content-main > .object-tools > li.btn-group-lg > a:not([class*="btn-"]) .caret, #changelist #toolbar #changelist-search .btn-group-lg > input[type='submit'] .caret, #changelist #changelist-form .actions .btn-group-lg > button .caret, #changelist #changelist-form .paginator .btn-group-lg > input[type='submit'] .caret, body.delete-confirmation .content-wrap input[type='button'] .caret, body.delete-confirmation .content-wrap input[type='submit'] .caret, body.delete-confirmation .content-wrap button .caret, .submit-row input[type='submit']:not([class*="btn-"]) .caret, .submit-row input[type='button']:not([class*="btn-"]) .caret, .submit-row button:not([class*="btn-"]) .caret, body.login .submit-row input[type='submit'] .caret {
    border-width: 0.3em 0.3em 0;
    border-bottom-width: 0;
}

.dropup .btn-lg .caret, .dropup .btn-group-lg > .btn .caret, .dropup .submit-row .deletelink-box .btn-group-lg > .deletelink .caret, .submit-row .deletelink-box .dropup .btn-group-lg > .deletelink .caret, .dropup #content-main > .object-tools > li.btn-group-lg > a:not([class*="btn-"]) .caret, .dropup #changelist #toolbar #changelist-search .btn-group-lg > input[type='submit'] .caret, #changelist #toolbar #changelist-search .dropup .btn-group-lg > input[type='submit'] .caret, .dropup #changelist #changelist-form .actions .btn-group-lg > button .caret, #changelist #changelist-form .actions .dropup .btn-group-lg > button .caret, .dropup #changelist #changelist-form .paginator .btn-group-lg > input[type='submit'] .caret, #changelist #changelist-form .paginator .dropup .btn-group-lg > input[type='submit'] .caret, .dropup body.delete-confirmation .content-wrap input[type='button'] .caret, body.delete-confirmation .content-wrap .dropup input[type='button'] .caret, .dropup body.delete-confirmation .content-wrap input[type='submit'] .caret, body.delete-confirmation .content-wrap .dropup input[type='submit'] .caret, .dropup body.delete-confirmation .content-wrap button .caret, body.delete-confirmation .content-wrap .dropup button .caret, .dropup .submit-row input[type='submit']:not([class*="btn-"]) .caret, .submit-row .dropup input[type='submit']:not([class*="btn-"]) .caret, .dropup .submit-row input[type='button']:not([class*="btn-"]) .caret, .submit-row .dropup input[type='button']:not([class*="btn-"]) .caret, .dropup .submit-row button:not([class*="btn-"]) .caret, .submit-row .dropup button:not([class*="btn-"]) .caret, .dropup body.login .submit-row input[type='submit'] .caret, body.login .submit-row .dropup input[type='submit'] .caret {
    border-width: 0 0.3em 0.3em;
}

.btn-group-vertical > .btn, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'], body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'], body.delete-confirmation .content-wrap .btn-group-vertical > button, .submit-row .deletelink-box .btn-group-vertical > .deletelink, .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]), .submit-row .btn-group-vertical > button:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > input[type='submit'], #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'], #changelist #changelist-form .actions .btn-group-vertical > button, #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'], .btn-group-vertical > .btn-group, .btn-group-vertical > .btn-group > .btn, body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group > input[type='button'], body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group > input[type='submit'], body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group > button, .submit-row .deletelink-box .btn-group-vertical > .btn-group > .deletelink, .submit-row .btn-group-vertical > .btn-group > input[type='submit']:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn-group > input[type='button']:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn-group > button:not([class*="btn-"]), #content-main > .object-tools.btn-group-vertical > li.btn-group > a:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > .btn-group > input[type='submit'], #changelist #toolbar #changelist-search .btn-group-vertical > .btn-group > input[type='submit'], #changelist #changelist-form .actions .btn-group-vertical > .btn-group > button, #changelist #changelist-form .paginator .btn-group-vertical > .btn-group > input[type='submit'] {
    display: block;
    float: none;
    width: 100%;
    max-width: 100%;
}

.btn-group-vertical > .btn-group::after {
    content: "";
    display: table;
    clear: both;
}

.btn-group-vertical > .btn-group > .btn, body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group > input[type='button'], body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group > input[type='submit'], body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group > button, .submit-row .deletelink-box .btn-group-vertical > .btn-group > .deletelink, .submit-row .btn-group-vertical > .btn-group > input[type='submit']:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn-group > input[type='button']:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn-group > button:not([class*="btn-"]), #content-main > .object-tools.btn-group-vertical > li.btn-group > a:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > .btn-group > input[type='submit'], #changelist #toolbar #changelist-search .btn-group-vertical > .btn-group > input[type='submit'], #changelist #changelist-form .actions .btn-group-vertical > .btn-group > button, #changelist #changelist-form .paginator .btn-group-vertical > .btn-group > input[type='submit'] {
    float: none;
}

.btn-group-vertical > .btn + .btn, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + .btn, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + .btn, body.delete-confirmation .content-wrap .btn-group-vertical > button + .btn, .submit-row .deletelink-box .btn-group-vertical > .deletelink + .btn, .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + .btn, .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]) + .btn, .submit-row .btn-group-vertical > button:not([class*="btn-"]) + .btn, #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + .btn, #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + .btn, body.login .submit-row .btn-group-vertical > input[type='submit'] + .btn, #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + .btn, #changelist #changelist-form .actions .btn-group-vertical > button + .btn, #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + .btn, body.delete-confirmation .content-wrap .btn-group-vertical > .btn + input[type='button'], body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + input[type='button'], body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap .btn-group-vertical > button + input[type='button'], .submit-row .deletelink-box body.delete-confirmation .content-wrap .btn-group-vertical > .deletelink + input[type='button'], body.delete-confirmation .content-wrap .submit-row .deletelink-box .btn-group-vertical > .deletelink + input[type='button'], .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + input[type='button'], .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button']:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]) + input[type='button'], .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > button:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > button:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + input[type='button'], body.login .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap body.login .submit-row .btn-group-vertical > input[type='submit'] + input[type='button'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + input[type='button'], #changelist #changelist-form .actions body.delete-confirmation .content-wrap .btn-group-vertical > button + input[type='button'], body.delete-confirmation .content-wrap #changelist #changelist-form .actions .btn-group-vertical > button + input[type='button'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap .btn-group-vertical > .btn + input[type='submit'], body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group-vertical > button + input[type='submit'], .submit-row .deletelink-box body.delete-confirmation .content-wrap .btn-group-vertical > .deletelink + input[type='submit'], body.delete-confirmation .content-wrap .submit-row .deletelink-box .btn-group-vertical > .deletelink + input[type='submit'], .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + input[type='submit'], .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button']:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]) + input[type='submit'], .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > button:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > button:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + input[type='submit'], body.login .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap body.login .submit-row .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #changelist-form .actions body.delete-confirmation .content-wrap .btn-group-vertical > button + input[type='submit'], body.delete-confirmation .content-wrap #changelist #changelist-form .actions .btn-group-vertical > button + input[type='submit'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap .btn-group-vertical > .btn + button, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + button, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + button, body.delete-confirmation .content-wrap .btn-group-vertical > button + button, .submit-row .deletelink-box body.delete-confirmation .content-wrap .btn-group-vertical > .deletelink + button, body.delete-confirmation .content-wrap .submit-row .deletelink-box .btn-group-vertical > .deletelink + button, .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + button, .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button']:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]) + button, .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > button:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > button:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + button, body.login .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + button, body.delete-confirmation .content-wrap body.login .submit-row .btn-group-vertical > input[type='submit'] + button, #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + button, body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + button, #changelist #changelist-form .actions body.delete-confirmation .content-wrap .btn-group-vertical > button + button, body.delete-confirmation .content-wrap #changelist #changelist-form .actions .btn-group-vertical > button + button, #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + button, body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + button, .submit-row .deletelink-box .btn-group-vertical > .btn + .deletelink, body.delete-confirmation .content-wrap .submit-row .deletelink-box .btn-group-vertical > input[type='button'] + .deletelink, .submit-row .deletelink-box body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + .deletelink, body.delete-confirmation .content-wrap .submit-row .deletelink-box .btn-group-vertical > input[type='submit'] + .deletelink, .submit-row .deletelink-box body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + .deletelink, body.delete-confirmation .content-wrap .submit-row .deletelink-box .btn-group-vertical > button + .deletelink, .submit-row .deletelink-box body.delete-confirmation .content-wrap .btn-group-vertical > button + .deletelink, .submit-row .deletelink-box .btn-group-vertical > .deletelink + .deletelink, .submit-row .deletelink-box .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box .btn-group-vertical > input[type='button']:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box .btn-group-vertical > button:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + .deletelink, body.login .submit-row .deletelink-box .btn-group-vertical > input[type='submit'] + .deletelink, #changelist #toolbar #changelist-search .submit-row .deletelink-box .btn-group-vertical > input[type='submit'] + .deletelink, .submit-row .deletelink-box #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + .deletelink, #changelist #changelist-form .actions .submit-row .deletelink-box .btn-group-vertical > button + .deletelink, .submit-row .deletelink-box #changelist #changelist-form .actions .btn-group-vertical > button + .deletelink, #changelist #changelist-form .paginator .submit-row .deletelink-box .btn-group-vertical > input[type='submit'] + .deletelink, .submit-row .deletelink-box #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + .deletelink, .submit-row .btn-group-vertical > .btn + input[type='submit']:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > input[type='button'] + input[type='submit']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + input[type='submit']:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='submit']:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > button + input[type='submit']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > button + input[type='submit']:not([class*="btn-"]), .submit-row .deletelink-box .btn-group-vertical > .deletelink + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group-vertical > button:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > input[type='submit'] + input[type='submit']:not([class*="btn-"]), #changelist #toolbar #changelist-search .submit-row .btn-group-vertical > input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + input[type='submit']:not([class*="btn-"]), #changelist #changelist-form .actions .submit-row .btn-group-vertical > button + input[type='submit']:not([class*="btn-"]), .submit-row #changelist #changelist-form .actions .btn-group-vertical > button + input[type='submit']:not([class*="btn-"]), #changelist #changelist-form .paginator .submit-row .btn-group-vertical > input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn + input[type='button']:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > input[type='button'] + input[type='button']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + input[type='button']:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='button']:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > button + input[type='button']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > button + input[type='button']:not([class*="btn-"]), .submit-row .deletelink-box .btn-group-vertical > .deletelink + input[type='button']:not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row .btn-group-vertical > button:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > input[type='submit'] + input[type='button']:not([class*="btn-"]), #changelist #toolbar #changelist-search .submit-row .btn-group-vertical > input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + input[type='button']:not([class*="btn-"]), #changelist #changelist-form .actions .submit-row .btn-group-vertical > button + input[type='button']:not([class*="btn-"]), .submit-row #changelist #changelist-form .actions .btn-group-vertical > button + input[type='button']:not([class*="btn-"]), #changelist #changelist-form .paginator .submit-row .btn-group-vertical > input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn + button:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > input[type='button'] + button:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + button:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > input[type='submit'] + button:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + button:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .btn-group-vertical > button + button:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > button + button:not([class*="btn-"]), .submit-row .deletelink-box .btn-group-vertical > .deletelink + button:not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row .btn-group-vertical > button:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + button:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > input[type='submit'] + button:not([class*="btn-"]), #changelist #toolbar #changelist-search .submit-row .btn-group-vertical > input[type='submit'] + button:not([class*="btn-"]), .submit-row #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + button:not([class*="btn-"]), #changelist #changelist-form .actions .submit-row .btn-group-vertical > button + button:not([class*="btn-"]), .submit-row #changelist #changelist-form .actions .btn-group-vertical > button + button:not([class*="btn-"]), #changelist #changelist-form .paginator .submit-row .btn-group-vertical > input[type='submit'] + button:not([class*="btn-"]), .submit-row #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + button:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > .btn + a:not([class*="btn-"]), body.delete-confirmation .content-wrap #content-main > .object-tools > li.btn-group-vertical > input[type='button'] + a:not([class*="btn-"]), body.delete-confirmation .content-wrap #content-main > .object-tools > li.btn-group-vertical > input[type='submit'] + a:not([class*="btn-"]), body.delete-confirmation .content-wrap #content-main > .object-tools > li.btn-group-vertical > button + a:not([class*="btn-"]), .submit-row .deletelink-box #content-main > .object-tools > li.btn-group-vertical > .deletelink + a:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.btn-group-vertical > input[type='submit']:not([class*="btn-"]) + a:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.btn-group-vertical > input[type='button']:not([class*="btn-"]) + a:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.btn-group-vertical > button:not([class*="btn-"]) + a:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + a:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + a:not([class*="btn-"]), body.login .submit-row #content-main > .object-tools > li.btn-group-vertical > input[type='submit'] + a:not([class*="btn-"]), #changelist #toolbar #changelist-search #content-main > .object-tools > li.btn-group-vertical > input[type='submit'] + a:not([class*="btn-"]), #changelist #changelist-form .actions #content-main > .object-tools > li.btn-group-vertical > button + a:not([class*="btn-"]), #changelist #changelist-form .paginator #content-main > .object-tools > li.btn-group-vertical > input[type='submit'] + a:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > .btn + a.addlink:not([class*="btn-"]), body.delete-confirmation .content-wrap #content-main > .object-tools > li.btn-group-vertical > input[type='button'] + a.addlink:not([class*="btn-"]), body.delete-confirmation .content-wrap #content-main > .object-tools > li.btn-group-vertical > input[type='submit'] + a.addlink:not([class*="btn-"]), body.delete-confirmation .content-wrap #content-main > .object-tools > li.btn-group-vertical > button + a.addlink:not([class*="btn-"]), .submit-row .deletelink-box #content-main > .object-tools > li.btn-group-vertical > .deletelink + a.addlink:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.btn-group-vertical > input[type='submit']:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.btn-group-vertical > input[type='button']:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.btn-group-vertical > button:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), body.login .submit-row #content-main > .object-tools > li.btn-group-vertical > input[type='submit'] + a.addlink:not([class*="btn-"]), #changelist #toolbar #changelist-search #content-main > .object-tools > li.btn-group-vertical > input[type='submit'] + a.addlink:not([class*="btn-"]), #changelist #changelist-form .actions #content-main > .object-tools > li.btn-group-vertical > button + a.addlink:not([class*="btn-"]), #changelist #changelist-form .paginator #content-main > .object-tools > li.btn-group-vertical > input[type='submit'] + a.addlink:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > .btn + input[type='submit'], body.delete-confirmation .content-wrap body.login .submit-row .btn-group-vertical > input[type='button'] + input[type='submit'], body.login .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + input[type='submit'], body.delete-confirmation .content-wrap body.login .submit-row .btn-group-vertical > input[type='submit'] + input[type='submit'], body.login .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap body.login .submit-row .btn-group-vertical > button + input[type='submit'], body.login .submit-row body.delete-confirmation .content-wrap .btn-group-vertical > button + input[type='submit'], body.login .submit-row .deletelink-box .btn-group-vertical > .deletelink + input[type='submit'], body.login .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + input[type='submit'], body.login .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]) + input[type='submit'], body.login .submit-row .btn-group-vertical > button:not([class*="btn-"]) + input[type='submit'], body.login .submit-row #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + input[type='submit'], body.login .submit-row #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + input[type='submit'], body.login .submit-row .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search body.login .submit-row .btn-group-vertical > input[type='submit'] + input[type='submit'], body.login .submit-row #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #changelist-form .actions body.login .submit-row .btn-group-vertical > button + input[type='submit'], body.login .submit-row #changelist #changelist-form .actions .btn-group-vertical > button + input[type='submit'], #changelist #changelist-form .paginator body.login .submit-row .btn-group-vertical > input[type='submit'] + input[type='submit'], body.login .submit-row #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search .btn-group-vertical > .btn + input[type='submit'], body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .btn-group-vertical > input[type='button'] + input[type='submit'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .btn-group-vertical > button + input[type='submit'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .btn-group-vertical > button + input[type='submit'], .submit-row .deletelink-box #changelist #toolbar #changelist-search .btn-group-vertical > .deletelink + input[type='submit'], #changelist #toolbar #changelist-search .submit-row .deletelink-box .btn-group-vertical > .deletelink + input[type='submit'], .submit-row #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + input[type='submit'], .submit-row #changelist #toolbar #changelist-search .btn-group-vertical > input[type='button']:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]) + input[type='submit'], .submit-row #changelist #toolbar #changelist-search .btn-group-vertical > button:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .submit-row .btn-group-vertical > button:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + input[type='submit'], body.login .submit-row #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search body.login .submit-row .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #changelist-form .actions #toolbar #changelist-search .btn-group-vertical > button + input[type='submit'], #changelist #toolbar #changelist-search #changelist-form .actions .btn-group-vertical > button + input[type='submit'], #changelist #changelist-form .paginator #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search #changelist-form .paginator .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #changelist-form .actions .btn-group-vertical > .btn + button, body.delete-confirmation .content-wrap #changelist #changelist-form .actions .btn-group-vertical > input[type='button'] + button, #changelist #changelist-form .actions body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + button, body.delete-confirmation .content-wrap #changelist #changelist-form .actions .btn-group-vertical > input[type='submit'] + button, #changelist #changelist-form .actions body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + button, body.delete-confirmation .content-wrap #changelist #changelist-form .actions .btn-group-vertical > button + button, #changelist #changelist-form .actions body.delete-confirmation .content-wrap .btn-group-vertical > button + button, .submit-row .deletelink-box #changelist #changelist-form .actions .btn-group-vertical > .deletelink + button, #changelist #changelist-form .actions .submit-row .deletelink-box .btn-group-vertical > .deletelink + button, .submit-row #changelist #changelist-form .actions .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + button, #changelist #changelist-form .actions .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + button, .submit-row #changelist #changelist-form .actions .btn-group-vertical > input[type='button']:not([class*="btn-"]) + button, #changelist #changelist-form .actions .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]) + button, .submit-row #changelist #changelist-form .actions .btn-group-vertical > button:not([class*="btn-"]) + button, #changelist #changelist-form .actions .submit-row .btn-group-vertical > button:not([class*="btn-"]) + button, #changelist #changelist-form .actions #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + button, #changelist #changelist-form .actions #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + button, body.login .submit-row #changelist #changelist-form .actions .btn-group-vertical > input[type='submit'] + button, #changelist #changelist-form .actions body.login .submit-row .btn-group-vertical > input[type='submit'] + button, #changelist #toolbar #changelist-search #changelist-form .actions .btn-group-vertical > input[type='submit'] + button, #changelist #changelist-form .actions #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + button, #changelist #changelist-form .actions .btn-group-vertical > button + button, #changelist #changelist-form .paginator .actions .btn-group-vertical > input[type='submit'] + button, #changelist #changelist-form .actions .paginator .btn-group-vertical > input[type='submit'] + button, #changelist #changelist-form .paginator .btn-group-vertical > .btn + input[type='submit'], body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .btn-group-vertical > input[type='button'] + input[type='submit'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .btn-group-vertical > button + input[type='submit'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .btn-group-vertical > button + input[type='submit'], .submit-row .deletelink-box #changelist #changelist-form .paginator .btn-group-vertical > .deletelink + input[type='submit'], #changelist #changelist-form .paginator .submit-row .deletelink-box .btn-group-vertical > .deletelink + input[type='submit'], .submit-row #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + input[type='submit'], .submit-row #changelist #changelist-form .paginator .btn-group-vertical > input[type='button']:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]) + input[type='submit'], .submit-row #changelist #changelist-form .paginator .btn-group-vertical > button:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .submit-row .btn-group-vertical > button:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator #content-main > .object-tools > li.btn-group-vertical > a.addlink:not([class*="btn-"]) + input[type='submit'], body.login .submit-row #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator body.login .submit-row .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search #changelist-form .paginator .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + input[type='submit'], #changelist #changelist-form .actions .paginator .btn-group-vertical > button + input[type='submit'], #changelist #changelist-form .paginator .actions .btn-group-vertical > button + input[type='submit'], #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + input[type='submit'], .btn-group-vertical > .btn + .btn-group, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button'] + .btn-group, body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit'] + .btn-group, body.delete-confirmation .content-wrap .btn-group-vertical > button + .btn-group, .submit-row .deletelink-box .btn-group-vertical > .deletelink + .btn-group, .submit-row .btn-group-vertical > input[type='submit']:not([class*="btn-"]) + .btn-group, .submit-row .btn-group-vertical > input[type='button']:not([class*="btn-"]) + .btn-group, .submit-row .btn-group-vertical > button:not([class*="btn-"]) + .btn-group, #content-main > .object-tools > li.btn-group-vertical > a:not([class*="btn-"]) + .btn-group, body.login .submit-row .btn-group-vertical > input[type='submit'] + .btn-group, #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit'] + .btn-group, #changelist #changelist-form .actions .btn-group-vertical > button + .btn-group, #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit'] + .btn-group, .btn-group-vertical > .btn-group + .btn, body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group + input[type='button'], body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group + input[type='submit'], body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group + button, .submit-row .deletelink-box .btn-group-vertical > .btn-group + .deletelink, .submit-row .btn-group-vertical > .btn-group + input[type='submit']:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn-group + input[type='button']:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn-group + button:not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > .btn-group + a:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > .btn-group + input[type='submit'], #changelist #toolbar #changelist-search .btn-group-vertical > .btn-group + input[type='submit'], #changelist #changelist-form .actions .btn-group-vertical > .btn-group + button, #changelist #changelist-form .paginator .btn-group-vertical > .btn-group + input[type='submit'], .btn-group-vertical > .btn-group + .btn-group {
    margin-top: -1px;
    margin-left: 0;
}

.btn-group-vertical > .btn:not(:first-child):not(:last-child), body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button']:not(:first-child):not(:last-child), body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit']:not(:first-child):not(:last-child), body.delete-confirmation .content-wrap .btn-group-vertical > button:not(:first-child):not(:last-child), .submit-row .deletelink-box .btn-group-vertical > .deletelink:not(:first-child):not(:last-child), .submit-row .btn-group-vertical > input[type='submit']:not(:first-child):not(:last-child):not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='button']:not(:first-child):not(:last-child):not([class*="btn-"]), .submit-row .btn-group-vertical > button:not(:first-child):not(:last-child):not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a:not(:first-child):not(:last-child):not([class*="btn-"]), body.login .submit-row .btn-group-vertical > input[type='submit']:not(:first-child):not(:last-child), #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit']:not(:first-child):not(:last-child), #changelist #changelist-form .actions .btn-group-vertical > button:not(:first-child):not(:last-child), #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit']:not(:first-child):not(:last-child) {
    border-radius: 0;
}

.btn-group-vertical > .btn:first-child:not(:last-child), body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button']:first-child:not(:last-child), body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit']:first-child:not(:last-child), body.delete-confirmation .content-wrap .btn-group-vertical > button:first-child:not(:last-child), .submit-row .deletelink-box .btn-group-vertical > .deletelink:first-child:not(:last-child), .submit-row .btn-group-vertical > input[type='submit']:first-child:not(:last-child):not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='button']:first-child:not(:last-child):not([class*="btn-"]), .submit-row .btn-group-vertical > button:first-child:not(:last-child):not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a:first-child:not(:last-child):not([class*="btn-"]), body.login .submit-row .btn-group-vertical > input[type='submit']:first-child:not(:last-child), #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit']:first-child:not(:last-child), #changelist #changelist-form .actions .btn-group-vertical > button:first-child:not(:last-child), #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit']:first-child:not(:last-child) {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
}

.btn-group-vertical > .btn:last-child:not(:first-child), body.delete-confirmation .content-wrap .btn-group-vertical > input[type='button']:last-child:not(:first-child), body.delete-confirmation .content-wrap .btn-group-vertical > input[type='submit']:last-child:not(:first-child), body.delete-confirmation .content-wrap .btn-group-vertical > button:last-child:not(:first-child), .submit-row .deletelink-box .btn-group-vertical > .deletelink:last-child:not(:first-child), .submit-row .btn-group-vertical > input[type='submit']:last-child:not(:first-child):not([class*="btn-"]), .submit-row .btn-group-vertical > input[type='button']:last-child:not(:first-child):not([class*="btn-"]), .submit-row .btn-group-vertical > button:last-child:not(:first-child):not([class*="btn-"]), #content-main > .object-tools > li.btn-group-vertical > a:last-child:not(:first-child):not([class*="btn-"]), body.login .submit-row .btn-group-vertical > input[type='submit']:last-child:not(:first-child), #changelist #toolbar #changelist-search .btn-group-vertical > input[type='submit']:last-child:not(:first-child), #changelist #changelist-form .actions .btn-group-vertical > button:last-child:not(:first-child), #changelist #changelist-form .paginator .btn-group-vertical > input[type='submit']:last-child:not(:first-child) {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
}

.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn, body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > input[type='button'], body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > input[type='submit'], body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > button, .submit-row .deletelink-box .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .deletelink, .submit-row .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > input[type='submit']:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > input[type='button']:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > button:not([class*="btn-"]), #content-main > .object-tools.btn-group-vertical > li.btn-group:not(:first-child):not(:last-child) > a:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > input[type='submit'], #changelist #toolbar #changelist-search .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > input[type='submit'], #changelist #changelist-form .actions .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > button, #changelist #changelist-form .paginator .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > input[type='submit'] {
    border-radius: 0;
}

.btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child, body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group:first-child:not(:last-child) > input[type='button']:last-child, body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group:first-child:not(:last-child) > input[type='submit']:last-child, body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group:first-child:not(:last-child) > button:last-child, .submit-row .deletelink-box .btn-group-vertical > .btn-group:first-child:not(:last-child) > .deletelink:last-child, .submit-row .btn-group-vertical > .btn-group:first-child:not(:last-child) > input[type='submit']:last-child:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn-group:first-child:not(:last-child) > input[type='button']:last-child:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn-group:first-child:not(:last-child) > button:last-child:not([class*="btn-"]), #content-main > .object-tools.btn-group-vertical > li.btn-group:first-child:not(:last-child) > a:last-child:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > .btn-group:first-child:not(:last-child) > input[type='submit']:last-child, #changelist #toolbar #changelist-search .btn-group-vertical > .btn-group:first-child:not(:last-child) > input[type='submit']:last-child, #changelist #changelist-form .actions .btn-group-vertical > .btn-group:first-child:not(:last-child) > button:last-child, #changelist #changelist-form .paginator .btn-group-vertical > .btn-group:first-child:not(:last-child) > input[type='submit']:last-child, .btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
}

.btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child, body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group:last-child:not(:first-child) > input[type='button']:first-child, body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group:last-child:not(:first-child) > input[type='submit']:first-child, body.delete-confirmation .content-wrap .btn-group-vertical > .btn-group:last-child:not(:first-child) > button:first-child, .submit-row .deletelink-box .btn-group-vertical > .btn-group:last-child:not(:first-child) > .deletelink:first-child, .submit-row .btn-group-vertical > .btn-group:last-child:not(:first-child) > input[type='submit']:first-child:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn-group:last-child:not(:first-child) > input[type='button']:first-child:not([class*="btn-"]), .submit-row .btn-group-vertical > .btn-group:last-child:not(:first-child) > button:first-child:not([class*="btn-"]), #content-main > .object-tools.btn-group-vertical > li.btn-group:last-child:not(:first-child) > a:first-child:not([class*="btn-"]), body.login .submit-row .btn-group-vertical > .btn-group:last-child:not(:first-child) > input[type='submit']:first-child, #changelist #toolbar #changelist-search .btn-group-vertical > .btn-group:last-child:not(:first-child) > input[type='submit']:first-child, #changelist #changelist-form .actions .btn-group-vertical > .btn-group:last-child:not(:first-child) > button:first-child, #changelist #changelist-form .paginator .btn-group-vertical > .btn-group:last-child:not(:first-child) > input[type='submit']:first-child {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
}

[data-toggle="buttons"] > .btn input[type="radio"], body.delete-confirmation .content-wrap [data-toggle="buttons"] > input[type='button'] input[type="radio"], body.delete-confirmation .content-wrap [data-toggle="buttons"] > input[type='submit'] input[type="radio"], body.delete-confirmation .content-wrap [data-toggle="buttons"] > button input[type="radio"], .submit-row .deletelink-box [data-toggle="buttons"] > .deletelink input[type="radio"], .submit-row [data-toggle="buttons"] > input[type='submit']:not([class*="btn-"]) input[type="radio"], .submit-row [data-toggle="buttons"] > input[type='button']:not([class*="btn-"]) input[type="radio"], .submit-row [data-toggle="buttons"] > button:not([class*="btn-"]) input[type="radio"], #content-main > .object-tools > li[data-toggle="buttons"] > a:not([class*="btn-"]) input[type="radio"], body.login .submit-row [data-toggle="buttons"] > input[type='submit'] input[type="radio"], #changelist #toolbar #changelist-search [data-toggle="buttons"] > input[type='submit'] input[type="radio"], #changelist #changelist-form .actions [data-toggle="buttons"] > button input[type="radio"], #changelist #changelist-form .paginator [data-toggle="buttons"] > input[type='submit'] input[type="radio"], [data-toggle="buttons"] > .btn input[type="checkbox"], body.delete-confirmation .content-wrap [data-toggle="buttons"] > input[type='button'] input[type="checkbox"], body.delete-confirmation .content-wrap [data-toggle="buttons"] > input[type='submit'] input[type="checkbox"], body.delete-confirmation .content-wrap [data-toggle="buttons"] > button input[type="checkbox"], .submit-row .deletelink-box [data-toggle="buttons"] > .deletelink input[type="checkbox"], .submit-row [data-toggle="buttons"] > input[type='submit']:not([class*="btn-"]) input[type="checkbox"], .submit-row [data-toggle="buttons"] > input[type='button']:not([class*="btn-"]) input[type="checkbox"], .submit-row [data-toggle="buttons"] > button:not([class*="btn-"]) input[type="checkbox"], #content-main > .object-tools > li[data-toggle="buttons"] > a:not([class*="btn-"]) input[type="checkbox"], body.login .submit-row [data-toggle="buttons"] > input[type='submit'] input[type="checkbox"], #changelist #toolbar #changelist-search [data-toggle="buttons"] > input[type='submit'] input[type="checkbox"], #changelist #changelist-form .actions [data-toggle="buttons"] > button input[type="checkbox"], #changelist #changelist-form .paginator [data-toggle="buttons"] > input[type='submit'] input[type="checkbox"], [data-toggle="buttons"] > .btn-group > .btn input[type="radio"], body.delete-confirmation .content-wrap [data-toggle="buttons"] > .btn-group > input[type='button'] input[type="radio"], body.delete-confirmation .content-wrap [data-toggle="buttons"] > .btn-group > input[type='submit'] input[type="radio"], body.delete-confirmation .content-wrap [data-toggle="buttons"] > .btn-group > button input[type="radio"], .submit-row .deletelink-box [data-toggle="buttons"] > .btn-group > .deletelink input[type="radio"], .submit-row [data-toggle="buttons"] > .btn-group > input[type='submit']:not([class*="btn-"]) input[type="radio"], .submit-row [data-toggle="buttons"] > .btn-group > input[type='button']:not([class*="btn-"]) input[type="radio"], .submit-row [data-toggle="buttons"] > .btn-group > button:not([class*="btn-"]) input[type="radio"], #content-main > .object-tools[data-toggle="buttons"] > li.btn-group > a:not([class*="btn-"]) input[type="radio"], body.login .submit-row [data-toggle="buttons"] > .btn-group > input[type='submit'] input[type="radio"], #changelist #toolbar #changelist-search [data-toggle="buttons"] > .btn-group > input[type='submit'] input[type="radio"], #changelist #changelist-form .actions [data-toggle="buttons"] > .btn-group > button input[type="radio"], #changelist #changelist-form .paginator [data-toggle="buttons"] > .btn-group > input[type='submit'] input[type="radio"], [data-toggle="buttons"] > .btn-group > .btn input[type="checkbox"], body.delete-confirmation .content-wrap [data-toggle="buttons"] > .btn-group > input[type='button'] input[type="checkbox"], body.delete-confirmation .content-wrap [data-toggle="buttons"] > .btn-group > input[type='submit'] input[type="checkbox"], body.delete-confirmation .content-wrap [data-toggle="buttons"] > .btn-group > button input[type="checkbox"], .submit-row .deletelink-box [data-toggle="buttons"] > .btn-group > .deletelink input[type="checkbox"], .submit-row [data-toggle="buttons"] > .btn-group > input[type='submit']:not([class*="btn-"]) input[type="checkbox"], .submit-row [data-toggle="buttons"] > .btn-group > input[type='button']:not([class*="btn-"]) input[type="checkbox"], .submit-row [data-toggle="buttons"] > .btn-group > button:not([class*="btn-"]) input[type="checkbox"], #content-main > .object-tools[data-toggle="buttons"] > li.btn-group > a:not([class*="btn-"]) input[type="checkbox"], body.login .submit-row [data-toggle="buttons"] > .btn-group > input[type='submit'] input[type="checkbox"], #changelist #toolbar #changelist-search [data-toggle="buttons"] > .btn-group > input[type='submit'] input[type="checkbox"], #changelist #changelist-form .actions [data-toggle="buttons"] > .btn-group > button input[type="checkbox"], #changelist #changelist-form .paginator [data-toggle="buttons"] > .btn-group > input[type='submit'] input[type="checkbox"] {
    position: absolute;
    clip: rect(0, 0, 0, 0);
    pointer-events: none;
}

.input-group {
    position: relative;
    width: 100%;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
}

.input-group .form-control, .input-group fieldset input[type=text], fieldset .input-group input[type=text], .input-group fieldset input[type=url], fieldset .input-group input[type=url], .input-group fieldset input[type=email], fieldset .input-group input[type=email], .input-group fieldset input[type=number], fieldset .input-group input[type=number], .input-group fieldset input[type=password], fieldset .input-group input[type=password], .input-group fieldset input[type=date], fieldset .input-group input[type=date], .input-group fieldset input[type=tel], fieldset .input-group input[type=tel], .input-group fieldset .vTextField, fieldset .input-group .vTextField, .input-group fieldset .vURLField, fieldset .input-group .vURLField, .input-group fieldset .vLargeTextField, fieldset .input-group .vLargeTextField, .input-group fieldset .vTimeField, fieldset .input-group .vTimeField, .input-group fieldset .vDateField, fieldset .input-group .vDateField, .input-group .selector .selector-available select, .selector .selector-available .input-group select, .input-group .selector .selector-chosen select, .selector .selector-chosen .input-group select, .input-group #changelist #toolbar #changelist-search input[type='text'], #changelist #toolbar #changelist-search .input-group input[type='text'], .input-group #changelist #changelist-form .actions select, #changelist #changelist-form .actions .input-group select {
    position: relative;
    z-index: 2;
    -webkit-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
    margin-bottom: 0;
}

.input-group .form-control:focus, .input-group fieldset input[type=text]:focus, fieldset .input-group input[type=text]:focus, .input-group fieldset input[type=url]:focus, fieldset .input-group input[type=url]:focus, .input-group fieldset input[type=email]:focus, fieldset .input-group input[type=email]:focus, .input-group fieldset input[type=number]:focus, fieldset .input-group input[type=number]:focus, .input-group fieldset input[type=password]:focus, fieldset .input-group input[type=password]:focus, .input-group fieldset input[type=date]:focus, fieldset .input-group input[type=date]:focus, .input-group fieldset input[type=tel]:focus, fieldset .input-group input[type=tel]:focus, .input-group fieldset .vTextField:focus, fieldset .input-group .vTextField:focus, .input-group fieldset .vURLField:focus, fieldset .input-group .vURLField:focus, .input-group fieldset .vLargeTextField:focus, fieldset .input-group .vLargeTextField:focus, .input-group fieldset .vTimeField:focus, fieldset .input-group .vTimeField:focus, .input-group fieldset .vDateField:focus, fieldset .input-group .vDateField:focus, .input-group .selector .selector-available select:focus, .selector .selector-available .input-group select:focus, .input-group .selector .selector-chosen select:focus, .selector .selector-chosen .input-group select:focus, .input-group #changelist #toolbar #changelist-search input[type='text']:focus, #changelist #toolbar #changelist-search .input-group input[type='text']:focus, .input-group #changelist #changelist-form .actions select:focus, #changelist #changelist-form .actions .input-group select:focus, .input-group .form-control:active, .input-group fieldset input[type=text]:active, fieldset .input-group input[type=text]:active, .input-group fieldset input[type=url]:active, fieldset .input-group input[type=url]:active, .input-group fieldset input[type=email]:active, fieldset .input-group input[type=email]:active, .input-group fieldset input[type=number]:active, fieldset .input-group input[type=number]:active, .input-group fieldset input[type=password]:active, fieldset .input-group input[type=password]:active, .input-group fieldset input[type=date]:active, fieldset .input-group input[type=date]:active, .input-group fieldset input[type=tel]:active, fieldset .input-group input[type=tel]:active, .input-group fieldset .vTextField:active, fieldset .input-group .vTextField:active, .input-group fieldset .vURLField:active, fieldset .input-group .vURLField:active, .input-group fieldset .vLargeTextField:active, fieldset .input-group .vLargeTextField:active, .input-group fieldset .vTimeField:active, fieldset .input-group .vTimeField:active, .input-group fieldset .vDateField:active, fieldset .input-group .vDateField:active, .input-group .selector .selector-available select:active, .selector .selector-available .input-group select:active, .input-group .selector .selector-chosen select:active, .selector .selector-chosen .input-group select:active, .input-group #changelist #toolbar #changelist-search input[type='text']:active, #changelist #toolbar #changelist-search .input-group input[type='text']:active, .input-group #changelist #changelist-form .actions select:active, #changelist #changelist-form .actions .input-group select:active, .input-group .form-control:hover, .input-group fieldset input[type=text]:hover, fieldset .input-group input[type=text]:hover, .input-group fieldset input[type=url]:hover, fieldset .input-group input[type=url]:hover, .input-group fieldset input[type=email]:hover, fieldset .input-group input[type=email]:hover, .input-group fieldset input[type=number]:hover, fieldset .input-group input[type=number]:hover, .input-group fieldset input[type=password]:hover, fieldset .input-group input[type=password]:hover, .input-group fieldset input[type=date]:hover, fieldset .input-group input[type=date]:hover, .input-group fieldset input[type=tel]:hover, fieldset .input-group input[type=tel]:hover, .input-group fieldset .vTextField:hover, fieldset .input-group .vTextField:hover, .input-group fieldset .vURLField:hover, fieldset .input-group .vURLField:hover, .input-group fieldset .vLargeTextField:hover, fieldset .input-group .vLargeTextField:hover, .input-group fieldset .vTimeField:hover, fieldset .input-group .vTimeField:hover, .input-group fieldset .vDateField:hover, fieldset .input-group .vDateField:hover, .input-group .selector .selector-available select:hover, .selector .selector-available .input-group select:hover, .input-group .selector .selector-chosen select:hover, .selector .selector-chosen .input-group select:hover, .input-group #changelist #toolbar #changelist-search input[type='text']:hover, #changelist #toolbar #changelist-search .input-group input[type='text']:hover, .input-group #changelist #changelist-form .actions select:hover, #changelist #changelist-form .actions .input-group select:hover {
    z-index: 3;
}

.input-group-addon:not(:first-child):not(:last-child), .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink']:not(:first-child):not(:last-child), .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink']:not(:first-child):not(:last-child), .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink']:not(:first-child):not(:last-child), .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink']:not(:first-child):not(:last-child), .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink']:not(:first-child):not(:last-child), .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink']:not(:first-child):not(:last-child), .input-group-btn:not(:first-child):not(:last-child), .input-group .form-control:not(:first-child):not(:last-child), .input-group fieldset input[type=text]:not(:first-child):not(:last-child), fieldset .input-group input[type=text]:not(:first-child):not(:last-child), .input-group fieldset input[type=url]:not(:first-child):not(:last-child), fieldset .input-group input[type=url]:not(:first-child):not(:last-child), .input-group fieldset input[type=email]:not(:first-child):not(:last-child), fieldset .input-group input[type=email]:not(:first-child):not(:last-child), .input-group fieldset input[type=number]:not(:first-child):not(:last-child), fieldset .input-group input[type=number]:not(:first-child):not(:last-child), .input-group fieldset input[type=password]:not(:first-child):not(:last-child), fieldset .input-group input[type=password]:not(:first-child):not(:last-child), .input-group fieldset input[type=date]:not(:first-child):not(:last-child), fieldset .input-group input[type=date]:not(:first-child):not(:last-child), .input-group fieldset input[type=tel]:not(:first-child):not(:last-child), fieldset .input-group input[type=tel]:not(:first-child):not(:last-child), .input-group fieldset .vTextField:not(:first-child):not(:last-child), fieldset .input-group .vTextField:not(:first-child):not(:last-child), .input-group fieldset .vURLField:not(:first-child):not(:last-child), fieldset .input-group .vURLField:not(:first-child):not(:last-child), .input-group fieldset .vLargeTextField:not(:first-child):not(:last-child), fieldset .input-group .vLargeTextField:not(:first-child):not(:last-child), .input-group fieldset .vTimeField:not(:first-child):not(:last-child), fieldset .input-group .vTimeField:not(:first-child):not(:last-child), .input-group fieldset .vDateField:not(:first-child):not(:last-child), fieldset .input-group .vDateField:not(:first-child):not(:last-child), .input-group .selector .selector-available select:not(:first-child):not(:last-child), .selector .selector-available .input-group select:not(:first-child):not(:last-child), .input-group .selector .selector-chosen select:not(:first-child):not(:last-child), .selector .selector-chosen .input-group select:not(:first-child):not(:last-child), .input-group #changelist #toolbar #changelist-search input[type='text']:not(:first-child):not(:last-child), #changelist #toolbar #changelist-search .input-group input[type='text']:not(:first-child):not(:last-child), .input-group #changelist #changelist-form .actions select:not(:first-child):not(:last-child), #changelist #changelist-form .actions .input-group select:not(:first-child):not(:last-child) {
    border-radius: 0;
}

.input-group-addon, .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'], .input-group-btn {
    white-space: nowrap;
    vertical-align: middle;
}

.input-group-addon, .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'] {
    padding: 0.5rem 0.75rem;
    margin-bottom: 0;
    font-size: 1rem;
    font-weight: normal;
    line-height: 1.25;
    color: #55595c;
    text-align: center;
    background-color: #eceeef;
    border: 1px solid rgba(0, 0, 0, 0.15);
    border-radius: 0.25rem;
}

.input-group-addon.form-control-sm, .input-group-sm > .input-group-addon.form-control, fieldset .input-group-sm > input.input-group-addon[type=text], fieldset .input-group-sm > input.input-group-addon[type=url], fieldset .input-group-sm > input.input-group-addon[type=email], fieldset .input-group-sm > input.input-group-addon[type=number], fieldset .input-group-sm > input.input-group-addon[type=password], fieldset .input-group-sm > input.input-group-addon[type=date], fieldset .input-group-sm > input.input-group-addon[type=tel], fieldset .input-group-sm > .input-group-addon.vTextField, fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.vTextField[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-sm > a.vTextField[id^='calendarlink'], fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.vTextField[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-sm > a.vTextField[id^='clocklink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.vTextField[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-sm > a.vTextField[id^='calendarlink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.vTextField[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-sm > a.vTextField[id^='clocklink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.vTextField[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-sm > a.vTextField[id^='calendarlink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.vTextField[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-sm > a.vTextField[id^='clocklink'], fieldset .input-group-sm > .input-group-addon.vURLField, fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.vURLField[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-sm > a.vURLField[id^='calendarlink'], fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.vURLField[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-sm > a.vURLField[id^='clocklink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.vURLField[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-sm > a.vURLField[id^='calendarlink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.vURLField[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-sm > a.vURLField[id^='clocklink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.vURLField[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-sm > a.vURLField[id^='calendarlink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.vURLField[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-sm > a.vURLField[id^='clocklink'], fieldset .input-group-sm > .input-group-addon.vLargeTextField, fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.vLargeTextField[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-sm > a.vLargeTextField[id^='calendarlink'], fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.vLargeTextField[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-sm > a.vLargeTextField[id^='clocklink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.vLargeTextField[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-sm > a.vLargeTextField[id^='calendarlink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.vLargeTextField[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-sm > a.vLargeTextField[id^='clocklink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.vLargeTextField[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-sm > a.vLargeTextField[id^='calendarlink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.vLargeTextField[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-sm > a.vLargeTextField[id^='clocklink'], fieldset .input-group-sm > .input-group-addon.vTimeField, fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.vTimeField[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-sm > a.vTimeField[id^='calendarlink'], fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.vTimeField[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-sm > a.vTimeField[id^='clocklink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.vTimeField[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-sm > a.vTimeField[id^='calendarlink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.vTimeField[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-sm > a.vTimeField[id^='clocklink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.vTimeField[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-sm > a.vTimeField[id^='calendarlink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.vTimeField[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-sm > a.vTimeField[id^='clocklink'], fieldset .input-group-sm > .input-group-addon.vDateField, fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.vDateField[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-sm > a.vDateField[id^='calendarlink'], fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.vDateField[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-sm > a.vDateField[id^='clocklink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.vDateField[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-sm > a.vDateField[id^='calendarlink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.vDateField[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-sm > a.vDateField[id^='clocklink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.vDateField[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-sm > a.vDateField[id^='calendarlink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.vDateField[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-sm > a.vDateField[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.form-control[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a.form-control[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.form-control[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a.form-control[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.form-control[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a.form-control[id^='clocklink'], .selector .selector-available .input-group-sm > select.input-group-addon, .selector .selector-chosen .input-group-sm > select.input-group-addon, #changelist #toolbar #changelist-search .input-group-sm > input.input-group-addon[type='text'], #changelist #changelist-form .actions .input-group-sm > select.input-group-addon, .input-group-sm > .input-group-addon, .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a[id^='clocklink'], .input-group-sm > .input-group-btn > .input-group-addon.btn, .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > .input-group-btn > a.btn[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .submit-row .deletelink-box .input-group-sm > .input-group-btn > a[id^='calendarlink'].deletelink, .submit-row .deletelink-box .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > .input-group-btn > a[id^='calendarlink'].deletelink, .widget-AdminSplitDateTime .datetimeshortcuts #content-main > .object-tools.input-group-sm > li.input-group-btn > a[id^='calendarlink']:not([class*="btn-"]), .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > .input-group-btn > a.btn[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts .submit-row .deletelink-box .input-group-sm > .input-group-btn > a[id^='clocklink'].deletelink, .submit-row .deletelink-box .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > .input-group-btn > a[id^='clocklink'].deletelink, .widget-AdminSplitDateTime .datetimeshortcuts #content-main > .object-tools.input-group-sm > li.input-group-btn > a[id^='clocklink']:not([class*="btn-"]), .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > .input-group-btn > a.btn[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .submit-row .deletelink-box .input-group-sm > .input-group-btn > a[id^='calendarlink'].deletelink, .submit-row .deletelink-box .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > .input-group-btn > a[id^='calendarlink'].deletelink, .widget-AdminDateWidget .datetimeshortcuts #content-main > .object-tools.input-group-sm > li.input-group-btn > a[id^='calendarlink']:not([class*="btn-"]), .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > .input-group-btn > a.btn[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .submit-row .deletelink-box .input-group-sm > .input-group-btn > a[id^='clocklink'].deletelink, .submit-row .deletelink-box .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > .input-group-btn > a[id^='clocklink'].deletelink, .widget-AdminDateWidget .datetimeshortcuts #content-main > .object-tools.input-group-sm > li.input-group-btn > a[id^='clocklink']:not([class*="btn-"]), .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > .input-group-btn > a.btn[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .submit-row .deletelink-box .input-group-sm > .input-group-btn > a[id^='calendarlink'].deletelink, .submit-row .deletelink-box .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > .input-group-btn > a[id^='calendarlink'].deletelink, .widget-AdminTimeWidget .datetimeshortcuts #content-main > .object-tools.input-group-sm > li.input-group-btn > a[id^='calendarlink']:not([class*="btn-"]), .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > .input-group-btn > a.btn[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .submit-row .deletelink-box .input-group-sm > .input-group-btn > a[id^='clocklink'].deletelink, .submit-row .deletelink-box .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > .input-group-btn > a[id^='clocklink'].deletelink, .widget-AdminTimeWidget .datetimeshortcuts #content-main > .object-tools.input-group-sm > li.input-group-btn > a[id^='clocklink']:not([class*="btn-"]), body.delete-confirmation .content-wrap .input-group-sm > .input-group-btn > input.input-group-addon[type='button'], body.delete-confirmation .content-wrap .input-group-sm > .input-group-btn > input.input-group-addon[type='submit'], body.delete-confirmation .content-wrap .input-group-sm > .input-group-btn > button.input-group-addon, .submit-row .deletelink-box .input-group-sm > .input-group-btn > .input-group-addon.deletelink, .submit-row .input-group-sm > .input-group-btn > input.input-group-addon[type='submit']:not([class*="btn-"]), .submit-row .input-group-sm > .input-group-btn > input.input-group-addon[type='button']:not([class*="btn-"]), .submit-row .input-group-sm > .input-group-btn > button.input-group-addon:not([class*="btn-"]), #content-main > .object-tools.input-group-sm > li.input-group-btn > a.input-group-addon:not([class*="btn-"]), body.login .submit-row .input-group-sm > .input-group-btn > input.input-group-addon[type='submit'], #changelist #toolbar #changelist-search .input-group-sm > .input-group-btn > input.input-group-addon[type='submit'], #changelist #changelist-form .actions .input-group-sm > .input-group-btn > button.input-group-addon, #changelist #changelist-form .paginator .input-group-sm > .input-group-btn > input.input-group-addon[type='submit'], .widget-AdminSplitDateTime .datetimeshortcuts a.form-control-sm[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a[id^='calendarlink'].input-group-addon, .widget-AdminSplitDateTime .datetimeshortcuts a.form-control-sm[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-sm > a[id^='clocklink'].input-group-addon, .widget-AdminDateWidget .datetimeshortcuts a.form-control-sm[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a[id^='calendarlink'].input-group-addon, .widget-AdminDateWidget .datetimeshortcuts a.form-control-sm[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-sm > a[id^='clocklink'].input-group-addon, .widget-AdminTimeWidget .datetimeshortcuts a.form-control-sm[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a[id^='calendarlink'].input-group-addon, .widget-AdminTimeWidget .datetimeshortcuts a.form-control-sm[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-sm > a[id^='clocklink'].input-group-addon {
    padding: 0.35rem 0.75rem;
    font-size: 0.929rem;
    border-radius: 0.2rem;
}

.input-group-addon.form-control-lg, .input-group-lg > .input-group-addon.form-control, fieldset .input-group-lg > input.input-group-addon[type=text], fieldset .input-group-lg > input.input-group-addon[type=url], fieldset .input-group-lg > input.input-group-addon[type=email], fieldset .input-group-lg > input.input-group-addon[type=number], fieldset .input-group-lg > input.input-group-addon[type=password], fieldset .input-group-lg > input.input-group-addon[type=date], fieldset .input-group-lg > input.input-group-addon[type=tel], fieldset .input-group-lg > .input-group-addon.vTextField, fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.vTextField[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-lg > a.vTextField[id^='calendarlink'], fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.vTextField[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-lg > a.vTextField[id^='clocklink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.vTextField[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-lg > a.vTextField[id^='calendarlink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.vTextField[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-lg > a.vTextField[id^='clocklink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.vTextField[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-lg > a.vTextField[id^='calendarlink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.vTextField[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-lg > a.vTextField[id^='clocklink'], fieldset .input-group-lg > .input-group-addon.vURLField, fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.vURLField[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-lg > a.vURLField[id^='calendarlink'], fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.vURLField[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-lg > a.vURLField[id^='clocklink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.vURLField[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-lg > a.vURLField[id^='calendarlink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.vURLField[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-lg > a.vURLField[id^='clocklink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.vURLField[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-lg > a.vURLField[id^='calendarlink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.vURLField[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-lg > a.vURLField[id^='clocklink'], fieldset .input-group-lg > .input-group-addon.vLargeTextField, fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.vLargeTextField[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-lg > a.vLargeTextField[id^='calendarlink'], fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.vLargeTextField[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-lg > a.vLargeTextField[id^='clocklink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.vLargeTextField[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-lg > a.vLargeTextField[id^='calendarlink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.vLargeTextField[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-lg > a.vLargeTextField[id^='clocklink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.vLargeTextField[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-lg > a.vLargeTextField[id^='calendarlink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.vLargeTextField[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-lg > a.vLargeTextField[id^='clocklink'], fieldset .input-group-lg > .input-group-addon.vTimeField, fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.vTimeField[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-lg > a.vTimeField[id^='calendarlink'], fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.vTimeField[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-lg > a.vTimeField[id^='clocklink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.vTimeField[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-lg > a.vTimeField[id^='calendarlink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.vTimeField[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-lg > a.vTimeField[id^='clocklink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.vTimeField[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-lg > a.vTimeField[id^='calendarlink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.vTimeField[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-lg > a.vTimeField[id^='clocklink'], fieldset .input-group-lg > .input-group-addon.vDateField, fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.vDateField[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-lg > a.vDateField[id^='calendarlink'], fieldset .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.vDateField[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts fieldset .input-group-lg > a.vDateField[id^='clocklink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.vDateField[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-lg > a.vDateField[id^='calendarlink'], fieldset .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.vDateField[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts fieldset .input-group-lg > a.vDateField[id^='clocklink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.vDateField[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-lg > a.vDateField[id^='calendarlink'], fieldset .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.vDateField[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts fieldset .input-group-lg > a.vDateField[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.form-control[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a.form-control[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.form-control[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a.form-control[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.form-control[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a.form-control[id^='clocklink'], .selector .selector-available .input-group-lg > select.input-group-addon, .selector .selector-chosen .input-group-lg > select.input-group-addon, #changelist #toolbar #changelist-search .input-group-lg > input.input-group-addon[type='text'], #changelist #changelist-form .actions .input-group-lg > select.input-group-addon, .input-group-lg > .input-group-addon, .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a[id^='clocklink'], .input-group-lg > .input-group-btn > .input-group-addon.btn, .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > .input-group-btn > a.btn[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .submit-row .deletelink-box .input-group-lg > .input-group-btn > a[id^='calendarlink'].deletelink, .submit-row .deletelink-box .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > .input-group-btn > a[id^='calendarlink'].deletelink, .widget-AdminSplitDateTime .datetimeshortcuts #content-main > .object-tools.input-group-lg > li.input-group-btn > a[id^='calendarlink']:not([class*="btn-"]), .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > .input-group-btn > a.btn[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts .submit-row .deletelink-box .input-group-lg > .input-group-btn > a[id^='clocklink'].deletelink, .submit-row .deletelink-box .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > .input-group-btn > a[id^='clocklink'].deletelink, .widget-AdminSplitDateTime .datetimeshortcuts #content-main > .object-tools.input-group-lg > li.input-group-btn > a[id^='clocklink']:not([class*="btn-"]), .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > .input-group-btn > a.btn[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .submit-row .deletelink-box .input-group-lg > .input-group-btn > a[id^='calendarlink'].deletelink, .submit-row .deletelink-box .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > .input-group-btn > a[id^='calendarlink'].deletelink, .widget-AdminDateWidget .datetimeshortcuts #content-main > .object-tools.input-group-lg > li.input-group-btn > a[id^='calendarlink']:not([class*="btn-"]), .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > .input-group-btn > a.btn[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .submit-row .deletelink-box .input-group-lg > .input-group-btn > a[id^='clocklink'].deletelink, .submit-row .deletelink-box .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > .input-group-btn > a[id^='clocklink'].deletelink, .widget-AdminDateWidget .datetimeshortcuts #content-main > .object-tools.input-group-lg > li.input-group-btn > a[id^='clocklink']:not([class*="btn-"]), .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > .input-group-btn > a.btn[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .submit-row .deletelink-box .input-group-lg > .input-group-btn > a[id^='calendarlink'].deletelink, .submit-row .deletelink-box .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > .input-group-btn > a[id^='calendarlink'].deletelink, .widget-AdminTimeWidget .datetimeshortcuts #content-main > .object-tools.input-group-lg > li.input-group-btn > a[id^='calendarlink']:not([class*="btn-"]), .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > .input-group-btn > a.btn[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .submit-row .deletelink-box .input-group-lg > .input-group-btn > a[id^='clocklink'].deletelink, .submit-row .deletelink-box .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > .input-group-btn > a[id^='clocklink'].deletelink, .widget-AdminTimeWidget .datetimeshortcuts #content-main > .object-tools.input-group-lg > li.input-group-btn > a[id^='clocklink']:not([class*="btn-"]), body.delete-confirmation .content-wrap .input-group-lg > .input-group-btn > input.input-group-addon[type='button'], body.delete-confirmation .content-wrap .input-group-lg > .input-group-btn > input.input-group-addon[type='submit'], body.delete-confirmation .content-wrap .input-group-lg > .input-group-btn > button.input-group-addon, .submit-row .deletelink-box .input-group-lg > .input-group-btn > .input-group-addon.deletelink, .submit-row .input-group-lg > .input-group-btn > input.input-group-addon[type='submit']:not([class*="btn-"]), .submit-row .input-group-lg > .input-group-btn > input.input-group-addon[type='button']:not([class*="btn-"]), .submit-row .input-group-lg > .input-group-btn > button.input-group-addon:not([class*="btn-"]), #content-main > .object-tools.input-group-lg > li.input-group-btn > a.input-group-addon:not([class*="btn-"]), body.login .submit-row .input-group-lg > .input-group-btn > input.input-group-addon[type='submit'], #changelist #toolbar #changelist-search .input-group-lg > .input-group-btn > input.input-group-addon[type='submit'], #changelist #changelist-form .actions .input-group-lg > .input-group-btn > button.input-group-addon, #changelist #changelist-form .paginator .input-group-lg > .input-group-btn > input.input-group-addon[type='submit'], .widget-AdminSplitDateTime .datetimeshortcuts a.form-control-lg[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a[id^='calendarlink'].input-group-addon, .widget-AdminSplitDateTime .datetimeshortcuts a.form-control-lg[id^='clocklink'], .widget-AdminSplitDateTime .datetimeshortcuts .input-group-lg > a[id^='clocklink'].input-group-addon, .widget-AdminDateWidget .datetimeshortcuts a.form-control-lg[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a[id^='calendarlink'].input-group-addon, .widget-AdminDateWidget .datetimeshortcuts a.form-control-lg[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts .input-group-lg > a[id^='clocklink'].input-group-addon, .widget-AdminTimeWidget .datetimeshortcuts a.form-control-lg[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a[id^='calendarlink'].input-group-addon, .widget-AdminTimeWidget .datetimeshortcuts a.form-control-lg[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts .input-group-lg > a[id^='clocklink'].input-group-addon {
    padding: 0.75rem 1.5rem;
    font-size: 1.143rem;
    border-radius: 0.3rem;
}

.input-group-addon input[type="radio"], .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'] input[type="radio"], .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'] input[type="radio"], .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'] input[type="radio"], .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'] input[type="radio"], .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'] input[type="radio"], .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'] input[type="radio"], .input-group-addon input[type="checkbox"], .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'] input[type="checkbox"], .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'] input[type="checkbox"], .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'] input[type="checkbox"], .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'] input[type="checkbox"], .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'] input[type="checkbox"], .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'] input[type="checkbox"] {
    margin-top: 0;
}

.input-group .form-control:not(:last-child), .input-group fieldset input[type=text]:not(:last-child), fieldset .input-group input[type=text]:not(:last-child), .input-group fieldset input[type=url]:not(:last-child), fieldset .input-group input[type=url]:not(:last-child), .input-group fieldset input[type=email]:not(:last-child), fieldset .input-group input[type=email]:not(:last-child), .input-group fieldset input[type=number]:not(:last-child), fieldset .input-group input[type=number]:not(:last-child), .input-group fieldset input[type=password]:not(:last-child), fieldset .input-group input[type=password]:not(:last-child), .input-group fieldset input[type=date]:not(:last-child), fieldset .input-group input[type=date]:not(:last-child), .input-group fieldset input[type=tel]:not(:last-child), fieldset .input-group input[type=tel]:not(:last-child), .input-group fieldset .vTextField:not(:last-child), fieldset .input-group .vTextField:not(:last-child), .input-group fieldset .vURLField:not(:last-child), fieldset .input-group .vURLField:not(:last-child), .input-group fieldset .vLargeTextField:not(:last-child), fieldset .input-group .vLargeTextField:not(:last-child), .input-group fieldset .vTimeField:not(:last-child), fieldset .input-group .vTimeField:not(:last-child), .input-group fieldset .vDateField:not(:last-child), fieldset .input-group .vDateField:not(:last-child), .input-group .selector .selector-available select:not(:last-child), .selector .selector-available .input-group select:not(:last-child), .input-group .selector .selector-chosen select:not(:last-child), .selector .selector-chosen .input-group select:not(:last-child), .input-group #changelist #toolbar #changelist-search input[type='text']:not(:last-child), #changelist #toolbar #changelist-search .input-group input[type='text']:not(:last-child), .input-group #changelist #changelist-form .actions select:not(:last-child), #changelist #changelist-form .actions .input-group select:not(:last-child), .input-group-addon:not(:last-child), .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink']:not(:last-child), .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink']:not(:last-child), .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink']:not(:last-child), .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink']:not(:last-child), .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink']:not(:last-child), .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink']:not(:last-child), .input-group-btn:not(:last-child) > .btn, body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > input[type='button'], body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > button, .submit-row .deletelink-box .input-group-btn:not(:last-child) > .deletelink, .submit-row .input-group-btn:not(:last-child) > input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn:not(:last-child) > input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn:not(:last-child) > button:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn:not(:last-child) > a:not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:last-child) > input[type='submit'], #changelist #toolbar #changelist-search .input-group-btn:not(:last-child) > input[type='submit'], #changelist #changelist-form .actions .input-group-btn:not(:last-child) > button, #changelist #changelist-form .paginator .input-group-btn:not(:last-child) > input[type='submit'], .input-group-btn:not(:last-child) > .btn-group > .btn, body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > .btn-group > input[type='button'], body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > .btn-group > input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > .btn-group > button, .submit-row .deletelink-box .input-group-btn:not(:last-child) > .btn-group > .deletelink, .submit-row .input-group-btn:not(:last-child) > .btn-group > input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn:not(:last-child) > .btn-group > input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn:not(:last-child) > .btn-group > button:not([class*="btn-"]), #content-main > .object-tools.input-group-btn:not(:last-child) > li.btn-group > a:not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:last-child) > .btn-group > input[type='submit'], #changelist #toolbar #changelist-search .input-group-btn:not(:last-child) > .btn-group > input[type='submit'], #changelist #changelist-form .actions .input-group-btn:not(:last-child) > .btn-group > button, #changelist #changelist-form .paginator .input-group-btn:not(:last-child) > .btn-group > input[type='submit'], .input-group-btn:not(:last-child) > .dropdown-toggle, .input-group-btn:not(:first-child) > .btn:not(:last-child):not(.dropdown-toggle), body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > input[type='button']:not(:last-child):not(.dropdown-toggle), body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > input[type='submit']:not(:last-child):not(.dropdown-toggle), body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > button:not(:last-child):not(.dropdown-toggle), .submit-row .deletelink-box .input-group-btn:not(:first-child) > .deletelink:not(:last-child):not(.dropdown-toggle), .submit-row .input-group-btn:not(:first-child) > input[type='submit']:not(:last-child):not(.dropdown-toggle):not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > input[type='button']:not(:last-child):not(.dropdown-toggle):not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > button:not(:last-child):not(.dropdown-toggle):not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn:not(:first-child) > a:not(:last-child):not(.dropdown-toggle):not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:first-child) > input[type='submit']:not(:last-child):not(.dropdown-toggle), #changelist #toolbar #changelist-search .input-group-btn:not(:first-child) > input[type='submit']:not(:last-child):not(.dropdown-toggle), #changelist #changelist-form .actions .input-group-btn:not(:first-child) > button:not(:last-child):not(.dropdown-toggle), #changelist #changelist-form .paginator .input-group-btn:not(:first-child) > input[type='submit']:not(:last-child):not(.dropdown-toggle), .input-group-btn:not(:first-child) > .btn-group:not(:last-child) > .btn, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > .btn-group:not(:last-child) > input[type='button'], body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > .btn-group:not(:last-child) > input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > .btn-group:not(:last-child) > button, .submit-row .deletelink-box .input-group-btn:not(:first-child) > .btn-group:not(:last-child) > .deletelink, .submit-row .input-group-btn:not(:first-child) > .btn-group:not(:last-child) > input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > .btn-group:not(:last-child) > input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > .btn-group:not(:last-child) > button:not([class*="btn-"]), #content-main > .object-tools.input-group-btn:not(:first-child) > li.btn-group:not(:last-child) > a:not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:first-child) > .btn-group:not(:last-child) > input[type='submit'], #changelist #toolbar #changelist-search .input-group-btn:not(:first-child) > .btn-group:not(:last-child) > input[type='submit'], #changelist #changelist-form .actions .input-group-btn:not(:first-child) > .btn-group:not(:last-child) > button, #changelist #changelist-form .paginator .input-group-btn:not(:first-child) > .btn-group:not(:last-child) > input[type='submit'] {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
}

.input-group-addon:not(:last-child), .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink']:not(:last-child), .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink']:not(:last-child), .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink']:not(:last-child), .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink']:not(:last-child), .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink']:not(:last-child), .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink']:not(:last-child) {
    border-right: 0;
}

.input-group .form-control:not(:first-child), .input-group fieldset input[type=text]:not(:first-child), fieldset .input-group input[type=text]:not(:first-child), .input-group fieldset input[type=url]:not(:first-child), fieldset .input-group input[type=url]:not(:first-child), .input-group fieldset input[type=email]:not(:first-child), fieldset .input-group input[type=email]:not(:first-child), .input-group fieldset input[type=number]:not(:first-child), fieldset .input-group input[type=number]:not(:first-child), .input-group fieldset input[type=password]:not(:first-child), fieldset .input-group input[type=password]:not(:first-child), .input-group fieldset input[type=date]:not(:first-child), fieldset .input-group input[type=date]:not(:first-child), .input-group fieldset input[type=tel]:not(:first-child), fieldset .input-group input[type=tel]:not(:first-child), .input-group fieldset .vTextField:not(:first-child), fieldset .input-group .vTextField:not(:first-child), .input-group fieldset .vURLField:not(:first-child), fieldset .input-group .vURLField:not(:first-child), .input-group fieldset .vLargeTextField:not(:first-child), fieldset .input-group .vLargeTextField:not(:first-child), .input-group fieldset .vTimeField:not(:first-child), fieldset .input-group .vTimeField:not(:first-child), .input-group fieldset .vDateField:not(:first-child), fieldset .input-group .vDateField:not(:first-child), .input-group .selector .selector-available select:not(:first-child), .selector .selector-available .input-group select:not(:first-child), .input-group .selector .selector-chosen select:not(:first-child), .selector .selector-chosen .input-group select:not(:first-child), .input-group #changelist #toolbar #changelist-search input[type='text']:not(:first-child), #changelist #toolbar #changelist-search .input-group input[type='text']:not(:first-child), .input-group #changelist #changelist-form .actions select:not(:first-child), #changelist #changelist-form .actions .input-group select:not(:first-child), .input-group-addon:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink']:not(:first-child), .input-group-btn:not(:first-child) > .btn, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > input[type='button'], body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > button, .submit-row .deletelink-box .input-group-btn:not(:first-child) > .deletelink, .submit-row .input-group-btn:not(:first-child) > input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > button:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn:not(:first-child) > a:not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:first-child) > input[type='submit'], #changelist #toolbar #changelist-search .input-group-btn:not(:first-child) > input[type='submit'], #changelist #changelist-form .actions .input-group-btn:not(:first-child) > button, #changelist #changelist-form .paginator .input-group-btn:not(:first-child) > input[type='submit'], .input-group-btn:not(:first-child) > .btn-group > .btn, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > .btn-group > input[type='button'], body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > .btn-group > input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > .btn-group > button, .submit-row .deletelink-box .input-group-btn:not(:first-child) > .btn-group > .deletelink, .submit-row .input-group-btn:not(:first-child) > .btn-group > input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > .btn-group > input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > .btn-group > button:not([class*="btn-"]), #content-main > .object-tools.input-group-btn:not(:first-child) > li.btn-group > a:not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:first-child) > .btn-group > input[type='submit'], #changelist #toolbar #changelist-search .input-group-btn:not(:first-child) > .btn-group > input[type='submit'], #changelist #changelist-form .actions .input-group-btn:not(:first-child) > .btn-group > button, #changelist #changelist-form .paginator .input-group-btn:not(:first-child) > .btn-group > input[type='submit'], .input-group-btn:not(:first-child) > .dropdown-toggle, .input-group-btn:not(:last-child) > .btn:not(:first-child), body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > input[type='button']:not(:first-child), body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > input[type='submit']:not(:first-child), body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > button:not(:first-child), .submit-row .deletelink-box .input-group-btn:not(:last-child) > .deletelink:not(:first-child), .submit-row .input-group-btn:not(:last-child) > input[type='submit']:not(:first-child):not([class*="btn-"]), .submit-row .input-group-btn:not(:last-child) > input[type='button']:not(:first-child):not([class*="btn-"]), .submit-row .input-group-btn:not(:last-child) > button:not(:first-child):not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn:not(:last-child) > a:not(:first-child):not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:last-child) > input[type='submit']:not(:first-child), #changelist #toolbar #changelist-search .input-group-btn:not(:last-child) > input[type='submit']:not(:first-child), #changelist #changelist-form .actions .input-group-btn:not(:last-child) > button:not(:first-child), #changelist #changelist-form .paginator .input-group-btn:not(:last-child) > input[type='submit']:not(:first-child), .input-group-btn:not(:last-child) > .btn-group:not(:first-child) > .btn, body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > .btn-group:not(:first-child) > input[type='button'], body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > .btn-group:not(:first-child) > input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > .btn-group:not(:first-child) > button, .submit-row .deletelink-box .input-group-btn:not(:last-child) > .btn-group:not(:first-child) > .deletelink, .submit-row .input-group-btn:not(:last-child) > .btn-group:not(:first-child) > input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn:not(:last-child) > .btn-group:not(:first-child) > input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn:not(:last-child) > .btn-group:not(:first-child) > button:not([class*="btn-"]), #content-main > .object-tools.input-group-btn:not(:last-child) > li.btn-group:not(:first-child) > a:not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:last-child) > .btn-group:not(:first-child) > input[type='submit'], #changelist #toolbar #changelist-search .input-group-btn:not(:last-child) > .btn-group:not(:first-child) > input[type='submit'], #changelist #changelist-form .actions .input-group-btn:not(:last-child) > .btn-group:not(:first-child) > button, #changelist #changelist-form .paginator .input-group-btn:not(:last-child) > .btn-group:not(:first-child) > input[type='submit'] {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}

.form-control + .input-group-addon:not(:first-child), fieldset input[type=text] + .input-group-addon:not(:first-child), fieldset input[type=url] + .input-group-addon:not(:first-child), fieldset input[type=email] + .input-group-addon:not(:first-child), fieldset input[type=number] + .input-group-addon:not(:first-child), fieldset input[type=password] + .input-group-addon:not(:first-child), fieldset input[type=date] + .input-group-addon:not(:first-child), fieldset input[type=tel] + .input-group-addon:not(:first-child), fieldset .vTextField + .input-group-addon:not(:first-child), fieldset .vURLField + .input-group-addon:not(:first-child), fieldset .vLargeTextField + .input-group-addon:not(:first-child), fieldset .vTimeField + .input-group-addon:not(:first-child), fieldset .vDateField + .input-group-addon:not(:first-child), .selector .selector-available select + .input-group-addon:not(:first-child), .selector .selector-chosen select + .input-group-addon:not(:first-child), #changelist #toolbar #changelist-search input[type='text'] + .input-group-addon:not(:first-child), #changelist #changelist-form .actions select + .input-group-addon:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts .form-control + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=text] + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=text] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=url] + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=url] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=email] + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=email] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=number] + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=number] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=password] + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=password] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=date] + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=date] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=tel] + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=tel] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts .vTextField + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset .vTextField + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts .vURLField + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset .vURLField + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts .vLargeTextField + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset .vLargeTextField + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts .vTimeField + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset .vTimeField + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts .vDateField + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset .vDateField + a[id^='calendarlink']:not(:first-child), .selector .selector-available .widget-AdminSplitDateTime .datetimeshortcuts select + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts .selector .selector-available select + a[id^='calendarlink']:not(:first-child), .selector .selector-chosen .widget-AdminSplitDateTime .datetimeshortcuts select + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts .selector .selector-chosen select + a[id^='calendarlink']:not(:first-child), #changelist #toolbar #changelist-search .widget-AdminSplitDateTime .datetimeshortcuts input[type='text'] + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts #changelist #toolbar #changelist-search input[type='text'] + a[id^='calendarlink']:not(:first-child), #changelist #changelist-form .actions .widget-AdminSplitDateTime .datetimeshortcuts select + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts #changelist #changelist-form .actions select + a[id^='calendarlink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts .form-control + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=text] + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=text] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=url] + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=url] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=email] + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=email] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=number] + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=number] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=password] + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=password] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=date] + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=date] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts input[type=tel] + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset input[type=tel] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts .vTextField + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset .vTextField + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts .vURLField + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset .vURLField + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts .vLargeTextField + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset .vLargeTextField + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts .vTimeField + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset .vTimeField + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminSplitDateTime .datetimeshortcuts .vDateField + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts fieldset .vDateField + a[id^='clocklink']:not(:first-child), .selector .selector-available .widget-AdminSplitDateTime .datetimeshortcuts select + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts .selector .selector-available select + a[id^='clocklink']:not(:first-child), .selector .selector-chosen .widget-AdminSplitDateTime .datetimeshortcuts select + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts .selector .selector-chosen select + a[id^='clocklink']:not(:first-child), #changelist #toolbar #changelist-search .widget-AdminSplitDateTime .datetimeshortcuts input[type='text'] + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts #changelist #toolbar #changelist-search input[type='text'] + a[id^='clocklink']:not(:first-child), #changelist #changelist-form .actions .widget-AdminSplitDateTime .datetimeshortcuts select + a[id^='clocklink']:not(:first-child), .widget-AdminSplitDateTime .datetimeshortcuts #changelist #changelist-form .actions select + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts .form-control + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=text] + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=text] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=url] + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=url] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=email] + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=email] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=number] + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=number] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=password] + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=password] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=date] + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=date] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=tel] + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=tel] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts .vTextField + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset .vTextField + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts .vURLField + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset .vURLField + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts .vLargeTextField + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset .vLargeTextField + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts .vTimeField + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset .vTimeField + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts .vDateField + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset .vDateField + a[id^='calendarlink']:not(:first-child), .selector .selector-available .widget-AdminDateWidget .datetimeshortcuts select + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts .selector .selector-available select + a[id^='calendarlink']:not(:first-child), .selector .selector-chosen .widget-AdminDateWidget .datetimeshortcuts select + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts .selector .selector-chosen select + a[id^='calendarlink']:not(:first-child), #changelist #toolbar #changelist-search .widget-AdminDateWidget .datetimeshortcuts input[type='text'] + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts #changelist #toolbar #changelist-search input[type='text'] + a[id^='calendarlink']:not(:first-child), #changelist #changelist-form .actions .widget-AdminDateWidget .datetimeshortcuts select + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts #changelist #changelist-form .actions select + a[id^='calendarlink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts .form-control + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=text] + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=text] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=url] + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=url] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=email] + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=email] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=number] + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=number] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=password] + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=password] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=date] + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=date] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts input[type=tel] + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset input[type=tel] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts .vTextField + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset .vTextField + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts .vURLField + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset .vURLField + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts .vLargeTextField + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset .vLargeTextField + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts .vTimeField + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset .vTimeField + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminDateWidget .datetimeshortcuts .vDateField + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts fieldset .vDateField + a[id^='clocklink']:not(:first-child), .selector .selector-available .widget-AdminDateWidget .datetimeshortcuts select + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts .selector .selector-available select + a[id^='clocklink']:not(:first-child), .selector .selector-chosen .widget-AdminDateWidget .datetimeshortcuts select + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts .selector .selector-chosen select + a[id^='clocklink']:not(:first-child), #changelist #toolbar #changelist-search .widget-AdminDateWidget .datetimeshortcuts input[type='text'] + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts #changelist #toolbar #changelist-search input[type='text'] + a[id^='clocklink']:not(:first-child), #changelist #changelist-form .actions .widget-AdminDateWidget .datetimeshortcuts select + a[id^='clocklink']:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts #changelist #changelist-form .actions select + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts .form-control + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=text] + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=text] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=url] + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=url] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=email] + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=email] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=number] + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=number] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=password] + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=password] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=date] + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=date] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=tel] + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=tel] + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts .vTextField + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset .vTextField + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts .vURLField + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset .vURLField + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts .vLargeTextField + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset .vLargeTextField + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts .vTimeField + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset .vTimeField + a[id^='calendarlink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts .vDateField + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset .vDateField + a[id^='calendarlink']:not(:first-child), .selector .selector-available .widget-AdminTimeWidget .datetimeshortcuts select + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts .selector .selector-available select + a[id^='calendarlink']:not(:first-child), .selector .selector-chosen .widget-AdminTimeWidget .datetimeshortcuts select + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts .selector .selector-chosen select + a[id^='calendarlink']:not(:first-child), #changelist #toolbar #changelist-search .widget-AdminTimeWidget .datetimeshortcuts input[type='text'] + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts #changelist #toolbar #changelist-search input[type='text'] + a[id^='calendarlink']:not(:first-child), #changelist #changelist-form .actions .widget-AdminTimeWidget .datetimeshortcuts select + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts #changelist #changelist-form .actions select + a[id^='calendarlink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts .form-control + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=text] + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=text] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=url] + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=url] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=email] + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=email] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=number] + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=number] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=password] + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=password] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=date] + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=date] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts input[type=tel] + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset input[type=tel] + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts .vTextField + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset .vTextField + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts .vURLField + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset .vURLField + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts .vLargeTextField + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset .vLargeTextField + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts .vTimeField + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset .vTimeField + a[id^='clocklink']:not(:first-child), fieldset .widget-AdminTimeWidget .datetimeshortcuts .vDateField + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts fieldset .vDateField + a[id^='clocklink']:not(:first-child), .selector .selector-available .widget-AdminTimeWidget .datetimeshortcuts select + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts .selector .selector-available select + a[id^='clocklink']:not(:first-child), .selector .selector-chosen .widget-AdminTimeWidget .datetimeshortcuts select + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts .selector .selector-chosen select + a[id^='clocklink']:not(:first-child), #changelist #toolbar #changelist-search .widget-AdminTimeWidget .datetimeshortcuts input[type='text'] + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts #changelist #toolbar #changelist-search input[type='text'] + a[id^='clocklink']:not(:first-child), #changelist #changelist-form .actions .widget-AdminTimeWidget .datetimeshortcuts select + a[id^='clocklink']:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts #changelist #changelist-form .actions select + a[id^='clocklink']:not(:first-child) {
    border-left: 0;
}

.input-group-btn {
    position: relative;
    font-size: 0;
    white-space: nowrap;
}

.input-group-btn > .btn, body.delete-confirmation .content-wrap .input-group-btn > input[type='button'], body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn > button, .submit-row .deletelink-box .input-group-btn > .deletelink, .submit-row .input-group-btn > input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn > input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn > button:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]), body.login .submit-row .input-group-btn > input[type='submit'], #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'], #changelist #changelist-form .actions .input-group-btn > button, #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] {
    position: relative;
}

.input-group-btn > .btn + .btn, body.delete-confirmation .content-wrap .input-group-btn > input[type='button'] + .btn, body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + .btn, body.delete-confirmation .content-wrap .input-group-btn > button + .btn, .submit-row .deletelink-box .input-group-btn > .deletelink + .btn, .submit-row .input-group-btn > input[type='submit']:not([class*="btn-"]) + .btn, .submit-row .input-group-btn > input[type='button']:not([class*="btn-"]) + .btn, .submit-row .input-group-btn > button:not([class*="btn-"]) + .btn, #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + .btn, #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + .btn, body.login .submit-row .input-group-btn > input[type='submit'] + .btn, #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'] + .btn, #changelist #changelist-form .actions .input-group-btn > button + .btn, #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] + .btn, body.delete-confirmation .content-wrap .input-group-btn > .btn + input[type='button'], body.delete-confirmation .content-wrap .input-group-btn > input[type='button'] + input[type='button'], body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap .input-group-btn > button + input[type='button'], .submit-row .deletelink-box body.delete-confirmation .content-wrap .input-group-btn > .deletelink + input[type='button'], body.delete-confirmation .content-wrap .submit-row .deletelink-box .input-group-btn > .deletelink + input[type='button'], .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='submit']:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .submit-row .input-group-btn > input[type='submit']:not([class*="btn-"]) + input[type='button'], .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='button']:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .submit-row .input-group-btn > input[type='button']:not([class*="btn-"]) + input[type='button'], .submit-row body.delete-confirmation .content-wrap .input-group-btn > button:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap .submit-row .input-group-btn > button:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + input[type='button'], body.delete-confirmation .content-wrap #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + input[type='button'], body.login .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap body.login .submit-row .input-group-btn > input[type='submit'] + input[type='button'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'] + input[type='button'], #changelist #changelist-form .actions body.delete-confirmation .content-wrap .input-group-btn > button + input[type='button'], body.delete-confirmation .content-wrap #changelist #changelist-form .actions .input-group-btn > button + input[type='button'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] + input[type='button'], body.delete-confirmation .content-wrap .input-group-btn > .btn + input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn > input[type='button'] + input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn > button + input[type='submit'], .submit-row .deletelink-box body.delete-confirmation .content-wrap .input-group-btn > .deletelink + input[type='submit'], body.delete-confirmation .content-wrap .submit-row .deletelink-box .input-group-btn > .deletelink + input[type='submit'], .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='submit']:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .submit-row .input-group-btn > input[type='submit']:not([class*="btn-"]) + input[type='submit'], .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='button']:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .submit-row .input-group-btn > input[type='button']:not([class*="btn-"]) + input[type='submit'], .submit-row body.delete-confirmation .content-wrap .input-group-btn > button:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap .submit-row .input-group-btn > button:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + input[type='submit'], body.delete-confirmation .content-wrap #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + input[type='submit'], body.login .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap body.login .submit-row .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #changelist-form .actions body.delete-confirmation .content-wrap .input-group-btn > button + input[type='submit'], body.delete-confirmation .content-wrap #changelist #changelist-form .actions .input-group-btn > button + input[type='submit'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn > .btn + button, body.delete-confirmation .content-wrap .input-group-btn > input[type='button'] + button, body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + button, body.delete-confirmation .content-wrap .input-group-btn > button + button, .submit-row .deletelink-box body.delete-confirmation .content-wrap .input-group-btn > .deletelink + button, body.delete-confirmation .content-wrap .submit-row .deletelink-box .input-group-btn > .deletelink + button, .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='submit']:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .submit-row .input-group-btn > input[type='submit']:not([class*="btn-"]) + button, .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='button']:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .submit-row .input-group-btn > input[type='button']:not([class*="btn-"]) + button, .submit-row body.delete-confirmation .content-wrap .input-group-btn > button:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap .submit-row .input-group-btn > button:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + button, body.delete-confirmation .content-wrap #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + button, body.login .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + button, body.delete-confirmation .content-wrap body.login .submit-row .input-group-btn > input[type='submit'] + button, #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + button, body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'] + button, #changelist #changelist-form .actions body.delete-confirmation .content-wrap .input-group-btn > button + button, body.delete-confirmation .content-wrap #changelist #changelist-form .actions .input-group-btn > button + button, #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + button, body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] + button, .submit-row .deletelink-box .input-group-btn > .btn + .deletelink, body.delete-confirmation .content-wrap .submit-row .deletelink-box .input-group-btn > input[type='button'] + .deletelink, .submit-row .deletelink-box body.delete-confirmation .content-wrap .input-group-btn > input[type='button'] + .deletelink, body.delete-confirmation .content-wrap .submit-row .deletelink-box .input-group-btn > input[type='submit'] + .deletelink, .submit-row .deletelink-box body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + .deletelink, body.delete-confirmation .content-wrap .submit-row .deletelink-box .input-group-btn > button + .deletelink, .submit-row .deletelink-box body.delete-confirmation .content-wrap .input-group-btn > button + .deletelink, .submit-row .deletelink-box .input-group-btn > .deletelink + .deletelink, .submit-row .deletelink-box .input-group-btn > input[type='submit']:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box .input-group-btn > input[type='button']:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box .input-group-btn > button:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + .deletelink, .submit-row .deletelink-box #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + .deletelink, body.login .submit-row .deletelink-box .input-group-btn > input[type='submit'] + .deletelink, #changelist #toolbar #changelist-search .submit-row .deletelink-box .input-group-btn > input[type='submit'] + .deletelink, .submit-row .deletelink-box #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'] + .deletelink, #changelist #changelist-form .actions .submit-row .deletelink-box .input-group-btn > button + .deletelink, .submit-row .deletelink-box #changelist #changelist-form .actions .input-group-btn > button + .deletelink, #changelist #changelist-form .paginator .submit-row .deletelink-box .input-group-btn > input[type='submit'] + .deletelink, .submit-row .deletelink-box #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] + .deletelink, .submit-row .input-group-btn > .btn + input[type='submit']:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .input-group-btn > input[type='button'] + input[type='submit']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='button'] + input[type='submit']:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .input-group-btn > input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='submit']:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .input-group-btn > button + input[type='submit']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .input-group-btn > button + input[type='submit']:not([class*="btn-"]), .submit-row .deletelink-box .input-group-btn > .deletelink + input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn > input[type='submit']:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn > input[type='button']:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn > button:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + input[type='submit']:not([class*="btn-"]), body.login .submit-row .input-group-btn > input[type='submit'] + input[type='submit']:not([class*="btn-"]), #changelist #toolbar #changelist-search .submit-row .input-group-btn > input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'] + input[type='submit']:not([class*="btn-"]), #changelist #changelist-form .actions .submit-row .input-group-btn > button + input[type='submit']:not([class*="btn-"]), .submit-row #changelist #changelist-form .actions .input-group-btn > button + input[type='submit']:not([class*="btn-"]), #changelist #changelist-form .paginator .submit-row .input-group-btn > input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] + input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn > .btn + input[type='button']:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .input-group-btn > input[type='button'] + input[type='button']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='button'] + input[type='button']:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .input-group-btn > input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='button']:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .input-group-btn > button + input[type='button']:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .input-group-btn > button + input[type='button']:not([class*="btn-"]), .submit-row .deletelink-box .input-group-btn > .deletelink + input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn > input[type='submit']:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn > input[type='button']:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn > button:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + input[type='button']:not([class*="btn-"]), body.login .submit-row .input-group-btn > input[type='submit'] + input[type='button']:not([class*="btn-"]), #changelist #toolbar #changelist-search .submit-row .input-group-btn > input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'] + input[type='button']:not([class*="btn-"]), #changelist #changelist-form .actions .submit-row .input-group-btn > button + input[type='button']:not([class*="btn-"]), .submit-row #changelist #changelist-form .actions .input-group-btn > button + input[type='button']:not([class*="btn-"]), #changelist #changelist-form .paginator .submit-row .input-group-btn > input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] + input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn > .btn + button:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .input-group-btn > input[type='button'] + button:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='button'] + button:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .input-group-btn > input[type='submit'] + button:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + button:not([class*="btn-"]), body.delete-confirmation .content-wrap .submit-row .input-group-btn > button + button:not([class*="btn-"]), .submit-row body.delete-confirmation .content-wrap .input-group-btn > button + button:not([class*="btn-"]), .submit-row .deletelink-box .input-group-btn > .deletelink + button:not([class*="btn-"]), .submit-row .input-group-btn > input[type='submit']:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row .input-group-btn > input[type='button']:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row .input-group-btn > button:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + button:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + button:not([class*="btn-"]), body.login .submit-row .input-group-btn > input[type='submit'] + button:not([class*="btn-"]), #changelist #toolbar #changelist-search .submit-row .input-group-btn > input[type='submit'] + button:not([class*="btn-"]), .submit-row #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'] + button:not([class*="btn-"]), #changelist #changelist-form .actions .submit-row .input-group-btn > button + button:not([class*="btn-"]), .submit-row #changelist #changelist-form .actions .input-group-btn > button + button:not([class*="btn-"]), #changelist #changelist-form .paginator .submit-row .input-group-btn > input[type='submit'] + button:not([class*="btn-"]), .submit-row #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] + button:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn > .btn + a:not([class*="btn-"]), body.delete-confirmation .content-wrap #content-main > .object-tools > li.input-group-btn > input[type='button'] + a:not([class*="btn-"]), body.delete-confirmation .content-wrap #content-main > .object-tools > li.input-group-btn > input[type='submit'] + a:not([class*="btn-"]), body.delete-confirmation .content-wrap #content-main > .object-tools > li.input-group-btn > button + a:not([class*="btn-"]), .submit-row .deletelink-box #content-main > .object-tools > li.input-group-btn > .deletelink + a:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.input-group-btn > input[type='submit']:not([class*="btn-"]) + a:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.input-group-btn > input[type='button']:not([class*="btn-"]) + a:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.input-group-btn > button:not([class*="btn-"]) + a:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + a:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + a:not([class*="btn-"]), body.login .submit-row #content-main > .object-tools > li.input-group-btn > input[type='submit'] + a:not([class*="btn-"]), #changelist #toolbar #changelist-search #content-main > .object-tools > li.input-group-btn > input[type='submit'] + a:not([class*="btn-"]), #changelist #changelist-form .actions #content-main > .object-tools > li.input-group-btn > button + a:not([class*="btn-"]), #changelist #changelist-form .paginator #content-main > .object-tools > li.input-group-btn > input[type='submit'] + a:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn > .btn + a.addlink:not([class*="btn-"]), body.delete-confirmation .content-wrap #content-main > .object-tools > li.input-group-btn > input[type='button'] + a.addlink:not([class*="btn-"]), body.delete-confirmation .content-wrap #content-main > .object-tools > li.input-group-btn > input[type='submit'] + a.addlink:not([class*="btn-"]), body.delete-confirmation .content-wrap #content-main > .object-tools > li.input-group-btn > button + a.addlink:not([class*="btn-"]), .submit-row .deletelink-box #content-main > .object-tools > li.input-group-btn > .deletelink + a.addlink:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.input-group-btn > input[type='submit']:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.input-group-btn > input[type='button']:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), .submit-row #content-main > .object-tools > li.input-group-btn > button:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + a.addlink:not([class*="btn-"]), body.login .submit-row #content-main > .object-tools > li.input-group-btn > input[type='submit'] + a.addlink:not([class*="btn-"]), #changelist #toolbar #changelist-search #content-main > .object-tools > li.input-group-btn > input[type='submit'] + a.addlink:not([class*="btn-"]), #changelist #changelist-form .actions #content-main > .object-tools > li.input-group-btn > button + a.addlink:not([class*="btn-"]), #changelist #changelist-form .paginator #content-main > .object-tools > li.input-group-btn > input[type='submit'] + a.addlink:not([class*="btn-"]), body.login .submit-row .input-group-btn > .btn + input[type='submit'], body.delete-confirmation .content-wrap body.login .submit-row .input-group-btn > input[type='button'] + input[type='submit'], body.login .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='button'] + input[type='submit'], body.delete-confirmation .content-wrap body.login .submit-row .input-group-btn > input[type='submit'] + input[type='submit'], body.login .submit-row body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap body.login .submit-row .input-group-btn > button + input[type='submit'], body.login .submit-row body.delete-confirmation .content-wrap .input-group-btn > button + input[type='submit'], body.login .submit-row .deletelink-box .input-group-btn > .deletelink + input[type='submit'], body.login .submit-row .input-group-btn > input[type='submit']:not([class*="btn-"]) + input[type='submit'], body.login .submit-row .input-group-btn > input[type='button']:not([class*="btn-"]) + input[type='submit'], body.login .submit-row .input-group-btn > button:not([class*="btn-"]) + input[type='submit'], body.login .submit-row #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + input[type='submit'], body.login .submit-row #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + input[type='submit'], body.login .submit-row .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search body.login .submit-row .input-group-btn > input[type='submit'] + input[type='submit'], body.login .submit-row #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #changelist-form .actions body.login .submit-row .input-group-btn > button + input[type='submit'], body.login .submit-row #changelist #changelist-form .actions .input-group-btn > button + input[type='submit'], #changelist #changelist-form .paginator body.login .submit-row .input-group-btn > input[type='submit'] + input[type='submit'], body.login .submit-row #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search .input-group-btn > .btn + input[type='submit'], body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .input-group-btn > input[type='button'] + input[type='submit'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .input-group-btn > input[type='button'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #toolbar #changelist-search .input-group-btn > button + input[type='submit'], #changelist #toolbar #changelist-search body.delete-confirmation .content-wrap .input-group-btn > button + input[type='submit'], .submit-row .deletelink-box #changelist #toolbar #changelist-search .input-group-btn > .deletelink + input[type='submit'], #changelist #toolbar #changelist-search .submit-row .deletelink-box .input-group-btn > .deletelink + input[type='submit'], .submit-row #changelist #toolbar #changelist-search .input-group-btn > input[type='submit']:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .submit-row .input-group-btn > input[type='submit']:not([class*="btn-"]) + input[type='submit'], .submit-row #changelist #toolbar #changelist-search .input-group-btn > input[type='button']:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .submit-row .input-group-btn > input[type='button']:not([class*="btn-"]) + input[type='submit'], .submit-row #changelist #toolbar #changelist-search .input-group-btn > button:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search .submit-row .input-group-btn > button:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + input[type='submit'], #changelist #toolbar #changelist-search #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + input[type='submit'], body.login .submit-row #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search body.login .submit-row .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #changelist-form .actions #toolbar #changelist-search .input-group-btn > button + input[type='submit'], #changelist #toolbar #changelist-search #changelist-form .actions .input-group-btn > button + input[type='submit'], #changelist #changelist-form .paginator #toolbar #changelist-search .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search #changelist-form .paginator .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #changelist-form .actions .input-group-btn > .btn + button, body.delete-confirmation .content-wrap #changelist #changelist-form .actions .input-group-btn > input[type='button'] + button, #changelist #changelist-form .actions body.delete-confirmation .content-wrap .input-group-btn > input[type='button'] + button, body.delete-confirmation .content-wrap #changelist #changelist-form .actions .input-group-btn > input[type='submit'] + button, #changelist #changelist-form .actions body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + button, body.delete-confirmation .content-wrap #changelist #changelist-form .actions .input-group-btn > button + button, #changelist #changelist-form .actions body.delete-confirmation .content-wrap .input-group-btn > button + button, .submit-row .deletelink-box #changelist #changelist-form .actions .input-group-btn > .deletelink + button, #changelist #changelist-form .actions .submit-row .deletelink-box .input-group-btn > .deletelink + button, .submit-row #changelist #changelist-form .actions .input-group-btn > input[type='submit']:not([class*="btn-"]) + button, #changelist #changelist-form .actions .submit-row .input-group-btn > input[type='submit']:not([class*="btn-"]) + button, .submit-row #changelist #changelist-form .actions .input-group-btn > input[type='button']:not([class*="btn-"]) + button, #changelist #changelist-form .actions .submit-row .input-group-btn > input[type='button']:not([class*="btn-"]) + button, .submit-row #changelist #changelist-form .actions .input-group-btn > button:not([class*="btn-"]) + button, #changelist #changelist-form .actions .submit-row .input-group-btn > button:not([class*="btn-"]) + button, #changelist #changelist-form .actions #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + button, #changelist #changelist-form .actions #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + button, body.login .submit-row #changelist #changelist-form .actions .input-group-btn > input[type='submit'] + button, #changelist #changelist-form .actions body.login .submit-row .input-group-btn > input[type='submit'] + button, #changelist #toolbar #changelist-search #changelist-form .actions .input-group-btn > input[type='submit'] + button, #changelist #changelist-form .actions #toolbar #changelist-search .input-group-btn > input[type='submit'] + button, #changelist #changelist-form .actions .input-group-btn > button + button, #changelist #changelist-form .paginator .actions .input-group-btn > input[type='submit'] + button, #changelist #changelist-form .actions .paginator .input-group-btn > input[type='submit'] + button, #changelist #changelist-form .paginator .input-group-btn > .btn + input[type='submit'], body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .input-group-btn > input[type='button'] + input[type='submit'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .input-group-btn > input[type='button'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .input-group-btn > input[type='submit'] + input[type='submit'], body.delete-confirmation .content-wrap #changelist #changelist-form .paginator .input-group-btn > button + input[type='submit'], #changelist #changelist-form .paginator body.delete-confirmation .content-wrap .input-group-btn > button + input[type='submit'], .submit-row .deletelink-box #changelist #changelist-form .paginator .input-group-btn > .deletelink + input[type='submit'], #changelist #changelist-form .paginator .submit-row .deletelink-box .input-group-btn > .deletelink + input[type='submit'], .submit-row #changelist #changelist-form .paginator .input-group-btn > input[type='submit']:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .submit-row .input-group-btn > input[type='submit']:not([class*="btn-"]) + input[type='submit'], .submit-row #changelist #changelist-form .paginator .input-group-btn > input[type='button']:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .submit-row .input-group-btn > input[type='button']:not([class*="btn-"]) + input[type='submit'], .submit-row #changelist #changelist-form .paginator .input-group-btn > button:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator .submit-row .input-group-btn > button:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator #content-main > .object-tools > li.input-group-btn > a:not([class*="btn-"]) + input[type='submit'], #changelist #changelist-form .paginator #content-main > .object-tools > li.input-group-btn > a.addlink:not([class*="btn-"]) + input[type='submit'], body.login .submit-row #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator body.login .submit-row .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #toolbar #changelist-search #changelist-form .paginator .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #changelist-form .paginator #toolbar #changelist-search .input-group-btn > input[type='submit'] + input[type='submit'], #changelist #changelist-form .actions .paginator .input-group-btn > button + input[type='submit'], #changelist #changelist-form .paginator .actions .input-group-btn > button + input[type='submit'], #changelist #changelist-form .paginator .input-group-btn > input[type='submit'] + input[type='submit'] {
    margin-left: -1px;
}

.input-group-btn > .btn:focus, body.delete-confirmation .content-wrap .input-group-btn > input[type='button']:focus, body.delete-confirmation .content-wrap .input-group-btn > input[type='submit']:focus, body.delete-confirmation .content-wrap .input-group-btn > button:focus, .submit-row .deletelink-box .input-group-btn > .deletelink:focus, .submit-row .input-group-btn > input[type='submit']:focus:not([class*="btn-"]), .submit-row .input-group-btn > input[type='button']:focus:not([class*="btn-"]), .submit-row .input-group-btn > button:focus:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn > a:focus:not([class*="btn-"]), body.login .submit-row .input-group-btn > input[type='submit']:focus, #changelist #toolbar #changelist-search .input-group-btn > input[type='submit']:focus, #changelist #changelist-form .actions .input-group-btn > button:focus, #changelist #changelist-form .paginator .input-group-btn > input[type='submit']:focus, .input-group-btn > .btn:active, body.delete-confirmation .content-wrap .input-group-btn > input[type='button']:active, body.delete-confirmation .content-wrap .input-group-btn > input[type='submit']:active, body.delete-confirmation .content-wrap .input-group-btn > button:active, .submit-row .deletelink-box .input-group-btn > .deletelink:active, .submit-row .input-group-btn > input[type='submit']:active:not([class*="btn-"]), .submit-row .input-group-btn > input[type='button']:active:not([class*="btn-"]), .submit-row .input-group-btn > button:active:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn > a:active:not([class*="btn-"]), body.login .submit-row .input-group-btn > input[type='submit']:active, #changelist #toolbar #changelist-search .input-group-btn > input[type='submit']:active, #changelist #changelist-form .actions .input-group-btn > button:active, #changelist #changelist-form .paginator .input-group-btn > input[type='submit']:active, .input-group-btn > .btn:hover, body.delete-confirmation .content-wrap .input-group-btn > input[type='button']:hover, body.delete-confirmation .content-wrap .input-group-btn > input[type='submit']:hover, body.delete-confirmation .content-wrap .input-group-btn > button:hover, .submit-row .deletelink-box .input-group-btn > .deletelink:hover, .submit-row .input-group-btn > input[type='submit']:hover:not([class*="btn-"]), .submit-row .input-group-btn > input[type='button']:hover:not([class*="btn-"]), .submit-row .input-group-btn > button:hover:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn > a:hover:not([class*="btn-"]), body.login .submit-row .input-group-btn > input[type='submit']:hover, #changelist #toolbar #changelist-search .input-group-btn > input[type='submit']:hover, #changelist #changelist-form .actions .input-group-btn > button:hover, #changelist #changelist-form .paginator .input-group-btn > input[type='submit']:hover {
    z-index: 3;
}

.input-group-btn:not(:last-child) > .btn, body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > input[type='button'], body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn:not(:last-child) > button, .submit-row .deletelink-box .input-group-btn:not(:last-child) > .deletelink, .submit-row .input-group-btn:not(:last-child) > input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn:not(:last-child) > input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn:not(:last-child) > button:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn:not(:last-child) > a:not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:last-child) > input[type='submit'], #changelist #toolbar #changelist-search .input-group-btn:not(:last-child) > input[type='submit'], #changelist #changelist-form .actions .input-group-btn:not(:last-child) > button, #changelist #changelist-form .paginator .input-group-btn:not(:last-child) > input[type='submit'], .input-group-btn:not(:last-child) > .btn-group {
    margin-right: -1px;
}

.input-group-btn:not(:first-child) > .btn, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > input[type='button'], body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > input[type='submit'], body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > button, .submit-row .deletelink-box .input-group-btn:not(:first-child) > .deletelink, .submit-row .input-group-btn:not(:first-child) > input[type='submit']:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > input[type='button']:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > button:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn:not(:first-child) > a:not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:first-child) > input[type='submit'], #changelist #toolbar #changelist-search .input-group-btn:not(:first-child) > input[type='submit'], #changelist #changelist-form .actions .input-group-btn:not(:first-child) > button, #changelist #changelist-form .paginator .input-group-btn:not(:first-child) > input[type='submit'], .input-group-btn:not(:first-child) > .btn-group {
    z-index: 2;
    margin-left: -1px;
}

.input-group-btn:not(:first-child) > .btn:focus, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > input[type='button']:focus, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > input[type='submit']:focus, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > button:focus, .submit-row .deletelink-box .input-group-btn:not(:first-child) > .deletelink:focus, .submit-row .input-group-btn:not(:first-child) > input[type='submit']:focus:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > input[type='button']:focus:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > button:focus:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn:not(:first-child) > a:focus:not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:first-child) > input[type='submit']:focus, #changelist #toolbar #changelist-search .input-group-btn:not(:first-child) > input[type='submit']:focus, #changelist #changelist-form .actions .input-group-btn:not(:first-child) > button:focus, #changelist #changelist-form .paginator .input-group-btn:not(:first-child) > input[type='submit']:focus, .input-group-btn:not(:first-child) > .btn:active, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > input[type='button']:active, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > input[type='submit']:active, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > button:active, .submit-row .deletelink-box .input-group-btn:not(:first-child) > .deletelink:active, .submit-row .input-group-btn:not(:first-child) > input[type='submit']:active:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > input[type='button']:active:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > button:active:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn:not(:first-child) > a:active:not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:first-child) > input[type='submit']:active, #changelist #toolbar #changelist-search .input-group-btn:not(:first-child) > input[type='submit']:active, #changelist #changelist-form .actions .input-group-btn:not(:first-child) > button:active, #changelist #changelist-form .paginator .input-group-btn:not(:first-child) > input[type='submit']:active, .input-group-btn:not(:first-child) > .btn:hover, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > input[type='button']:hover, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > input[type='submit']:hover, body.delete-confirmation .content-wrap .input-group-btn:not(:first-child) > button:hover, .submit-row .deletelink-box .input-group-btn:not(:first-child) > .deletelink:hover, .submit-row .input-group-btn:not(:first-child) > input[type='submit']:hover:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > input[type='button']:hover:not([class*="btn-"]), .submit-row .input-group-btn:not(:first-child) > button:hover:not([class*="btn-"]), #content-main > .object-tools > li.input-group-btn:not(:first-child) > a:hover:not([class*="btn-"]), body.login .submit-row .input-group-btn:not(:first-child) > input[type='submit']:hover, #changelist #toolbar #changelist-search .input-group-btn:not(:first-child) > input[type='submit']:hover, #changelist #changelist-form .actions .input-group-btn:not(:first-child) > button:hover, #changelist #changelist-form .paginator .input-group-btn:not(:first-child) > input[type='submit']:hover, .input-group-btn:not(:first-child) > .btn-group:focus, .input-group-btn:not(:first-child) > .btn-group:active, .input-group-btn:not(:first-child) > .btn-group:hover {
    z-index: 3;
}

.custom-control {
    position: relative;
    display: inline-block;
    padding-left: 1.5rem;
    cursor: pointer;
}

.custom-control + .custom-control {
    margin-left: 1rem;
}

.custom-control-input {
    position: absolute;
    z-index: -1;
    opacity: 0;
}

.custom-control-input:checked ~ .custom-control-indicator {
    color: #fff;
    background-color: #0074d9;
}

.custom-control-input:focus ~ .custom-control-indicator {
    box-shadow: 0 0 0 0.075rem #fff, 0 0 0 0.2rem #0074d9;
}

.custom-control-input:active ~ .custom-control-indicator {
    color: #fff;
    background-color: #84c6ff;
}

.custom-control-input:disabled ~ .custom-control-indicator {
    cursor: not-allowed;
    background-color: #eee;
}

.custom-control-input:disabled ~ .custom-control-description {
    color: #767676;
    cursor: not-allowed;
}

.custom-control-indicator {
    position: absolute;
    top: .25rem;
    left: 0;
    display: block;
    width: 1rem;
    height: 1rem;
    pointer-events: none;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    background-color: #ddd;
    background-repeat: no-repeat;
    background-position: center center;
    background-size: 50% 50%;
}

.custom-checkbox .custom-control-indicator {
    border-radius: 0.25rem;
}

.custom-checkbox .custom-control-input:checked ~ .custom-control-indicator {
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3E%3Cpath fill='#fff' d='M6.564.75l-3.59 3.612-1.538-1.55L0 4.26 2.974 7.25 8 2.193z'/%3E%3C/svg%3E");
}

.custom-checkbox .custom-control-input:indeterminate ~ .custom-control-indicator {
    background-color: #0074d9;
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 4 4'%3E%3Cpath stroke='#fff' d='M0 2h4'/%3E%3C/svg%3E");
}

.custom-radio .custom-control-indicator {
    border-radius: 50%;
}

.custom-radio .custom-control-input:checked ~ .custom-control-indicator {
    background-image: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'%3E%3Ccircle r='3' fill='#fff'/%3E%3C/svg%3E");
}

.custom-controls-stacked .custom-control {
    float: left;
    clear: left;
}

.custom-controls-stacked .custom-control + .custom-control {
    margin-left: 0;
}

.custom-select, fieldset select:not([multiple="multiple"]) {
    display: inline-block;
    max-width: 100%;
    height: calc(2.5rem - 2px);
    padding: 0.375rem 1.75rem 0.375rem 0.75rem;
    padding-right: 0.75rem \9;
    color: #55595c;
    vertical-align: middle;
    background: #fff url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 4 5'%3E%3Cpath fill='#333' d='M2 0L0 2h4zm0 5L0 3h4z'/%3E%3C/svg%3E") no-repeat right 0.75rem center;
    background-image: none \9;
    background-size: 8px 10px;
    border: 1px solid rgba(0, 0, 0, 0.15);
    border-radius: 0.25rem;
    -moz-appearance: none;
    -webkit-appearance: none;
}

.custom-select:focus, fieldset select:focus:not([multiple="multiple"]) {
    border-color: #51a7e8;
    outline: none;
}

.custom-select:focus::-ms-value, fieldset select:not([multiple="multiple"]):focus::-ms-value {
    color: #55595c;
    background-color: #fff;
}

.custom-select:disabled, fieldset select:disabled:not([multiple="multiple"]) {
    color: #818a91;
    cursor: not-allowed;
    background-color: #eceeef;
}

.custom-select::-ms-expand, fieldset select:not([multiple="multiple"])::-ms-expand {
    opacity: 0;
}

.custom-select-sm {
    padding-top: 0.375rem;
    padding-bottom: 0.375rem;
    font-size: 0.857rem;
}

.custom-file {
    position: relative;
    display: inline-block;
    max-width: 100%;
    height: 2.5rem;
    cursor: pointer;
}

.custom-file-input {
    min-width: 14rem;
    max-width: 100%;
    margin: 0;
    filter: alpha(opacity=0);
    opacity: 0;
}

.custom-file-control {
    position: absolute;
    top: 0;
    right: 0;
    left: 0;
    z-index: 5;
    height: 2.5rem;
    padding: 0.5rem 1rem;
    line-height: 1.5;
    color: #555;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    background-color: #fff;
    border: 1px solid #ddd;
    border-radius: 0.25rem;
}

.custom-file-control:lang(en)::after {
    content: "Choose file...";
}

.custom-file-control::before {
    position: absolute;
    top: -1px;
    right: -1px;
    bottom: -1px;
    z-index: 6;
    display: block;
    height: 2.5rem;
    padding: 0.5rem 1rem;
    line-height: 1.5;
    color: #555;
    background-color: #eee;
    border: 1px solid #ddd;
    border-radius: 0 0.25rem 0.25rem 0;
}

.custom-file-control:lang(en)::before {
    content: "Browse";
}

.nav {
    padding-left: 0;
    margin-bottom: 0;
    list-style: none;
}

.nav-link {
    display: inline-block;
}

.nav-link:focus, .nav-link:hover {
    text-decoration: none;
}

.nav-link.disabled {
    color: #818a91;
}

.nav-link.disabled, .nav-link.disabled:focus, .nav-link.disabled:hover {
    color: #818a91;
    cursor: not-allowed;
    background-color: transparent;
}

.nav-inline .nav-item {
    display: inline-block;
}

.nav-inline .nav-item + .nav-item, .nav-inline .nav-link + .nav-link {
    margin-left: 1rem;
}

.nav-tabs {
    border-bottom: 1px solid #ddd;
}

.nav-tabs::after {
    content: "";
    display: table;
    clear: both;
}

.nav-tabs .nav-item {
    float: left;
    margin-bottom: -1px;
}

.nav-tabs .nav-item + .nav-item {
    margin-left: 0.2rem;
}

.nav-tabs .nav-link {
    display: block;
    padding: 0.5em 1em;
    border: 1px solid transparent;
    border-top-right-radius: 0.25rem;
    border-top-left-radius: 0.25rem;
}

.nav-tabs .nav-link:focus, .nav-tabs .nav-link:hover {
    border-color: #eceeef #eceeef #ddd;
}

.nav-tabs .nav-link.disabled, .nav-tabs .nav-link.disabled:focus, .nav-tabs .nav-link.disabled:hover {
    color: #818a91;
    background-color: transparent;
    border-color: transparent;
}

.nav-tabs .nav-link.active, .nav-tabs .nav-link.active:focus, .nav-tabs .nav-link.active:hover, .nav-tabs .nav-item.open .nav-link, .nav-tabs .nav-item.open .nav-link:focus, .nav-tabs .nav-item.open .nav-link:hover {
    color: #55595c;
    background-color: #f1f1f1;
    border-color: #ddd #ddd transparent;
}

.nav-tabs .dropdown-menu {
    margin-top: -1px;
    border-top-right-radius: 0;
    border-top-left-radius: 0;
}

.nav-pills::after {
    content: "";
    display: table;
    clear: both;
}

.nav-pills .nav-item {
    float: left;
}

.nav-pills .nav-item + .nav-item {
    margin-left: 0.2rem;
}

.nav-pills .nav-link {
    display: block;
    padding: 0.5em 1em;
    border-radius: 0.25rem;
}

.nav-pills .nav-link.active, .nav-pills .nav-link.active:focus, .nav-pills .nav-link.active:hover, .nav-pills .nav-item.open .nav-link, .nav-pills .nav-item.open .nav-link:focus, .nav-pills .nav-item.open .nav-link:hover {
    color: #fff;
    cursor: default;
    background-color: #4298DE;
}

.nav-stacked .nav-item {
    display: block;
    float: none;
}

.nav-stacked .nav-item + .nav-item {
    margin-top: 0.2rem;
    margin-left: 0;
}

.tab-content > .tab-pane {
    display: none;
}

.tab-content > .active {
    display: block;
}

.card {
    position: relative;
    display: block;
    margin-bottom: 0.75rem;
    background-color: #fff;
    border-radius: 0;
    border: 1px solid transparent;
}

.card-block {
    padding: 1.25rem;
}

.card-block::after {
    content: "";
    display: table;
    clear: both;
}

.card-title {
    margin-bottom: 0.75rem;
}

.card-subtitle {
    margin-top: -0.375rem;
    margin-bottom: 0;
}

.card-text:last-child {
    margin-bottom: 0;
}

.card-link:hover {
    text-decoration: none;
}

.card-link + .card-link {
    margin-left: 1.25rem;
}

.card > .list-group:first-child .list-group-item:first-child {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
}

.card > .list-group:last-child .list-group-item:last-child {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
}

.card-header {
    padding: 0.75rem 1.25rem;
    margin-bottom: 0;
    background-color: #5d6478;
    border-bottom: 1px solid transparent;
}

.card-header::after {
    content: "";
    display: table;
    clear: both;
}

.card-header:first-child {
    border-radius: 0 0 0 0;
}

.card-footer {
    padding: 0.75rem 1.25rem;
    background-color: #5d6478;
    border-top: 1px solid transparent;
}

.card-footer::after {
    content: "";
    display: table;
    clear: both;
}

.card-footer:last-child {
    border-radius: 0 0 0 0;
}

.card-header-tabs {
    margin-right: -0.625rem;
    margin-bottom: -0.75rem;
    margin-left: -0.625rem;
    border-bottom: 0;
}

.card-header-pills {
    margin-right: -0.625rem;
    margin-left: -0.625rem;
}

.card-primary {
    background-color: #4298DE;
    border-color: #4298DE;
}

.card-primary .card-header, .card-primary .card-footer {
    background-color: transparent;
}

.card-success {
    background-color: #4ACB68;
    border-color: #4ACB68;
}

.card-success .card-header, .card-success .card-footer {
    background-color: transparent;
}

.card-info {
    background-color: #5bc0de;
    border-color: #5bc0de;
}

.card-info .card-header, .card-info .card-footer {
    background-color: transparent;
}

.card-warning {
    background-color: #F3C544;
    border-color: #F3C544;
}

.card-warning .card-header, .card-warning .card-footer {
    background-color: transparent;
}

.card-danger {
    background-color: #E04F3C;
    border-color: #E04F3C;
}

.card-danger .card-header, .card-danger .card-footer {
    background-color: transparent;
}

.card-outline-primary {
    background-color: transparent;
    border-color: #4298DE;
}

.card-outline-secondary {
    background-color: transparent;
    border-color: #ccc;
}

.card-outline-info {
    background-color: transparent;
    border-color: #5bc0de;
}

.card-outline-success {
    background-color: transparent;
    border-color: #4ACB68;
}

.card-outline-warning {
    background-color: transparent;
    border-color: #F3C544;
}

.card-outline-danger {
    background-color: transparent;
    border-color: #E04F3C;
}

.card-inverse .card-header, .card-inverse .card-footer {
    border-color: rgba(255, 255, 255, 0.2);
}

.card-inverse .card-header, .card-inverse .card-footer, .card-inverse .card-title, .card-inverse .card-blockquote {
    color: #fff;
}

.card-inverse .card-link, .card-inverse .card-text, .card-inverse .card-subtitle, .card-inverse .card-blockquote .blockquote-footer {
    color: rgba(255, 255, 255, 0.65);
}

.card-inverse .card-link:focus, .card-inverse .card-link:hover {
    color: #fff;
}

.card-blockquote {
    padding: 0;
    margin-bottom: 0;
    border-left: 0;
}

.card-img {
    border-radius: 0;
}

.card-img-overlay {
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    padding: 1.25rem;
}

.card-img-top {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
}

.card-img-bottom {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
}

@media (min-width: 576px) {
    .card-deck {
        display: -webkit-box;
        display: -ms-flexbox;
        display: flex;
        -ms-flex-flow: row wrap;
        flex-flow: row wrap;
        margin-right: -0.625rem;
        margin-bottom: 0.75rem;
        margin-left: -0.625rem;
    }

    .card-deck .card {
        -webkit-box-flex: 1;
        -ms-flex: 1 0 0;
        flex: 1 0 0;
        margin-right: 0.625rem;
        margin-bottom: 0;
        margin-left: 0.625rem;
    }
}

@media (min-width: 576px) {
    .card-group {
        display: -webkit-box;
        display: -ms-flexbox;
        display: flex;
        -ms-flex-flow: row wrap;
        flex-flow: row wrap;
    }

    .card-group .card {
        -webkit-box-flex: 1;
        -ms-flex: 1 0 0;
        flex: 1 0 0;
    }

    .card-group .card + .card {
        margin-left: 0;
        border-left: 0;
    }

    .card-group .card:first-child {
        border-bottom-right-radius: 0;
        border-top-right-radius: 0;
    }

    .card-group .card:first-child .card-img-top {
        border-top-right-radius: 0;
    }

    .card-group .card:first-child .card-img-bottom {
        border-bottom-right-radius: 0;
    }

    .card-group .card:last-child {
        border-bottom-left-radius: 0;
        border-top-left-radius: 0;
    }

    .card-group .card:last-child .card-img-top {
        border-top-left-radius: 0;
    }

    .card-group .card:last-child .card-img-bottom {
        border-bottom-left-radius: 0;
    }

    .card-group .card:not(:first-child):not(:last-child) {
        border-radius: 0;
    }

    .card-group .card:not(:first-child):not(:last-child) .card-img-top, .card-group .card:not(:first-child):not(:last-child) .card-img-bottom {
        border-radius: 0;
    }
}

@media (min-width: 576px) {
    .card-columns {
        -webkit-column-count: 3;
        -moz-column-count: 3;
        column-count: 3;
        -webkit-column-gap: 1.25rem;
        -moz-column-gap: 1.25rem;
        column-gap: 1.25rem;
    }

    .card-columns .card {
        display: inline-block;
        width: 100%;
    }
}

.tag {
    display: inline-block;
    padding: 0.25em 0.4em;
    font-size: 75%;
    font-weight: bold;
    line-height: 1;
    color: #fff;
    text-align: center;
    white-space: nowrap;
    vertical-align: baseline;
    border-radius: 0.25rem;
}

.tag:empty {
    display: none;
}

.btn .tag, body.delete-confirmation .content-wrap input[type='button'] .tag, body.delete-confirmation .content-wrap input[type='submit'] .tag, body.delete-confirmation .content-wrap button .tag, .submit-row .deletelink-box .deletelink .tag, .submit-row input[type='submit']:not([class*="btn-"]) .tag, .submit-row input[type='button']:not([class*="btn-"]) .tag, .submit-row button:not([class*="btn-"]) .tag, #content-main > .object-tools > li > a:not([class*="btn-"]) .tag, body.login .submit-row input[type='submit'] .tag, #changelist #toolbar #changelist-search input[type='submit'] .tag, #changelist #changelist-form .actions button .tag, #changelist #changelist-form .paginator input[type='submit'] .tag {
    position: relative;
    top: -1px;
}

a.tag:focus, a.tag:hover {
    color: #fff;
    text-decoration: none;
    cursor: pointer;
}

.tag-pill {
    padding-right: 0.6em;
    padding-left: 0.6em;
    border-radius: 10rem;
}

.tag-default {
    background-color: #818a91;
}

.tag-default[href]:focus, .tag-default[href]:hover {
    background-color: #687077;
}

.tag-primary {
    background-color: #4298DE;
}

.tag-primary[href]:focus, .tag-primary[href]:hover {
    background-color: #237fca;
}

.tag-success {
    background-color: #4ACB68;
}

.tag-success[href]:focus, .tag-success[href]:hover {
    background-color: #32b050;
}

.tag-info {
    background-color: #5bc0de;
}

.tag-info[href]:focus, .tag-info[href]:hover {
    background-color: #31b0d5;
}

.tag-warning {
    background-color: #F3C544;
}

.tag-warning[href]:focus, .tag-warning[href]:hover {
    background-color: #f0b614;
}

.tag-danger {
    background-color: #E04F3C;
}

.tag-danger[href]:focus, .tag-danger[href]:hover {
    background-color: #c93420;
}

.alert, .errornote, .messagelist li, body.delete-confirmation .content-wrap {
    padding: 0.75rem 1.25rem;
    margin-bottom: 1rem;
    border: 1px solid transparent;
    border-radius: 0.25rem;
}

.alert-heading {
    color: inherit;
}

.alert-link {
    font-weight: bold;
}

.alert-dismissible {
    padding-right: 2.5rem;
}

.alert-dismissible .close {
    position: relative;
    top: -.125rem;
    right: -1.25rem;
    color: inherit;
}

.alert-success, .messagelist li.success {
    background-color: #dff0d8;
    border-color: #d0e9c6;
    color: #3c763d;
}

.alert-success hr, .messagelist li.success hr {
    border-top-color: #c1e2b3;
}

.alert-success .alert-link, .messagelist li.success .alert-link {
    color: #2b542c;
}

.alert-info, .messagelist li.info {
    background-color: #d9edf7;
    border-color: #bcdff1;
    color: #31708f;
}

.alert-info hr, .messagelist li.info hr {
    border-top-color: #a6d5ec;
}

.alert-info .alert-link, .messagelist li.info .alert-link {
    color: #245269;
}

.alert-warning, .messagelist li.warning {
    background-color: #fcf8e3;
    border-color: #faf2cc;
    color: #8a6d3b;
}

.alert-warning hr, .messagelist li.warning hr {
    border-top-color: #f7ecb5;
}

.alert-warning .alert-link, .messagelist li.warning .alert-link {
    color: #66512c;
}

.alert-danger, .errornote, .messagelist li.danger, .messagelist li.error, body.delete-confirmation .content-wrap {
    background-color: #f2dede;
    border-color: #ebcccc;
    color: #a94442;
}

.alert-danger hr, .errornote hr, .messagelist li.danger hr, .messagelist li.error hr, body.delete-confirmation .content-wrap hr {
    border-top-color: #e4b9b9;
}

.alert-danger .alert-link, .errornote .alert-link, .messagelist li.danger .alert-link, .messagelist li.error .alert-link, body.delete-confirmation .content-wrap .alert-link {
    color: #843534;
}

@-webkit-keyframes progress-bar-stripes {
    from {
        background-position: 1rem 0;
    }
    to {
        background-position: 0 0;
    }
}

@keyframes progress-bar-stripes {
    from {
        background-position: 1rem 0;
    }
    to {
        background-position: 0 0;
    }
}

.progress {
    display: block;
    width: 100%;
    height: 1rem;
    margin-bottom: 1rem;
}

.progress[value] {
    background-color: #eee;
    border: 0;
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    border-radius: 0.25rem;
}

.progress[value]::-ms-fill {
    background-color: #0074d9;
    border: 0;
}

.progress[value]::-moz-progress-bar {
    background-color: #0074d9;
    border-bottom-left-radius: 0.25rem;
    border-top-left-radius: 0.25rem;
}

.progress[value]::-webkit-progress-value {
    background-color: #0074d9;
    border-bottom-left-radius: 0.25rem;
    border-top-left-radius: 0.25rem;
}

.progress[value="100"]::-moz-progress-bar {
    border-bottom-right-radius: 0.25rem;
    border-top-right-radius: 0.25rem;
}

.progress[value="100"]::-webkit-progress-value {
    border-bottom-right-radius: 0.25rem;
    border-top-right-radius: 0.25rem;
}

.progress[value]::-webkit-progress-bar {
    background-color: #eee;
    border-radius: 0.25rem;
}

base::-moz-progress-bar, .progress[value] {
    background-color: #eee;
    border-radius: 0.25rem;
}

@media screen and (min-width: 0\0
) {
    .progress {
        background-color: #eee;
        border-radius: 0.25rem;
    }

    .progress-bar {
        display: inline-block;
        height: 1rem;
        text-indent: -999rem;
        background-color: #0074d9;
        border-bottom-left-radius: 0.25rem;
        border-top-left-radius: 0.25rem;
    }

    .progress[width="100%"] {
        border-bottom-right-radius: 0.25rem;
        border-top-right-radius: 0.25rem;
    }
}

.progress-striped[value]::-webkit-progress-value {
    background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-size: 1rem 1rem;
}

.progress-striped[value]::-moz-progress-bar {
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-size: 1rem 1rem;
}

.progress-striped[value]::-ms-fill {
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-size: 1rem 1rem;
}

@media screen and (min-width: 0\0
) {
    .progress-bar-striped {
        background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
        background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
        background-size: 1rem 1rem;
    }
}

.progress-animated[value]::-webkit-progress-value {
    -webkit-animation: progress-bar-stripes 2s linear infinite;
    animation: progress-bar-stripes 2s linear infinite;
}

.progress-animated[value]::-moz-progress-bar {
    animation: progress-bar-stripes 2s linear infinite;
}

@media screen and (min-width: 0\0
) {
    .progress-animated .progress-bar-striped {
        -webkit-animation: progress-bar-stripes 2s linear infinite;
        animation: progress-bar-stripes 2s linear infinite;
    }
}

.progress-success[value]::-webkit-progress-value {
    background-color: #4ACB68;
}

.progress-success[value]::-moz-progress-bar {
    background-color: #4ACB68;
}

.progress-success[value]::-ms-fill {
    background-color: #4ACB68;
}

@media screen and (min-width: 0\0
) {
    .progress-success .progress-bar {
        background-color: #4ACB68;
    }
}

.progress-info[value]::-webkit-progress-value {
    background-color: #5bc0de;
}

.progress-info[value]::-moz-progress-bar {
    background-color: #5bc0de;
}

.progress-info[value]::-ms-fill {
    background-color: #5bc0de;
}

@media screen and (min-width: 0\0
) {
    .progress-info .progress-bar {
        background-color: #5bc0de;
    }
}

.progress-warning[value]::-webkit-progress-value {
    background-color: #F3C544;
}

.progress-warning[value]::-moz-progress-bar {
    background-color: #F3C544;
}

.progress-warning[value]::-ms-fill {
    background-color: #F3C544;
}

@media screen and (min-width: 0\0
) {
    .progress-warning .progress-bar {
        background-color: #F3C544;
    }
}

.progress-danger[value]::-webkit-progress-value {
    background-color: #E04F3C;
}

.progress-danger[value]::-moz-progress-bar {
    background-color: #E04F3C;
}

.progress-danger[value]::-ms-fill {
    background-color: #E04F3C;
}

@media screen and (min-width: 0\0
) {
    .progress-danger .progress-bar {
        background-color: #E04F3C;
    }
}

.embed-responsive {
    position: relative;
    display: block;
    height: 0;
    padding: 0;
    overflow: hidden;
}

.embed-responsive .embed-responsive-item, .embed-responsive iframe, .embed-responsive embed, .embed-responsive object, .embed-responsive video {
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    width: 100%;
    height: 100%;
    border: 0;
}

.embed-responsive-21by9 {
    padding-bottom: 42.85714%;
}

.embed-responsive-16by9 {
    padding-bottom: 56.25%;
}

.embed-responsive-4by3 {
    padding-bottom: 75%;
}

.embed-responsive-1by1 {
    padding-bottom: 100%;
}

.close {
    float: right;
    font-size: 1.5rem;
    font-weight: bold;
    line-height: 1;
    color: #000;
    text-shadow: 0 1px 0 #fff;
    opacity: .2;
}

.close:focus, .close:hover {
    color: #000;
    text-decoration: none;
    cursor: pointer;
    opacity: .5;
}

button.close {
    padding: 0;
    cursor: pointer;
    background: transparent;
    border: 0;
    -webkit-appearance: none;
}

.modal-open {
    overflow: hidden;
}

.modal {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1050;
    display: none;
    overflow: hidden;
    outline: 0;
}

.modal.fade .modal-dialog {
    -webkit-transition: -webkit-transform .3s ease-out;
    transition: -webkit-transform .3s ease-out;
    transition: transform .3s ease-out;
    transition: transform .3s ease-out, -webkit-transform .3s ease-out;
    -webkit-transform: translate(0, -25%);
    transform: translate(0, -25%);
}

.modal.in .modal-dialog {
    -webkit-transform: translate(0, 0);
    transform: translate(0, 0);
}

.modal-open .modal {
    overflow-x: hidden;
    overflow-y: auto;
}

.modal-dialog {
    position: relative;
    width: auto;
    margin: 10px;
}

.modal-content {
    position: relative;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid rgba(0, 0, 0, 0.2);
    border-radius: 0.3rem;
    outline: 0;
}

.modal-backdrop {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1040;
    background-color: #000;
}

.modal-backdrop.fade {
    opacity: 0;
}

.modal-backdrop.in {
    opacity: 0.5;
}

.modal-header {
    padding: 15px;
    border-bottom: 1px solid #e5e5e5;
}

.modal-header::after {
    content: "";
    display: table;
    clear: both;
}

.modal-header .close {
    margin-top: -2px;
}

.modal-title {
    margin: 0;
    line-height: 1.5;
}

.modal-body {
    position: relative;
    padding: 15px;
}

.modal-footer {
    padding: 15px;
    text-align: right;
    border-top: 1px solid #e5e5e5;
}

.modal-footer::after {
    content: "";
    display: table;
    clear: both;
}

.modal-scrollbar-measure {
    position: absolute;
    top: -9999px;
    width: 50px;
    height: 50px;
    overflow: scroll;
}

@media (min-width: 576px) {
    .modal-dialog {
        max-width: 600px;
        margin: 30px auto;
    }

    .modal-sm {
        max-width: 300px;
    }
}

@media (min-width: 992px) {
    .modal-lg {
        max-width: 900px;
    }
}

.tooltip {
    position: absolute;
    z-index: 1070;
    display: block;
    font-family: "Roboto", "Helvetica Neue", Helvetica, Arial, sans-serif;
    font-style: normal;
    font-weight: normal;
    letter-spacing: normal;
    line-break: auto;
    line-height: 1.5;
    text-align: left;
    text-align: start;
    text-decoration: none;
    text-shadow: none;
    text-transform: none;
    white-space: normal;
    word-break: normal;
    word-spacing: normal;
    font-size: 0.929rem;
    word-wrap: break-word;
    opacity: 0;
}

.tooltip.in {
    opacity: 0.9;
}

.tooltip.tooltip-top, .tooltip.bs-tether-element-attached-bottom {
    padding: 5px 0;
    margin-top: -3px;
}

.tooltip.tooltip-top .tooltip-inner::before, .tooltip.bs-tether-element-attached-bottom .tooltip-inner::before {
    bottom: 0;
    left: 50%;
    margin-left: -5px;
    content: "";
    border-width: 5px 5px 0;
    border-top-color: #000;
}

.tooltip.tooltip-right, .tooltip.bs-tether-element-attached-left {
    padding: 0 5px;
    margin-left: 3px;
}

.tooltip.tooltip-right .tooltip-inner::before, .tooltip.bs-tether-element-attached-left .tooltip-inner::before {
    top: 50%;
    left: 0;
    margin-top: -5px;
    content: "";
    border-width: 5px 5px 5px 0;
    border-right-color: #000;
}

.tooltip.tooltip-bottom, .tooltip.bs-tether-element-attached-top {
    padding: 5px 0;
    margin-top: 3px;
}

.tooltip.tooltip-bottom .tooltip-inner::before, .tooltip.bs-tether-element-attached-top .tooltip-inner::before {
    top: 0;
    left: 50%;
    margin-left: -5px;
    content: "";
    border-width: 0 5px 5px;
    border-bottom-color: #000;
}

.tooltip.tooltip-left, .tooltip.bs-tether-element-attached-right {
    padding: 0 5px;
    margin-left: -3px;
}

.tooltip.tooltip-left .tooltip-inner::before, .tooltip.bs-tether-element-attached-right .tooltip-inner::before {
    top: 50%;
    right: 0;
    margin-top: -5px;
    content: "";
    border-width: 5px 0 5px 5px;
    border-left-color: #000;
}

.tooltip-inner {
    max-width: 200px;
    padding: 3px 8px;
    color: #fff;
    text-align: center;
    background-color: #000;
    border-radius: 0.25rem;
}

.tooltip-inner::before {
    position: absolute;
    width: 0;
    height: 0;
    border-color: transparent;
    border-style: solid;
}

.align-baseline {
    vertical-align: baseline !important;
}

.align-top {
    vertical-align: top !important;
}

.align-middle {
    vertical-align: middle !important;
}

.align-bottom {
    vertical-align: bottom !important;
}

.align-text-bottom {
    vertical-align: text-bottom !important;
}

.align-text-top {
    vertical-align: text-top !important;
}

.bg-faded {
    background-color: #f7f7f9;
}

.bg-primary {
    background-color: #4298DE !important;
}

a.bg-primary:focus, a.bg-primary:hover {
    background-color: #237fca !important;
}

.bg-success {
    background-color: #4ACB68 !important;
}

a.bg-success:focus, a.bg-success:hover {
    background-color: #32b050 !important;
}

.bg-info {
    background-color: #5bc0de !important;
}

a.bg-info:focus, a.bg-info:hover {
    background-color: #31b0d5 !important;
}

.bg-warning {
    background-color: #F3C544 !important;
}

a.bg-warning:focus, a.bg-warning:hover {
    background-color: #f0b614 !important;
}

.bg-danger {
    background-color: #E04F3C !important;
}

a.bg-danger:focus, a.bg-danger:hover {
    background-color: #c93420 !important;
}

.bg-inverse {
    background-color: #373a3c !important;
}

a.bg-inverse:focus, a.bg-inverse:hover {
    background-color: #1f2021 !important;
}

.rounded {
    border-radius: 0.25rem;
}

.rounded-top {
    border-top-right-radius: 0.25rem;
    border-top-left-radius: 0.25rem;
}

.rounded-right {
    border-bottom-right-radius: 0.25rem;
    border-top-right-radius: 0.25rem;
}

.rounded-bottom {
    border-bottom-right-radius: 0.25rem;
    border-bottom-left-radius: 0.25rem;
}

.rounded-left {
    border-bottom-left-radius: 0.25rem;
    border-top-left-radius: 0.25rem;
}

.rounded-circle {
    border-radius: 50%;
}

.clearfix::after {
    content: "";
    display: table;
    clear: both;
}

.d-block {
    display: block !important;
}

.d-inline-block {
    display: inline-block !important;
}

.d-inline {
    display: inline !important;
}

.flex-xs-first {
    -webkit-box-ordinal-group: 0;
    -ms-flex-order: -1;
    order: -1;
}

.flex-xs-last {
    -webkit-box-ordinal-group: 2;
    -ms-flex-order: 1;
    order: 1;
}

.flex-xs-unordered {
    -webkit-box-ordinal-group: 1;
    -ms-flex-order: 0;
    order: 0;
}

.flex-items-xs-top {
    -webkit-box-align: start;
    -ms-flex-align: start;
    align-items: flex-start;
}

.flex-items-xs-middle {
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
}

.flex-items-xs-bottom {
    -webkit-box-align: end;
    -ms-flex-align: end;
    align-items: flex-end;
}

.flex-xs-top {
    -ms-flex-item-align: start;
    align-self: flex-start;
}

.flex-xs-middle {
    -ms-flex-item-align: center;
    -ms-grid-row-align: center;
    align-self: center;
}

.flex-xs-bottom {
    -ms-flex-item-align: end;
    align-self: flex-end;
}

.flex-items-xs-left {
    -webkit-box-pack: start;
    -ms-flex-pack: start;
    justify-content: flex-start;
}

.flex-items-xs-center {
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
}

.flex-items-xs-right {
    -webkit-box-pack: end;
    -ms-flex-pack: end;
    justify-content: flex-end;
}

.flex-items-xs-around {
    -ms-flex-pack: distribute;
    justify-content: space-around;
}

.flex-items-xs-between {
    -webkit-box-pack: justify;
    -ms-flex-pack: justify;
    justify-content: space-between;
}

@media (min-width: 576px) {
    .flex-sm-first {
        -webkit-box-ordinal-group: 0;
        -ms-flex-order: -1;
        order: -1;
    }

    .flex-sm-last {
        -webkit-box-ordinal-group: 2;
        -ms-flex-order: 1;
        order: 1;
    }

    .flex-sm-unordered {
        -webkit-box-ordinal-group: 1;
        -ms-flex-order: 0;
        order: 0;
    }
}

@media (min-width: 576px) {
    .flex-items-sm-top {
        -webkit-box-align: start;
        -ms-flex-align: start;
        align-items: flex-start;
    }

    .flex-items-sm-middle {
        -webkit-box-align: center;
        -ms-flex-align: center;
        align-items: center;
    }

    .flex-items-sm-bottom {
        -webkit-box-align: end;
        -ms-flex-align: end;
        align-items: flex-end;
    }
}

@media (min-width: 576px) {
    .flex-sm-top {
        -ms-flex-item-align: start;
        align-self: flex-start;
    }

    .flex-sm-middle {
        -ms-flex-item-align: center;
        -ms-grid-row-align: center;
        align-self: center;
    }

    .flex-sm-bottom {
        -ms-flex-item-align: end;
        align-self: flex-end;
    }
}

@media (min-width: 576px) {
    .flex-items-sm-left {
        -webkit-box-pack: start;
        -ms-flex-pack: start;
        justify-content: flex-start;
    }

    .flex-items-sm-center {
        -webkit-box-pack: center;
        -ms-flex-pack: center;
        justify-content: center;
    }

    .flex-items-sm-right {
        -webkit-box-pack: end;
        -ms-flex-pack: end;
        justify-content: flex-end;
    }

    .flex-items-sm-around {
        -ms-flex-pack: distribute;
        justify-content: space-around;
    }

    .flex-items-sm-between {
        -webkit-box-pack: justify;
        -ms-flex-pack: justify;
        justify-content: space-between;
    }
}

@media (min-width: 768px) {
    .flex-md-first {
        -webkit-box-ordinal-group: 0;
        -ms-flex-order: -1;
        order: -1;
    }

    .flex-md-last {
        -webkit-box-ordinal-group: 2;
        -ms-flex-order: 1;
        order: 1;
    }

    .flex-md-unordered {
        -webkit-box-ordinal-group: 1;
        -ms-flex-order: 0;
        order: 0;
    }
}

@media (min-width: 768px) {
    .flex-items-md-top {
        -webkit-box-align: start;
        -ms-flex-align: start;
        align-items: flex-start;
    }

    .flex-items-md-middle {
        -webkit-box-align: center;
        -ms-flex-align: center;
        align-items: center;
    }

    .flex-items-md-bottom {
        -webkit-box-align: end;
        -ms-flex-align: end;
        align-items: flex-end;
    }
}

@media (min-width: 768px) {
    .flex-md-top {
        -ms-flex-item-align: start;
        align-self: flex-start;
    }

    .flex-md-middle {
        -ms-flex-item-align: center;
        -ms-grid-row-align: center;
        align-self: center;
    }

    .flex-md-bottom {
        -ms-flex-item-align: end;
        align-self: flex-end;
    }
}

@media (min-width: 768px) {
    .flex-items-md-left {
        -webkit-box-pack: start;
        -ms-flex-pack: start;
        justify-content: flex-start;
    }

    .flex-items-md-center {
        -webkit-box-pack: center;
        -ms-flex-pack: center;
        justify-content: center;
    }

    .flex-items-md-right {
        -webkit-box-pack: end;
        -ms-flex-pack: end;
        justify-content: flex-end;
    }

    .flex-items-md-around {
        -ms-flex-pack: distribute;
        justify-content: space-around;
    }

    .flex-items-md-between {
        -webkit-box-pack: justify;
        -ms-flex-pack: justify;
        justify-content: space-between;
    }
}

@media (min-width: 992px) {
    .flex-lg-first {
        -webkit-box-ordinal-group: 0;
        -ms-flex-order: -1;
        order: -1;
    }

    .flex-lg-last {
        -webkit-box-ordinal-group: 2;
        -ms-flex-order: 1;
        order: 1;
    }

    .flex-lg-unordered {
        -webkit-box-ordinal-group: 1;
        -ms-flex-order: 0;
        order: 0;
    }
}

@media (min-width: 992px) {
    .flex-items-lg-top {
        -webkit-box-align: start;
        -ms-flex-align: start;
        align-items: flex-start;
    }

    .flex-items-lg-middle {
        -webkit-box-align: center;
        -ms-flex-align: center;
        align-items: center;
    }

    .flex-items-lg-bottom {
        -webkit-box-align: end;
        -ms-flex-align: end;
        align-items: flex-end;
    }
}

@media (min-width: 992px) {
    .flex-lg-top {
        -ms-flex-item-align: start;
        align-self: flex-start;
    }

    .flex-lg-middle {
        -ms-flex-item-align: center;
        -ms-grid-row-align: center;
        align-self: center;
    }

    .flex-lg-bottom {
        -ms-flex-item-align: end;
        align-self: flex-end;
    }
}

@media (min-width: 992px) {
    .flex-items-lg-left {
        -webkit-box-pack: start;
        -ms-flex-pack: start;
        justify-content: flex-start;
    }

    .flex-items-lg-center {
        -webkit-box-pack: center;
        -ms-flex-pack: center;
        justify-content: center;
    }

    .flex-items-lg-right {
        -webkit-box-pack: end;
        -ms-flex-pack: end;
        justify-content: flex-end;
    }

    .flex-items-lg-around {
        -ms-flex-pack: distribute;
        justify-content: space-around;
    }

    .flex-items-lg-between {
        -webkit-box-pack: justify;
        -ms-flex-pack: justify;
        justify-content: space-between;
    }
}

@media (min-width: 1200px) {
    .flex-xl-first {
        -webkit-box-ordinal-group: 0;
        -ms-flex-order: -1;
        order: -1;
    }

    .flex-xl-last {
        -webkit-box-ordinal-group: 2;
        -ms-flex-order: 1;
        order: 1;
    }

    .flex-xl-unordered {
        -webkit-box-ordinal-group: 1;
        -ms-flex-order: 0;
        order: 0;
    }
}

@media (min-width: 1200px) {
    .flex-items-xl-top {
        -webkit-box-align: start;
        -ms-flex-align: start;
        align-items: flex-start;
    }

    .flex-items-xl-middle {
        -webkit-box-align: center;
        -ms-flex-align: center;
        align-items: center;
    }

    .flex-items-xl-bottom {
        -webkit-box-align: end;
        -ms-flex-align: end;
        align-items: flex-end;
    }
}

@media (min-width: 1200px) {
    .flex-xl-top {
        -ms-flex-item-align: start;
        align-self: flex-start;
    }

    .flex-xl-middle {
        -ms-flex-item-align: center;
        -ms-grid-row-align: center;
        align-self: center;
    }

    .flex-xl-bottom {
        -ms-flex-item-align: end;
        align-self: flex-end;
    }
}

@media (min-width: 1200px) {
    .flex-items-xl-left {
        -webkit-box-pack: start;
        -ms-flex-pack: start;
        justify-content: flex-start;
    }

    .flex-items-xl-center {
        -webkit-box-pack: center;
        -ms-flex-pack: center;
        justify-content: center;
    }

    .flex-items-xl-right {
        -webkit-box-pack: end;
        -ms-flex-pack: end;
        justify-content: flex-end;
    }

    .flex-items-xl-around {
        -ms-flex-pack: distribute;
        justify-content: space-around;
    }

    .flex-items-xl-between {
        -webkit-box-pack: justify;
        -ms-flex-pack: justify;
        justify-content: space-between;
    }
}

.float-xs-left {
    float: left !important;
}

.float-xs-right {
    float: right !important;
}

.float-xs-none {
    float: none !important;
}

@media (min-width: 576px) {
    .float-sm-left {
        float: left !important;
    }

    .float-sm-right {
        float: right !important;
    }

    .float-sm-none {
        float: none !important;
    }
}

@media (min-width: 768px) {
    .float-md-left {
        float: left !important;
    }

    .float-md-right {
        float: right !important;
    }

    .float-md-none {
        float: none !important;
    }
}

@media (min-width: 992px) {
    .float-lg-left {
        float: left !important;
    }

    .float-lg-right {
        float: right !important;
    }

    .float-lg-none {
        float: none !important;
    }
}

@media (min-width: 1200px) {
    .float-xl-left {
        float: left !important;
    }

    .float-xl-right {
        float: right !important;
    }

    .float-xl-none {
        float: none !important;
    }
}

.sr-only {
    position: absolute;
    width: 1px;
    height: 1px;
    padding: 0;
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    border: 0;
}

.sr-only-focusable:active, .sr-only-focusable:focus {
    position: static;
    width: auto;
    height: auto;
    margin: 0;
    overflow: visible;
    clip: auto;
}

.w-100 {
    width: 100% !important;
}

.h-100 {
    height: 100% !important;
}

.mx-auto {
    margin-right: auto !important;
    margin-left: auto !important;
}

.m-0 {
    margin: 0 0 !important;
}

.mt-0 {
    margin-top: 0 !important;
}

.mr-0 {
    margin-right: 0 !important;
}

.mb-0 {
    margin-bottom: 0 !important;
}

.ml-0 {
    margin-left: 0 !important;
}

.mx-0 {
    margin-right: 0 !important;
    margin-left: 0 !important;
}

.my-0 {
    margin-top: 0 !important;
    margin-bottom: 0 !important;
}

.m-1 {
    margin: 1rem 1rem !important;
}

.mt-1 {
    margin-top: 1rem !important;
}

.mr-1 {
    margin-right: 1rem !important;
}

.mb-1 {
    margin-bottom: 1rem !important;
}

.ml-1 {
    margin-left: 1rem !important;
}

.mx-1 {
    margin-right: 1rem !important;
    margin-left: 1rem !important;
}

.my-1 {
    margin-top: 1rem !important;
    margin-bottom: 1rem !important;
}

.m-2 {
    margin: 1.5rem 1.5rem !important;
}

.mt-2 {
    margin-top: 1.5rem !important;
}

.mr-2 {
    margin-right: 1.5rem !important;
}

.mb-2 {
    margin-bottom: 1.5rem !important;
}

.ml-2 {
    margin-left: 1.5rem !important;
}

.mx-2 {
    margin-right: 1.5rem !important;
    margin-left: 1.5rem !important;
}

.my-2 {
    margin-top: 1.5rem !important;
    margin-bottom: 1.5rem !important;
}

.m-3 {
    margin: 3rem 3rem !important;
}

.mt-3 {
    margin-top: 3rem !important;
}

.mr-3 {
    margin-right: 3rem !important;
}

.mb-3 {
    margin-bottom: 3rem !important;
}

.ml-3 {
    margin-left: 3rem !important;
}

.mx-3 {
    margin-right: 3rem !important;
    margin-left: 3rem !important;
}

.my-3 {
    margin-top: 3rem !important;
    margin-bottom: 3rem !important;
}

.p-0 {
    padding: 0 0 !important;
}

.pt-0 {
    padding-top: 0 !important;
}

.pr-0 {
    padding-right: 0 !important;
}

.pb-0 {
    padding-bottom: 0 !important;
}

.pl-0 {
    padding-left: 0 !important;
}

.px-0 {
    padding-right: 0 !important;
    padding-left: 0 !important;
}

.py-0 {
    padding-top: 0 !important;
    padding-bottom: 0 !important;
}

.p-1 {
    padding: 1rem 1rem !important;
}

.pt-1 {
    padding-top: 1rem !important;
}

.pr-1 {
    padding-right: 1rem !important;
}

.pb-1 {
    padding-bottom: 1rem !important;
}

.pl-1 {
    padding-left: 1rem !important;
}

.px-1 {
    padding-right: 1rem !important;
    padding-left: 1rem !important;
}

.py-1 {
    padding-top: 1rem !important;
    padding-bottom: 1rem !important;
}

.p-2 {
    padding: 1.5rem 1.5rem !important;
}

.pt-2 {
    padding-top: 1.5rem !important;
}

.pr-2 {
    padding-right: 1.5rem !important;
}

.pb-2 {
    padding-bottom: 1.5rem !important;
}

.pl-2 {
    padding-left: 1.5rem !important;
}

.px-2 {
    padding-right: 1.5rem !important;
    padding-left: 1.5rem !important;
}

.py-2 {
    padding-top: 1.5rem !important;
    padding-bottom: 1.5rem !important;
}

.p-3 {
    padding: 3rem 3rem !important;
}

.pt-3 {
    padding-top: 3rem !important;
}

.pr-3 {
    padding-right: 3rem !important;
}

.pb-3 {
    padding-bottom: 3rem !important;
}

.pl-3 {
    padding-left: 3rem !important;
}

.px-3 {
    padding-right: 3rem !important;
    padding-left: 3rem !important;
}

.py-3 {
    padding-top: 3rem !important;
    padding-bottom: 3rem !important;
}

.pos-f-t {
    position: fixed;
    top: 0;
    right: 0;
    left: 0;
    z-index: 1030;
}

.text-justify {
    text-align: justify !important;
}

.text-nowrap {
    white-space: nowrap !important;
}

.text-truncate {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

.text-xs-left {
    text-align: left !important;
}

.text-xs-right {
    text-align: right !important;
}

.text-xs-center {
    text-align: center !important;
}

@media (min-width: 576px) {
    .text-sm-left {
        text-align: left !important;
    }

    .text-sm-right {
        text-align: right !important;
    }

    .text-sm-center {
        text-align: center !important;
    }
}

@media (min-width: 768px) {
    .text-md-left {
        text-align: left !important;
    }

    .text-md-right {
        text-align: right !important;
    }

    .text-md-center {
        text-align: center !important;
    }
}

@media (min-width: 992px) {
    .text-lg-left {
        text-align: left !important;
    }

    .text-lg-right {
        text-align: right !important;
    }

    .text-lg-center {
        text-align: center !important;
    }
}

@media (min-width: 1200px) {
    .text-xl-left {
        text-align: left !important;
    }

    .text-xl-right {
        text-align: right !important;
    }

    .text-xl-center {
        text-align: center !important;
    }
}

.text-lowercase {
    text-transform: lowercase !important;
}

.text-uppercase {
    text-transform: uppercase !important;
}

.text-capitalize {
    text-transform: capitalize !important;
}

.font-weight-normal {
    font-weight: normal;
}

.font-weight-bold {
    font-weight: bold;
}

.font-italic {
    font-style: italic;
}

.text-white {
    color: #fff !important;
}

.text-muted, fieldset > .description, fieldset .text-help, .timezonewarning {
    color: #9ca3a9 !important;
}

a.text-muted:focus, fieldset > a.description:focus, fieldset a.text-help:focus, a.timezonewarning:focus, a.text-muted:hover, fieldset > a.description:hover, fieldset a.text-help:hover, a.timezonewarning:hover {
    color: #818a91 !important;
}

.text-primary {
    color: #4298DE !important;
}

a.text-primary:focus, a.text-primary:hover {
    color: #237fca !important;
}

.text-success {
    color: #4ACB68 !important;
}

a.text-success:focus, a.text-success:hover {
    color: #32b050 !important;
}

.text-info {
    color: #5bc0de !important;
}

a.text-info:focus, a.text-info:hover {
    color: #31b0d5 !important;
}

.text-warning {
    color: #F3C544 !important;
}

a.text-warning:focus, a.text-warning:hover {
    color: #f0b614 !important;
}

.text-danger {
    color: #E04F3C !important;
}

a.text-danger:focus, a.text-danger:hover {
    color: #c93420 !important;
}

.text-gray-dark {
    color: #373a3c !important;
}

a.text-gray-dark:focus, a.text-gray-dark:hover {
    color: #1f2021 !important;
}

.text-hide {
    font: 0/0 a;
    color: transparent;
    text-shadow: none;
    background-color: transparent;
    border: 0;
}

.invisible {
    visibility: hidden !important;
}

.hidden-xs-up {
    display: none !important;
}

@media (max-width: 575px) {
    .hidden-xs-down {
        display: none !important;
    }
}

@media (min-width: 576px) {
    .hidden-sm-up {
        display: none !important;
    }
}

@media (max-width: 767px) {
    .hidden-sm-down {
        display: none !important;
    }
}

@media (min-width: 768px) {
    .hidden-md-up {
        display: none !important;
    }
}

@media (max-width: 991px) {
    .hidden-md-down {
        display: none !important;
    }
}

@media (min-width: 992px) {
    .hidden-lg-up {
        display: none !important;
    }
}

@media (max-width: 1199px) {
    .hidden-lg-down {
        display: none !important;
    }
}

@media (min-width: 1200px) {
    .hidden-xl-up {
        display: none !important;
    }
}

.hidden-xl-down {
    display: none !important;
}

.visible-print-block {
    display: none !important;
}

@media print {
    .visible-print-block {
        display: block !important;
    }
}

.visible-print-inline {
    display: none !important;
}

@media print {
    .visible-print-inline {
        display: inline !important;
    }
}

.visible-print-inline-block {
    display: none !important;
}

@media print {
    .visible-print-inline-block {
        display: inline-block !important;
    }
}

@media print {
    .hidden-print {
        display: none !important;
    }
}

.text-lighter {
    font-weight: 200;
}

.text-light, .text-light-bold, body.cap_layout_horizontal #header #user-tools strong, body.cap_layout_vertical #header #user-tools:not(.cap-user-tools) strong {
    font-weight: 300;
}

.text-normal {
    font-weight: 400;
}

.text-semibold, .text-light-bold strong, #result_list tbody > tr > th, .tabular table tbody > tr > th, table#change-history tbody > tr > th, .nav-tabs-cap .nav-link.active, .nav-tabs-cap .nav-link.active:focus, body.login #header #branding #site-name a {
    font-weight: 500;
}

.link-with-icon .fa {
    vertical-align: text-bottom;
    margin-left: 3px;
}

.btn-round, #content-main > .object-tools > li > a:not([class*="btn-"]) {
    border-radius: 40px;
}

.btn-outline-danger, .submit-row .deletelink-box .deletelink {
    border-color: rgba(224, 79, 60, 0.75);
    background-color: #fff;
}

textarea.form-control, fieldset textarea.vTextField, fieldset textarea.vURLField, fieldset textarea.vLargeTextField, fieldset textarea.vTimeField, fieldset textarea.vDateField {
    line-height: 1.5;
}

fieldset {
    box-shadow: 0 1px 0 0 #e4e4e4;
    margin-bottom: 2rem;
}

fieldset > h2 {
    float: left;
    padding-right: 2rem;
}

fieldset > .description {
    font-size: 0.929rem;
    padding-top: .35rem;
    display: inline-block;
}

fieldset h2 + .description + *, fieldset .inline-related {
    clear: both;
}

fieldset .form-row:not(.form-group):not(tr) {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    background-color: #f6f6f6;
    padding: 0.5rem 1.1rem;
}

fieldset .form-row:not(.form-group):not(tr):last-child > label:not(.form-control-label) {
    border-bottom: 0;
}

@media (max-width: 575px) {
    fieldset .form-row:not(.form-group):not(tr) {
        -ms-flex-wrap: wrap;
        flex-wrap: wrap;
    }
}

fieldset .form-row:not(.form-group):not(tr) > * {
    -ms-flex-item-align: start;
    align-self: flex-start;
}

fieldset .form-row:not(.form-group):not(tr) > label:not(.form-control-label) {
    -ms-flex-item-align: stretch;
    -ms-grid-row-align: stretch;
    align-self: stretch;
    margin: -0.5rem 1.1rem -0.5rem -1.1rem;
}

fieldset .form-row:not(.form-group):not(tr) > label:not(.form-control-label).required {
    padding-right: 1.5rem;
}

@media (max-width: 767px) {
    fieldset .form-row:not(.form-group):not(tr) > label:not(.form-control-label) {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 25%;
        flex: 0 0 25%;
    }
}

@media (max-width: 575px) {
    fieldset .form-row:not(.form-group):not(tr) > label:not(.form-control-label) {
        -webkit-box-flex: 0;
        -ms-flex: 0 0 100%;
        flex: 0 0 100%;
    }
}

.cap-include fieldset:not(.cap-form):not(.module) {
    box-shadow: none;
}

.cap-include .card:last-child {
    margin-bottom: 0;
}

fieldset .text-help {
    margin-top: .5rem;
    display: block;
}

fieldset input[type="checkbox"] + .text-help, fieldset .form-inline .text-help {
    display: inline;
    margin-left: .5rem;
}

fieldset .form-inline .text-help {
    display: inline-block;
    margin-left: .5rem;
}

fieldset .form-row, fieldset .cap-form .form-group {
    clear: both;
}

fieldset .form-row label, fieldset .cap-form .form-group label {
    font-size: 0.929rem;
}

fieldset .form-row label.required:after, fieldset .cap-form .form-group label.required:after {
    content: '*';
    margin: 0 0 0 5px;
    position: absolute;
    color: #ccc;
}

fieldset .form-row > label, fieldset .cap-form .form-group > label {
    margin: 0;
    line-height: 1.25rem;
    text-align: right;
    background-color: #fff;
    padding-top: 1.05rem;
    padding-bottom: 0.9rem;
    border-bottom: 1px solid #eeeeee;
}

@media (max-width: 575px) {
    fieldset .form-row > label, fieldset .cap-form .form-group > label {
        padding-top: 0.525rem;
        background-color: transparent;
        text-align: left;
        font-weight: bold;
        border-bottom: none;
    }
}

fieldset .form-row.has-danger, fieldset .cap-form .form-group.has-danger {
    display: -webkit-box !important;
    display: -ms-flexbox !important;
    display: flex !important;
}

fieldset .form-row:last-child > label, fieldset .cap-form .form-group:last-child > label {
    border-bottom: none;
}

fieldset .form-row > ul, fieldset .form-row .errorlist, fieldset .cap-form .form-group > ul, fieldset .cap-form .form-group .errorlist {
    margin: 0;
    padding-left: 2rem;
    font-size: 0.857rem;
}

@media (max-width: 575px) {
    fieldset .form-row > ul, fieldset .form-row .errorlist, fieldset .cap-form .form-group > ul, fieldset .cap-form .form-group .errorlist {
        margin-top: .5rem;
        padding-left: 1.5rem;
    }
}

.cap-form .form-group {
    margin: 0;
    background-color: #f6f6f6;
}

@media (max-width: 575px) {
    .cap-form .form-group {
        padding-bottom: 1rem;
    }
}

.cap-form .form-group label {
    margin: 0;
}

.cap-form .form-group label.required {
    padding-right: .55rem;
}

.cap-form .form-group .form-control-label + div[class*='col-'] {
    padding-top: 0.5rem;
    padding-bottom: 0.5rem;
}

@media (max-width: 575px) {
    .cap-form .form-group .form-control-label + div[class*='col-'] {
        padding-top: 0;
    }
}

.cap-form .form-group p.form-control-static, .cap-form .form-group .inline-group .tabular table tbody td.original p, .inline-group .tabular table tbody td.original .cap-form .form-group p {
    margin: 0;
}

.cap-form .form-group:first-child .form-control-label {
    padding-top: 1.3rem;
}

.cap-form .form-group:first-child .form-control-label + div[class*='col-'] {
    padding-top: 0.75rem;
}

.cap-form .form-group:last-child .form-control-label + div[class*='col-'] {
    padding-bottom: 0.75rem;
}

.col-multi-fields {
    padding-bottom: 0 !important;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
}

@media (max-width: 575px) {
    .col-multi-fields {
        padding-top: 0 !important;
    }
}

.col-multi-fields .multi-field {
    -ms-flex-preferred-size: 15rem;
    flex-basis: 15rem;
    white-space: nowrap;
    margin-bottom: 0.5rem;
    padding-right: 1rem;
}

@media (max-width: 575px) {
    .col-multi-fields .multi-field {
        -ms-flex-preferred-size: 100%;
        flex-basis: 100%;
        padding-bottom: 0;
    }
}

.col-multi-fields .multi-field .form-control-label {
    vertical-align: top;
    display: inline-block;
    padding-top: 0.5rem !important;
    padding-left: 0;
    padding-right: 0.55rem;
}

@media (min-width: 576px) {
    .col-multi-fields .multi-field .form-control-label {
        padding-bottom: 0;
    }
}

@media (max-width: 575px) {
    .col-multi-fields .multi-field .form-control-label {
        font-weight: bold;
    }
}

.col-multi-fields .multi-field .multi-field-content {
    display: inline-block;
}

@media (min-width: 576px) {
    .col-multi-fields .multi-field .multi-field-content {
        padding-top: 0 !important;
    }

    .col-multi-fields .multi-field .multi-field-content input, .col-multi-fields .multi-field .multi-field-content select {
        width: auto;
    }
}

@media (max-width: 575px) {
    .col-multi-fields .multi-field .form-control-label, .col-multi-fields .multi-field .multi-field-content {
        display: block;
    }
}

.hidden {
    display: none;
}

/* COLLAPSED FIELDSETS */
fieldset.collapsed {
    background-color: #f6f6f6;
    margin-top: -1rem;
    overflow: hidden;
}

fieldset.collapsed > * {
    display: none;
}

fieldset.collapsed h2 {
    display: block;
    font-size: 1.143rem;
    font-weight: normal;
    margin: 0;
    padding: .5rem 1rem;
}

fieldset.collapse {
    display: block;
}

/* IN-LINES */
.empty-form {
    display: none !important;
}

.inline-group .tabular table thead > tr th {
    padding: 0.7rem 0.8rem;
}

.inline-group .tabular table th, .inline-group .tabular table td {
    font-size: 1rem;
}

.inline-group .tabular table tbody td.original p {
    margin: 0;
}

.inline-group .tabular table tbody td.original p a {
    float: right;
    font-size: 0.857rem;
}

.inline-group .tabular table tbody td .errorlist {
    margin: 0;
    padding-left: 1.5rem;
    font-size: 0.857rem;
    color: #E04F3C;
}

.inline-group .tabular table tbody td .errorlist + input {
    border-color: #E04F3C;
}

.cap-inlines-hide-original:not(.cap-inlines-show-original) .inline-group .tabular table tbody > tr td.original, .cap-inlines-hide-original:not(.cap-inlines-show-original) .inline-group .tabular table tbody > tr th.original, .cap-inlines-hide-original:not(.cap-inlines-show-original) .inline-group .tabular table thead > tr td.original, .cap-inlines-hide-original:not(.cap-inlines-show-original) .inline-group .tabular table thead > tr th.original {
    font-size: 0;
    width: 0;
    padding: 0;
    border-color: transparent;
    box-shadow: none;
}

.cap-inlines-hide-original:not(.cap-inlines-show-original) .inline-group .tabular table tbody > tr td.original > *, .cap-inlines-hide-original:not(.cap-inlines-show-original) .inline-group .tabular table tbody > tr th.original > *, .cap-inlines-hide-original:not(.cap-inlines-show-original) .inline-group .tabular table thead > tr td.original > *, .cap-inlines-hide-original:not(.cap-inlines-show-original) .inline-group .tabular table thead > tr th.original > * {
    display: none;
}

.cap-inlines-hide-original:not(.cap-inlines-show-original) .inline-group .tabular table tbody > tr th.original:empty + th, .cap-inlines-hide-original:not(.cap-inlines-show-original) .inline-group .tabular table thead > tr th.original:empty + th {
    box-shadow: none;
}

.inline-group .tabular fieldset {
    box-shadow: none;
}

.inline-group .inline-related h3 {
    margin: 0;
    color: #fff;
    font-size: 1rem;
    padding: 0.7rem 0.8rem;
    font-weight: normal;
    background-color: #5d6478;
}

.inline-group .inline-related h3 b {
    display: inline-block;
    min-width: 17.5%;
}

.inline-group .inline-related h3 a {
    color: #fff;
    text-decoration: underline;
}

.inline-group .inline-related h3 a.inline-deletelink {
    float: right;
}

.inline-group .inline-related h3 label {
    margin: 0;
}

.inline-group .inline-related h3 span.delete, .inline-group .inline-related h3 span:not(.inline_label):not(:first-child) {
    float: right;
}

.inline-group .inline-related h3 .stacked-inline-sortable {
    float: right;
    margin-left: 1.5rem;
}

.inline-group .inline-related fieldset.cap-form {
    margin-bottom: 1rem;
}

.inline-group .inline-related + .empty-form + .add-row {
    margin-top: -1rem;
}

.inline-group div.add-row {
    border-top: 2px solid #f1f1f1;
    margin-bottom: 2rem;
    padding: 0.4rem 0.8rem;
    background-color: #f6f6f6;
}

.custom-select-sm {
    height: calc(2.5rem - 2px - 5px);
}

/* TabularInlines Sortables */
.inline-sortable {
    white-space: nowrap;
}

.inline-sortable a {
    color: #000;
    padding: .3rem .4rem 0 .2rem;
    display: inline-block;
    opacity: .4;
}

#result_list .inline-sortable a, .tabular table .inline-sortable a, table#change-history .inline-sortable a {
    padding-top: .05rem;
}

.inline-sortable a:last-child {
    padding: 0;
}

.inline-sortable a:hover {
    opacity: .7;
}

.cap-sortable {
    color: #373a3c;
}

.selected td .inline-sortable a {
    color: #fff;
}

tr:first-child td .inline-sortable .sortable-up {
    visibility: hidden;
    cursor: default;
}

.tabular tr.last-sortable td .inline-sortable .sortable-down, .tabular tr.form-row:nth-last-child(2) td .inline-sortable .sortable-down {
    visibility: hidden;
    cursor: default;
}

#result_list tr:last-child td .inline-sortable .sortable-down, .tabular table tr:last-child td .inline-sortable .sortable-down, table#change-history tr:last-child td .inline-sortable .sortable-down {
    visibility: hidden;
    cursor: default;
}

/* StackedInline sortables */
.stacked-inline-sortable {
    float: left;
}

.stacked-inline-sortable :first-child {
    padding-right: 1px;
}

.stacked-inline-sortable:nth-last-child(2) {
    margin-right: 10px;
}

.stacked-inline-sortable a {
    color: #eceeef;
}

.stacked-inline-sortable a:hover {
    color: #fff;
}

.inline-group > div:first-of-type .stacked-inline-sortable .sortable-up, .inline-group > div:nth-last-child(3) .stacked-inline-sortable .sortable-down {
    opacity: .15 !important;
    cursor: default;
}

fieldset input[type=text], fieldset input[type=url], fieldset input[type=email], fieldset input[type=number], fieldset input[type=password], fieldset input[type=date], fieldset input[type=tel], fieldset .vTextField, fieldset .vURLField, fieldset .vLargeTextField, fieldset .vTimeField, fieldset .vDateField {
    display: inline-block;
}

@media (max-width: 575px) {
    fieldset input[type=text], fieldset input[type=url], fieldset input[type=email], fieldset input[type=number], fieldset input[type=password], fieldset input[type=date], fieldset input[type=tel], fieldset .vTextField, fieldset .vURLField, fieldset .vLargeTextField, fieldset .vTimeField, fieldset .vDateField {
        max-width: none;
    }
}

fieldset select:not([multiple="multiple"]) {
    border-radius: 0.25rem;
}

fieldset input[type=number], fieldset input[type=date], fieldset input.vIntegerField, fieldset input.vIntegerField, fieldset input.vDateField, fieldset input.vTimeField, fieldset input.vForeignKeyRawIdAdminField {
    width: auto;
}

.timezonewarning {
    display: inline-block;
    margin-top: .5rem;
}

.related-lookup:before {
    display: inline-block;
    width: 20px;
    height: 20px;
    font-family: FontAwesome;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    text-rendering: auto;
    content: "";
    color: #373a3c;
    font-size: 1.143rem;
    margin-left: 5px;
}

.autosize {
    max-height: 12rem;
}

.ImageWidget .float-xs-left {
    margin-right: 1rem;
    max-width: 75px;
    height: auto;
}

.widget-AdminSplitDateTime, .widget-AdminDateWidget, .widget-AdminTimeWidget {
    font-size: 0;
    color: transparent;
}

.widget-AdminSplitDateTime p, .widget-AdminDateWidget p, .widget-AdminTimeWidget p {
    margin: 0;
}

.widget-AdminSplitDateTime .datetimeshortcuts, .widget-AdminDateWidget .datetimeshortcuts, .widget-AdminTimeWidget .datetimeshortcuts {
    position: relative;
    margin: 0 1.5rem 0 0;
    white-space: nowrap;
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
}

.widget-AdminSplitDateTime .datetimeshortcuts a, .widget-AdminDateWidget .datetimeshortcuts a, .widget-AdminTimeWidget .datetimeshortcuts a {
    white-space: nowrap;
    font-size: 0.929rem;
}

.widget-AdminSplitDateTime .datetimeshortcuts a:first-child, .widget-AdminDateWidget .datetimeshortcuts a:first-child, .widget-AdminTimeWidget .datetimeshortcuts a:first-child {
    margin-left: 3.15rem;
    margin-top: .45rem;
}

.widget-AdminSplitDateTime .datetimeshortcuts a:not(:first-child), .widget-AdminDateWidget .datetimeshortcuts a:not(:first-child), .widget-AdminTimeWidget .datetimeshortcuts a:not(:first-child) {
    vertical-align: top;
}

.widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'], .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'], .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'], .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'], .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'] {
    padding: 0.5rem 0.75rem;
    position: absolute;
    left: -1px;
    z-index: 0;
    text-align: center;
    white-space: nowrap;
}

.widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink']:hover, .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink']:focus, .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink']:hover, .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink']:focus, .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink']:hover, .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink']:focus, .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink']:hover, .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink']:focus, .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink']:hover, .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink']:focus, .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink']:hover, .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink']:focus {
    text-decoration: none;
    color: #0d64a2;
}

.widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'] .date-icon, .widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'] .clock-icon, .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'] .date-icon, .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'] .clock-icon, .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'] .date-icon, .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'] .clock-icon, .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'] .date-icon, .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'] .clock-icon, .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'] .date-icon, .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'] .clock-icon, .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'] .date-icon, .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'] .clock-icon {
    font-family: FontAwesome;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    text-rendering: auto;
}

.widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'] .date-icon:before, .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'] .date-icon:before, .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'] .date-icon:before, .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'] .date-icon:before, .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'] .date-icon:before, .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'] .date-icon:before {
    content: "";
}

.widget-AdminSplitDateTime .datetimeshortcuts a[id^='calendarlink'] .clock-icon:before, .widget-AdminSplitDateTime .datetimeshortcuts a[id^='clocklink'] .clock-icon:before, .widget-AdminDateWidget .datetimeshortcuts a[id^='calendarlink'] .clock-icon:before, .widget-AdminDateWidget .datetimeshortcuts a[id^='clocklink'] .clock-icon:before, .widget-AdminTimeWidget .datetimeshortcuts a[id^='calendarlink'] .clock-icon:before, .widget-AdminTimeWidget .datetimeshortcuts a[id^='clocklink'] .clock-icon:before {
    content: "";
}

.widget-AdminSplitDateTime input, .widget-AdminDateWidget input, .widget-AdminTimeWidget input {
    white-space: nowrap;
    vertical-align: top;
}

.widget-AdminSplitDateTime input.vDateField, .widget-AdminSplitDateTime input.vTimeField, .widget-AdminDateWidget input.vDateField, .widget-AdminDateWidget input.vTimeField, .widget-AdminTimeWidget input.vDateField, .widget-AdminTimeWidget input.vTimeField {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
    position: relative;
    z-index: 2;
    text-indent: 0;
}

@media (min-width: 768px) {
    .widget-AdminSplitDateTime br, .widget-AdminDateWidget br, .widget-AdminTimeWidget br {
        display: none;
    }
}

.widget-AdminSplitDateTime .timezonewarning, .widget-AdminDateWidget .timezonewarning, .widget-AdminTimeWidget .timezonewarning {
    display: block;
    font-size: 11px;
}

@media (max-width: 991px) {
    .widget-AdminSplitDateTime input.vDateField {
        margin-bottom: .2rem;
    }
}

.calendarbox, .clockbox {
    margin: 0 0 0 2rem;
    background-color: #f1f1f1;
    border-radius: 0.25rem;
    box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.15);
}

.calendarbox .calendar-cancel, .clockbox .calendar-cancel {
    margin: 0;
}

.calendarbox .calendar-cancel a, .clockbox .calendar-cancel a {
    padding: .3rem 0;
    display: block;
    color: #fff;
    border-bottom-left-radius: 0.25rem;
    border-bottom-right-radius: 0.25rem;
    text-align: center;
    background-color: #828a9f;
}

.calendarbox .calendar-cancel a:hover, .clockbox .calendar-cancel a:hover {
    text-decoration: none;
    background-color: #5d6478;
}

.widget-CheckboxInput input[type="checkbox"], [class*='CheckboxInput'] input[type="checkbox"], .tabular .form-row input[type="checkbox"] {
    margin-top: .65rem;
}

.widget-CheckboxInput > .text-help, [class*='CheckboxInput'] > .text-help, .tabular .form-row > .text-help {
    margin-top: .25rem;
}

.calendarbox {
    z-index: 3;
}

.calendarbox > div:first-child {
    border-top-left-radius: 0.25rem;
    border-top-right-radius: 0.25rem;
    background-color: #687086;
    overflow: auto;
}

.calendarbox > div:first-child a {
    display: block;
    text-align: center;
    padding: .3rem .2rem .3rem 1rem;
    position: relative;
    z-index: 2;
    color: transparent;
    font-family: FontAwesome;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    text-rendering: auto;
}

.calendarbox > div:first-child a:hover {
    background-color: #464c5b;
}

.calendarbox > div:first-child a:hover, .calendarbox > div:first-child a:focus {
    text-decoration: none;
}

.calendarbox > div:first-child a.calendarnav-previous {
    float: left;
    text-align: center;
}

.calendarbox > div:first-child a.calendarnav-previous:before {
    content: "\f053";
    color: #fff;
}

.calendarbox > div:first-child a.calendarnav-next {
    float: right;
}

.calendarbox > div:first-child a.calendarnav-next:before {
    content: "\f054";
    color: #fff;
}

.calendarbox table {
    width: 100%;
}

.calendarbox table caption {
    left: 0;
    right: 0;
    top: .3rem;
    text-align: center;
    position: absolute;
    color: #fff;
}

.calendarbox table tbody td {
    padding: 0;
    text-align: center;
    font-size: 0.929rem;
}

.calendarbox table tbody td.nonday {
    background-color: transparent;
}

.calendarbox table tbody td a {
    display: block;
    padding: .35rem .5rem;
    background-color: #fff;
    box-shadow: inset -1px -1px 0 0 #f1f1f1;
}

.calendarbox table tbody td.today a {
    background-color: #d5f3dc;
    box-shadow: inset -1px -1px 0 0 #d5f3dc;
}

.calendarbox table tbody td a:hover, .calendarbox table tbody td .today a:hover {
    background-color: #828a9f;
    box-shadow: inset -1px -1px 0 0 #828a9f;
    color: #fff;
    text-decoration: none;
}

.calendarbox table tbody td.selected a {
    background-color: #5d6478;
    color: #fff;
    box-shadow: inset 1px 1px 2px 0 rgba(0, 0, 0, 0.2);
}

.calendarbox table tbody td.selected.today a {
    color: #d5f3dc;
}

.calendarbox table tbody th {
    padding: .4rem 0 .3rem;
    font-size: 0.929rem;
    text-align: center;
}

.calendarbox .calendar-shortcuts {
    padding: .75rem 0;
    text-align: center;
    color: #c5c9cc;
    font-size: 0.929rem;
}

.calendarbox .calendar-shortcuts a {
    color: #0d64a2;
    padding: 0 .2rem;
}

.clockbox h2 {
    padding: .75rem 1.5rem;
    font-weight: normal;
    font-size: 1rem;
    border-top-left-radius: 0.25rem;
    border-top-right-radius: 0.25rem;
    background-color: #687086;
    color: #fff;
    margin: 0;
}

.clockbox .timelist {
    list-style: none;
    margin: 0;
    padding: 0;
}

.clockbox .timelist li a {
    display: block;
    background-color: #fff;
    text-align: center;
    padding: .3rem 0;
    font-size: 0.929rem;
}

.clockbox .timelist li a:hover {
    background-color: transparent;
    text-decoration: none;
}

.clockbox .timelist li:not(:last-child) a {
    margin-bottom: 1px;
}

/* Two column selector */
.selector {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -ms-flex-direction: row;
    flex-direction: row;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
    -ms-flex-line-pack: center;
    align-content: center;
    -webkit-box-align: start;
    -ms-flex-align: start;
    align-items: flex-start;
}

.selector .selector-chooser {
    list-style: none;
    margin: 0;
    padding: 0;
    min-height: 200px;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
    -ms-flex-line-pack: center;
    align-content: center;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    padding: 0 1rem;
}

.selector .selector-chooser > * {
    height: 20px;
}

.selector .selector-available, .selector .selector-chosen {
    -webkit-box-flex: 1;
    -ms-flex: 1 1 200px;
    flex: 1 1 200px;
}

.selector .selector-available h2, .selector .selector-chosen h2 {
    font-size: 16px;
    margin-top: .1rem;
}

.selector .selector-available p, .selector .selector-chosen p {
    margin: 0;
}

.selector .selector-available label, .selector .selector-chosen label {
    display: none;
}

.selector .selector-available select, .selector .selector-chosen select {
    padding: .25rem 0;
    display: block;
}

.selector .selector-available input {
    display: block;
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
}

.selector .selector-available select {
    border-top-left-radius: 0;
    border-top-right-radius: 0;
    margin-top: -1px;
    min-height: 142px;
}

.selector .selector-chosen select {
    min-height: 162px;
}

.radiolist {
    list-style: none;
    margin: 0;
    padding: 0;
    margin-top: 0.375rem;
}

.radiolist input {
    margin-right: .35rem;
}

.radiolist.inline li {
    display: inline-block;
}

.radiolist.inline li:not(:last-child) {
    margin-right: .5rem;
}

.cap-char-count {
    position: absolute;
    height: 1rem;
    right: 1.25rem;
    margin-top: -1.15rem;
    font-size: 11px;
    color: #9ca3a9;
}

.cap-char-count a {
    color: #9ca3a9;
}

.cap-char-count a:hover, .cap-char-count a:focus {
    color: #55acee;
    text-decoration: none;
}

.cap-char-count a .fa {
    font-size: 12px;
    display: inline-block;
    padding-left: 2px;
}

.related-widget-wrapper ul, .widget-AdminRadioSelect ul {
    list-style: none;
    padding: 0;
    margin: 0;
}

.related-widget-wrapper ul > li label input[type='checkbox'], .related-widget-wrapper ul > li label input[type='radio'], .widget-AdminRadioSelect ul > li label input[type='checkbox'], .widget-AdminRadioSelect ul > li label input[type='radio'] {
    margin-right: 3px;
}

.related-widget-wrapper-link:not([href]) {
    display: none;
}

.related-widget-wrapper-link:hover, .related-widget-wrapper-link:focus {
    text-decoration: none;
}

.messagelist {
    list-style: none;
    margin: 0;
    padding: 0;
    display: block;
    margin: 1rem 1.875rem 0;
}

.messagelist li:last-child {
    margin-bottom: 0;
}

body.delete-confirmation .content-wrap {
    display: block;
    margin: 1.5rem 2.625rem;
}

body.delete-confirmation .content-wrap h1, body.delete-confirmation .content-wrap h2, body.delete-confirmation .content-wrap ul {
    display: block;
    float: none;
}

body.delete-confirmation .content-wrap h1 {
    font-size: 1.571rem;
}

body.delete-confirmation .content-wrap h2 {
    margin-top: 1.2rem;
    font-size: 1.143rem;
}

body.delete-confirmation .content-wrap form {
    margin-top: 2rem;
}

body.delete-confirmation .content-wrap input[type='button'], body.delete-confirmation .content-wrap input[type='submit'], body.delete-confirmation .content-wrap button {
    margin-right: 1.5rem;
}

.submit-row .deletelink-box {
    float: right;
    margin: 0;
    padding-left: 20px;
}

.submit-row input[type='submit'], .submit-row input[type='button'], .submit-row button, .submit-row .btn, .submit-row body.delete-confirmation .content-wrap input[type='button'], body.delete-confirmation .content-wrap .submit-row input[type='button'], .submit-row body.delete-confirmation .content-wrap input[type='submit'], body.delete-confirmation .content-wrap .submit-row input[type='submit'], .submit-row body.delete-confirmation .content-wrap button, body.delete-confirmation .content-wrap .submit-row button, .submit-row .deletelink-box .deletelink, .submit-row input[type='submit']:not([class*="btn-"]), .submit-row input[type='button']:not([class*="btn-"]), .submit-row button:not([class*="btn-"]), .submit-row #content-main > .object-tools > li > a:not([class*="btn-"]), body.login .submit-row input[type='submit'], .submit-row #changelist #toolbar #changelist-search input[type='submit'], #changelist #toolbar #changelist-search .submit-row input[type='submit'], .submit-row #changelist #changelist-form .actions button, #changelist #changelist-form .actions .submit-row button, .submit-row #changelist #changelist-form .paginator input[type='submit'], #changelist #changelist-form .paginator .submit-row input[type='submit'] {
    margin-bottom: .5rem;
}

.submit-row.fixed {
    position: fixed;
    left: 0;
    right: 0;
    bottom: 0;
    background-color: #fff;
    padding: 1.2rem 1.875rem 1rem;
    z-index: 5000;
    box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.15);
}

@media (min-width: 992px) {
    body.cap_form_submit_on_right .col-right .submit-row {
        position: relative;
        padding: 0.9375rem;
        background-color: #f6f6f6;
        display: -webkit-box;
        display: -ms-flexbox;
        display: flex;
        -ms-flex-wrap: wrap;
        flex-wrap: wrap;
        box-shadow: 0 1px 0 0 #e4e4e4;
    }

    body.cap_form_submit_on_right .col-right .submit-row a.btn:not(.deletelink), body.cap_form_submit_on_right .col-right .submit-row .deletelink-box a.deletelink:not(.deletelink), body.cap_form_submit_on_right .col-right .submit-row #content-main > .object-tools > li > a:not(.deletelink):not([class*="btn-"]), body.cap_form_submit_on_right .col-right .submit-row button, body.cap_form_submit_on_right .col-right .submit-row input[type='submit'], body.cap_form_submit_on_right .col-right .submit-row input[type='button'] {
        padding-left: 0;
        padding-right: 0;
    }

    body.cap_form_submit_on_right .col-right .submit-row > * {
        width: 100%;
    }

    body.cap_form_submit_on_right .col-right .submit-row .deletelink-box {
        text-align: right;
        margin-top: 0.9375rem;
        -webkit-box-ordinal-group: 11;
        -ms-flex-order: 10;
        order: 10;
    }
}

body.cap_form_submit_on_right .col-right .object-tools {
    list-style: none;
    margin: 0;
    padding: 0;
    margin-top: 1.875rem;
}

@media (max-width: 991px) {
    body.cap_form_submit_on_right .col-right .object-tools {
        display: none;
    }

    body.cap_form_submit_on_right .col-right .object-tools li {
        display: inline-block;
        margin-right: 10px;
    }

    body.cap_form_submit_on_right .col-right .object-tools li.heading {
        display: block;
        font-weight: bold;
    }
}

@media (min-width: 992px) {
    body.cap_form_submit_on_right .col-right .object-tools li.list-item, body.cap_form_submit_on_right .col-right .object-tools li:not(.list-item) > a {
        display: block;
        margin-top: 1px;
        background-color: #f6f6f6;
        padding: 0.625rem 0.9375rem;
        box-shadow: 0 1px 0 0 #e4e4e4;
    }

    body.cap_form_submit_on_right .col-right .object-tools li:not(.list-item) a:hover {
        text-decoration: none;
        background-color: #fff;
    }

    body.cap_form_submit_on_right .col-right .object-tools li:not(.list-item) a .fa {
        margin-right: .2rem;
    }

    body.cap_form_submit_on_right .col-right .object-tools li.heading {
        font-weight: 500;
        font-size: 1.143rem;
        padding: 0 0.625rem 0.46875rem;
    }

    body.cap_form_submit_on_right .col-right .object-tools li.heading.heading-inverse {
        background-color: #5d6478;
        color: #fff;
        font-weight: normal;
        font-size: 1rem;
        padding: 0.46875rem 0.625rem;
    }
}

.breadcrumbs {
    font-size: 0.929rem;
    color: #687086;
    position: relative;
}

.breadcrumbs li {
    float: left;
}

.breadcrumbs a {
    color: #0d64a2;
    display: inline-block;
    margin: 0 .2rem;
}

.breadcrumbs a:first-child {
    margin-left: 0;
}

body.cap_layout_vertical { /*&.change-form { #container { > .breadcrumbs { display: none; } } #content { .breadcrumbs { } } }*/
}

body.cap_layout_vertical #container > .breadcrumbs {
    display: block;
    position: absolute;
    padding: 1.5rem 1.875rem;
    left: 230px;
}

body.cap_layout_vertical #container #content .breadcrumbs {
    display: none;
}

body.cap_layout_vertical #container #content .messagelist {
    margin: 0 0 0.9375rem 0;
}

body.cap_layout_vertical #container > .messagelist {
    display: none;
}

body.cap_layout_horizontal .breadcrumbs {
    padding: 1.5rem 2.625rem 0;
}

body.cap_layout_horizontal.change-list .breadcrumbs {
    display: none;
}

body.cap_layout_horizontal.change-form #content .breadcrumbs {
    display: none;
    padding: 1.5rem 0;
    position: relative;
    z-index: 6;
}

body.cap_layout_horizontal.change-form #content .breadcrumbs li {
    float: left;
}

body.cap_layout_horizontal #content .content-wrap .messagelist {
    display: none;
}

#result_list, .tabular table, table#change-history {
    width: 100%;
    border: 0;
    background-color: #fff;
    border-collapse: collapse;
}

#result_list thead > tr th, .tabular table thead > tr th, table#change-history thead > tr th {
    box-shadow: inset 1px 0 0 rgba(255, 255, 255, 0.2);
    font-weight: normal;
    background-color: #5d6478;
    color: #eceeef;
    padding: 0;
    position: relative;
    line-height: normal;
}

#result_list thead > tr th.action-checkbox-column, .tabular table thead > tr th.action-checkbox-column, table#change-history thead > tr th.action-checkbox-column {
    width: 2rem;
}

#result_list thead > tr th.sorted, .tabular table thead > tr th.sorted, table#change-history thead > tr th.sorted {
    background-color: #464c5b;
}

#result_list thead > tr th.sorted:after, .tabular table thead > tr th.sorted:after, table#change-history thead > tr th.sorted:after {
    content: '';
    position: absolute;
    left: 0;
    right: 0;
    bottom: 0;
    height: 3px;
    background-color: #279bee;
}

#result_list thead > tr th .sortoptions, .tabular table thead > tr th .sortoptions, table#change-history thead > tr th .sortoptions {
    float: right;
    font-size: 0.857rem;
    margin: .1rem .3rem 0 0;
}

#result_list thead > tr th .sortoptions .sortpriority, .tabular table thead > tr th .sortoptions .sortpriority, table#change-history thead > tr th .sortoptions .sortpriority, #result_list thead > tr th .sortoptions .sortremove, .tabular table thead > tr th .sortoptions .sortremove, table#change-history thead > tr th .sortoptions .sortremove, #result_list thead > tr th .sortoptions .toggle, .tabular table thead > tr th .sortoptions .toggle, table#change-history thead > tr th .sortoptions .toggle {
    display: block;
    float: right;
    padding: .2rem;
}

#result_list thead > tr th .sortoptions .sortremove:hover, .tabular table thead > tr th .sortoptions .sortremove:hover, table#change-history thead > tr th .sortoptions .sortremove:hover, #result_list thead > tr th .sortoptions .toggle:hover, .tabular table thead > tr th .sortoptions .toggle:hover, table#change-history thead > tr th .sortoptions .toggle:hover {
    text-decoration: none;
}

#result_list thead > tr th .sortoptions .sortremove:hover:before, .tabular table thead > tr th .sortoptions .sortremove:hover:before, table#change-history thead > tr th .sortoptions .sortremove:hover:before, #result_list thead > tr th .sortoptions .toggle:hover:before, .tabular table thead > tr th .sortoptions .toggle:hover:before, table#change-history thead > tr th .sortoptions .toggle:hover:before {
    color: #279bee;
}

#result_list thead > tr th .sortoptions .sortremove:before, .tabular table thead > tr th .sortoptions .sortremove:before, table#change-history thead > tr th .sortoptions .sortremove:before, #result_list thead > tr th .sortoptions .toggle:before, .tabular table thead > tr th .sortoptions .toggle:before, table#change-history thead > tr th .sortoptions .toggle:before {
    font-family: FontAwesome;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    text-rendering: auto;
}

#result_list thead > tr th .sortoptions .sortremove:before, .tabular table thead > tr th .sortoptions .sortremove:before, table#change-history thead > tr th .sortoptions .sortremove:before {
    content: "";
}

#result_list thead > tr th .sortoptions .toggle.ascending:before, .tabular table thead > tr th .sortoptions .toggle.ascending:before, table#change-history thead > tr th .sortoptions .toggle.ascending:before {
    content: "";
}

#result_list thead > tr th .sortoptions .toggle.descending:before, .tabular table thead > tr th .sortoptions .toggle.descending:before, table#change-history thead > tr th .sortoptions .toggle.descending:before {
    content: "";
}

#result_list thead > tr th div.text span, .tabular table thead > tr th div.text span, table#change-history thead > tr th div.text span, #result_list thead > tr th div.text a, .tabular table thead > tr th div.text a, table#change-history thead > tr th div.text a {
    display: block;
    padding: 0.7rem 0.8rem;
}

#result_list thead > tr th a, .tabular table thead > tr th a, table#change-history thead > tr th a {
    color: #eceeef;
    display: block;
}

#result_list tbody > tr > td, .tabular table tbody > tr > td, table#change-history tbody > tr > td, #result_list tbody > tr > th, .tabular table tbody > tr > th, table#change-history tbody > tr > th {
    padding: 0.4rem 0.8rem;
    font-size: 0.857rem;
    border: 1px solid #f2f2f2;
    border-left: 0;
    border-right: 0;
}

#result_list tbody > tr:nth-child(even), .tabular table tbody > tr:nth-child(even), table#change-history tbody > tr:nth-child(even) {
    background-color: #f7f7f7;
}

#result_list tbody > tr:nth-child(even):hover, .tabular table tbody > tr:nth-child(even):hover, table#change-history tbody > tr:nth-child(even):hover {
    background-color: #e8e8e8;
}

#result_list tbody > tr:hover, .tabular table tbody > tr:hover, table#change-history tbody > tr:hover {
    background-color: #e6e6e6;
}

#result_list tbody > tr:hover > th, .tabular table tbody > tr:hover > th, table#change-history tbody > tr:hover > th, #result_list tbody > tr:hover > td, .tabular table tbody > tr:hover > td, table#change-history tbody > tr:hover > td {
    border-color: transparent;
}

#result_list tbody > tr:first-child > th, .tabular table tbody > tr:first-child > th, table#change-history tbody > tr:first-child > th, #result_list tbody > tr:first-child > td, .tabular table tbody > tr:first-child > td, table#change-history tbody > tr:first-child > td {
    border-top: 0 !important;
}

#result_list tbody > tr.selected, .tabular table tbody > tr.selected, table#change-history tbody > tr.selected {
    background-color: #828a9f !important;
}

#result_list tbody > tr.selected:hover, .tabular table tbody > tr.selected:hover, table#change-history tbody > tr.selected:hover {
    background-color: #51586a;
}

#result_list tbody > tr.selected:nth-child(even), .tabular table tbody > tr.selected:nth-child(even), table#change-history tbody > tr.selected:nth-child(even) {
    background-color: #687086 !important;
}

#result_list tbody > tr.selected:nth-child(even):hover, .tabular table tbody > tr.selected:nth-child(even):hover, table#change-history tbody > tr.selected:nth-child(even):hover {
    background-color: #51586a;
}

#result_list tbody > tr.selected > th, .tabular table tbody > tr.selected > th, table#change-history tbody > tr.selected > th, #result_list tbody > tr.selected > td, .tabular table tbody > tr.selected > td, table#change-history tbody > tr.selected > td {
    border-color: transparent;
}

#result_list tbody > tr.selected > th, .tabular table tbody > tr.selected > th, table#change-history tbody > tr.selected > th, #result_list tbody > tr.selected > th a, .tabular table tbody > tr.selected > th a, table#change-history tbody > tr.selected > th a, #result_list tbody > tr.selected > td, .tabular table tbody > tr.selected > td, table#change-history tbody > tr.selected > td, #result_list tbody > tr.selected > td a, .tabular table tbody > tr.selected > td a, table#change-history tbody > tr.selected > td a {
    color: #fff;
}

#result_list tbody > tr.table-danger.selected > td, .tabular table tbody > tr.table-danger.selected > td, table#change-history tbody > tr.table-danger.selected > td, #result_list tbody > tr.table-danger.selected > th, .tabular table tbody > tr.table-danger.selected > th, table#change-history tbody > tr.table-danger.selected > th, #result_list tbody > tr.table-warning.selected > td, .tabular table tbody > tr.table-warning.selected > td, table#change-history tbody > tr.table-warning.selected > td, #result_list tbody > tr.table-warning.selected > th, .tabular table tbody > tr.table-warning.selected > th, table#change-history tbody > tr.table-warning.selected > th, #result_list tbody > tr.table-info.selected > td, .tabular table tbody > tr.table-info.selected > td, table#change-history tbody > tr.table-info.selected > td, #result_list tbody > tr.table-info.selected > th, .tabular table tbody > tr.table-info.selected > th, table#change-history tbody > tr.table-info.selected > th, #result_list tbody > tr.table-success.selected > td, .tabular table tbody > tr.table-success.selected > td, table#change-history tbody > tr.table-success.selected > td, #result_list tbody > tr.table-success.selected > th, .tabular table tbody > tr.table-success.selected > th, table#change-history tbody > tr.table-success.selected > th {
    background-color: transparent;
}

#result_list tbody > tr.table-danger > td, .tabular table tbody > tr.table-danger > td, table#change-history tbody > tr.table-danger > td, #result_list tbody > tr.table-danger > th, .tabular table tbody > tr.table-danger > th, table#change-history tbody > tr.table-danger > th {
    border-bottom: 1px solid #ebcccc;
}

#result_list tbody > tr.table-warning > td, .tabular table tbody > tr.table-warning > td, table#change-history tbody > tr.table-warning > td, #result_list tbody > tr.table-warning > th, .tabular table tbody > tr.table-warning > th, table#change-history tbody > tr.table-warning > th {
    border-bottom: 1px solid #faf2cc;
}

#result_list tbody > tr.table-info > td, .tabular table tbody > tr.table-info > td, table#change-history tbody > tr.table-info > td, #result_list tbody > tr.table-info > th, .tabular table tbody > tr.table-info > th, table#change-history tbody > tr.table-info > th {
    border-bottom: 1px solid #bcdff1;
}

#result_list tbody > tr.table-success > td, .tabular table tbody > tr.table-success > td, table#change-history tbody > tr.table-success > td, #result_list tbody > tr.table-success > th, .tabular table tbody > tr.table-success > th, table#change-history tbody > tr.table-success > th {
    border-bottom: 1px solid #d0e9c6;
}

#result_list tbody > tr th.table-danger, .tabular table tbody > tr th.table-danger, table#change-history tbody > tr th.table-danger, #result_list tbody > tr td.table-danger, .tabular table tbody > tr td.table-danger, table#change-history tbody > tr td.table-danger {
    background-color: #f2dede;
    border-bottom: 1px solid #ebcccc;
}

#result_list tbody > tr th.table-warning, .tabular table tbody > tr th.table-warning, table#change-history tbody > tr th.table-warning, #result_list tbody > tr td.table-warning, .tabular table tbody > tr td.table-warning, table#change-history tbody > tr td.table-warning {
    background-color: #fcf8e3;
    border-bottom: 1px solid #faf2cc;
}

#result_list tbody > tr th.table-info, .tabular table tbody > tr th.table-info, table#change-history tbody > tr th.table-info, #result_list tbody > tr td.table-info, .tabular table tbody > tr td.table-info, table#change-history tbody > tr td.table-info {
    background-color: #d9edf7;
    border-bottom: 1px solid #bcdff1;
}

#result_list tbody > tr th.table-success, .tabular table tbody > tr th.table-success, table#change-history tbody > tr th.table-success, #result_list tbody > tr td.table-success, .tabular table tbody > tr td.table-success, table#change-history tbody > tr td.table-success {
    background-color: #dff0d8;
    border-bottom: 1px solid #d0e9c6;
}

.nav-tabs-cap {
    margin-bottom: 1rem;
}

.nav-tabs-cap .nav-item:first-child {
    margin-left: .75rem;
}

.nav-tabs-cap .nav-item + .nav-item {
    margin-left: .3rem;
}

.nav-tabs-cap .nav-link {
    border-radius: 2px;
    padding: 0.65em 1.5em;
    background-color: #fff;
    border-color: #ddd;
}

.nav-tabs-cap .nav-link:focus, .nav-tabs-cap .nav-link:hover {
    border-color: #91b6d0 #91b6d0 #ddd;
}

.nav-tabs-cap .nav-link.active, .nav-tabs-cap .nav-link.active:focus {
    color: #222;
}

.nav-tabs-cap .nav-link.has-error, .nav-tabs-cap .nav-link.has-error.active, .nav-tabs-cap .nav-link.has-error:focus {
    color: #a94442;
}

.table, .tabular table, table#change-history {
    background-color: #fff;
}

.table-inverse {
    color: #eceeef;
    background-color: #fff;
}

.table-inverse th, .table-inverse td, .table-inverse thead th {
    border-color: #f2f2f2;
    font-weight: normal;
}

.table-inverse thead th {
    background-color: #5d6478;
}

.table-inverse:not(.table-bordered) thead th:not(:first-child) {
    box-shadow: inset 1px 0 0 rgba(255, 255, 255, 0.2);
}

.table-inverse tbody th, .table-inverse tbody td {
    color: #373a3c;
}

.thead-inverse th {
    background-color: #5d6478;
    color: #eceeef;
    font-weight: normal;
}

.card {
    box-shadow: 0 1px 0 0 #e4e4e4;
    border: none;
}

.card .card-header {
    color: #fff;
}

body {
    margin: 0;
    padding: 0;
}

body.cap_layout_vertical:not(.login) {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    min-height: 100vh;
}

body.cap_layout_vertical:not(.login) #container {
    -webkit-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    position: relative;
    -ms-flex-line-pack: start;
    align-content: flex-start;
}

body.cap_layout_vertical:not(.login) #container #header {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column;
    width: 230px;
    -ms-flex-negative: 0;
    flex-shrink: 0;
}

body.cap_layout_vertical:not(.login) #container #content {
    -webkit-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
    -webkit-box-align: start;
    -ms-flex-align: start;
    align-items: flex-start;
    -ms-flex-line-pack: start;
    align-content: flex-start;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    padding-bottom: 96px;
    padding-top: 4rem;
}

body.cap_layout_vertical:not(.login) #container #footer {
    left: 230px;
    bottom: 0;
    right: 0;
    position: absolute;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -ms-flex-preferred-size: 100%;
    flex-basis: 100%;
}

body.cap_layout_vertical:not(.login).dashboard:not([class*="app-"]) #container #content {
    padding-top: 1.875rem;
}

body.cap_layout_horizontal #header {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -ms-flex-direction: row;
    flex-direction: row;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-box-pack: start;
    -ms-flex-pack: start;
    justify-content: flex-start;
    -ms-flex-line-pack: center;
    align-content: center;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    background-color: #252830;
    padding-top: 1.04167rem;
}

body.cap_layout_horizontal #header a {
    color: #fff;
}

body.cap_layout_horizontal #header #branding, body.cap_layout_horizontal #header #user-tools {
    -ms-flex-preferred-size: 288px;
    flex-basis: 288px;
}

body.cap_layout_horizontal #header .header-label {
    font-size: 0.857rem;
    color: #687086;
    text-transform: uppercase;
    font-weight: normal;
}

body.cap_layout_horizontal #header #branding {
    min-width: 200px;
    padding-left: 1.875rem;
}

body.cap_layout_horizontal #header #branding #site-name {
    font-size: 1.714rem;
}

body.cap_layout_horizontal #header #branding #site-name a {
    display: inline-block;
}

body.cap_layout_horizontal #header #branding #site-name a:hover {
    text-decoration: none;
    color: rgba(255, 255, 255, 0.8);
}

body.cap_layout_horizontal #header #branding #site-name a .header-label {
    display: block;
    margin-top: 2px;
    text-align: right;
}

@media (max-width: 767px) {
    body.cap_layout_horizontal #header #branding #site-name a .header-label {
        text-align: left;
    }
}

body.cap_layout_horizontal #header #user-tools {
    -webkit-box-flex: 2;
    -ms-flex-positive: 2;
    flex-grow: 2;
    padding: 0 1.875rem;
    text-align: right;
    color: #687086;
}

body.cap_layout_horizontal #header #user-tools strong {
    color: #fff;
}

body.cap_layout_horizontal #header #user-tools a {
    display: inline-block;
    margin: 0 2px;
    color: #5bb0ed;
}

body.cap_layout_horizontal #header #user-tools a:nth-child(2):not(:last-child) {
    margin-left: 20px;
}

body.cap_layout_horizontal #header #user-tools a:hover {
    color: #fff;
    text-decoration: none;
}

body.cap_layout_horizontal #header .cap-user-tools .welcome {
    display: inline-block;
}

body.cap_layout_horizontal #header .cap-user-tools .user-links {
    display: inline-block;
}

body.cap_layout_horizontal #header #site-name {
    margin: 0;
    font-weight: normal;
}

body.cap_layout_horizontal #header #site-name a {
    color: #fff;
}

body.cap_layout_vertical #header {
    background-color: #252830;
}

body.cap_layout_vertical #header #branding {
    padding: 5px;
    background-color: #fff;
}

body.cap_layout_vertical #header #branding #site-name {
    margin: 0;
    font-weight: normal;
    font-size: 1.429rem;
    line-height: 1.33333;
    text-align: center;
}

body.cap_layout_vertical #header #branding #site-name a {
    display: inline-block;
}

body.cap_layout_vertical #header #branding #site-name a:hover {
    text-decoration: none;
    color: rgba(255, 255, 255, 0.8);
}

body.cap_layout_vertical #header #branding #site-name a .header-label {
    display: none;
    margin-top: 2px;
    text-align: left;
}

body.cap_layout_vertical #header #site-name a {
    color: #fff;
}

body.cap_layout_vertical #header a {
    color: #fff;
}

body.cap_layout_vertical #header .header-label {
    font-size: 0.857rem;
    color: #687086;
    text-transform: uppercase;
    font-weight: normal;
}

body.cap_layout_vertical #header #user-tools:not(.cap-user-tools) {
    padding: 0.86806rem 0.625rem;
    font-size: 0.857rem;
    color: #687086;
    background-color: #282c37;
}

body.cap_layout_vertical #header #user-tools:not(.cap-user-tools) strong {
    color: #fff;
}

body.cap_layout_vertical #header #user-tools:not(.cap-user-tools) a {
    display: inline-block;
    margin: 0 2px;
    color: #5bb0ed;
}

body.cap_layout_vertical #header #user-tools:not(.cap-user-tools) a:nth-child(2):not(:last-child) {
    margin-left: 5px;
}

body.cap_layout_vertical #header .cap-user-tools {
    background-color: #383d4b;
    padding: 1.14583rem 0.9375rem;
    text-align: center;
    font-size: 13px;
}

body.cap_layout_vertical #header .cap-user-tools .separator {
    display: none;
}

body.cap_layout_vertical #header .cap-user-tools .welcome {
    display: block;
    font-size: 12px;
    color: #687086;
    margin-bottom: .25rem;
}

body.cap_layout_vertical #header .cap-user-tools .welcome strong {
    color: #fff;
    font-weight: normal;
}

body.cap_layout_vertical #header .cap-user-tools .welcome .fa, body.cap_layout_vertical #header .cap-user-tools .welcome .icon-link:before {
    margin-right: 2px;
    font-size: 13px;
}

body.cap_layout_vertical #header .cap-user-tools .user-links {
    display: inline-block;
    margin-right: .75rem;
    margin-bottom: .25rem;
}

body.cap_layout_vertical #header .cap-user-tools .icon-link {
    font: 0/0 a;
    color: transparent;
    text-shadow: none;
    background-color: transparent;
    border: 0;
    display: inline-block;
    padding: .4rem 0;
    width: 26px;
    text-align: center;
    border-radius: 0.2rem;
    position: relative;
    -webkit-transition: background-color .2s, color .2s;
    transition: background-color .2s, color .2s;
    color: #fff;
}

body.cap_layout_vertical #header .cap-user-tools .icon-link:hover {
    background-color: #282c37;
    color: #279bee;
}

body.cap_layout_vertical #header .cap-user-tools .icon-link:hover:after {
    opacity: 1;
}

body.cap_layout_vertical #header .cap-user-tools .icon-link:before {
    font-family: FontAwesome;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    text-rendering: auto;
    font-size: 1.143rem;
    line-height: normal;
    display: inline-block;
}

body.cap_layout_vertical #header .cap-user-tools .icon-link:after {
    font-family: "Roboto", "Helvetica Neue", Helvetica, Arial, sans-serif;
    display: block;
    position: absolute;
    content: attr(data-title);
    left: 0;
    top: 40px;
    font-size: 10px;
    white-space: nowrap;
    opacity: 0;
    -webkit-transition: opacity .2s;
    transition: opacity .2s;
}

body.cap_layout_vertical #header .cap-user-tools .icon-link.view-site-link:before {
    content: "";
}

body.cap_layout_vertical #header .cap-user-tools .icon-link.change-password-link:before {
    content: "\f084";
}

body.cap_layout_vertical #header .cap-user-tools .icon-link.documentation-link:before {
    content: "\f02d";
}

body.cap_layout_vertical #header .cap-user-tools .icon-link.logout-link:before {
    content: "\f08b";
}

body.cap_layout_horizontal #cap-nav {
    -ms-flex-preferred-size: 100%;
    flex-basis: 100%;
    margin-top: 1.04167rem;
    background-color: #383d4b;
}

body.cap_layout_horizontal #cap-nav > ul {
    list-style: none;
    margin: 0;
    padding: 0;
    margin: 0 1.875rem;
}

body.cap_layout_horizontal #cap-nav > ul > li {
    position: relative;
    display: block;
    float: left;
}

body.cap_layout_horizontal #cap-nav > ul > li a {
    display: block;
    color: rgba(255, 255, 255, 0.7);
}

body.cap_layout_horizontal #cap-nav > ul > li a:hover {
    color: #fff;
    text-decoration: none;
}

body.cap_layout_horizontal #cap-nav > ul > li > a {
    position: relative;
    padding: 0.69444rem 1.33929rem;
    border-left: 1px solid #252830;
}

body.cap_layout_horizontal #cap-nav > ul > li:last-child > a {
    border-right: 1px solid #252830;
}

body.cap_layout_horizontal #cap-nav > ul > li.active a {
    background-color: #fff;
    color: #373a3c;
    font-weight: bold;
    box-shadow: inset 0 3px 0 #279bee;
}

body.cap_layout_horizontal #cap-nav > ul > li.active a:hover {
    background-image: -webkit-linear-gradient(top, #e9e9e9 0%, #fff 100%);
    background-image: linear-gradient(to bottom, #e9e9e9 0%, #fff 100%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFE9E9E9', endColorstr='#FFFFFFFF', GradientType=0);
}

body.cap_layout_horizontal #cap-nav > ul > li:hover > a {
    background-color: #43495a;
}

body.cap_layout_horizontal #cap-nav > ul > li:hover > ul {
    background-color: #43495a;
    display: block;
}

body.cap_layout_horizontal #cap-nav > ul > li > ul {
    list-style: none;
    margin: 0;
    padding: 0;
    z-index: 1000;
    display: none;
    background-color: #383d4b;
    position: absolute;
    min-width: 180px;
    box-shadow: 0 -1px 2px 0 rgba(0, 0, 0, 0.07);
    font-size: 0.929rem;
}

body.cap_layout_horizontal #cap-nav > ul > li > ul > li > a {
    display: block;
    padding: 0.52083rem 1.33929rem;
    border-bottom: 1px solid #2d313d;
}

body.cap_layout_horizontal #cap-nav > ul > li > ul > li > a:hover {
    background-color: #333845;
}

body.cap_layout_horizontal #cap-nav > ul.cap-nav-right {
    float: right;
}

body.cap_layout_horizontal #cap-nav > ul.cap-nav-right > li > ul {
    right: 0;
}

body.cap_layout_horizontal #cap-sub-nav {
    -ms-flex-preferred-size: 100%;
    flex-basis: 100%;
    display: block;
    background-color: #fff;
    box-shadow: 0 0 3px 0 rgba(0, 0, 0, 0.15);
}

body.cap_layout_horizontal #cap-sub-nav ul {
    list-style: none;
    margin: 0;
    padding: 0;
    margin: 0 2.625rem;
}

body.cap_layout_horizontal #cap-sub-nav ul > li > a {
    color: #0d64a2;
    display: block;
    float: left;
    font-size: 0.929rem;
    padding: 0.80128rem 4px;
    margin: 2px 0.5rem 0;
    margin-bottom: -3px;
}

body.cap_layout_horizontal #cap-sub-nav ul > li:first-child a {
    margin-left: 0;
}

body.cap_layout_horizontal #cap-sub-nav ul > li.active a {
    color: #373a3c;
    font-weight: bold;
    border-bottom: 3px solid #1081d2;
}

body.cap_layout_vertical #cap-nav {
    -ms-flex-preferred-size: 100%;
    flex-basis: 100%;
    background-color: #383d4b;
}

body.cap_layout_vertical #cap-nav > ul {
    list-style: none;
    margin: 0;
    padding: 0;
}

body.cap_layout_vertical #cap-nav > ul > li {
    position: relative;
}

body.cap_layout_vertical #cap-nav > ul > li a:hover, body.cap_layout_vertical #cap-nav > ul > li a:focus {
    text-decoration: none;
}

body.cap_layout_vertical #cap-nav > ul > li.active {
    background-color: #252830;
}

body.cap_layout_vertical #cap-nav > ul > li.active:after {
    font-family: FontAwesome;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    text-rendering: auto;
    color: #5d6478;
    position: absolute;
    right: 1rem;
    top: .85rem;
    font-size: 9px;
}

body.cap_layout_vertical #cap-nav > ul > li.active.has-children:after {
    content: "\f078";
}

body.cap_layout_vertical #cap-nav > ul > li.active:not(.has-children):after {
    content: "\f054";
}

body.cap_layout_vertical #cap-nav > ul > li.active > a, body.cap_layout_vertical #cap-nav > ul > li.active > a:hover {
    color: #fff;
}

body.cap_layout_vertical #cap-nav > ul > li.active > ul {
    display: block;
}

body.cap_layout_vertical #cap-nav > ul > li > a {
    display: block;
    padding: 0.6rem 1.25rem;
    color: rgba(255, 255, 255, 0.7);
}

body.cap_layout_vertical #cap-nav > ul > li > a .fa {
    margin-right: .7rem;
}

body.cap_layout_vertical #cap-nav > ul > li:not(.active) a:hover {
    color: #fff;
}

body.cap_layout_vertical #cap-nav > ul > li:not(.active):hover {
    background-color: #2d313d;
}

body.cap_layout_vertical #cap-nav > ul > li:not(.active):hover > ul {
    box-shadow: 0 0 2px 2px rgba(0, 0, 0, 0.1);
    top: 0;
    left: 70%;
    display: block;
    position: absolute;
    z-index: 1000;
    padding: 0;
}

body.cap_layout_vertical #cap-nav > ul > li:not(.active):hover > ul > li > a {
    white-space: nowrap;
}

body.cap_layout_vertical #cap-nav > ul > li:not(.active):hover > ul > li > a:hover {
    background-color: #464c5b;
}

body.cap_layout_vertical #cap-nav > ul > li > ul {
    list-style: none;
    margin: 0;
    padding: 0;
    background-color: #fff;
    display: none;
    font-size: 13px;
    padding: 0;
}

body.cap_layout_vertical #cap-nav > ul > li > ul > li:not(:last-child) {
    border-bottom: 1px solid #f6f6f6;
}

body.cap_layout_vertical #cap-nav > ul > li > ul > li.active {
    background-color: #fff;
}

body.cap_layout_vertical #cap-nav > ul > li > ul > li.active a {
    box-shadow: inset 4px 0 0 #279bee;
}

body.cap_layout_vertical #cap-nav > ul > li > ul > li.active a, body.cap_layout_vertical #cap-nav > ul > li > ul > li.active a:hover, body.cap_layout_vertical #cap-nav > ul > li > ul > li.active a:focus {
    color: #279bee;
}

body.cap_layout_vertical #cap-nav > ul > li > ul > li a {
    color: #687086;
    display: block;
    padding: 0.4rem 1.25rem;
}

body.cap_layout_vertical #cap-nav > ul > li > ul > li a:hover {
    background-color: #f6f6f6;
    color: #30343e;
}

body.change-form #container br.clear:last-child {
    display: none;
}

#content {
    padding: 1.5rem 1.875rem;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -ms-flex-direction: row;
    flex-direction: row;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-box-pack: start;
    -ms-flex-pack: start;
    justify-content: flex-start;
    -ms-flex-line-pack: end;
    align-content: flex-end;
    -webkit-box-align: start;
    -ms-flex-align: start;
    align-items: flex-start;
}

#content .content-wrap {
    -ms-flex-preferred-size: 100%;
    flex-basis: 100%;
}

body.dashboard #content .content-wrap {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
}

#content .content-wrap > h1 {
    -ms-flex-preferred-size: 100%;
    flex-basis: 100%;
}

#content .content-wrap > h1:first-child, #content .content-wrap > .messagelist + h1 {
    display: none;
}

#content #content-main {
    -webkit-box-flex: 1;
    -ms-flex-positive: 1;
    flex-grow: 1;
}

#content #content-related {
    -webkit-box-flex: 1;
    -ms-flex-positive: 1;
    flex-grow: 1;
}

#content-main > .object-tools {
    list-style: none;
    margin: 0;
    padding: 0;
    position: relative;
    overflow: hidden;
    z-index: 6;
}

#content-main > .object-tools > li {
    display: inline;
}

#content-main > .object-tools > li:not(:first-child) {
    margin-left: .5rem;
}

#content-main > .object-tools > li > a:not([class*="btn-"]) {
    display: inline-block;
    border-radius: 70px;
}

#content-main > .object-tools > li > a:not([class*="btn-"]):before {
    margin-right: 3px;
    display: inline-block;
    font-family: FontAwesome;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    text-rendering: auto;
    content: none;
}

#content-main > .object-tools > li > a:not([class*="btn-"]).addlink {
    display: inline-block;
    border-radius: 70px;
}

#content-main > .object-tools > li > a:not([class*="btn-"]).addlink:before {
    margin-right: 3px;
    display: inline-block;
    font-family: FontAwesome;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    text-rendering: auto;
    content: "";
}

/* Sticky footer styles  */
@media (min-width: 576px) {
    html {
        position: relative;
        min-height: 100%;
    }

    body.cap_layout_horizontal, body.login {
        margin-bottom: 66px;
    }

    body.cap_layout_horizontal #footer, body.login #footer {
        position: absolute;
        left: 0;
        right: 0;
        bottom: 0;
        width: 100%;
        min-height: 66px;
        margin-top: -66px;
    }
}

/* Styles */
.footer {
    min-height: 66px;
    background-color: #e4e4e4;
    color: #55595c;
    font-size: 0.929rem;
}

.footer > .container-fluid {
    padding: 1rem 1.875rem;
}

.footer > .container-fluid > .row {
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
    -ms-flex-line-pack: center;
    align-content: center;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
}

@media (max-width: 575px) {
    .footer > .container-fluid > .row > div:not(:first-child) {
        margin-top: .75rem;
    }
}

.footer .footer-links a {
    white-space: nowrap;
}

.footer .footer-links a:not(:last-child) {
    margin-right: .75rem;
}

/* Override BS4 [hidden] in reboot.scss to show Django debug toolbar */
#djDebug[hidden], #djDebug [hidden][style*="display: block"], #djDebug [hidden][style*="display:block"] {
    display: block !important;
}

.login #container {
    background: #fff;
    border-radius: 4px;
    overflow: hidden;
    width: 28em;
    margin: 0 auto;
}

@media (min-width: 576px) {
    .login #container {
        min-width: 400px;
        margin-top: 15vh;
    }
}

body.login svg * {
    fill: #373a3c;
}

body.login .cap-login-graphic {
    display: block;
    margin: 2rem auto 1.5rem;
}

body.login #content {
    padding: 1.5rem;
}

body.login #content .errornote {
    border-radius: 0;
    border: 0;
}

body.login #header {
    background-color: transparent;
    padding: 0;
}

body.login #header #branding {
    padding: 0;
    -ms-flex-preferred-size: 100%;
    flex-basis: 100%;
    text-align: center;
}

body.login #header #branding #site-name {
    margin: 0 auto;
}

body.login #header #branding #site-name:first-child {
    margin-top: 2.25rem;
}

body.login #header #branding #site-name a, body.login #header #branding #site-name a:hover {
    color: #373a3c;
}

body.login #header #branding #site-name a .header-label {
    font-weight: normal;
    text-align: center;
    margin-top: .3rem;
}

body.login .errorlist {
    list-style: none;
    margin: 0;
    padding: 0;
    margin: -0.5rem 0.75rem 1.5rem;
    color: #a94442;
}

body.login .form-row input:not([type='hidden']) {
    padding-left: 0.75rem;
    padding-right: 0.75rem;
    margin-bottom: 0.85714rem;
}

body.login .form-row input:not([type='hidden']):not(:focus) {
    background-color: #f1f1f1;
    border-color: #f1f1f1;
}

body.login .form-row.has-danger input:not([type='hidden']) {
    border-color: #a94442;
}

body.login .submit-row label {
    display: none;
}

body.login .submit-row input[type='submit'] {
    display: block;
    width: 100%;
    margin: 1.5rem 0 0 0;
    border: none;
    text-align: center;
    padding: 1rem 1.5rem;
}

body.dashboard .module {
    margin: 0 1.875rem 0.9375rem 0;
}

body.dashboard .module table {
    width: 100%;
    border-spacing: 1px;
    border-collapse: separate;
}

body.dashboard .module table caption {
    caption-side: inherit;
    font-weight: 500;
    font-size: 1.286rem;
    padding: 0;
}

body.dashboard .module table tr td, body.dashboard .module table tr th {
    font-size: 0.929rem;
    padding: 0.4rem 0.8rem;
    background-color: #f6f6f6;
}

body.dashboard .module table tr th {
    width: 200px;
    background-color: #fff;
    font-weight: normal;
}

body.dashboard #recent-actions-module h2 {
    display: none;
}

body.dashboard #recent-actions-module h3 {
    font-size: 1.286rem;
}

body.dashboard #recent-actions-module ul.actionlist {
    list-style: none;
    margin: 0;
    padding: 0;
}

body.dashboard #recent-actions-module ul.actionlist > li {
    background-color: #f6f6f6;
    margin-bottom: 1px;
    padding: 0.4rem 0.8rem;
    font-size: 0.929rem;
    padding-left: 2.8rem;
    overflow: auto;
    position: relative;
}

body.dashboard #recent-actions-module ul.actionlist > li span {
    display: block;
    float: right;
    color: #9ca3a9;
    font-size: 0.857rem;
}

body.dashboard #recent-actions-module ul.actionlist > li br {
    display: none;
}

body.dashboard #recent-actions-module ul.actionlist > li:before {
    min-width: 2rem;
    text-align: center;
    background-color: #fff;
    border-right: 1px solid #f1f1f1;
    position: absolute;
    padding-top: .4rem;
    top: 0;
    left: 0;
    height: 100%;
}

body.dashboard .addlink:before, body.dashboard .changelink:before, body.dashboard .deletelink:before {
    font-family: FontAwesome;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    text-rendering: auto;
    display: block;
    float: left;
    min-width: 1.2rem;
}

body.dashboard .addlink:before {
    content: "";
    color: #4ACB68;
}

body.dashboard .changelink:before {
    content: "";
    color: #F3C544;
}

body.dashboard .deletelink:before {
    content: "";
    color: #E04F3C;
}

#changelist {
    display: block;
    position: relative;
}

#changelist.filtered {
    clear: both;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
}

#changelist.filtered #toolbar {
    -webkit-box-flex: 10;
    -ms-flex: 10;
    flex: 10;
    -ms-flex-preferred-size: 100%;
    flex-basis: 100%;
}

#changelist.filtered #changelist-filter:not(:empty) {
    -ms-flex-preferred-size: 15rem;
    flex-basis: 15rem;
    -webkit-box-ordinal-group: 4;
    -ms-flex-order: 3;
    order: 3;
}

#changelist.filtered #changelist-filter:empty {
    display: none;
}

#changelist #changelist-filter:not(:empty) + #changelist-form {
    margin-right: 2rem;
}

#changelist #toolbar {
    margin-bottom: 1.5rem;
}

#changelist #toolbar #changelist-search label {
    display: none;
}

#changelist #toolbar #changelist-search input[type='submit'] {
    display: inline-block;
    margin-right: 1rem;
}

#changelist #toolbar #changelist-search input[type='submit']:before {
    margin-right: 3px;
    display: inline-block;
    font-family: FontAwesome;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    text-rendering: auto;
    content: "";
}

#changelist #toolbar #changelist-search input[type='text'] {
    display: inline-block;
    width: auto;
    vertical-align: middle;
}

#changelist #toolbar #changelist-search input[type='text']:before {
    font-family: FontAwesome;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    text-rendering: auto;
    content: "";
}

#changelist #toolbar #changelist-search .small {
    font-size: 0.929rem;
}

#changelist #changelist-filter {
    float: right;
    width: 15rem;
    top: 0;
    right: 0;
    font-size: 0.929rem;
}

#changelist #changelist-filter h2 {
    margin-bottom: 0.9375rem;
    display: none;
}

#changelist #changelist-filter h3 {
    background-color: #5d6478;
    color: #fff;
    font-size: 0.929rem;
    font-weight: normal;
    padding: 0.46875rem 0.625rem;
    margin: 0;
}

#changelist #changelist-filter ul {
    background-color: #fff;
    list-style: none;
    margin: 0;
    padding: 0;
    padding: 0.625rem 0;
    margin-bottom: 1.25rem;
}

#changelist #changelist-filter ul li {
    border-left: 3px solid transparent;
    margin-left: -3px;
}

#changelist #changelist-filter ul li.selected:not(:first-child) {
    border-left-color: #1081d2;
}

#changelist #changelist-filter ul li.selected a {
    font-weight: bold;
    color: #373a3c;
}

#changelist #changelist-filter ul li a {
    padding: .1rem;
    padding-left: 1.25rem;
    display: block;
}

#changelist #changelist-form {
    -webkit-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
}

#changelist #changelist-form .actions {
    margin: -.5rem 0 1rem 0;
    font-size: 0.929rem;
    -webkit-box-align: baseline;
    -ms-flex-align: baseline;
    align-items: baseline;
}

#changelist #changelist-form .actions[style*='block'] {
    display: -webkit-box !important;
    display: -ms-flexbox !important;
    display: flex !important;
}

#changelist #changelist-form .actions button {
    display: inline-block;
    margin-right: 1rem;
}

#changelist #changelist-form .actions select {
    display: inline;
    width: auto;
    height: 2.05rem;
    margin-right: .25rem;
}

#changelist #changelist-form .actions span.all, #changelist #changelist-form .actions span.action-counter, #changelist #changelist-form .actions span.clear, #changelist #changelist-form .actions span.question {
    font-size: 13px;
    margin: 0 0.5em;
    display: none;
}

.cap_toggle_changelist_top_actions #changelist #changelist-form .actions {
    display: none;
}

#changelist #changelist-form .results + .actions {
    margin: 1rem 0 0;
}

.cap_toggle_changelist_top_actions #changelist #changelist-form .results + .actions {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
}

#changelist #changelist-form .paginator {
    margin-top: 1rem;
    font-size: 0.929rem;
}

#changelist #changelist-form .paginator a:not(.showall), #changelist #changelist-form .paginator span {
    font-size: 1rem;
    display: inline-block;
    padding: .5rem;
    background-color: #fff;
    line-height: normal;
    min-width: 2.3rem;
    text-align: center;
    margin-left: -.1rem;
}

#changelist #changelist-form .paginator a:not(.showall).end, #changelist #changelist-form .paginator span.end {
    margin-right: 1rem;
}

#changelist #changelist-form .paginator a:hover {
    background-color: #f9f9f9;
    text-decoration: none;
}

#changelist #changelist-form .paginator span.this-page {
    background-color: #5d6478;
    color: #fff;
}

#changelist #changelist-form .paginator input[type='submit'] {
    float: right;
    margin-top: -.75rem;
}

#changelist .xfull {
    -ms-flex-preferred-size: 100%;
    flex-basis: 100%;
}

#changelist .toplinks {
    list-style: none;
    margin: 0;
    padding: 0;
    margin-right: 17rem;
}

#changelist .toplinks li {
    display: inline-block;
}

#changelist .toplinks li a {
    margin-right: .28rem;
    display: inline-block;
}

.object-tools + #changelist.filtered #toolbar {
    margin-top: -3.5rem;
}

body.change-list #content-main .object-tools {
    float: right;
    margin-bottom: 1.5rem;
    min-height: 2rem;
}

body.change-list .hiddenfields {
    display: none;
}

body.change-form #content-main > .object-tools {
    float: right;
    margin-top: -2.85rem;
    margin-bottom: 20px;
    overflow: hidden;
}

body.change-form #content-main > .object-tools li {
    display: inline-block;
}

body.change-form #content-main > .object-tools li.list-item {
    display: none;
}

body.change-form #content-main > .object-tools + form {
    width: 100%;
    clear: both;
}

body.change-form .edit-row {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
}

body.change-form .edit-row > div {
    margin: 0 0.9375rem;
}

body.change-form:not(.cap_form_submit_on_right) .edit-row > div.col-left, body.change-form:not(.cap_form_submit_on_right) .edit-row > div.col-right {
    -webkit-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
    -ms-flex-preferred-size: 100%;
    flex-basis: 100%;
}

body.change-form:not(.cap_form_submit_on_right) .edit-row > div.col-right .object-tools {
    display: none;
}

body.change-form.cap_form_submit_on_right #content-main > .object-tools {
    margin-top: 0;
}

body.change-form.cap_form_submit_on_right #content-main > .object-tools li.heading {
    display: none;
}

@media (min-width: 992px) {
    body.change-form.cap_form_submit_on_right #content-main > .object-tools {
        display: none;
    }
}

body.change-form.cap_form_submit_on_right .edit-row {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
}

body.change-form.cap_form_submit_on_right .edit-row > div {
    margin: 0 0.9375rem;
}

body.change-form.cap_form_submit_on_right .edit-row > div.col-left {
    -webkit-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
}

body.change-form.cap_form_submit_on_right .edit-row > div.col-right {
    width: 22%;
}

@media (min-width: 992px) and (max-width: 1199px) {
    body.change-form.cap_form_submit_on_right .edit-row > div.col-right {
        width: 25%;
    }
}

@media (max-width: 991px) {
    body.change-form.cap_form_submit_on_right .edit-row > div.col-right {
        width: auto;
        -webkit-box-flex: 1;
        -ms-flex: 1;
        flex: 1;
        -ms-flex-preferred-size: 100%;
        flex-basis: 100%;
    }
}

table#change-history thead > tr th {
    padding: 0.7rem 0.8rem !important;
}

/* Refactor */

.col-multi-fields .multi-field {
    flex-basis: 25%;
    padding-right: 3rem;
}

fieldset input[type=number],
fieldset input[type=date],
fieldset input.vIntegerField,
fieldset input.vIntegerField,
fieldset input.vDateField,
fieldset input.vTimeField,
fieldset input.vForeignKeyRawIdAdminField {
    width: 100%;
}

.cap-form .form-group label {
    font-weight: 500;
}

body.cap_layout_vertical #cap-nav > ul > li > a {
    color: #fff;
}

body.cap_layout_vertical #cap-nav > ul > li > ul > li a {
    color: #333;
}

.multi-field input[type=checkbox] {
    float: left;
    width: 25px;
    height: 25px;
}

#container #content {
    background-color: #f5f5f5;
}

.change-form .submit-row {
    position: fixed;
    bottom: 0;
    right: 0;
    z-index: 100;
    background: #e4ebf1;
    border: 2px solid #544848;
    border-bottom: none;
    padding: 10px 10px 5px 10px;
    border-radius: 10px 0 0 0;
}

.file-upload input[type=file] {
    max-width: 300px;
}

tr.form-row {
    display: table-row;
}

.form-row input[type=checkbox].form-control {
    width: calc(1.5em + .75rem + 2px);
}
